---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2000-12-23;388
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20001229&codiceRedaz=000G0441&dataVigenza=20251104
dataGU: 20001229
codiceRedaz: 000G0441
dataVigenza: 20251104
---

# Disposizioni per la formazione del bilancio annuale e pluriennale
dello Stato (legge finanziaria 2001).

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

PROMULGA la seguente legge:

## DISPOSIZIONI DI CARATTERE FINANZIARIO

### Art. 1. - (Risultati differenziali)

1. Per l'anno 2001, il livello massimo del saldo netto da finanziare resta determinato in termini di competenza in lire 74.000 miliardi, al netto di lire 34.349 miliardi per regolazioni debitorie, nonche' degli importi posti a carico del bilancio dello Stato ai sensi dell'articolo 68, comma 8. Tenuto conto delle operazioni di rimborso di prestiti, il livello massimo del ricorso al mercato finanziario di cui all'articolo 11 della legge 5 agosto 1978, n. 468, come modificato dall'articolo 2, commi 13, 14, 15, 16 e 17, della legge 25 giugno 1999, n. 208, ivi compreso l'indebitamento all'estero per un importo complessivo non superiore a lire 4.000 miliardi relativo ad interventi non considerati nel bilancio di previsione per il 2001, resta fissato, in termini di competenza, in lire 455.200 miliardi per l'anno finanziario 2001.

2. Per gli anni 2002 e 2003 il livello massimo del saldo netto da finanziare del bilancio pluriennale a legislazione vigente, tenuto conto degli effetti della presente legge, e' determinato, rispettivamente, in lire 73.500 miliardi ed in lire 55.000 miliardi, al netto di lire 11.429 miliardi per l'anno 2002 e lire 6.029 miliardi per l'anno 2003, per le regolazioni debitorie; il livello massimo del ricorso al mercato e' determinato, rispettivamente, in lire 339.500 miliardi ed in lire 328.000 miliardi. Per il bilancio programmatico degli anni 2002 e 2003, il livello massimo del saldo netto da finanziere e' determinato, rispettivamente, in lire 62.600 miliardi ed in lire 49.200 miliardi ed il livello massimo del ricorso al mercato e' determinato, rispettivamente, in lire 328.000 miliardi ed in lire 323.000 miliardi.

3. I livelli del ricorso al mercato di cui ai commi 1 e 2 si intendono al netto delle operazioni effettuate al fine di rimborsare prima della scadenza o ristrutturare passivita' preesistenti con ammortamento a carico dello Stato.

4. Le eventuali maggiori entrate rispetto alle previsioni iniziali riscontrate nel 2001 a seguito dell'approvazione degli atti di cui all'articolo 17, commi primo e secondo, della legge 5 agosto 1978, n. 468, sono destinate prioritariamente a garantire il conseguimento degli obiettivi pluriennali relativi all'indebitamento netto delle pubbliche amministrazioni e ai saldi di finanza pubblica definiti dal Documento di programmazione economico-finanziaria 2001-2004, come approvato dalla relativa risoluzione parlamentare, nonche' dalla presente legge. Le eventuali maggiori entrate eccedenti rispetto a tali obiettivi e non riconducibili alla maggiore crescita economica rispetto a quella prevista nel Documento di programmazione economico-finanziaria sono destinate alla riduzione della pressione fiscale, salvo che si renda necessario finanziare interventi urgenti e imprevisti connessi a calamita' naturali, pericoli per la sicurezza del Paese o situazioni di emergenza economico-finanziaria.

## DISPOSIZIONI PER LA RIDUZIONE DEL CARICO FISCALE DELLE FAMIGLIE

### Art. 2. - (Disposizioni in materia di imposte sui redditi relative alla riduzione delle aliquote e alla disciplina delle detrazioni e delle deduzioni)

1. Al testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e successive modificazioni, sono apportate le seguenti modificazioni:

- a) all'articolo 10, comma 3-bis, primo periodo, in materia di deduzione per l'abitazione principale, le parole: "fino a lire 1.800.000" sono sostituite dalle seguenti: "fino all'ammontare della rendita catastale dell'unita' immobiliare stessa e delle relative pertinenze,"; nel medesimo comma il secondo periodo e' soppresso;
- b) all'articolo 10, comma 3-bis, il quinto periodo e' sostituito dal seguente: "Non si tiene conto della variazione della dimora abituale se dipendente da ricovero permanente in istituti di ricovero o sanitari, a condizione che l'unita' immobiliare non risulti locata";
- c) all'articolo 11, comma 1, concernente le aliquote e gli scaglioni dell'imposta sul reddito delle persone fisiche: 1) la lettera a), relativa al primo scaglione di reddito, e' sostituita dalla seguente: "a) fino a lire 20.000.000 ........ 18 per cento;"; 2) la lettera b), relativa al secondo scaglione di reddito, e' sostituita dalla seguente: "b) oltre lire 20.000.000 e fino a lire 30.000.000 .... 24 per cento, per l'anno 2001, 23 per cento, per l'anno 2002, e 22 per cento, a decorrere dall'anno 2003;"; 3) nella lettera c), relativa al terzo scaglione di reddito, le parole: "33,5 per cento" sono sostituite dalle seguenti: "32 per cento a decorrere dall'anno 2001"; 4) nella lettera d), relativa al quarto scaglione di reddito, le parole: "39,5 per cento" sono sostituite dalle seguenti: "39 per cento, per l'anno 2001, 38,5 per cento, per l'anno 2002, e 38 per cento, a decorrere dall'anno 2003"; 5) nella lettera e), relativa al quinto scaglione di reddito, le parole: "45,5 per cento" sono sostituite dalle seguenti: "45 per cento, per l'anno 2001, 44,5 per cento, per l'anno 2002, e 44 per cento, a decorrere dall'anno 2003"; ((13))
- d) all'articolo 12, comma 1, lettera b), in materia di detrazioni per carichi di famiglia, sono aggiunti, in fine, i seguenti periodi: "L'importo di lire 516.000 per l'anno 2001 e di lire 552.000 a decorrere dal 1° gennaio 2002 e' aumentato, rispettivamente, a lire 552.000 per l'anno 2001 e a lire 588.000 a decorrere dal 1° gennaio 2002, a condizione che il reddito complessivo non superi lire 100.000.000. I predetti importi sono aumentati a lire 616.000 per l'anno 2001 e a lire 652.000 a decorrere dal 1° gennaio 2002, quando la detrazione sia relativa ai figli successivi al primo, sempre che il reddito complessivo non superi lire 100.000.000";
- e) all'articolo 13, relativo alle altre detrazioni: 1) il comma 1 e' sostituito dal seguente: "1. Se alla formazione del reddito complessivo concorrono uno o piu' redditi di lavoro dipendente spetta una detrazione dall'imposta lorda, rapportata al periodo di lavoro o di pensione nell'anno, anche a fronte delle spese inerenti alla produzione del reddito, secondo i seguenti importi: a) lire 2.220.000 se l'ammontare complessivo dei redditi di lavoro dipendente non supera lire 12.000.000; b) lire 2.100.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 12.000.000 ma non a lire 12.300.000; c) lire 2.000.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 12.300.000 ma non a lire 12.600.000; d) lire 1.900.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 12.600.000 ma non a lire 15.000.000; e) lire 1.750.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 15.000.000 ma non a lire 15.300.000; f) lire 1.600.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 15.300.000 ma non a lire 15.600.000; g) lire 1.450.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 15.600.000 ma non a lire 15.900.000; h) lire 1.330.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 15.900.000 ma non a lire 16.000.000; i) lire 1.260.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 16.000.000 ma non a lire 17.000.000; l) lire 1.190.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 17.000.000 ma non a lire 18.000.000; m) lire 1.120.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 18.000.000 ma non a lire 19.000.000; n) lire 1.050.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 19.000.000 ma non a lire 30.000.000; o) lire 950.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 30.000.000 ma non a lire 40.000.000; p) lire 850.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 40.000.000 ma non a lire 50.000.000; q) lire 750.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 50.000.000 ma non a lire 60.000.000; r) lire 650.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 60.000.000 ma non a lire 60.300.000; s) lire 550.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 60.300.000 ma non a lire 70.000.000; t) lire 450.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 70.000.000 ma non a lire 80.000.000; u) lire 350.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 80.000.000 ma non a lire 90.000.000; v) lire 250.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 90.000.000 ma non a lire 90.400.000; z) lire 150.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 90.400.000 ma non a lire 100.000.000; aa) lire 100.000 se l'ammontare complessivo dei redditi di lavoro dipendente e' superiore a lire 100.000.000"; 2) nel comma 2, all'alinea, dopo le parole: "redditi di pensione" sono inserite le seguenti: "redditi di terreni per un importo non superiore a lire 360.000"; 3) nel comma 2-ter, le parole: "il reddito derivante dagli assegni periodici percepiti in conseguenza di separazione legale ed effettiva, di scioglimento o annullamento del matrimonio o di cessazione dei suoi effetti civili" sono soppresse e le parole: "il reddito derivante da rapporti di lavoro dipendente di durata inferiore all'anno" sono sostituite dalle seguenti: "il reddito derivante da rapporti di lavoro dipendente con contratti a tempo indeterminato di durata inferiore all'anno"; 4) dopo il comma 2-ter, e' inserito il seguente: "2-quater. Se alla formazione del reddito complessivo concorrono soltanto il reddito, non superiore alla deduzione prevista dall'articolo 10, comma 3-bis, dell'unita' immobiliare adibita ad abitazione principale e delle relative pertinenze, il reddito derivante dai rapporti di lavoro dipendente con contratto a tempo determinato di durata inferiore all'anno e il reddito derivante dagli assegni periodici percepiti in conseguenza di separazione legale ed effettiva, di scioglimento o annullamento del matrimonio o di cessazione dei suoi effetti civili, spetta una detrazione secondo i seguenti importi: a) lire 400.000, se l'ammontare del reddito complessivo non supera lire 9.100.000; b) lire 300.000, se l'ammontare del reddito complessivo supera lire 9.100.000 ma non lire 10.000.000; c) lire 200.000 se l'ammontare del reddito complessivo supera lire 10.000.000 ma non lire 11.000.000; d) lire 100.000 se l'ammontare del reddito complessivo supera lire 11.000.000 ma non lire 12.000.000"; 5) il comma 3 e' sostituito dal seguente: "3. Se alla formazione del reddito complessivo concorrono uno o piu' redditi di lavoro autonomo di cui al comma 1 dell'articolo 49 o d'impresa di cui all'articolo 79, spetta una detrazione dall'imposta lorda, non cumulabile con quella prevista dal comma 1, pari a: a) lire 1.110.000 se l'ammontare complessivo dei redditi di lavoro autonomo e di impresa non supera lire 9.100.000; b) lire 1.000.000 se l'ammontare complessivo dei redditi di lavoro autonomo e di impresa e' superiore a lire 9.100.000 ma non a lire 9.300.000; c) lire 900.000 se l'ammontare complessivo dei redditi di lavoro autonomo e di impresa e' superiore a lire 9.300.000 ma non a lire 9.600.000; d) lire 800.000 se l'ammontare complessivo, dei redditi di lavoro autonomo e di impresa e' superiore a lire 9.600.000 ma non a lire 9.900.000; e) lire 700.000 se l'ammontare complessivo dei redditi di lavoro autonomo e di impresa e' superiore a lire 9.900.000 ma non a lire 15.000.000; f) lire 600.000 se l'ammontare complessivo dei redditi di lavoro autonomo e di impresa e' superiore a lire 15.000.000 ma non a lire 15.300.000; g) lire 480.000 se l'ammontare complessivo dei redditi di lavoro autonomo e di impresa e' superiore a lire 15.300.000 ma non a lire 16.000.000; h) lire 410.000 se l'ammontare complessivo dei redditi di lavoro autonomo e di impresa e' superiore a lire 16.000.000 ma non a lire 17.000.000; i) lire 340.000 se l'ammontare complessivo dei redditi di lavoro autonomo e di impresa e' superiore a lire 17.000.000 ma non a lire 18.000.000; l) lire 270.000 se l'ammontare complessivo dei redditi di lavoro autonomo e di impresa e' superiore a lire 18.000.000 ma non a lire 19.000.000; m) lire 200.000 se l'ammontare complessivo dei redditi di lavoro autonomo e di impresa e' superiore a lire 19.000.000 ma non a lire 30.000.000; n) lire 100.000 se l'ammontare complessivo dei redditi di lavoro autonomo e di impresa e' superiore a lire 30.000.000 ma non a lire 60.000.000";
- f) all'articolo 13-bis, comma 1, lettera b), in materia di detrazioni per oneri: 1) al primo periodo, le parole: "sei mesi" sono sostituite dalle seguenti: "un anno"; 2) al secondo periodo, le parole: "nei sei mesi antecedenti o successivi" sono sostituite dalle seguenti: "nell'anno precedente o successivo"; 3) dopo il terzo periodo e' inserito il seguente: "In caso di acquisto di unita' immobiliare locata, la detrazione spetta a condizione che entro tre mesi dall'acquisto sia stato notificato al locatario l'atto di intimazione di licenza o di sfratto per finita locazione e che entro un anno dal rilascio l'unita' immobiliare sia adibita ad abitazione principale"; 4) al quarto periodo, le parole: "il contribuente dimora abitualmente" sono sostituite dalle seguenti: "il contribuente o i suoi familiari dimorano abitualmente"; 5) dopo il quinto periodo sono inseriti i seguenti: "Non si tiene conto, altresi', delle variazioni dipendenti da ricoveri permanenti in istituti di ricovero o sanitari, a condizione che l'unita' immobiliare non risulti locata. Nel caso l'immobile acquistato sia oggetto di lavori di ristrutturazione edilizia, comprovata dalla relativa concessione edilizia o atto equivalente, la detrazione spetta a decorrere dalla data in cui l'unita' immobiliare e' adibita a dimora abituale, e comunque entro due anni dall'acquisto"; 6) e' aggiunto, in fine, il seguente periodo: "Se il mutuo e' intestato ad entrambi i coniugi, ciascuno di essi puo' fruire della detrazione unicamente per la propria quota di interessi; in caso di coniuge fiscalmente a carico dell'altro la detrazione spetta a quest'ultimo per entrambe le quote";
- g) all'articolo 13-bis, comma 1, lettera c), in materia di detrazioni per spese sanitarie, dopo il nono periodo e' inserito il seguente: "La medesima ripartizione della detrazione in quattro quote annuali di pari importo e' consentita, con riferimento alle altre spese di cui alla presente lettera, nel caso in cui queste ultime eccedano, complessivamente, il limite di lire 30 milioni annue";
- h) all'articolo 13-ter, in materia di detrazioni per canoni di locazione: 1) al comma 1, lettera a), le parole: "lire 640.000" sono sostituite dalle seguenti: "lire 960.000"; 2) al comma 1, lettera b), le parole: "lire 320.000" sono sostituite dalle seguenti: "lire 480.000"; 3) dopo il comma 1, e' aggiunto il seguente: "1-bis. A favore dei lavoratori dipendenti che hanno trasferito o trasferiscono la propria residenza nel comune di lavoro o in uno di quelli limitrofi nei tre anni antecedenti quello di richiesta della detrazione, e siano titolari di qualunque tipo di contratto di locazione di unita' immobiliari adibite ad abitazione principale degli stessi e situate nel nuovo comune di residenza, a non meno di 100 chilometri di distanza dal precedente e comunque al di fuori della propria regione, spetta una detrazione, per i primi tre anni, rapportata al periodo dell'anno durante il quale sussiste tale destinazione, nei seguenti importi: a) lire 1.920.000, se il reddito complessivo non supera lire 30 milioni; b) lire 960.000, se il reddito complessivo supera lire 30 milioni ma non lire 60 milioni";
- i) all'articolo 48-bis, comma 1, lettera a-bis), concernente la determinazione del reddito del personale dipendente del Servizio sanitario nazionale per l'attivita' libero-professionale intramuraria esercitata presso studi professionali privati, le parole: "nella misura del 90 per cento" sono sostituite dalle seguenti: "nella misura del 75 per cento".

2. All'articolo 1 della legge 27 dicembre 1997, n. 449, concernente detrazioni per interventi di ristrutturazione del patrimonio edilizio privato, sono apportate le seguenti modificazioni:

- a) al comma 1, terzo periodo, dopo le parole: "alla eliminazione delle barriere architettoniche," sono inserite le seguenti: "aventi ad oggetto ascensori e montacarichi, alla realizzazione di ogni strumento che, attraverso la comunicazione, la robotica e ogni altro mezzo di tecnologia piu' avanzata, sia adatto a favorire la mobilita' interna ed esterna all'abitazione per le persone portatrici di handicap in situazioni di gravita', ai sensi dell'articolo 3, comma 3, della legge 5 febbraio 1992, n. 104, all'adozione di misure finalizzate a prevenire il rischio del compimento di atti illeciti da parte di terzi," e dopo le parole: "sulle parti strutturali" sono aggiunte le seguenti: ",e all'esecuzione di opere volte ad evitare gli infortuni domestici";
- b) al comma 6, le parole: "nel periodo d'imposta in corso alla data del 1° gennaio 2000" sono sostituite dalle seguenti: "nei periodi d'imposta in corso alla data del 1° gennaio degli anni 2000 e 2001".

3. All'articolo 13 della legge 15 dicembre 1998, n. 441, concernente norme per la diffusione e la valorizzazione dell'imprenditoria giovanile in agricoltura, le parole: "nel periodo d'imposta, 2000" sono sostituite dalle seguenti: "nei periodi d'imposta 2000 e 2001 ".

4. Ai fini delle detrazioni di cui all'articolo 1 della legge 27 dicembre 1997, n. 449, per i lavori iniziati entro il 30 giugno 2000, si considerano validamente presentate le comunicazioni di cui al decreto del Ministro delle finanze 18 febbraio 1998, n. 41, trasmesse entro novanta giorni dall'inizio dei lavori.

5. Ai fini della determinazione del reddito delle cooperative edilizie a proprieta' indivisa si deduce un importo pari alla rendita catastale di ciascuna unita' immobiliare adibita ad abitazione principale dei soci assegnatari e delle relative pertinenze.

6. All'articolo 17 del decreto legislativo 30 dicembre 1992, n. 504, e successive modificazioni, il comma 3 e' abrogato.

7. All'articolo 6 della legge 23 dicembre 1999, n. 488, i commi 9, 10 e 11 sono abrogati.

8. Le disposizioni del comma 1, lettere a), e), numero 2), e h), numeri 1) e 2), si applicano a decorrere dal periodo d'imposta 2000; quelle di cui al medesimo comma, lettere b), c), d), e), numeri 1), 3), 4) e 5), f), g) e h), numero 3), e i), si applicano a decorrere dal periodo d'imposta 2001. Le disposizioni dei commi 5 e 6 si applicano a decorrere dal periodo d'imposta successivo a quello in corso alla data del 31 dicembre 1999.

9. Le modifiche apportate dalle disposizioni di cui al presente titolo in materia di imposta sul reddito delle persone fisiche valgono ai fini della restituzione del drenaggio fiscale disciplinata dall'articolo 3, comma 2, del decreto-legge 2 marzo 1989, n. 69, convertito, con modificazioni, dalla legge 27 aprile 1989, n. 154, e dall'articolo 9, comma 1, del decreto-legge 19 settembre 1992, n. 384, convertito, con modificazioni, dalla legge 14 novembre 1992, n. 438.

10. In deroga all'articolo 17, comma 1, del decreto legislativo 9 luglio 1997, n. 241, e successive modificazioni, sono legittimi gli atti compiuti dai sostituti di imposta che, nell'ipotesi in cui abbiano impiegato somme proprie per corrispondere l'acconto di cui all'articolo 1 del decreto-legge 30 settembre 2000, n. 268, convertito, con modificazioni, dalla legge 23 novembre 2000, n. 354, abbiano utilizzato il relativo credito in compensazione con i versamenti da effettuare nel mese di dicembre 2000.

------------- AGGIORNAMENTO (13) La L. 28 dicembre 2001, n. 448 ha disposto (con l'art. 2, comma 6) che "Il disposto dell'articolo 2, comma 1, lettera c), della legge 23 dicembre 2000, n. 388, e' sospeso per l'anno 2002".

### Art. 3. - (Disposizioni fiscali in materia di pensioni, assegni di fonte estera, nonche' di redditi da lavoro dipendente prestato all'estero)

1. Per i periodi d'imposta precedenti a quello in corso al 31 dicembre 2000, i redditi derivanti da pensioni di ogni genere ed assegni ad esse equiparati di fonte estera, imponibili in Italia per effetto di disciplina convenzionale, possono essere dichiarati entro il 30 giugno 2001 con apposita istanza. A tali redditi si applica l'aliquota marginale del contribuente ovvero quella del 25 per cento in caso di omessa presentazione della dichiarazione, per l'anno cui si riferiscono i redditi. Non si fa luogo all'applicazione di soprattasse, pene pecuniarie ed interessi a condizione che sia versata una somma pari al 25 per cento delle imposte cosi' calcolate. Le somme dovute ai sensi del presente comma devono essere versate in quattro rate di pari importo da corrispondere entro le date del 15 dicembre 2001, del 15 giugno 2002, del 15 dicembre 2002 e del 15 giugno 2003 senza applicazione di interessi. Le disposizioni del presente comma si applicano altresi' alle controversie pendenti originate da avvisi di accertamento riguardanti i redditi di cui al presente comma nonche' a coloro i quali si siano avvalsi della facolta' di cui all'articolo 9-bis del decreto-legge 28 marzo 1997, n. 79, convertito, con modificazioni, dalla legge 28 maggio 1997, n. 140, anche entro i termini stabiliti dall'articolo 38 della legge 8 maggio 1998, n. 146, e dall'articolo 45, comma 14, della legge 17 maggio 1999, n. 144.

2. ((Per gli anni 2001 e 2002)), i redditi derivanti da lavoro dipendente prestato, in via continuativa e come oggetto esclusivo del rapporto, all'estero in zone di frontiera ed in altri Paesi limitrofi da soggetti residenti nel territorio dello Stato sono esclusi dalla base imponibile; i percettori dei suddetti redditi non possono in alcun caso essere considerati fiscalmente a carico e, se richiedono prestazioni sociali agevolate alla pubblica amministrazione, sono comunque tenuti a dichiararli all'ufficio erogatore della prestazione, ai fini della valutazione della propria situazione economica.

## DISPOSIZIONI FISCALI PER FAVORIRE LO SVILUPPO EQUILIBRATO

### Art. 4. - (Riduzione della aliquota IRPEG)

1. Al testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, sono apportate le seguenti modificazioni:

- a) all'articolo 14, comma 1, in materia di credito d'imposta per gli utili distribuiti da societa' ed enti, le parole: "pari al 58,73 per cento" sono sostituite dalle seguenti: "pari al 56,25 per cento, per le distribuzioni deliberate a decorrere dal periodo d'imposta successivo a quello in corso al 1° gennaio 2001, e al 53,85 per cento, per le distribuzioni deliberate a decorrere dal periodo d'imposta successivo a quello in corso al 1° gennaio 2003,";
- b) all'articolo 91, in materia di aliquota dell'imposta sul reddito delle persone giuridiche, le parole: "con l'aliquota del 37 per cento" sono sostituite dalle seguenti: "con l'aliquota del 36 per cento, a decorrere dal periodo d'imposta in corso al 1° gennaio 2001, e del 35 per cento, a decorrere dal periodo d'imposta in corso al 1° gennaio 2003",
- c) all'articolo 105, comma 4, in materia di credito d'imposta ai soci o partecipanti sugli utili distribuiti, le parole: "nella misura del 58,73 per cento" sono sostituite dalle seguenti: "nella misura del 56,25 per cento, per i proventi conseguiti a decorrere dal periodo d'imposta in corso al 1° gennaio 2001, e del 53,85 per cento, per i proventi conseguiti a decorrere dal periodo d'imposta in corso al 1° gennaio 2003,";
- d) all'articolo 105, comma 5, le parole: di un importo pari al 58,73 per cento" sono sostituite dalle seguenti: "di un importo pari al 56,25 per cento, per le distribuzioni deliberate a decorrere dal periodo d'imposta successivo a quello in corso al 1° gennaio 2001, e al 53,85 per cento, per le distribuzioni deliberate a decorrere dal periodo d'imposta successivo a quello in corso al 1° gennaio 2003,". 2. All'articolo 4, comma 2, del decreto legislativo 18 dicembre 1997, n. 467, in materia di imposta sostitutiva della maggiorazione di conguaglio e di credito di imposta sugli utili societari, l'ultimo periodo e' sostituito dal seguente: "A tale fine si considera come provento non assoggettato a tassazione la quota del 47,22 per cento di dette plusvalenze e di detto reddito conseguiti a decorrere dal periodo d'imposta in corso al 1° gennaio 2001, e del 45,72 per cento delle plusvalenze e dei redditi medesimi conseguiti a decorrere dal periodo d'imposta in corso al 1° gennaio 2003; per le societa' quotate, tali misure sono pari rispettivamente, all'80,56 e all'80 per cento". 3. Per il reddito del periodo d'imposta in corso alla data del 1° gennaio 2001, la misura del 48,65 per cento, prevista dall'articolo 2, comma 10, della legge 13 maggio 1999, n. 133, in materia di reddito d'impresa, e' ridotta al 47,22 per cento. 4. La misura dell'acconto dell'imposta sul reddito delle persone giuridiche, per il periodo d'imposta in corso al 31 dicembre;.2001, e' ridotta dal 98 per cento al 93,5 per cento; per il periodo d'imposta in corso al 31 dicembre 2002, e' aumentata dal 98 per cento al 98,5 per cento; a decorrere dal periodo d'imposta in corso al 31 dicembre 2003, e' aumentata dal 98 per cento al 99 per cento.

### Art. 5. - (Emersione di basi imponibili e riduzione del carico tributario sui redditi d'impresa)

1. Le maggiori entrate che risulteranno dall'aumento delle basi imponibili dei tributi erariali e dei contributi sociali per effetto dell'applicazione delle disposizioni per favorire l'emersione, di cui all'articolo 116 della presente legge, sono destinate ad un fondo istituito presso lo stato di previsione del Ministero del tesoro, del bilancio e della programmazione economica finalizzato, con appositi provvedimenti, alla riduzione dell'imposta sul reddito delle persone giuridiche e dell'imposta sul reddito delle persone fisiche gravanti sul reddito d'impresa. La riduzione e' effettuata con priorita' temporale nelle aree e nei territori di cui al comma 10 dell'articolo 7.

2. ((IL D.L. 25 SETTEMBRE 2001, N. 350, CONVERTITO CON MODIFICAZIONI DALLA L. 23 NOVEMBRE 2001, N. 409, HA CONFERMATO L'ABROGAZIONE DEL PRESENTE COMMA)).

3. ((IL D.L. 25 SETTEMBRE 2001, N. 350, CONVERTITO CON MODIFICAZIONI DALLA L. 23 NOVEMBRE 2001, N. 409, HA CONFERMATO L'ABROGAZIONE DEL PRESENTE COMMA)).

### Art. 6. - (Disposizioni in materia di tassazione del reddito di impresa)

1. All'articolo 16, comma 1, lettera d), del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, in materia di redditi soggetti a tassazione separata, sono aggiunte, in fine, le parole: "e delle societa' di persone".

2. All'articolo 79, comma 8, del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, concernente la determinazione del reddito delle imprese autorizzate all'autotrasporto, dopo il primo periodo, e' inserito il seguente: "Per le medesime imprese compete, altresi', una deduzione forfetaria annua di lire 300.000 per ciascun motoveicolo e autoveicolo avente massa complessiva a pieno carico non superiore a 3.500 chilogrammi".

3. Le disposizioni di cui al comma 1 dell'articolo 21 della legge 23 dicembre 1998, n. 448, in materia di deduzione forfetaria in favore degli esercenti di impianti di distribuzione di carburante, si applicano per il periodo d'imposta in corso al 31 dicembre 2001 e per i due periodi di imposta successivi.

4. All'articolo 2, comma 11, primo periodo, della legge 13 maggio 1999, n. 133, dopo le parole: "sono applicabili" sono inserite le seguenti: "per i periodi di imposta 1999 e 2000". (12)

5. Al decreto legislativo 18 dicembre 1997, n. 466, in materia di riordino delle imposte sul reddito per favorire la capitalizzazione delle imprese, sono apportate le seguenti modificazioni:

- a) all'articolo 1, il comma 3, in materia di applicazione dell'aliquota ridotta, e' sostituito dal seguente: "3. La parte della remunerazione ordinaria di cui al comma 1 che supera il reddito complessivo netto dichiarato e' computata in aumento del reddito assoggettabile all'aliquota ridotta dei periodi d'imposta successivi, ma non oltre il quinto";
- b) all'articolo 6, comma 1, concernente l'applicazione dell'aliquota ridotta alle societa' quotate, le parole da: "le aliquote di cui ai commi" fino alla fine del periodo sono sostituite dalle seguenti: "l'aliquota di cui al comma 1 dell'articolo 1 e' ridotta al 7 per cento". (12)

6. Le disposizioni del comma 2 si applicano a decorrere dal periodo d'imposta successivo a quello in corso alla data del 31 dicembre 2000; a decorrere dal medesimo periodo d'imposta si applicano le disposizioni del comma 5, fermo restando il diritto al riporto a nuovo maturato in base alle disposizioni previgenti.

7. I soggetti che, avendo in precedenti esercizi imputato gli ammortamenti anticipati a riduzione del costo dei beni, adottino la diversa metodologia contabile di imputazione alla speciale riserva prevista dall'articolo 67, comma 3, del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, possono riclassificare gli ammortamenti anticipati pregressi imputandoli alla suddetta riserva, al netto dell'importo destinato al fondo imposte differite.

8. All'articolo 14, comma 1, alinea, della legge 15 dicembre 1998, n. 441, recante norme a favore dell'imprenditoria giovanile in agricoltura, le parole: "a fondi rustici" sono sostituite dalle seguenti: "ai beni costituenti l'azienda, ivi compresi i fabbricati, le pertinenze, le scorte vive e morte e quant'altro strumentale all'attivita' aziendale".

9. All'articolo 14, comma 6, della legge 15 dicembre 1998, n. 441, il primo periodo e' sostituito dal seguente: "Per favorire l'introduzione e la tenuta della contabilita' da parte delle imprese condotte da giovani agricoltori o da societa' di cui all'articolo 2, il Ministro delle politiche agricole e forestali, d'intesa con le regioni interessate, e' autorizzato a stipulare accordi o convenzioni per fornire assistenza, formazione e informatizzazione".

10. Per le finalita' di cui al comma 9 possono essere utilizzati anche i fondi residui disponibili sul capitolo 7627 dello stato di previsione del Ministero delle politiche agricole e forestali.

11. Alle persone fisiche in possesso della qualifica di imprenditore agricolo, partecipanti ad imprese familiari o socie delle societa' semplici, in nome collettivo, in accomandita semplice si applicano le condizioni previste dall'articolo 13 del decreto del Presidente della Repubblica 29 settembre 1973, n. 601, sempre che le suddette societa' o imprese familiari rivestano la qualifica di soci nella stessa cooperativa agricola.

12. All'articolo 45, comma 1, del decreto legislativo 15 dicembre 1997, n. 446, recante istituzione dell'imposta regionale sulle attivita' produttive, le parole: "e al 1° gennaio 1999" sono sostituite dalle seguenti: ", al 1° gennaio 1999 e al 1° gennaio 2000"; nel medesimo comma le parole: "per i quattro periodi d'imposta successivi, l'aliquota e' stabilita, rispettivamente, nelle misure del 2,3, del 2,5" sono sostituite dalle seguenti: "per i tre periodi d'imposta successivi, l'aliquota e' stabilita, rispettivamente, nella misura del 2,5".

13. ((COMMA ABROGATO DAL D.L. 22 GIUGNO 2012, N. 83, CONVERTITO, CON MODIFICAZIONI, DALLA L. 7 AGOSTO 2012, N. 134)).((71))

14. ((COMMA ABROGATO DAL D.L. 22 GIUGNO 2012, N. 83, CONVERTITO, CON MODIFICAZIONI, DALLA L. 7 AGOSTO 2012, N. 134)).((71))

15. ((COMMA ABROGATO DAL D.L. 22 GIUGNO 2012, N. 83, CONVERTITO, CON MODIFICAZIONI, DALLA L. 7 AGOSTO 2012, N. 134)).((71))

16. ((COMMA ABROGATO DAL D.L. 22 GIUGNO 2012, N. 83, CONVERTITO, CON MODIFICAZIONI, DALLA L. 7 AGOSTO 2012, N. 134)).((71))

17. ((COMMA ABROGATO DAL D.L. 22 GIUGNO 2012, N. 83, CONVERTITO, CON MODIFICAZIONI, DALLA L. 7 AGOSTO 2012, N. 134)).((71)) 18.((COMMA ABROGATO DAL D.L. 22 GIUGNO 2012, N. 83, CONVERTITO, CON MODIFICAZIONI, DALLA L. 7 AGOSTO 2012, N. 134)).((71)) 19. ((COMMA ABROGATO DAL D.L. 22 GIUGNO 2012, N. 83, CONVERTITO, CON MODIFICAZIONI, DALLA L. 7 AGOSTO 2012, N. 134)).((71)) 20. All'articolo 65, comma 2, del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e successive modificazioni, concernente oneri di utilita' sociale, dopo la lettera c-nonies) e' aggiunta la seguente: "c-decies) le erogazioni liberali in denaro a favore di organismi di gestione di parchi e riserve naturali, terrestri e marittimi, statali e regionali, e di ogni altra zona di tutela speciale paesistico-ambientale come individuata dalla vigente disciplina, statale e regionale, nonche' gestita dalle associazioni e fondazioni private indicate alla lettera a) del comma 2-bis dell'articolo 114, effettuate per sostenere attivita' di conservazione, valorizzazione, studio, ricerca e sviluppo dirette al conseguimento delle finalita' di interesse generale cui corrispondono tali ambiti protetti. Il Ministro dell'ambiente individua con proprio decreto, periodicamente, i soggetti e le categorie di soggetti che possono beneficiare delle predette erogazioni liberali; determina, a valere sulla somma allo scopo indicata, le quote assegnate a ciascun ente o soggetto beneficiario. Nel caso che in un dato anno le somme complessivamente erogate abbiano superato la somma allo scopo indicata o determinata i singoli soggetti beneficiari che abbiano ricevuto somme di importo maggiore della quota assegnata dal Ministero dell'ambiente, versano all'entrata dello Stato un importo pari al 37 per cento della differenza". 21. Le disposizioni di cui al comma 20 si applicano a decorrere dal periodo di imposta in corso al 31 dicembre 2002. 22. Ai fini di quanto previsto al comma 20, il Ministro dell'ambiente determina l'ammontare delle erogazioni deducibili in misura complessivamente non superiore a 15 miliardi di lire a decorrere dall'anno 2002. 23. L'articolo 12 del decreto del Presidente della Repubblica 29 settembre 1973, n. 601, e' sostituito dal seguente: "Art. 12. - (Somme ammesse in deduzione dal reddito). - 1. Per le societa' cooperative e loro consorzi sono ammesse in deduzione dal reddito le somme ripartite tra i soci sotto forma di restituzione di una parte del prezzo dei beni e servizi acquistati o di maggiore compenso per i conferimenti effettuati. Le predette somme possono essere imputate ad incremento delle quote sociali". 24. Al comma 8 dell'articolo 2 della legge 13 maggio 1999, n. 133, le parole: "il successivo" sono sostituite dalle seguenti: "i due successivi". (12)

------------- AGGIORNAMENTO (12) La L. 18 ottobre 2001, n. 383 ha disposto (con l'art. 5, comma 1) che le agevolazioni fiscali di cui ai commi 4, 5 e 24 del presente articolo sono soppresse, salvo quanto previsto dall'art. 5, comma 1, lettere a) e b). ------------- AGGIORNAMENTO (71) Il D.L. 22 giugno 2012, n. 83, convertito, con modificazioni, dalla L. 7 agosto 2012, n. 134, ha disposto (con l'art. 23, comma 11) che "I procedimenti avviati in data anteriore a quella di entrata in vigore del presente decreto-legge sono disciplinati, ai fini della concessione e dell'erogazione delle agevolazioni e comunque fino alla loro definizione, dalle disposizioni delle leggi di cui all'Allegato 1 e dalle norme di semplificazione recate dal presente decreto-legge".

### Art. 7. - (Incentivi per l'incremento dell'occupazione)

1. Ai datori di lavoro, che nel periodo compreso tra il 1 ottobre 2000 e il 31 dicembre 2003 incrementano il numero dei lavoratori dipendenti con contratto di lavoro a tempo indeterminato e' concesso un credito di imposta. Sono esclusi i soggetti di cui all'articolo 88 del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917.

2. Il credito di imposta e' commisurato, nella misura di lire 800.000 per ciascun lavoratore assunto e per ciascun mese, alla differenza tra il numero dei lavoratori con contratto di lavoro a tempo indeterminato rilevato in ciascun mese rispetto al numero dei lavoratori con contratto di lavoro a tempo indeterminato mediamente occupati nel periodo compreso tra il 1° ottobre 1999 e il 30 settembre 2000. Il credito di imposta decade se, su base annuale, il numero complessivo dei lavoratori dipendenti, a tempo indeterminato e a tempo determinato, compresi i lavoratori con contratti di lavoro con contenuto formativo, risulta inferiore o pari al numero complessivo dei lavoratori dipendenti mediamente occupati nel periodo compreso tra il 1° ottobre 1999 e il 30 settembre 2000. Per le assunzioni di dipendenti con contratti di lavoro a tempo parziale il credito d'imposta spetta in misura proporzionale alle ore prestate rispetto a quelle del contratto nazionale. Il credito d'imposta e' concesso anche ai datori di lavoro operanti nel settore agricolo che incrementano il numero dei lavoratori operai, ciascuno occupato per almeno 230 giornate all'anno.

3. L'incremento della base occupazionale va considerato, al netto delle diminuzioni occupazionali verificatesi in societa' controllate o collegate ai sensi dell'articolo 2359 del codice civile o facenti capo, anche per interposta persona, allo stesso soggetto. Per i soggetti che assumono la qualifica di datore di lavoro a decorrere dal 1° ottobre 2000, ogni lavoratore dipendente assunto costituisce incremento della base occupazionale. I lavoratori dipendenti con contratto di lavoro a tempo parziale si assumono nella base occupazionale in misura proporzionale alle ore prestate rispetto a quelle del contratto nazionale.

4. Il credito d'imposta, che non concorre alla formazione del reddito e del valore della produzione rilevante ai fini dell'imposta regionale sulle attivita' produttive ne ai fini del rapporto di cui all'articolo 63 del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e' utilizzabile, a decorrere dal 1° gennaio 2001, esclusivamente in compensazione ai sensi del decreto legislativo 9 luglio 1997, n. 241.

5. Il credito d'imposta di cui al comma 1 spetta a condizione che:

- a) i nuovi assunti siano di eta' non inferiore a 25 anni;
- b) i nuovi assunti non abbiano svolto attivita' di lavoro dipendente a tempo indeterminato da almeno 24 mesi o siano portatori di handicap individuati ai sensi della legge 5 febbraio 1992, n. 104;
- c) siano osservati i contratti collettivi nazionali anche con riferimento ai soggetti che non hanno dato diritto al credito d'imposta;
- d) siano rispettate le prescrizioni sulla salute e sulla sicurezza dei lavoratori previste dai decreti legislativi 19 settembre 1994, n. 626, e 14 agosto 1996, n. 494, e loro successive modificazioni, nonche' dai successivi decreti legislativi attuativi di direttive comunitarie in materia di sicurezza ed igiene del lavoro.

6. Nel caso di impresa subentrante ad altra nella gestione di un servizio pubblico, anche gestito da privati, comunque assegnata, il credito d'imposta spetta limitatamente al numero di lavoratori assunti in piu' rispetto a quello dell'impresa sostituita.

7. Qualora vengano definitivamente accertate violazioni non formali, e per le quali sono state irrogate sanzioni di importo superiore a lire 5 milioni, alla normativa fiscale e contributiva in materia di lavoro dipendente, ovvero violazioni alla normativa sulla salute e sulla sicurezza dei lavoratori, prevista dai decreti legislativi 19 settembre 1994, n. 626, e 14 agosto 1996, n. 494, e loro successive modificazioni, nonche' dai successivi decreti legislativi attuativi di direttive comunitarie in materia di sicurezza ed igiene del lavoro, commesse nel periodo in cui si applicano le disposizioni del presente articolo e qualora siano emanati provvedimenti definitivi della magistratura contro il datore di lavoro per condotta antisindacale ai sensi dell'articolo 28 della legge 20 maggio 1970, n. 300, le agevolazioni sono revocate. Dalla data del definitivo accertamento delle violazioni, decorrono i termini per far luogo al recupero delle minori imposte versate o del maggiore credito riportato e per l'applicazione delle relative sanzioni.

8. Le agevolazioni previste dal presente articolo sono cumulabili con altri benefici eventualmente concessi.

9. Entro il 31 dicembre 2001 il Governo provvede ad effettuare la verifica ed il monitoraggio degli effetti delle disposizioni di cui al presente articolo, identificando la nuova occupazione generata per area territoriale, sesso, eta' e professionalita'.

10. Le disposizioni di cui all'articolo 4 della legge 23 dicembre 1998, n. 448, e successive modificazioni, restano in vigore per le assunzioni intervenute nel periodo compreso tra il 1° gennaio 1999 e il 31 dicembre 2000. Per i datori di lavoro che nel periodo compreso tra il 1 gennaio 2001, e il 31 dicembre 2003 effettuano nuove assunzioni di lavoratori dipendenti con contratto a tempo indeterminato da destinare a unita' produttive ubicate nei territori individuati nel citato articolo 4 e nelle aree di cui all'obiettivo 1 del regolamento (CE) n. 1260/1999, del Consiglio, del 21 giugno 1999, nonche' in quelle delle regioni Abruzzo e Molise, spetta un ulteriore credito d'imposta. L'ulteriore credito d'imposta, che e' pari a lire 400.000 per ciascun nuovo dipendente, compete secondo la disciplina di cui al presente articolo. All'ulteriore credito di imposta di cui al presente comma si applica la regola de minimis di cui alla comunicazione della Commissione delle Comunita' europee 96/C68/06, pubblicata nella Gazzetta Ufficiale delle Comunita' europee C68 del 6 marzo 1996, e ad esso sono cumulabili altri benefici eventualmente concessi ai sensi della predetta comunicazione purche' non venga superato il limite massimo di lire 180 milioni nel triennio.

11. Ai fini delle agevolazioni previste dal presente articolo, i soci lavoratori di societa' cooperative sono equiparati ai lavoratori dipendenti. ((52))

------------- AGGIORNAMENTO (52) La L. 24 dicembre 2007, n. 244, ha disposto (con l'art. 1, comma 65) che "In relazione a quanto previsto dal primo periodo del presente comma e in considerazione dell'effettivo utilizzo dei crediti d'imposta previsti dagli articoli 7 e 8 della legge 23 dicembre 2000, n. 388, le risorse finanziarie a tale fine preordinate, esistenti presso la contabilita' speciale 1778 - Fondi di bilancio, sono ridotte di 1.500 milioni di euro. Le predette risorse sono versate al bilancio dello Stato nella misura di 450 milioni di euro per l'anno 2008 e di 525 milioni di euro per ciascuno degli anni 2009 e 2010".

### Art. 8. - Agevolazione per gli investimenti nelle aree svantaggiate

1. Alle imprese che operano nei settori delle attivita' estrattive e manifatturiere, dei servizi, del turismo, del commercio, delle costruzioni, della produzione e distribuzione di energia elettrica, vapore ed acqua calda, della pesca e dell'acquacoltura della trasformazione dei prodotti della pesca e dell'acquacoltura di cui all'allegato I del Trattato che istituisce la Comunita' europea, e successive modificazioni, che, fino alla chiusura del periodo di imposta in corso alla data del 31 dicembre 2006, effettuano nuovi investimenti nelle aree ammissibili alle deroghe previste dall'articolo 87, paragrafo 3, lettere a) e c), del citato Trattato, individuate dalla Carta italiana degli aiuti a finalita' regionale per il periodo 2000-2006, e' attribuito un contributo nella forma di credito di imposta nei limiti massimi di spesa pari a 870 milioni di euro per l'anno 2002 e pari a 1.725 milioni di euro per l'anno 2003, 1.740 milioni di euro per l'anno 2004, 1.511 milioni di euro per l'anno 2005, 1.250 milioni di euro per l'anno 2006, 700 milioni di euro per l'anno 2007 e 300 milioni di euro per l'anno 2008. Ai fini dell'individuazione dei predetti settori, salvo per il settore della pesca e dell'acquacoltura, si rinvia alla disciplina di attuazione delle agevolazioni di cui all'articolo 1, comma 2, del decreto-legge 22 ottobre 1992, n. 415, convertito, con modificazioni, dalla legge 19 dicembre 1992, n. 488. Per le aree ammissibili alle deroghe previste dal citato articolo 87, paragrafo 3, lettere a) e c), il credito compete entro la misura dell'85 per cento delle intensita' di aiuto previste dalla Carta italiana degli aiuti a finalita' regionale per il periodo 2000-2006. Il credito d'imposta non e' cumulabile con altri aiuti di Stato a finalita' regionale o con altri aiuti che abbiano ad oggetto i medesimi beni che fruiscono del credito di imposta. ((PERIODO SOPPRESSO DALLA L. 24 DICEMBRE 2007, N. 244)). ((52))

1-bis. Per fruire del contributo le imprese inoltrano, in via telematica, al Centro operativo di Pescara dell'Agenzia delle entrate un'istanza contenente gli elementi identificativi dell'impresa, l'ammontare complessivo dei nuovi investimenti e la ripartizione regionale degli stessi, nonche' l'impegno, a pena di disconoscimento del beneficio, ad avviare la realizzazione degli investimenti successivamente alla data di presentazione della medesima istanza e comunque entro sei mesi dalla predetta data.

1-ter. L'Agenzia delle entrate rilascia, in via telematica e con procedura automatizzata, certificazione della data di avvenuta presentazione della domanda, esamina le istanze di cui al comma 1-bis dando precedenza, secondo l'ordine cronologico di presentazione, alle domande presentate nell'anno precedente e non accolte per esaurimento dei fondi stanziati e, tra queste, a quelle delle piccole e medie imprese, come definite dall'allegato I del regolamento (CE) n. 70/2001 della Commissione, del 12 gennaio 2001, e successivamente secondo l'ordine di presentazione, alle altre domande. L'Agenzia delle entrate comunica in via telematica, entro trenta giorni dalla presentazione delle domande, il diniego del contributo per la mancanza di uno degli elementi di cui al comma 1-bis, ovvero per l'esaurimento dei fondi stanziati. Il beneficio si intende concesso decorsi 30 giorni dalla presentazione dell'istanza e senza comunicazione di diniego da parte dell'Agenzia delle entrate.

1-quater. COMMA ABROGATO DALLA L. 27 DICEMBRE 2002, N. 289.

1-quinquies. Con provvedimento del Direttore dell'Agenzia delle entrate sono stabilite le specifiche tecniche per la trasmissione dei dati di cui ai commi 1, 1-bis, 1-ter e 1-quater.

1-sexies. Per le modalita' delle trasmissioni telematiche previste dal presente articolo si applicano le disposizioni contenute nell'articolo 3 del regolamento di cui al decreto del Presidente della Repubblica 22 luglio 1998, n. 322, come sostituito dall'articolo 3 del regolamento di cui al decreto del Presidente della Repubblica 7 dicembre 2001, n. 435.

1-septies. L'Agenzia delle entrate provvede a pubblicare, con cadenza semestrale, sul proprio sito Internet, il numero delle istanze pervenute, l'ammontare totale dei contributi concessi, nonche' quello delle risorse finanziarie residue.

2. Per nuovi investimenti si intendono le acquisizioni di beni strumentali nuovi di cui agli articoli 67 e 68 del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, esclusi i costi relativi all'acquisto di "mobili e macchine ordinarie di ufficio" di cui alla tabella approvata con decreto del Ministro delle finanze 31 dicembre 1988, pubblicato nel supplemento ordinario alla Gazzetta Ufficiale n. 27 del 2 febbraio 1989, concernente i "coefficienti di ammortamento", destinati a strutture produttive gia' esistenti o che vengono impiantate nelle aree territoriali di cui al comma 1, per la parte del loro costo complessivo eccedente le cessioni e le dismissioni effettuate nonche' gli ammortamenti dedotti nel periodo d'imposta, relativi a beni d'investimento della stessa struttura produttiva. Sono esclusi gli ammortamenti dei beni che formano oggetto dell'investimento agevolato effettuati nel periodo d'imposta della loro entrata in funzione. Per gli investimenti effettuati mediante contratti di locazione finanziaria, si assume il costo sostenuto dal locatore per l'acquisto dei beni; detto costo non comprende le spese di manutenzione. Per le grandi imprese, come definite ai sensi della normativa comunitaria, gli investimenti in beni immateriali sono agevolabili nel limite del 25 per cento del complesso degli altri investimenti agevolati.

3. COMMA ABROGATO DAL D.L. 8 LUGLIO 2002, N. 138, CONVERTITO CON MODIFICAZIONI DALLA L. 8 AGOSTO 2002, N. 178.

4. All'articolo 1, comma 2, del decreto legislativo 18 dicembre 1997, n. 466, sono aggiunte, in fine, le seguenti parole: "differenziabile in funzione del settore di attivita' e delle dimensioni dell'impresa, nonche' della localizzazione".

5. Il credito d'imposta e' determinato con riguardo ai nuovi investimenti eseguiti in ciascun periodo d'imposta e va indicato nella relativa dichiarazione dei redditi. Esso non concorre alla formazione del reddito ne' della base imponibile dell'imposta regionale sulle attivita' produttive, non rileva ai fini del rapporto di cui all'articolo 63 del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, ed e' utilizzabile esclusivamente in compensazione, ai sensi del decreto legislativo 9 luglio 1997, n. 241, a decorrere dalla data di sostenimento dei costi.

6. Il credito d'imposta a favore di imprese o attivita' che riguardano prodotti o appartengono ai settori soggetti a discipline comunitarie specifiche, ivi inclusa la disciplina multisettoriale dei grandi progetti, e' riconosciuto nel rispetto delle condizioni sostanziali e procedurali definite dalle predette discipline dell'Unione europea e previa autorizzazione della Commissione delle Comunita' europee. Il Ministero dell'industria, del commercio e dell'artigianato procede all'inoltro alla Commissione della richiesta di preventiva autorizzazione, ove prescritta, nonche' al controllo del rispetto delle norme sostanziali e procedurali della normativa comunitaria.

7. Se i beni oggetto dell'agevolazione non entrano in funzione entro il secondo periodo d'imposta successivo a quello della loro acquisizione o ultimazione, il credito d'imposta e' rideterminato escludendo dagli investimenti agevolati il costo dei beni non entrati in funzione. Se entro il quinto periodo d'imposta successivo a quello nel quale sono entrati in funzione i beni sono dismessi, ceduti a terzi, destinati a finalita' estranee all'esercizio dell'impresa ovvero destinati a strutture produttive diverse da quelle che hanno dato diritto all'agevolazione, il credito d'imposta e' rideterminato escludendo dagli investimenti agevolati il costo dei beni anzidetti; se nel periodo di imposta in cui si verifica una delle predette ipotesi vengono acquisiti beni della stessa categoria di quelli agevolati, il credito d'imposta e' rideterminato escludendo il costo non ammortizzato degli investimenti agevolati per la parte che eccede i costi delle nuove acquisizioni. Per i beni acquisiti in locazione finanziaria le disposizioni precedenti si applicano anche se non viene esercitato il riscatto. Il minore credito d'imposta che deriva dall'applicazione del presente comma e' versato entro il termine per il versamento a saldo dell'imposta sui redditi dovuta per il periodo d'imposta in cui si verificano le ipotesi ivi indicate. (40)

7-bis. Con decreto del Ministro delle politiche agricole e forestali, d'intesa con la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, sono definite le tipologie di investimento per le imprese agricole e per quelle della prima trasformazione e commercializzazione ammesse agli aiuti, in osservanza di quanto previsto dal piano di sviluppo rurale di cui al citato regolamento (CE) n. 1257/1999 e di quanto previsto dall'articolo 17 del decreto legislativo 18 maggio 2001, n. 228.

8. Con uno o piu' decreti del Ministero delle finanze, di concerto con il Ministero del tesoro, del bilancio e della programmazione economica e con il Ministero dell'industria, del commercio e dell'artigianato, da emanare entro sessanta giorni dalla data di entrata in vigore della presente legge, verranno emanate disposizioni per l'effettuazione delle verifiche necessarie a garantire la corretta applicazione delle presenti disposizioni. Tali verifiche, da effettuare dopo almeno dodici mesi dall'attribuzione del credito di imposta, sono altresi' finalizzate alla valutazione della qualita' degli investimenti effettuati, anche al fine di valutare l'opportunita' di effettuare un riequilibrio con altri strumenti aventi analoga finalita'.

------------- AGGIORNAMENTO (40) Il D.L. 30 settembre 2005, n. 203, convertito con modificazioni dalla L. 2 dicembre 2005, n. 248, ha disposto (con l'art. 7, comma 1-bis) che "La disposizione di cui al secondo periodo del comma 7 dell'articolo 8 della legge 23 dicembre 2000, n. 388, si interpreta nel senso che gli immobili strumentali per natura, ai sensi dell' articolo 43, comma 2, secondo periodo, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, i quali costituiscono un complesso immobiliare unitario polifunzionale destinato allo svolgimento di attivita' commerciale, qualora siano locati a terzi, non si intendono destinati a struttura produttiva diversa, a condizione che gli stessi vengano destinati allo svolgimento di attivita' d'impresa ai sensi dell' articolo 55 del citato testo unico". ------------- AGGIORNAMENTO (52) La L. 24 dicembre 2007, n. 244, ha disposto (con l'art. 1, comma 65) che in relazione alla soppressione del suddetto periodo e in considerazione dell'effettivo utilizzo dei crediti d'imposta previsti dagli articoli 7 e 8 della legge 23 dicembre 2000, n. 388, le risorse finanziarie a tale fine preordinate, esistenti presso la contabilita' speciale 1778 - Fondi di bilancio, sono ridotte di 1.500 milioni di euro.

### Art. 9. - (Tassazione del reddito d'impresa con aliquota proporzionale)

1. Il reddito d'impresa degli imprenditori individuali, determinato ai sensi dell'articolo 52 del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, puo' essere escluso dalla formazione del reddito complessivo di cui all'articolo 8 del medesimo testo unico e assoggettato separatamente all'imposta sul reddito delle persone fisiche secondo le disposizioni dei commi successivi.

2. L'imposta e' commisurata al reddito di cui al comma 1 con l'aliquota prevista dall'articolo 91 del citato testo unico delle imposte sui redditi, come modificato dalla presente legge; si applicano le disposizioni dell'articolo 1 del decreto legislativo 18 dicembre 1997, n. 466, come modificato dalla presente legge, e dell'articolo 91-bis del citato testo unico.

3. L'imposta e' versata, anche a titolo d'acconto, con le modalita' e nei termini previsti per il versamento dell'imposta sul reddito delle persone fisiche; i crediti di imposta, i versamenti in acconto e le ritenute d'acconto sui proventi che concorrono a formare il reddito di cui al comma 1 sono scomputati dall'imposta ai sensi degli articoli 92, 93 e 94 del citato testo,unico delle imposte sui redditi. Si applicano le disposizioni del decreto legislativo 9 luglio 1997, n. 241.

4. La perdita di un periodo d'imposta puo' essere computata in diminuzione del reddito d'impresa dei periodi d'imposta successivi, ma non oltre il quinto, con le regole stabilite dall'articolo 102 del citato testo unico delle imposte sui redditi.

5. Il regime di cui al comma 1 e' applicato su opzione revocabile. L'opzione e la revoca sono esercitate nella dichiarazione dei redditi e hanno effetto a decorrere dal periodo d'imposta successivo a quello cui si riferisce la dichiarazione.

6. Ai fini dell'accertamento si applica l'articolo 40, primo comma, del decreto del Presidente della Repubblica 29 settembre 1973, n. 600.

7. Gli utili dei periodi d'imposta nei quali e' applicato il regime di cui al comma 1, se prelevati dal patrimonio dell'impresa, costituiscono per l'imprenditore redditi ai sensi dell'articolo 41, comma 1, lettera e), del citato testo unico delle imposte sui redditi e per essi spetta il credito d'imposta secondo i criteri dell'articolo 14 di detto testo unico, come modificato della presente legge; si applicano gli articoli 105, 105-bis e 106-bis dello stesso testo unico. A tale fine nella dichiarazione dei redditi vanno indicati separatamente il patrimonio netto formato con gli utili non distribuiti dei periodi d'imposta nei quali e' applicato il regime di cui al comma 1 e le altre componenti del patrimonio netto.

8. Le somme trasferite dal patrimonio dell'impresa a quello personale dell'imprenditore, al netto delle somme versate nello stesso periodo d'imposta, costituiscono prelievi degli utili dell'esercizio in corso e, per l'eccedenza, di quelli degli esercizi precedenti. L'importo che supera il patrimonio si considera prelievo degli utili dei periodi d'imposta successivi, da assoggettare a tassazione in tali periodi.

9. In caso di revoca, si considerano prelevati gli utili ancora esistenti al termine dell'ultimo periodo d'imposta di applicazione del regime di cui al comma 1.

10. Per le imprese familiari, le disposizioni dei commi da 7 a 9 si applicano al titolare dell'impresa e ai collaboratori in proporzione alle quote di partecipazione agli utili determinate secondo le disposizioni del comma 4 dell'articolo 5 del citato testo unico delle imposte sui redditi.

11. Le disposizioni dei commi da 1 a 9 si applicano, su opzione, anche alle societa' in nome collettivo e in accomandita semplice. In tale caso, dette societa' sono considerate soggetti passivi d'imposta assimilati alle societa' di cui all'articolo 87, comma 1, lettera a), del citato testo unico delle imposte sui redditi e ad esse si applicano, in quanto compatibili, le relative disposizioni.

12. Le disposizioni del presente articolo decorrono dal periodo d'imposta successivo a quello in corso al 1° gennaio 2001. ((12))

------------- AGGIORNAMENTO (12) La L. 18 ottobre 2001, n. 383 ha disposto (con l'art. 5, comma 1) che le agevolazioni fiscali di cui al presente articolo sono soppresse, salvo quanto previsto dall'art. 5, comma 1, lettere a) e b).

### Art. 10. - (Soppressione della tassa di proprieta' sugli autoscafi)

1. All'articolo 1 del testo unico delle leggi sulle tasse automobilistiche, approvato con decreto del Presidente della Repubblica 5 febbraio 1953, n. 39, le parole: ", la navigazione in acque pubbliche degli autoscafi" sono soppresse, e le parole: "sono soggette" sono sostituite dalle seguenti: "e' soggetta".

2. All'articolo 13 del citato testo unico approvato con decreto del Presidente della Repubblica 5 febbraio 1953, n. 39, le parole: "Gli autoveicoli, i rimorchi e gli autoscafi" sono sostituite dalle seguenti: "Gli autoveicoli e i rimorchi" e le parole: "su strade, aree od acque pubbliche" sono sostituite dalle seguenti: "su strade od aree pubbliche".

3. La tariffa E allegata al citato testo unico approvato con decreto del Presidente della Repubblica 5 febbraio 1953, n. 39, e' soppressa.

### Art. 11. - (Trattamento fiscale delle imprese che esercitano la pesca costiera o nelle acque interne e lagunari)

1. Per la salvaguardia dell'occupazione della gente di mare, i benefici di cui agli articoli 4 e 6 del decreto-legge 30 dicembre 1997, n. 457, convertito, con modificazioni, dalla legge 27 febbraio 1998, n. 30, sono estesi, per gli anni 2001, 2002 e 2003 e nel limite del 70 per cento, alle imprese che esercitano la pesca costiera, nonche' alle imprese che esercitano la pesca nelle acque interne e lagunari. (31) (36) (43) ((49))

------------- AGGIORNAMENTO (31) La L. 24 dicembre 2003, n. 350 ha disposto (con l'art. 2, comma 5) che "Per l'anno 2004 sono prorogate le disposizioni di cui all'articolo 11 della legge 23 dicembre 2000, n. 388". ------------- AGGIORNAMENTO (36) La L. 30 dicembre 2004, n. 311 ha disposto (con l'art. 1, comma 510) che "Per l'anno 2005 sono prorogate le disposizioni di cui all'articolo 11 della legge 23 dicembre 2000, n. 388". ------------- AGGIORNAMENTO (43) La L. 23 dicembre 2005, n. 266, ha disposto (con l'art. 1, comma 119) che "Per l'anno 2006 sono prorogate le disposizioni di cui all'articolo 11 della legge 23 dicembre 2000, n. 388". ------------- AGGIORNAMENTO (49) La L. 27 dicembre 2006, n. 296, ha disposto (con l'art. 1, comma 391) che "Per l'anno 2007 sono prorogate le disposizioni di cui all'articolo 11 della legge 23 dicembre 2000, n. 388".

### Art. 12. - (Trattamento fiscale degli avanzi di gestione di Consorzi)

1. Il trattamento fiscale degli avanzi di gestione, di cui al comma 2-bis dell'articolo 41 del decreto legislativo 5 febbraio 1997, n. 22, e successive modificazioni, e' esteso, alle medesime condizioni, anche agli eventuali avanzi di gestione accantonati dal Consorzio obbligatorio batterie al piombo esauste e rifiuti piombosi (COBAT), nonche' dal Consorzio nazionale di raccolta e trattamento degli olii e dei grassi vegetali ed animali, esausti.

### Art. 13.

((ARTICOLO ABROGATO DALLA L. 23 DICEMBRE 2014, N. 190)) ((82))

--------------- AGGIORNAMENTO (82) La L. 23 dicembre 2014, n. 190 ha disposto (con l'art. 1, comma 89) che la presente abrogazione ha effetto a decorrere dal periodo di imposta successivo a quello in corso al 31 dicembre 2014.

### Art. 14.

((ARTICOLO ABROGATO DALLA L. 24 DICEMBRE 2007, N. 244))

### Art. 15. - (Agevolazioni fiscali in materia di scambi di servizi fra aziende agricole dei comuni montani)

1. Il comma 1 dell'articolo 17 della legge 31 gennaio 1994, n. 97, e' sostituito dal seguente: "1. I coltivatori diretti, singoli o associati, i quali conducono aziende agricole ubicate nei comuni montani, in deroga alle vigenti disposizioni di legge possono assumere in appalto sia da enti pubblici che da privati, impiegando esclusivamente il lavoro proprio e dei familiari di cui all'articolo 230-bis del codice civile, nonche' utilizzando esclusivamente macchine ed attrezzature di loro proprieta', lavori relativi alla sistemazione e manutenzione del territorio montano, quali lavori di forestazione, di costruzione di piste forestali, di arginatura, di sistemazione idraulica, di difesa dalle avversita' atmosferiche e dagli incendi boschivi nonche' lavori agricoli e forestali tra i quali l'aratura, la semina, la potatura, la falciatura, la mietitrebbiatura, i trattamenti antiparassitari, la raccolta di prodotti agricoli, il taglio del bosco, per importi non superiori a cinquanta milioni di lire per ogni anno. Tale importo e' rivalutato annualmente con decreto del Ministro competente in base all'indice dei prezzi al consumo per le famiglie di operai e impiegati rilevato dall'Istituto nazionale di statistica".

2. Dopo il comma 1 dell'articolo 17 della citata legge n. 97 del 1994, come sostituito dal comma 1 del presente articolo, sono inseriti i seguenti: "1-bis. I lavori di cui al comma 1 non sono considerati prestazioni di servizi ai fini fiscali e non sono soggetti ad imposta, se sono resi tra soci di una stessa associazione non avente fini di lucro ed avente lo scopo di migliorare la situazione economica delle aziende agricole associate e lo scambio interaziendale di servizi. 1-ter. I soggetti di cui al comma 1 possono trasportare il latte fresco fino alla propria cooperativa per se' e per altri soci della stessa cooperativa impiegando mezzi di trasporto di loro proprieta', anche agricoli, iscritti nell'ufficio meccanizzazione agricola (UMA). Tale attivita' ai fini fiscali non e' considerata quale prestazione di servizio e non e' soggetta ad imposta. 1-quater. I contributi agricoli unificati versati dai coltivatori diretti all'INPS, gestione agricola, garantiscono la copertura assicurativa infortunistica per i soggetti e le attivita' di cui ai commi 1-bis e 1-ter. 1-quinquies. I soggetti di cui al comma 1 possono assumere in appalto da enti pubblici l'incarico di trasporto locale di persone, utilizzando esclusivamente automezzi di proprieta'".

### Art. 16. - (Disposizioni in materia di base imponibile IRAP)

1. Al decreto legislativo 15 dicembre 1997, n. 446, concernente l'imposta regionale sulle attivita' produttive, sono apportate le seguenti modificazioni:

- a) all'articolo 10-bis, comma 1, dopo il secondo periodo e' inserito il seguente: "Sono in ogni caso escluse dalla base imponibile le borse di studio e gli altri interventi di sostegno erogati dalle regioni, dalle province autonome e dai relativi organismi regionali per il diritto allo studio universitario, nonche' dalle universita', ai sensi della legge 2 dicembre 1991, n. 390";
- b) all'articolo 11, comma 1, lettera a), dopo le parole: "relative agli apprendisti," sono inserite le seguenti: "ai disabili";
- c) all'articolo 11, dopo il comma 4 sono aggiunti i seguenti: "4-bis. Per i soggetti di cui all'articolo 3, comma 1, lettere da a) ad e), sono ammessi in deduzione dalla base imponibile, fino a concorrenza, i seguenti importi: a) lire 10.000.000 se la base imponibile non supera lire 350.000.000; b) lire 7.500.000 se la base imponibile supera lire 350.000.000 ma non lire 350.100.000; c) lire 5.000.000 se la base imponibile supera lire 350.100.000 ma non lire 350.200.000; d) lire 2.500.000 se la base imponibile supera lire 350.200.000 ma non lire 350.300.000. 4-ter. I soggetti di cui all'articolo 4, comma 2, applicano la deduzione di cui al comma 4-bis sul valore della produzione netta prima della ripartizione dello stesso su base regionale.";
- d) all'articolo 41, commi 2 e 3, le parole: "per il 1998 e 1999", ovunque ricorrano, sono soppresse;
- e) all'articolo 42, comma 7, primo periodo, le parole: "per gli anni 1998 e 1999" sono sostituite dalle seguenti: "per gli anni dal 1998 al 2002" e al medesimo comma, la parola: "2000" e' sostituita dalla seguente: "2003".

2. Le disposizioni di cui al comma 1, lettera c), si applicano a decorrere dal periodo d'imposta successivo a quello in corso alla data del 31 dicembre 1999.

### Art. 17. - (Interpretazione autentica sull'inderogabilita' delle clausole mutualistiche da parte delle societa' cooperative e loro consorzi)

1. Le disposizioni di cui all'articolo 26 del decreto legislativo del Capo provvisorio dello Stato 14 dicembre 1947, n. 1577, ratificato, con modificazioni dalla legge 2 aprile 1951, n. 302, all'articolo 14 del decreto del Presidente della Repubblica 29 settembre 1973, n. 601, e all'articolo 11, comma 5, della legge 31 gennaio 1992, n. 59, si interpretano nel senso che la soppressione da parte di societa' cooperative o loro consorzi delle clausole di cui al predetto articolo 26 comporta comunque per le stesse l'obbligo di devolvere il patrimonio effettivo in essere alla data della soppressione, dedotti il capitale versato e rivalutato ed i dividendi eventualmente maturati, ai fondi mutualistici di cui al citato articolo 11, comma 5. Allo stesso obbligo si intendono soggette le stesse societa' cooperative e loro consorzi nei casi di fusione e di trasformazione, ove non vietati dalla normativa vigente, in enti diversi dalle cooperative per le quali vigono le clausole di cui al citato articolo 26, nonche' in caso di decadenza dai benefici fiscali.

## DISPOSIZIONI IN MATERIA DI FISCALITA' SUGLI IMMOBILI

### Art. 18. - (Modifica alla disciplina dei versamenti ICI)

1. All'articolo 10 del decreto legislativo 30 dicembre 1992, n. 504, recante la disciplina dell'imposta comunale sugli immobili, il comma 2 e' sostituito dal seguente: "2. I soggetti indicati nell'articolo 3 devono effettuare il versamento dell'imposta complessivamente dovuta al comune per l'anno in corso in due rate delle quali la prima, entro il 30 giugno, pari al 50 per cento dell'imposta dovuta calcolata sulla base dell'aliquota e delle detrazioni dei dodici mesi dell'anno precedente. La seconda rata deve essere versata dal 1° al 20 dicembre, a saldo dell'imposta dovuta per l'intero anno, con eventuale conguaglio sulla prima rata versata. Il versamento dell'imposta puo' essere effettuato anche tramite versamenti su conto corrente postale con bollettini conformi al modello indicato con circolare del Ministero delle finanze. Resta in ogni caso nella facolta' del contribuente provvedere al versamento dell'imposta complessivamente dovuta in unica soluzione annuale, da corrispondere entro il 30 giugno".

2. Al comma 12 dell'articolo 30 della legge 23 dicembre 1999, n. 488, le parole: "Fino all'anno di imposta 1999", sono sostituite dalle seguenti: "Fino all'anno di imposta 2000".

3. All'articolo 3, comma 2, del decreto legislativo 30 dicembre 1992, n. 504, e' aggiunto, in fine, il seguente periodo: "Nel caso di concessione su aree demaniali soggetto passivo e' il concessionario".

4. In deroga alle disposizioni dell'articolo 3, comma 3, della legge 27 luglio 2000, n. 212, concernente l'efficacia temporale delle norme tributarie, i termini per la liquidazione e l'accertamento dell'imposta comunale sugli immobili, scadenti al 31 dicembre 2000, sono prorogati al 31 dicembre 2001, limitatamente alle annualita' d'imposta 1995 e successive. Il termine per l'attivita' di liquidazione a seguito di attribuzione di rendita da parte degli uffici del territorio competenti di cui all'articolo 11, comma 1, ultimo periodo, del decreto legislativo 30 dicembre 1992, n. 504, e' prorogato al 31 dicembre 2001 per le annualita' d'imposta 1994 e successive.

### Art. 19. - (Versamento dell'ICI nel caso di immobili con diritti di godimento a tempo parziale)

1. Per i beni immobili sui quali sono costituiti diritti di godimento a tempo parziale, di cui all'articolo 1, comma 1, lettera a), del decreto legislativo 9 novembre 1998, n. 427, il versamento dell'ICI e' effettuato dall'amministratore del condominio o della comunione.

2. L'amministratore e' autorizzato a prelevare l'importo necessario al pagamento dell'ICI dalle disponibilita' finanziarie del condominio attribuendo le quote al singolo titolare dei diritti di cui al comma 1 con addebito nel rendiconto annuale.

### Art. 20. - (Semplificazione per l'INVIM decennale)

1. Per gli immobili di cui all'articolo 3 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 643, concernente l'imposta comunale sull'incremento di valore degli immobili, e successive modificazioni, per i quali il decennio si compie tra il 1° gennaio e il 31 dicembre 2002, puo' essere corrisposta entro il 30 marzo 2001, in luogo dell'imposta INVIM decennale, un'imposta sostitutiva pari allo 0,10 per cento del loro valore al 31 dicembre 1992, determinato con l'applicazione alla rendita catastale, anche presunta, dei moltiplicatori di cui al decreto del Ministro delle finanze del 14 dicembre 1991, pubblicato nella Gazzetta Ufficiale n. 295 del 17 dicembre 1991.

2. Per gli immobili suscettibili di destinazione edificatoria l'imposta sostitutiva di cui al comma 1 e' commisurata al valore finale dichiarato o definitivamente accertato per l'imposta INVIM di cui agli articoli 2 e 3 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 643, e successive modificazion1.

3. Per gli immobili assoggettati all'imposta INVIM straordinaria di cui al decreto-legge 13 settembre 1991, n. 299, convertito, con modificazioni, dalla legge 18 novembre 1991, n. 363, imposta sostitutiva di cui al comma 1 e' commisurata al valore finale dichiarato o definitivamente accertato per la medesima imposta straordinaria. In tal caso e' escluso l'obbligo della dichiarazione di cui all'articolo 18 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 643.

4. Con decreto del Ministero delle finanze sono individuati i casi di esclusione dell'obbligo della dichiarazione di cui all'articolo 18 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 643, nonche' ogni altra disposizione necessaria all'attuazione del presente articolo.

## DISPOSIZIONI IN MATERIA DI TASSAZIONE DELL'ENERGIA

### Art. 21. - (Disposizioni concernenti l'esenzione dall'accisa sul biodiesel)

1. A decorrere dal 1° luglio 2001, il comma 6 dell'articolo 21 del testo unico delle disposizioni legislative concernenti le imposte sulla produzione e sui consumi, approvato con decreto legislativo 26 ottobre 1995, n. 504, e successive modificazioni, e' sostituito dal seguente: "6. Le disposizioni del comma 2 si applicano anche al prodotto denominato "biodiesel", ottenuto dalla esterificazione di oli vegetali e loro derivati usato come carburante, come combustibile, come additivo, ovvero per accrescere il volume finale dei carburanti e dei combustibili. La fabbricazione o la miscelazione con gasolio o altri oli minerali del "biodiesel" e' effettuata in regime di deposito fiscale. Il "biodiesel", puro o in miscela con gasolio o con oli combustibili in qualsiasi percentuale, e' esentato dall'accisa nei limiti di un contingente annuo di 300.000 tonnellate nell'ambito di un programma triennale, tendente a favorire lo sviluppo tecnologico. Con decreto del Ministro delle finanze, di concerto con il Ministro dell'industria, del commercio e dell'artigianato, con il Ministro dell'ambiente e con il Ministro delle politiche agricole e forestali, sono determinati i requisiti degli operatori, le caratteristiche tecniche degli impianti di produzione, nazionali ed esteri, le caratteristiche fiscali del prodotto con i relativi metodi di prova, le modalita' di distribuzione ed i criteri di assegnazione dei quantitativi esenti agli operatori. Per il trattamento fiscale del "Biodiesel" destinato al riscaldamento valgono, in quanto applicabili, le disposizioni dell'articolo 61".

2. Al fine di promuovere l'impiego del prodotto denominato "biodiesel", di cui al comma 1, come carburante per autotrazione, il Ministro dell'industria, del commercio e dell'artigianato e' autorizzato alla realizzazione di un progetto pilota che, in deroga a quanto previsto dall'articolo 2, comma 4, del decreto del Ministro delle finanze 22 maggio 1998, n. 219, preveda l'avvio al consumo del "biodiesel" puro presso utenti in rete, a partire dalle aree urbane a maggiore concentrazione di traffico.

3. Tra i soggetti beneficiari di quote del quantitativo di 125.000 tonnellate di "biodiesel" esente da accisa nell'ambito del progetto-pilota triennale di cui all'articolo 21, comma 6, del citato testo unico approvato con decreto legislativo 26 ottobre 1995, n. 504, nel testo previgente alla data di entrata in vigore della presente legge, relativo al periodo 1° luglio 2000-30 giugno 2001 sono ripartiti, proporzionalmente alle relative quote e purche' vengano immessi in consumo nel suddetto periodo, i quantitativi di "biodiesel" esente complessivamente non immessi in consumo nei due precedenti periodi 1° luglio 1998-30 giugno 1999 e 1° luglio 1999-30 giugno 2000. In caso di rinuncia, totale o parziale, delle quote risultanti dalla suddetta ripartizione da parte di un beneficiario, le stesse sono redistribuite, proporzionalmente alle relative assegnazioni, fra gli altri beneficiari.

### Art. 22. - (Riduzione dell'accisa su alcuni prodotti a fini di tutela ambientale)

1. All'articolo 21 del testo unico delle disposizioni legislative concernenti le imposte sulla produzione e sui consumi approvato, con decreto legislativo 26 ottobre 1995, n. 504, e successive modificazioni, dopo il comma 6, sono inseriti i seguenti: "6-bis. Allo scopo di incrementare l'utilizzo di fonti energetiche che determinino un ridotto impatto ambientale e' stabilita, nell'ambito di un progetto sperimentale, una accisa ridotta, secondo le aliquote di seguito indicate, applicabili sui seguenti prodotti impiegati come carburanti da soli od in miscela con oli minerali: a) bioetanolo derivato da prodotti di origine agricola... lire 560.000 per 1.000 litri; b) etere etilterbutilico (ETBE), derivato da alcole di origine agricola... lire 560.000 per 1.000 litri; c) additivi e riformulati prodotti da biomasse: 1) per benzina senza piombo... lire 560.000 per 1.000 litri; 2) per gasolio, escluso il biodiesel... lire 475.000 per 1.000 litri. 6-ter. Con decreto del Ministro delle finanze, di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, il Ministro dell'industria, del commercio e dell'artigianato, il Ministro dell'ambiente ed il Ministro delle politiche agricole e forestali sono fissati, entro il limite complessivo di spesa di lire 30 miliardi annue, comprensivo dell'imposta sul valore aggiunto. i criteri di ripartizione dell'agevolazione tra le varie tipologie e tra gli operatori, le caratteristiche tecniche dei prodotti singoli e delle relative miscele ai fini dell'impiego nella carburazione, nonche' le modalita' di verifica della loro idoneita' ad abbattere i principali agenti dinamici, valutata sull'intero ciclo di vita".

2. Il progetto sperimentale di cui al comma 1 ha la durata di un triennio a decorrere ((dal 1 gennaio 2005)).

### Art. 23. - (Riduzione dell'accisa per alcuni impieghi agevolati)

1. I punti 12 e 13 della tabella A allegata al testo unico delle disposizioni legislative concernenti le imposte sulla produzione e sui consumi, approvato con decreto legislativo 26 ottobre 1995, n. 504. sono sostituiti dai seguenti: "12. Azionamento delle autovetture da noleggio da piazza, compresi i motoscafi che in talune localita' sostituiscono le vetture da piazza e quelli lacuali, adibiti al servizio pubblico da banchina per il trasporto di persone: benzina e benzina senza piombo... 40 per cento aliquota normale della benzina senza piombo; gasolio... 40 per cento aliquota normale; gas di petrolio liquefatti (GPL)... 40 per cento aliquota normale, gas metano... 40 per cento aliquota normale. L'agevolazione e' concessa entro i seguenti quantitativi giornalieri presumendo, in caso di alimentazione promiscua a benzina e GPL o gas metano, un consumo di GPL o gas metano pari al 70 per cento del consumo totale: a) litri 18 o metri cubi 18 relativamente al gas metano per ogni autovettura circolante nei comuni con popolazione superiore a 500.000 abitanti; b) litri 14 o metri cubi 14 relativamente al gas metano per ogni autovettura circolante nei comuni con popolazione superiore a 100.000 abitanti, ma non a 500.000 abitanti; c) litri 11 o metri cubi 11 relativamente al gas metano per ogni autovettura circolante nei comuni con popolazione di 100.000 abitanti o meno. 13. Azionamento delle autoambulanze, destinate al trasporto degli ammalati e dei feriti di pertinenza dei vari enti di assistenza e di pronto soccorso da determinare con provvedimento dell'amministrazione finanziaria (nei limiti e con le modalita' stabiliti con il decreto del Ministro delle finanze di cui all'articolo 67): benzina... 40 per cento aliquota normale; benzina senza piombo... 40 per cento aliquota normale; gasolio... 40 per cento aliquota normale; gas di petrolio liquefatti (GPL)... 40 per cento aliquote normali; gas - metano... 40 per cento aliquota normale. Le agevolazioni previste per le autovettura da noleggio da piazza e per le autoambulanze, di cui ai punti 12 e 13, sono concesse mediante crediti d'imposta da utilizzare in compensazione ai sensi dell'articolo 17 del decreto legislativo 9 luglio 1997, n. 241, e successive modificazioni, ovvero mediante buoni d'imposta. I crediti ed i buoni d'imposta non concorrono alla formazione del reddito imponibile e non vanno considerati ai fini del rapporto di cui all'articolo 63 del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e successive modificazioni".

### Art. 24. - (Riduzione delle aliquote delle accise sui prodotti petroliferi)

1. Al fine di compensare le variazioni dell'incidenza sui prezzi al consumo derivanti dall'andamento, dei prezzi internazionali del petrolio, a decorrere dal 1 gennaio 2001 e fino al 30 giugno 2001, le aliquote di accisa dei seguenti prodotti petroliferi sono stabilite nella sottoindicata misura:

- a) benzina: lire 1.077.962 per mille litri;
- b) benzina senza piombo: lire 1.007.486 per mille litri;
- c) olio da gas o gasolio: 1) usato come carburante: lire 739.064 per mille litri; 2) usato come combustibile per riscaldamento: lire 697.398 per mille litri;
- d) emulsioni stabilizzate di oli da gas ovvero di olio combustibile denso con acqua contenuta in misura variabile dal 12 al 15 per cento in peso, idonee all'impiego nella carburazione e nella combustione: 1) emulsione con oli da gas usata come carburante: lire 474.693 per mille litri; 2) emulsione con oli da gas usata come combustibile per riscaldamento: lire 474.693 per mille litri; 3) emulsione con olio combustibile denso usata come combustibile per riscaldamento: 3.1) con olio combustibile ATZ: lire 192.308 per mille chilogrammi; 3.2) con olio combustibile BTZ: lire 57.154 per mille chilogrammi; 4) emulsione con olio combustibile denso per uso industriale: 4.1) con olio combustibile ATZ: lire 80.717 per mille chilogrammi; 4.2) con olio combustibile BTZ: lire 40.359 per mille chilogrammi; (14) (19) ((25))
- e) gas di petrolio liquefatti (GPL): 1) usati come carburante: lire 509.729 per mille chilogrammi; 2) usati come combustibile per riscaldamento: lire 281.125 per mille chilogrammi;
- f) gas metano: 1) per autotrazione: lire 7,11 per metro cubo; 2) per combustione per usi civili: 2.1) per usi domestici di cottura di cibi e produzione di acqua calda di cui alla tariffa T1 prevista dal provvedimento CIP n. 37 del 26 giugno 1986: lire 56,99 per metro cubo; 2.2) per uso riscaldamento individuale a tariffa T2 fino a 250 metri cubi annui: lire 124,62 per metro cubo; 2.3) per altri usi civili: lire 307,51 per metro cubo; 3) per i consumi nei territori di cui all'articolo 1 del testo unico delle leggi sugli interventi nel Mezzogiorno, approvato con decreto del Presidente della Repubblica 6 marzo 1978, n. 218, si applicano le seguenti aliquote: 3.1) per gli usi di cui ai numeri 2.1) e 2.2): lire 46,78 per metro cubo; 3.2) per altri usi civili: lire 212,46 per metro cubo. (6) (10)

2. Il regime agevolato previsto dall'articolo 7, comma 1-ter, del decreto-legge 30 dicembre 1991, n. 417, convertito, con modificazioni, dalla legge 6 febbraio 1992, n. 66, concernente il gasolio destinato al fabbisogno della provincia di Trieste e dei comuni della provincia di Udine gia' individuati dal decreto del Ministro delle finanze 30 luglio 1993, pubblicato nella Gazzetta Ufficiale n. 227 del 27 settembre 1993, e' ripristinato per l'anno 2001. Il quantitativo e' stabilito per la provincia di Trieste in litri 7,2 milioni, mentre per i comuni della provincia di Udine in litri 3,6 milioni. Il costo complessivo e' fissato in lire 8 miliardi.

3. Per il periodo 1 gennaio 2001-30 giugno 2001 il gasolio utilizzato nelle coltivazioni sotto serra e' esente da accisa. Per le modalita' di erogazione del beneficio si applicano le disposizioni di cui all'articolo 2, comma 127, secondo periodo, della legge 23 dicembre 1996, n. 662.

4. L'aliquota normale di riferimento per il gasolio destinato agli impieghi di cui al numero 5 della tabella A allegata al testo unico delle disposizioni legislative concernenti le imposte sulla produzione e consumi, approvato con decreto legislativo 26 ottobre 1995, n. 504 ivi compreso il riscaldamento delle serre, e quella prevista per il gasolio usato come carburante.

5. A decorrere dal 1 gennaio 2001 e fino al 30 giugno 2001, l'accisa sul gas metano, stabilita con il citato testo unico approvato con decreto legislativo 26 ottobre 1995, n. 504, e successive modificazioni, e' ridotta del 40 per cento per gli utilizzatori industriali, termoelettrici esclusi, con consumi superiori a 1.200.000 metri cubi per anno.

------------- AGGIORNAMENTO (6) Il D.L. 30 giugno 2001, n. 246, convertito con modificazioni dalla L. 4 agosto 2001, n. 330, ha disposto (con l'art. 1, comma 2) che "Le aliquote delle accise sui prodotti petroliferi indicati nell'articolo 24, comma 1, della legge 23 dicembre 2000, n. 388, sono prorogate, fino al 30 settembre 2001, nella misura ivi fissata". ------------- AGGIORNAMENTO (10) Il D.L. 1 ottobre 2001, n. 356, convertito con modificazioni dalla L. 30 novembre 2001, n. 418, ha disposto (con l'art. 1, comma 2) che "Le aliquote di accisa sui prodotti petroliferi indicati nell'articolo 24, comma 1, della legge 23 dicembre 2000, n. 388, sono prorogate, fino al 31 ottobre 2001, nelle misure ivi fissate, e le sole aliquote di accisa sulle emulsioni stabilizzate di cui all'articolo 24, comma 1, lettera d), della legge 23 dicembre 2000, n. 388, restano ulteriormente prorogate fino al 31 dicembre 2001". ------------- AGGIORNAMENTO (14) Il D.L. 28 dicembre 2001, n. 452, convertito con modificazioni dalla L. 27 febbraio 2002, n. 16 ha disposto (con l'art. 1, comma 1) che "Le aliquote di accisa sulle emulsioni stabilizzate di cui all'articolo 24, comma 1, lettera d), della legge 23 dicembre 2000, n. 388, sono prorogate fino al 30 giugno 2002". ------------- AGGIORNAMENTO (19) Il D.L. 8 luglio 2002, n. 138, convertito con modificazioni dalla L. 8 agosto 2002, n. 178, ha disposto (con l'art. 1, comma 1) che le disposizioni in materia di aliquote di accisa sulle emulsioni stabilizzate, di cui all'articolo 24, comma 1, lettera d) sono ulteriormente prorogate dal 1 luglio 2002 fino al 31 dicembre 2002. ------------- AGGIORNAMENTO (25) La L. 27 dicembre 2002, n. 289 ha disposto (con l'art. 21, comma 1) che le disposizioni in materia di riduzione di aliquote di accisa sulle emulsioni stabilizzate, di cui all'articolo 24, comma 1, lettera d), della legge 23 dicembre 2000, n. 388 sono ulteriormente prorogate fino al 30 giugno 2003.

### Art. 25. - (Agevolazioni sul gasolio per autotrazione impiegato dagli autotrasportatori)

1. A decorrere dal 1° gennaio 2001, e fino al 30 giugno 2001, l'aliquota prevista nell'allegato I annesso al testo unico delle disposizioni legislative concernenti le imposte sulla produzione e sui consumi, approvato con decreto legislativo 26 ottobre 1995, n. 504, e successive modificazioni, per il gasolio per autotrazione utilizzato dagli esercenti le attivita' di trasporto merci con veicoli di massa massima complessiva superiore a 3,5 tonnellate e' ridotta della misura determinata con riferimento al 31 dicembre 2000.((14))

2. La riduzione prevista al comma 1 si applica altresi' ai seguenti soggetti:

- a) agli enti pubblici ed alle imprese pubbliche locali esercenti l'attivita' di trasporto di cui al decreto legislativo 19 novembre 1997, n. 422, e relative leggi regionali di attuazione;
- b) alle imprese esercenti autoservizi di competenza statale, regionale e locale di cui alla legge 28 settembre 1939, n. 1822,. al regolamento (CEE) n. 684/92 del Consiglio del 16 marzo 1992, e successive modificazioni, e al decreto legislativo 19 novembre 1997, n. 422;
- c) agli enti pubblici e alle imprese esercenti trasporti a fune in servizio pubblico per trasporto di persone.

3. Con decreto del Ministro dell'economia e delle finanze, da pubblicare nella Gazzetta Ufficiale entro il 10 ottobre 2001, e' eventualmente rideterminata, per il periodo dal 1 gennaio 2001 al 30 giugno 2001, la riduzione di cui al comma 1, al fine di compensare la variazione del prezzo di vendita al consumo del gasolio per autotrazione, rilevato settimanalmente dal Ministero delle attivita' produttive, purche' lo scostamento del medesimo prezzo che risulti alla fine del semestre, rispetto al prezzo rilevato nella prima settimana di gennaio 2001, superi mediamente il 10 per cento in piu' o in meno dell'ammontare di tale riduzione. Con il medesimo decreto vengono altresi' stabilite le modalita' per la regolazione contabile dei crediti di imposta.

4. Per ottenere il rimborso di quanto spettante, anche mediante la compensazione di cui all'articolo 17 del decreto legislativo 9 luglio 1997, n. 241, e successive modificazioni i destinatari del beneficio di cui ai commi 1 e 2 presentano, entro il termine del 31 ottobre 2001, apposita dichiarazione ai competenti uffici dell'Agenzia delle dogane, secondo le modalita' e con gli effetti previsti dal regolamento di cui all'articolo 3, comma 13, della legge 23 dicembre 1998, n. 448, e successive modificazioni. E' consentito ai medesimi destinatari di presentare dichiarazione relativa ai commi effettuati nel primo trimestre dell'anno 2001; in tal caso, nella successiva dichiarazione, oltre agli elementi richiesti, sara' indicato l'importo residuo spettante, determinato anche in attuazione delle disposizioni stabilite con il decreto di cui al comma 3.

--------------- AGGIORNAMENTO (14) Il Decreto 9 ottobre 2001 (in G.U. 12/10/2001, n.238) ha disposto (con l'art. 1, comma 1) che "Per il periodo dal 1 gennaio al 30 giugno 2001, l'importo della riduzione di accisa di cui all'art. 25, comma 1, della legge 23 dicembre 2000, n. 388, come modificato dall'art. 8, comma 1, del decreto-legge 1 ottobre 2001, n. 356, e' stabilita in lire 112.000 per mille litri di gasolio".

### Art. 26. - (Soggetti obbligati nel settore dell'accisa sul gas metano)

1. I commi 4 e 5 dell'articolo 26 del testo unico delle disposizioni legislative concernenti le imposte sulla produzione e sui consumi, approvato con decreto legislativo 26 ottobre 1995, n. 504, sono sostituiti dai seguenti: "4. L'accisa e' dovuta, secondo le modalita' previste dal comma 8, dai soggetti che vendono direttamente il prodotto ai consumatori o dai soggetti consumatori che si avvalgono delle reti di gasdotti per il vettoriamento di prodotto proprio. Sono considerati consumatori anche gli esercenti i distributori stradali di gas metano per autotrazione che non abbiano, presso l'impianto di distribuzione, impianti di compressione per il riempimento di carri bombolai. Possono essere riconosciuti soggetti obbligati al pagamento dell'accisa i titolari di raffinerie, di impianti petrolchimici e di impianti di produzione combinata di energia elettrica e di calore. 5. Sono gestiti in regime di depositi fiscali: a) l'impianto utilizzato per le operazioni di liquefazione del gas naturale, o di scarico, stoccaggio e rigassificazione di GNL; b) l'impianto utilizzato per lo stoccaggio di gas naturale di proprieta' o gestito da un'impresa di gas naturale; l'insieme di piu' concessioni di stoccaggio relative ad impianti ubicati nel territorio nazionale e facenti capo ad un solo titolare possono costituire, anche ai fini fiscali, un unico doposito fiscale; c) il terminale di trattamento ed il terminale costiero con le rispettive pertinenze; d) le reti nazionali di gasdotti e le reti di distribuzioni locali, comprese le reti interconnesse; e) gli impianti di compressione".

2. Dopo il comma 8 dell'articolo 26 del citato testo unico approvato con decreto legislativo 26 ottobre 1995, n. 504, e' aggiunto il seguente: "8-bis. I depositari autorizzati e tutti i soggetti che cedono gas metano sono obbligati alla dichiarazione annuale anche quando non sorge il debito di imposta".

### Art. 27. - (Agevolazioni sul gasolio e sul GPL impiegati nelle zone montane ed in altri specifici territori nazionali)

1. Per il periodo 1 gennaio - 30 giugno 2001, l'ammontare della riduzione minima di costo prevista dall'articolo 8, comma 10, lettera c), della legge 23 dicembre 1998, n. 448, come modificato dal comma 4 dell'articolo 12 della legge 23 dicembre 1999, n. 488, e successive modificazioni, e' aumentato di lire 50 per litro di gasolio usato come combustibile per riscaldamento e di lire 50 per chilogrammo di gas di petrolio liquefatto.

2. Le agevolazioni per il gasolio e per il gas di petrolio liquefatto usati come combustibili per riscaldamento in particolari zone geografiche, di cui alla lettera c) del comma 10 dell'articolo 8 della legge 23 dicembre 1998, n. 448, come sostituita dall'articolo 12, comma 4, della legge 23 dicembre 1999, n. 488, sono concesse, fino alla data di entrata in vigore di un successivo regolamento da emanare ai sensi dell'articolo 8, comma 13, della citata legge n. 448 del 998, secondo le procedure di cui al decreto del Presidente della Repubblica 30 settembre 1999, n. 361, in quanto applicabili, e secondo le istruzioni fornite con decreto dirigenziale del Ministero delle finanze.

3. All'articolo 4, comma 2, primo periodo, del decreto-legge 30 settembre 2000, n. 268, convertito, con modificazioni, dalla legge 23 novembre 2000, n. 354, dopo le parole: "n. 412," sono inserite le seguenti: "ubicate, a qualsiasi quota, al di fuori del centro abitato ove ha sede la casa comunale".

4. Per gli anni 2001 e 2002, per i consumi di gas metano per combustione per usi civili nelle province nelle quali oltre il 70 per cento dei comuni ricade nella zona climatica F di cui alla lettera c) del comma 10 dell'articolo 8 della citata legge n. 448 del 1998, si applicano le seguenti aliquote:

- a) per uso riscaldamento individuale a tariffe T2 fino a 250 metri cubi annui: lire 78,79 per metro cubo;
- b) per altri usi civili: lire 261,68 per metro cubo. (25) ((29))

5. Per il periodo dal 1 gennaio al 30 giugno 2001, l'ammontare della agevolazione fiscale con credito d'imposta prevista dall'articolo 8, comma 10, lettera f), della legge 23 dicembre 1998, n. 448, e successive modificazioni, e' aumentata di lire 30 per ogni chilovattora (Kwh) di calore fornito, per un onere complessivo pari a lire 8 miliardi.

------------- AGGIORNAMENTO (25) La L. 27 dicembre 2002, n. 289 ha disposto (con l'art. 21, comma 5) che "Le disposizioni in materia di aliquote di accisa sul gas metano per combustione per usi civili, di cui all'articolo 27, comma 4, della legge 23 dicembre 2000, n. 388, sono prorogate al 30 giugno 2003". ------------- AGGIORNAMENTO (29) Il D.L. 30 settembre 2003, n. 269, convertito con modificazioni dalla L. 24 novembre 2003, n. 326, ha disposto (con l'art. 25, comma 1) che "Le disposizioni in materia di aliquote di accisa sul gas metano per combustione per usi civili, di cui all'articolo 27, comma 4, della legge 23 dicembre 2000, n. 388, si applicano dalla data di entrata in vigore del presente decreto al 31 dicembre 2004".

### Art. 28. - (Razionalizzazione delle imposte e norme in materia di energia elettrica)

1. L'addizionale erariale di cui all'articolo 4 del decreto-legge 30 settembre 1989, n. 332, convertito, con modificazioni, dalla legge 27 novembre 1989, n. 384, come da ultimo modificato dall'articolo 10, comma 5, della legge 13 maggio 1999, n. 133, e' soppressa e il predetto articolo 4 e' abrogato.

2. Al testo unico delle disposizioni legislative concernenti le imposte sulla produzione e sui consumi, approvato con decreto legislativo 26 ottobre 1995, n. 504, e successive modificazioni, sono apportate le seguenti modifiche:

- a) all'articolo 3, comma 4, le parole: "entro il giorno 15" sono sostituite dalle seguenti: "entro il giorno 16";
- b) all'articolo 52, comma 2, e' aggiunta, in fine, la seguente lettera: "o-bis) utilizzata in opifici industriali aventi un consumo mensile superiore a 1.200.000 kWh, per i mesi nei quali tale consumo si e' verificato. Ai fini della fruizione dell'agevolazione gli autoproduttori dovranno trasmettere all'ufficio tecnico di finanza, competente per territorio, entro il 20 di ogni mese, i dati relativi al consumo del mese precedente";
- c) all'articolo 52, comma 3, e' aggiunta, in fine, la seguente lettera: "e-ter) impiegata come materia prima nei processi industriali elettrochimici, elettrometallurgici ed elettrosiderurgici";
- d) all'articolo 53, comma 2, e' aggiunta, in fine, la seguente lettera: "b-bis) che l'acquistano da due o piu' fornitori";
- e) all'articolo 56, comma 2, primo e secondo periodo, il numero "20" e' sostituito dal numero "16";
- f) la lettera b) del comma 3 dell'articolo 63 e' sostituita dalla seguente: "b) officine di produzione, cabine e punti di presa a scopo commerciale: lire 150.000";
- g) all'articolo 63, comma 4, le parole: "dal 1° al 15" sono sostituite dalle seguenti: "dal 1° al 16";
- h) all'allegato I le parole: "lire 4,10 fino a 200.000 kWh di consumo al mese e lire 2,45 per l'ulteriore consumo mensile" sono sostituite dalle seguenti: "lire 6 al kWh".

3. All'imposta erariale di consumo di cui all'articolo 52 del citato testo unico approvato con decreto legislativo 26 ottobre 1995, n. 504, e successive modificazioni, sono estese tutte le agevolazioni previste, fino alla data di entrata in vigore della presente legge, per l'addizionale erariale sull'energia elettrica.

4. L'articolo 4 del decreto-legge 28 giugno 1995, n. 250, convertito, con modificazioni, dalla legge 8 agosto 1995, n. 349, e' abrogato.

5. I clienti grossisti di cui al decreto legislativo" 16 marzo 1999, n. 79, non sono tenuti alla corresponsione del diritto di licenza. 6. Per i tributi previsti dal citato testo unico approvato con decreto legislativo 26 ottobre 1995, n. 504, e successive modificazioni, per la tassa sulle emissioni di anidride solforosa e di ossidi di azoto di cui all'articolo 17, comma 29, della legge 27 dicembre 1997, n. 449, nonche' per l'imposta di consumo sul carbone, coke di petrolio e sull'orimulsion di cui all'articolo 8, comma 7, della legge 23 dicembre 1998, n. 448, i versamenti per i quali la scadenza e' prevista il 31 dicembre dovranno essere effettuati entro il giorno 27 dello stesso mese. 7. A decorrere dal 1° marzo 2001 i pagamenti delle somme di cui alle lettere a), e) e g) del comma 2, nonche' di cui al comma 6 possono essere effettuati, limitatamente a quelle che affluiscono ai capitoli di bilancio dello Stato e alla contabilita' speciale ai sensi dell'articolo 3, comma 12, della legge 28 dicembre 1995, n. 549, anche mediante il versamento unitario previsto dall'articolo 17 del decreto legislativo 9 luglio 1997, n. 241, con possibilita' di compensazione con altre imposte e contributi. 8. La potenza nominale media di cui al comma 4 dell'articolo 28 della legge 30 aprile 1999, n. 136, deve essere ((calcolata annualmente quale rapporto fra il consumo da pompaggio di ciascun impianto nell'anno precedente, come risultante dai contatori di assorbimento, e il numero convenzionale di 2.850 ore medie di funzionamento annuo per tale tipologia di impianti. La metodologia di calcolo di cui al presente comma decorre dal 1° gennaio 2004)). 9. ((COMMA ABROGATO DAL D.L. 29 AGOSTO 2003, N. 239, CONVERTITO CON MODIFICAZIONI DALLA L. 27 OTTOBRE 2003, N. 290)). 10. ((COMMA ABROGATO DAL D.L. 29 AGOSTO 2003, N. 239, CONVERTITO CON MODIFICAZIONI DALLA L. 27 OTTOBRE 2003, N. 290)). 11. All'articolo 11, comma 2, del decreto legislativo 16 marzo 1999, n. 79, dopo le parole: "eccedenti i 100 GWh" sono inserite le seguenti: ", nonche' al netto dell'energia elettrica prodotta da impianti di gassificazione che utilizzino anche carbone di origine nazionale, l'uso della quale fonte e' altresi' esentato dall'imposta di consumo e dall'accisa di cui all'articolo 8 della legge 23 dicembre 1998, n. 448".

### Art. 29. - (Norme in materia di energia geotermica)

1. Al fine di sviluppare l'utilizzazione dell'energia geotermica quale fonte di energia rinnovabile, ferme restando le agevolazioni previste dalla normativa vigente, dal 1° gennaio 2001, agli utenti che si collegano ad una rete di teleriscaldamento alimentata da tale energia, e' concesso un contributo pari a lire 40.000 per ogni kW di potenza impegnata. Il contributo e' trasferito all'utente finale sotto forma di credito d'imposta a favore del soggetto nei cui confronti e' dovuto il costo di allaccio alla rete.

2. Agli utenti che si collegano a reti di teleriscaldamento alimentate da biomassa devono intendersi applicabili le stesse agevolazioni previste per l'utilizzazione di energia geotermica, secondo analoghe modalita'.

## DISPOSIZIONI DI ADEGUAMENTO ALL'ORDINAMENTO COMUNITARIO

### Art. 30. - (Disposizioni in materia di imposta sul valore aggiunto)

1. Al decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, sono apportate le seguenti modificazioni:

- a) all'articolo 10, relativo alle operazioni esenti dall'imposta, nel primo comma, il numero 6) e' sostituito dal seguente: "6) le operazioni relative all'esercizio del lotto, delle lotterie nazionali, dei giochi di abilita' e dei concorsi pronostici riservati allo Stato e agli enti indicati nel decreto legislativo 14 aprile 1948, n. 496, ratificato con legge 22 aprile 1953, n. 342, e successive modificazioni, nonche' quelle relative all'esercizio dei totalizzatori e delle scommesse di cui al regolamento approvato con decreto del Ministro per l'agricoltura e per le foreste 16 novembre 1955, pubblicato nella Gazzetta Ufficiale n. 273 del 26 novembre 1955, e alla legge 24 marzo 1942, n. 315, e successive modificazioni, ivi comprese le operazioni relative alla raccolta delle giocate";
- b) all'articolo 10, relativo alle operazioni esenti, dopo il numero 27-quinquies), e' aggiunto il seguente: "27-sexies) le importazioni nei porti effettuate dalle imprese di pesca marittima, dei prodotti della pesca allo stato naturale o dopo operazioni di conservazione ai fini della commercializzazione, ma prima di qualsiasi consegna";
- c) all'articolo 74, e' abrogato il settimo comma, concernente il regime speciale IVA applicabile ai giochi di abilita' ed ai concorsi pronostici.

2. Al decreto legislativo 23 dicembre 1998, n. 504, concernente il riordino dell'imposta unica sui concorsi pronostici e sulle scommesse, l'articolo 7 e' sostituito dal seguente: "Art. 7 - (Rapporto tra imposta unica e altri tributi) - 1. L'imposta unica e' sostitutiva, nei confronti del CONI e dell'UNIRE, di ogni imposta e tributo erariale e locale relativi all'esercizio dei concorsi pronostici ad esclusione dell'imposta di bollo sulle cambiali, sugli atti giudiziari e sugli avvisi al pubblico".

3. All'alinea del comma 1 dell'articolo 7 della legge 23 dicembre 1999, n. 488, concernente le prestazioni assoggettate ad aliquota del 10 per cento, le parole: "fino alla data del 31 dicembre 2000" sono sostituite dalle seguenti: "fino alla data del 31 dicembre 2001".

4. L'indetraibilita' dell'imposta sul valore aggiunto afferente le operazioni aventi per oggetto ciclomotori, motocicli, autovetture e autoveicoli di cui alla lettera c) del comma 1 dell'articolo 19-bis1 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, e' stabilita sino al ((31 dicembre 2006)); tuttavia limitatamente all'acquisto, all'importazione e all'acquisizione mediante contratti di locazione finanziaria, noleggio e simili di detti veicoli la indetraibilita' e' ridotta ((all' 85 per cento)) del relativo ammontare ed al 50 per cento nel caso di veicoli con propulsori non a combustione interna.

5. Per le cessioni dei veicoli per i quali l'imposta sul valore aggiunto e' stata detratta dal cedente solo in parte a norma del comma 4, la base imponibile e' assunta per il ((15 per cento)) ovvero per il 50 per cento del relative ammontare nel caso di veicoli con propulsioni non a combustione interna.

6. Il regime speciale previsto, per i rivenditori di beni usati, negli articoli 36 e seguenti del decreto-legge 23 febbraio 1995, n. 41, convertito, con modificazioni, dalla legge 22 marzo 1995, n. 85, si applica anche alle cessioni dei veicoli per l'acquisto dei quali ha trovato applicazione la disposizione di cui al comma 5 del presente articolo.

7. Le agevolazioni di cui all'articolo 8 della legge 27 dicembre 1997, n. 449, sono estese ai soggetti con handicap psichico o mentale di gravita' tale da aver determinato il riconoscimento dell'indennita' di accompagnamento e agli invalidi con grave limitazione della capacita' di deambulazione o affetti da pluriamputazioni, a prescindere dall'adattamento del veicolo.

8. Il Ministro del tesoro, del bilancio e della programmazione economica e' autorizzato ad iscrivere nello stato di previsione del Ministero per i beni e le attivita' culturali un importo pari al maggior gettito acquisito per effetto delle disposizioni del comma 2.

## DISPOSIZIONI IN MATERIA DI IMPOSTA SUL VALORE AGGIUNTO E ALTRE IMPOSTE INDIRETTE

### Art. 31. - (Ulteriori disposizioni in materia di imposta sul valore aggiunto)

1. Al decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, sono apportate le seguenti modificazioni:

- a) all'articolo 19-bis 1, comma 1, concernente limiti alla detrazione per alcuni beni e servizi: 1) alla lettera g), dopo le parole: "50 per cento;", sono aggiunte le seguenti: "la predetta limitazione non si applica agli impianti di telefonia fissa installati all'interno dei veicoli utilizzati per il trasporto di merci da parte delle imprese di autotrasporto"; 2) alla lettera h), sono aggiunte, in fine, le parole: ", tranne quelle sostenute per l'acquisto di beni di costo unitario non superiore a lire cinquantamila";
- b) all'articolo 74, nono comma, concernente disposizioni relative a particolari settori, dopo la lettera e-bis) sono aggiunte le seguenti: "e-ter) filo di rame con diametro superiore a 6 millimetri (vergella) (v.d. 7408.11); e-quater) filo di alluminio non legato con diametro superiore a 7 millimetri (vergella) (v.d. 7605.11); e-quinquies) filo di leghe di alluminio con diametro superiore a 7 millimetri (vergella) (v.d. 7605.21)";
- c) all'articolo 74-bis e' aggiunto, in fine, il seguente comma: "In deroga a quanto disposto dal primo comma dell'articolo 38-bis, i rimborsi previsti nell'articolo 30, non ancora liquidati alla data della dichiarazione di fallimento o di liquidazione coatta amministrativa e i rimborsi successivi, sono eseguiti senza la prestazione delle prescritte garanzie per un ammontare non superiore a lire cinquecento milioni";
- d) alla tabella A, parte II, relativa a beni e servizi soggetti all'aliquota del 4 per cento: 1) al numero 18), dopo le parole: "dispacci delle agenzie di stampa, libri, periodici," sono inserite le seguenti: "anche in scrittura braille e su supporti audio-magnetici per non vedenti e ipovedenti,"; 2) al numero 35), dopo le parole: "prestazioni relative. alla composizione," sono inserite le seguenti: "montaggio, duplicazione,"; e dopo le parole: "legatori e stampa" sono inserite le seguenti: ", anche in scrittura braille e su supporti audio-magnetici per non vedenti e ipovedenti,".

2. All'articolo 11 del decreto legislativo 2 settembre 1997, n. 313, concernente il regime speciale per i produttori agricoli, come modificato dal decreto-legge 15 febbraio 2000, n. 21, convertito dalla legge 14 aprile 2000, n. 92, sono apportate le seguenti modificazioni:

- a) al comma 5, le parole: "Per gli anni 1998, 1999 e 2000" sono sostituite dalle seguenti: "Per gli anni 1998, 1999, 2000 e 2001" e le parole: "negli anni 1998, 1999 e 2000" sono sostituite dalle seguenti: "negli anni 1998, 1999, 2000 e 2001";
- b) al comma 5-bis, le parole: "a decorrere dal 1° gennaio 2001" sono sostituite dalle seguenti: "a decorrere dal 1° gennaio 2002".

3. Per i soggetti che esercitano l'opzione di cui al comma 1 dell'articolo 7 del decreto del Presidente della Repubblica 14 ottobre 1999, n. 542, le somme da versare ai fini dell'imposta sul valore aggiunto sono maggiorate degli interessi nella misura dell'1 per cento, previa apposita annotazione nei registri di cui agli articoli 23 e 24 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633. La predetta misura puo' essere rideterminata con regolamento da emanare ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400.

4. L'articolo 45 della legge 21 novembre 2000, n. 342, concernente il regime speciale per gli esercenti agenzie di vendite all'asta, previsto ai fini dell'applicazione dell'imposta sul valore aggiunto, si applica a decorrere dal 1° gennaio 2001.

### Art. 32. - (Semplificazione degli adempimenti fiscali per le societa' sportive dilettantistiche)

1. All'articolo 18 del decreto legislativo 26 febbraio 1999, n. 60, e' aggiunto, in fine, il seguente comma: "2-bis. Con regolamento da emanare entro centottanta giorni dalla data di entrata in vigore della presente disposizione, ai sensi dell'articolo 3, comma 136, della legge 23 dicembre 1996, n. 662, sono dettate modalita' semplificate di certificazione dei corrispettivi per le societa' sportive dilettantistiche".

### Art. 33. - (Disposizioni in materia di imposta di registro e altre imposte indirette e disposizioni agevolative)

1. All'articolo 8 della tariffa, parte I, allegata al testo unico delle disposizioni concernenti l'imposta di registro, approvato con decreto del Presidente della Repubblica 26 aprile 1986, n. 131, relativo agli atti dell'autorita' giudiziaria soggetti a registrazione in termine fisso, sono apportate le seguenti modificazioni:

- a) dopo il comma 1 e' aggiunto il seguente: "1-bis. Atti del Consiglio di Stato e dei tribunali amministrativi regionali che definiscono, anche parzialmente, il giudizio, compresi i decreti ingiuntivi esecutivi, che recano condanna al pagamento di somme di danaro diverse dalle spese processuali: 3 per cento";
- b) nella nota II) le parole: "Gli atti di cui alla lettera b)" sono sostituite dalle seguenti: "Gli atti di cui al comma 1, lettera b), e al comma 1 -bis".

2. Le disposizioni del comma 1 si applicano a decorrere dal 1 marzo 2001.

3. ((COMMA ABROGATO DAL D.L. 4 LUGLIO 2006, N. 223, CONVERTITO CON MODIFICAZIONI DALLA L. 4 AGOSTO 2006, N. 248)). ((48))

4. Alla Tabella di cui all'allegato B del decreto del Presidente della Repubblica 26 ottobre 1972, n. 642, e successive modificazioni, recante gli atti, documenti e registri esenti dall'imposta di bollo sono apportate le seguenti modificazioni:

- a) all'articolo 7, primo comma, le parole: "ricevute ed altri documenti relativi a conti correnti postali" sono sostituite dalle seguenti: "ricevute, quietanze ed altri documenti recanti addebitamenti o accreditamenti formati, emessi ovvero ricevuti dalle banche nonche' dagli uffici della societa' Poste Italiane SPA";
- b) dopo l'articolo 8 e' inserito il seguente: "Art. 8-bis. Certificati anagrafici richiesti dalle societa' sportive, su disposizione delle rispettive federazioni e di enti ed associazioni di promozione sportiva di appartenenza";
- c) dopo l'articolo 13 e' inserito il seguente: "Art. 13-bis. Contrassegno invalidi, rilasciato ai sensi dell'articolo 381 del regolamento di esecuzione del nuovo codice della strada, approvato con decreto del Presidente della Repubblica 16 dicembre 1992, n. 495, a soggetti la cui invalidita' comporta ridotte o impedite capacita' motorie permanenti".

5. All'articolo 25 della legge 13 maggio 1999, n. 133, come modificato dall'articolo 37 della legge 21 novembre 2000, n. 342, dopo il comma 1 e' inserito il seguente: "1-bis. Le disposizioni di cui al comma 2 si applicano anche alle associazioni proloco".

6. A decorrere dal 1 gennaio 2001 la Croce Rossa Italiana e' esonerata dal pagamento del canone radio complessivamente dovuto per tutte le attivita' assistenziali, di protezione civile e di soccorso sanitario. Per la Croce Rossa Italiana sono altresi' autorizzati i collegamenti esercitati alla data del 31 dicembre 2000, che non risultino incompatibili con impianti di telecomunicazione esistenti appartenenti ad organi dello Stato o ad altri soggetti autorizzati.

7. COMMA ABROGATO DAL D.P.R. 30 MAGGIO 2002, N. 115.

8. Il comma 10 dell'articolo 9 della legge 23 dicembre 1999, n. 488, e' abrogato.

9. COMMA ABROGATO DAL D.P.R. 30 MAGGIO 2002, N. 115.

10. Sono esenti dall'imposta di cui all'articolo 3 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 643, con effetto dalla data della sua entrata in vigore, gli immobili appartenenti agli enti rappresentativi delle confessioni religiose aventi personalita' giuridica, nonche' agli enti religiosi riconosciuti in base alle leggi attuative delle intese stipulate dallo Stato ai sensi dell'articolo 8 della Costituzione. Non si fa comunque luogo a rimborsi di versamenti gia' effettuati.

11. All'articolo 56, comma 6, del decreto legislativo 15 dicembre 1997, n. 446, e successive modificazioni, e' aggiunto, in fine, il seguente periodo: "In caso di fusione tra societa' esercenti attivita' di locazione di veicoli senza conducente, le iscrizioni e le trascrizioni gia' esistenti al pubblico registro automobilistico relative ai veicoli compresi nell'atto di fusione conservano la loro validita' ed il loro grado a favore del cessionario, senza bisogno di alcuna formalita' o annotazione".

12. Alla lettera a) del comma 1 della nota II-bis all'articolo, 1 della tariffa, parte I, allegata al testo unico delle disposizioni concernenti l'imposta di registro, approvato con decreto del Presidente della Repubblica 26 aprile 1986, n. 131, e successive modificazioni, le parole: "entro un anno dall'acquisto" sono sostituite dalle seguenti: "entro diciotto mesi dall'acquisto".

13. All'articolo 6 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 640, come sostituito dal decreto legislativo 26 febbraio 1999, n. 60, dopo il comma 3 e' aggiunto il seguente: "3-bis. I soggetti che hanno optato ai sensi della legge 16 dicembre 1991, n. 398, nonche' le associazioni di promozione sociale di cui all'articolo 5 del decreto legislativo 4 dicembre 1997, n. 460, per le attivita' di intrattenimento a favore dei soci sono esonerati dall'obbligo di utilizzare i misuratori fiscali di cui al presente articolo".

------------- AGGIORNAMENTO (48) Il D.L. 4 luglio 2006, n. 223, convertito con modificazioni dalla L. 4 agosto 2006, n. 248, ha disposto (con l'art. 36, comma 15) l'abrogazione del comma 3 del presente articolo, "ad eccezione che per i trasferimenti di immobili in piani urbanistici particolareggiati, diretti all'attuazione dei programmi prevalentemente di edilizia residenziale convenzionata pubblica, comunque denominati, realizzati in accordo con le amministrazioni comunali per la definizione dei prezzi di cessione e dei canoni di locazione. Il periodo precedente ha effetto per gli atti pubblici formati e le scritture private autenticate a decorrere dalla data di entrata in vigore del presente decreto".

## DISPOSIZIONI IN MATERIA DI RISCOSSIONE E DI GIOCHI E ALTRE DISPOSIZIONI FISCALI

### Art. 34. - (Disposizioni in materia di compensazione e versamenti diretti)

1. A decorrere dal 1° gennaio 2001 il limite massimo dei crediti di imposta e dei contributi compensabili ai sensi dell'articolo 17 del decreto legislativo 9 luglio 1997, n. 241, ovvero rimborsabili ai soggetti intestatari di conto fiscale, e' fissato in lire 1 miliardo per ciascun anno solare. Tenendo conto delle esigenze di bilancio, con decreto del Ministro dell'economia e delle finanze, il limite di cui al periodo precedente puo' essere elevato, a decorrere dal 1° gennaio 2010, fino a 700.000 euro. (48) (79) (100) (102) ((104))

2. Le domande di rimborso presentate al 31 dicembre 2000 non possono essere revocate.

3. All'articolo 3, secondo comma, del decreto del Presidente della Repubblica 29 settembre 1973, n. 602, e' aggiunta, in fine, la seguente lettera: "h-bis) le ritenute operate dagli enti pubblici di cui alle tabelle A e B allegate alla legge 29 ottobre 1984, n. 720".

4. Se le ritenute o le imposte sostitutive sui redditi di capitale e sui redditi diversi di natura finanziaria, non sono state operate ovvero non sono stati effettuati dai sostituti d'imposta o dagli intermediari i relativi versamenti nei termini ivi previsti, si fa luogo in ogni caso esclusivamente all'applicazione della sanzione nella misura ridotta indicata nell'articolo 13, comma 1, lettera a), del decreto legislativo 18 dicembre 1997, n. 472, qualora gli stessi sostituti o intermediari, anteriormente alla presentazione della dichiarazione nella quale sono esposti i versamenti delle predette ritenute e imposte, abbiano eseguito il versamento dell'importo dovuto, maggiorato degli interessi legali. La presente disposizione si applica se la violazione non e' stata gia' constatata e comunque non sono iniziati accessi, ispezioni, verifiche o altre attivita' di accertamento delle quali il sostituto d'imposta o l'intermediario hanno avuto formale conoscenza e sempre che il pagamento della sanzione sia contestuale al versamento dell'imposta.

5. All'articolo 37, primo comma, del decreto del Presidente della Repubblica 29 settembre 1973, n. 602, le parole: "entro il termine previsto dall'articolo 2946 del codice civile" sono sostituite dalle seguenti: "entro il termine di decadenza di quarantotto mesi".

6. All'articolo 38, secondo comma, del decreto del Presidente della Repubblica 29 settembre 1973, n. 602, le parole: "di diciotto mesi" sono sostituite dalle seguenti: "di quarantotto mesi".

--------------- AGGIORNAMENTO (48) Il D.L. 4 luglio 2006, n. 223, convertito con modificazioni dalla L. 4 agosto 2006, n. 248, ha disposto (con l'art. 35, comma 6-ter) che "Per i soggetti subappaltatori ai quali si applica l'articolo 17, sesto comma, del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, resta ferma la possibilita' di effettuare la compensazione infrannuale ai sensi dell'articolo 8, comma 3, del regolamento di cui al decreto del Presidente della Repubblica 14 ottobre 1999, n. 542, e successive modificazioni. Qualora il volume di affari registrato dai predetti soggetti nell'anno precedente sia costituito per almeno l'80 per cento da prestazioni rese in esecuzione di contratti di subappalto, il limite di cui all'articolo 34, comma 1, della legge 23 dicembre 2000, n. 388, e' elevato a 1.000.000 di euro". --------------- AGGIORNAMENTO (79) Il D.L. 8 aprile 2013, n. 35, convertito con modificazioni dalla L. 6 giugno 2013, n. 64 ha disposto (con l'art. 9, comma 2) che "A decorrere dall'anno 2014, il limite di 516.000 euro previsto dall'articolo 34, comma 1, della legge 23 dicembre 2000, n. 388 e' aumentato a 700.000 euro". --------------- AGGIORNAMENTO (100) Il D.L. 19 maggio 2020, n. 34 ha disposto (con l'art. 147, comma 1) che "Per l'anno 2020, il limite previsto dall'articolo 34, comma 1, primo periodo, della legge 23 dicembre 2000, n. 388 e' elevato a 1 milione di euro". --------------- AGGIORNAMENTO (102) Il D.L. 25 maggio 2021, n. 73, ha disposto (con l'art. 22, comma 1) che "Per l'anno 2021, il limite previsto dall'articolo 34, comma 1, primo periodo, della legge 23 dicembre 2000, n. 388, e' elevato a 2 milioni di euro". --------------- AGGIORNAMENTO (104) La L. 30 dicembre 2021, n. 234 ha disposto (con l'art. 1, comma 72) che "A decorrere dal 1° gennaio 2022, il limite previsto dall'articolo 34, comma 1, primo periodo, della legge 23 dicembre 2000, n. 388, e' elevato a 2 milioni di euro".

### Art. 35. - (Regime fiscale di proventi spettanti a istituzioni o a soggetti stranieri e internazionali)

1. All'articolo 6, comma 1, ultimo periodo, del decreto legislativo 1° aprile 1996, n. 239, riguardante il regime fiscale degli interessi, premi ed altri frutti delle obbligazioni e titoli similari, pubblici e privati, e successive modificazioni, sono aggiunte, in fine, le seguenti parole: "nonche' quelli percepiti, anche in relazione all'investimento delle riserve ufficiali dello Stato, dalle Banche centrali di Paesi che non hanno stipulato con la Repubblica italiana convenzioni per evitare la doppia imposizione sul reddito, purche' tali Paesi non siano comunque inclusi nella lista di cui al decreto del Ministro delle finanze emanato in attuazione dell'articolo 76, comma 7-bis, del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e successive modificazioni".

2. All'articolo 8 del citato decreto legislativo 1° aprile 1996, n. 239, e successive modificazioni, e' aggiunto, in fine, il seguente comma: "3-ter. Le disposizioni del presente articolo e quelle dell'articolo 7 non si applicano altresi' ai proventi non soggetti ad imposizione in forza dell'articolo 6 quando essi sono percepiti da enti e organismi internazionali costituiti in base ad accordi internazionali resi esecutivi in Italia, o da Banche centrali estere, anche in relazione all'investimento delle riserve ufficiali dello Stato".

### Art. 36. - (Modalita' di riscossione dei tributi da parte di regioni ed enti locali)

1. Ferma restando l'eventuale utilizzazione di intermediari previsti da norme di legge o di regolamento, le regioni, le province, i comuni e gli altri enti locali possono prevedere la riscossione spontanea dei propri tributi secondo modalita' che, velocizzando le fasi di acquisizione delle somme riscosse, assicurino la piu' ampia diffusione dei canali di pagamento e la sollecita trasmissione all'ente creditore dei dati del pagamento stesso.

### Art. 37. - (Modifiche al testo unico delle leggi di pubblica sicurezza)

1. All'articolo 17-bis, comma 3, del testo unico delle leggi di pubblica sicurezza, approvato con regio decreto 18 giugno 1931, n. 773, e successive modificazioni, le parole: "escluse le attivita' previste all'articolo 126," sono soppresse.

2. All'articolo 86 del testo unico delle leggi di pubblica sicurezza, approvato con regio decreto 18 giugno 1931, n. 773, e successive modificazioni dopo il secondo comma, e' aggiunto il seguente: "La licenza e' altresi' necessaria per l'attivita' di distribuzione di apparecchi e congegni automatici, semiautomatici ed elettronici di cui al quinto comma dell'articolo 110, e di gestione, anche indiretta, dei medesimi apparecchi per i giochi consentiti. La licenza per l'esercizio di sale pubbliche da gioco in cui sono installati apparecchi o congegni automatici, semiautomatici ed elettronici da gioco di cui al presente comma e la licenza per lo svolgimento delle attivita' di distribuzione o di gestione, anche indiretta, di tali apparecchi, sono rilasciate previo nulla osta dell'Amministrazione finanziaria, necessario comunque anche per l'installazione degli stessi nei circoli privati".

3. All'articolo 110 del testo unico delle leggi di pubblica sicurezza, approvato con regio decreto 18 giugno 1931, n. 773, e successive modificazioni, sono apportate le seguenti modificazioni:

- a) il primo comma e' sostituito dal seguente: "In tutte le sale da biliardo o da gioco e negli altri esercizi, compresi i circoli privati, autorizzati a praticare il gioco o ad installare apparecchi da gioco deve essere esposta una tabella, vidimata dal questore, nella quale sono indicati, oltre ai giochi d'azzardo anche quelli che l'autorita' stessa ritenga di vietare nel pubblico interesse, e le prescrizioni e i divieti specifici che ritenga di disporre nel pubblico interesse";
- b) il quarto comma e' sostituito dal seguente: "Si considerano apparecchi e congegni automatici, semiautomatici ed elettronici il gioco d'azzardo quelli che hanno insita la scommessa o che consentono vincite puramente aleatorie di un qualsiasi premio in denaro o in natura o vincite di valore superiore ai limiti fissati al comma seguente, escluse le macchine vidimatrici per i giochi gestiti dallo Stato";
- c) al quinto comma: 1) dopo le parole: "all'elemento aleatorio", sono inserite le seguenti: "ed il valore del costo della partita non supera il valore della moneta metallica corrente di valore non superiore ad un euro"; 2) le parole da: "Tali apparecchi" fino a: "finalita' di lucro" sono sostituite dalle seguenti: "Tali apparecchi possono distribuire premi che consistono, per ciascuna partita ed immediatamente dopo la sua conclusione, nel prolungamento o nella ripetizione della partita stessa fino ad un massimo di dieci volte. La durata di ciascuna partita noti puo' essere inferiore a dodici secondi"
- d) i commi sesto e settimo sono sostituiti dal seguente: "Appartengono altresi' alla categoria dei giochi leciti gli apparecchi in cui il giocatore possa esprimere la sua abilita' fisica, mentale o strategica, attivabili unicamente con l'introduzione di una moneta metallica o di un gettone per un importo complessivo non superiore, per ciascuna partita, a quello della moneta metallica corrente di valore non superiore ad un euro, che distribuiscono, direttamente e immediatamente dopo la conclusione della partita, premi consistenti in prodotti di piccola oggettistica, non convertibili in denaro o scambiabili con premi di diversa specie, di valore complessivo non superiore a dieci volte il costo della partita";
- e) dopo l'ultimo comma e' aggiunto il seguente: "Oltre a quanto previsto dall'articolo 100, il questore, quando sono riscontrate violazioni alle disposizioni concernenti gli apparecchi di cui al presente articolo, puo' sospendere la licenza del trasgressore, informandone l'autorita' competente al rilascio, per un periodo non superiore a tre mesi. Il periodo di sospensione disposto a norma del presente comma e' computato nell'esecuzione della sanzione accessoria. In caso di sequestro degli apparecchi, l'autorita' procedente provvede a darne comunicazione all'Amministrazione finanziaria".

4. L'articolo 88 del testo unico delle leggi di pubblica sicurezza, approvato con regio decreto 18 giugno 1931, n. 773, e' sostituito dal seguente: "Art. 88. 1. La licenza per l'esercizio delle scommesse puo' essere concessa esclusivamente a soggetti concessionari o autorizzati da parte di Ministeri o di altri enti ai quali la legge riserva la facolta' di organizzazione e gestione delle scommesse, nonche' a soggetti incaricati dal concessionario o dal titolare di autorizzazione in forza della stessa concessione o autorizzazione".

5. All'articolo 4 della legge 13 dicembre 1989, n. 401, e successive modificazioni, sono aggiunti in fine i seguenti commi: "4-bis. Le sanzioni di cui al presente articolo sono applicate a chiunque, privo di concessione, autorizzazione o licenza ai sensi dell'articolo 88 del testo unico delle leggi di pubblica sicurezza, approvato con regio decreto 18 giugno 1931, n. 773, e successive modificazioni, svolga in Italia qualsiasi attivita' organizzata al fine di accettare o raccogliere o comunque favorire l'accettazione o in qualsiasi modo la raccolta, anche per via telefonica o telematica, di scommesse di qualsiasi genere da chiunque accettate in Italia o all'estero. 4-ter. Fermi restando i poteri attribuiti al Ministero delle finanze dall'articolo 11 del decreto-legge 30 dicembre 1993, n. 557, convertito, con modificazioni, dalla legge 26 febbraio 1994, n. 133, ed in applicazione dell'articolo 3, comma 228, della legge 28 dicembre 1995, n. 549, le sanzioni di cui al presente articolo si applicano a chiunque effettui la raccolta o la prenotazione di giocate del lotto, di concorsi pronostici o di scommesse per via telefonica o telematica, ove sprovvisto di apposita autorizzazione all'uso di tali mezzi per la predetta raccolta o prenotazione".

### Art. 38. - (Nulla osta rilasciato dall'Amministrazione finanziaria per gli apparecchi da divertimento e intrattenimento)

1. COMMA ABROGATO DALLA L. 30 DICEMBRE 2004, N. 311.

2. COMMA ABROGATO DALLA L. 30 DICEMBRE 2004, N. 311.

3. Gli importatori e i produttori degli apparecchi e dei congegni di cui all'articolo 110, commi 6, lettera a), e 7 , del testo unico delle leggi di pubblica sicurezza, di cui al regio decreto 18 giugno 1931, n. 773, e successive modificazioni, presentano un esemplare di ogni modello di apparecchio o congegno che essi intendono produrre o importare al Ministero dell'economia e delle finanze - Amministrazione autonoma dei Monopoli di Stato per la verifica tecnica della loro conformita' alle prescrizioni stabilite con l'articolo 110, commi 6 e 7, del predetto testo unico, e della loro dotazione di dispositivi che ne garantiscono la immodificabilita' delle caratteristiche tecniche e delle modalita' di funzionamento e di distribuzione dei premi, con l'impiego di programmi o schede che ne bloccano il funzionamento in caso di manomissione o, in alternativa, con l'impiego di dispositivi che impediscono l'accesso alla memoria. La verifica tecnica vale altresi' a constatare che la manomissione dei dispositivi ovvero dei programmi o delle schede, anche solo tentata, risulta automaticamente indicata sullo schermo video dell'apparecchio o del congegno ovvero che essa e' dagli stessi comunque altrimenti segnalata. La verifica tecnica vale inoltre a constatare la rispondenza delle caratteristiche tecniche, anche relative alla memoria, delle modalita' di funzionamento e di distribuzione dei premi, dei dispositivi di sicurezza, propri di ciascun apparecchio e congegno, ad un'apposita scheda esplicativa fornita dal produttore o dall'importatore in relazione all'apparecchio o al congegno sottoposto ad esame. Dell'esito positivo della verifica e' rilasciata apposita certificazione. Il Ministero dell'economia e delle finanze - Amministrazione autonoma dei Monopoli di Stato puo' stipulare convenzioni per l'effettuazione della verifica tecnica.

4. Il Ministero dell'economia e delle finanze - Amministrazione autonoma dei Monopoli di Stato rilascia nulla osta ai produttori e agli impertatori degli apparecchi e dei congegni di cui all'articolo 110, commi 6, lettera a), e 7 , del citato testo unico di cui al regio decreto n. 773 del 1931, nonche' ai loro gestori. A questo fine, con la richiesta di nulla osta per la distribuzione di un numero predeterminato di apparecchi e congegni, ciascuno identificato con un apposito e proprio numero progressivo, i produttori e gli importatori autocertificano che gli apparecchi e i congegni sono conformi al modello per il quale e' stata conseguita la certificazione di cui al comma 3. I produttori e gli importatori dotano ogni apparecchio e congegno, oggetto della richiesta di nulla osta, della scheda esplicativa di cui al comma 3. I produttori e gli importatori consegnano ai cessionari degli apparecchi e dei congegni una copia del nulla osta e, sempre per ogni apparecchio e congegno ceduto, la relativa scheda esplicativa. La copia del nulla osta e la scheda esplicativa sono altresi' consegnate, insieme agli apparecchi e congegni, in occasione di ogni loro ulteriore cessione.

5. I gestori degli apparecchi e dei congegni di cui al comma 3 prodotti o importati dopo il 1 gennaio 2003 richiedono il nulla osta previsto dal medesimo comma 3, precisando in particolare il numero progressivo di ogni apparecchio o congegno per il quale la richiesta e' effettuata nonche' gli estremi del nulla osta del produttore o dell'importatore ad essi relativo.

((5-bis. Fatta eccezione per gli apparecchi e congegni di cui all'articolo 110, commi 6, lettera b), e 7, del citato testo unico di cui al regio decreto 18 giugno 1931, n. 773, e successive modificazioni, il nulla osta, rilasciato ai sensi del comma 5 del presente articolo dal Ministero dell'economia e delle finanze-Amministrazione autonoma dei monopoli di Stato, decade automaticamente quando i relativi apparecchi e congegni risultino, in considerazione dell'apposizione degli stessi in stato di magazzino, ovvero di manutenzione straordinaria, per un periodo superiore a novanta giorni, anche non continuativi, temporaneamente non collegati alla rete telematica prevista dall'articolo 14-bis, comma 4, del decreto del Presidente della Repubblica 26 ottobre 1972, n. 640, e successive modificazioni))

6. Ai fini del rilascio dei nulla osta di cui ai precedenti commi, e' necessario il possesso delle licenze previste dall'articolo 86, terzo comma, lettera a) o b), del testo unico di cui al regio decreto 18 giugno 1931, n. 773, e successive modificazioni.

7. Oli ufficiali e gli agenti di pubblica sicurezza, secondo le direttive del Ministero dell'interno-Dipartimento della pubblica sicurezza, nonche' il Ministero dell'economia e delle finanze e gli ufficiali ed agenti di polizia tributaria effettuano il controllo degli apparecchi, anche a campione e con accesso alle sedi dei produttori, degli importatori e dei gestori degli apparecchi e dei congegni di cui ai commi 1 e 3 ovvero di coloro che comunque li detengono anche temporaneamente, verificando altresi' che, per ogni apparecchio e congegno, risulti rilasciato il nulla osta, che gli stessi siano contrassegnati dal numero progressivo e dotati della relativa scheda esplicativa. In caso di irregolarita', e' revocato il nulla osta al produttore o all'importatore ovvero al gestore, relativamente agli apparecchi e congegni irregolari, e il relativo titolo e' ritirato, ovvero dallo stesso sono espunti gli identificativi degli apparecchi e congegni irregolari.

8. Il Corpo della Guardia di finanza, in coordinamento con gli uffici finanziari competenti per l'attivita' finalizzata all'applicazione delle imposte dovute sui giochi, ai fini dell'acquisizione e del reperimento degli elementi utili per la repressione delle violazioni alle leggi in materia di lotto, lotterie, concorsi pronostici, scommesse e degli altri giochi amministrati dallo Stato, procede, di propria iniziativa o su richiesta dei predetti uffici, secondo le norme e con le facolta' di cui agli articoli 32 e 33 del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, e successive modificazioni, ed agli articoli 51 e 52 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, e successive modificazioni.

### Art. 39. - (Disposizioni transitorie)

1. In sede di prima applicazione, per l'installazione di apparecchi non muniti di scheda a deconto o strumenti similari e del dispositivo di cui al comma 1 dell'articolo 38, e' rilasciato, previa verifica della documentazione prodotta dal richiedente, attestante la conformita' degli apparecchi alle prescrizioni di legge o di regolamento, un nulla osta provvisorio i cui effetti cessano decorsi quattro mesi dalla data di entrata in vigore del decreto di cui al comma 1 dell'articolo 38 e comunque non prima della data del 31 maggio 2001.

2. Per gli apparecchi gia' installati, o comunque gia' in esercizio alla data di entrata in vigore della presente legge, il nulla osta provvisorio di cui al comma 1 e' richiesto entro quarantacinque giorni dalla medesima data. In caso di diniego del nulla osta provvisorio l'apparecchio deve essere immediatamente rimosso. Per i medesimi apparecchi, la licenza di cui all'articolo 86 del testo unico delle leggi di pubblica sicurezza, approvato con regio decreto 18 giugno 1931, n. 773, come modificato dall'articolo 37 della presente legge, e' acquisita entro la data del 30 giugno. 2001.

3. Al fine di garantire il conseguimento delle maggiori entrate previste dall'articolo 7 del decreto-legge 30 settembre 2000, n. 269, convertito, con modificazioni, dalla legge 23 novembre 2000, n. 354, per l'espletamento, secondo la normativa comunitaria, delle procedure delle gare previste dal citato articolo, nonche' per gli ulteriori adempimenti necessari per l'avvio del gioco del Bingo e per i connessi controlli, si provvede con oneri finanziari a carico e nei limiti delle disponibilita' del bilancio dell'incaricato del controllo centralizzato del gioco anche in deroga ai limiti di cui al decreto del Presidente della Repubblica 11 gennaio 1956, n. 5, e successive modificazioni, ove applicabile.

### Art. 40. - (Disposizioni in materia di capitale della societa' di gestione della casa da gioco di Campione d'Italia)

1. Al comma 38 dell'articolo 31 della legge 23 dicembre 1998, n. 448, il secondo periodo e' sostituito dai seguenti: "Al capitale della societa' partecipano esclusivamente, con quote massime stabilite nel decreto ministeriale autorizzativo, i seguenti soggetti: il comune di Campione d'Italia, la provincia di Como, la provincia di Lecco, la camera di commercio, industria, artigianato e agricoltura di Como la camera di commercio, industria, artigianato e agricoltura di Lecco. I soggetti medesimi approvano e trasmettono al Ministero dell'interno, entro il 31 gennaio 2001, l'atto costitutivo, lo statuto ed i patti parasociali della societa', sottoscritti dai rispettivi legali rappresentanti. Decorso inutilmente tale termine, il Ministero dell'interno provvede in via sostitutiva a mezzo di apposito commissario".

### Art. 41. - (Disposizioni in materia di concorso pronostici Enalotto e di gioco del lotto)

1. La posta unitaria di partecipazione al concorso pronostici Enalotto e' di lire 787 per colonna a decorrere dal 1° gennaio 2001, e di un Euro per giocata minima a decorrere dal 1° gennaio 2002.

2. Il comma 5 dell'articolo 12 della legge 2 agosto 1982, n. 528, come modificato dall'articolo 5 della legge 19 aprile 1990, n. 85, e' sostituito dal seguente: "5. Per l'installazione di ciascun terminale per la raccolta del gioco del lotto automatizzato ogni raccoglitore versa all'Amministrazione autonoma del Monopoli di Stato un contributo una tantum, stabilito in ragione di due milioni e cinquecentomila lire. Il contributo deve essere versato da parte dei raccoglitori, per ciascun terminale gia' funzionante alla data di entrata in vigore della presente disposizione, entro il 30 giugno 2001. Per quelli installati successivamente alla data di entrata in vigore della presente disposizione il contributo viene versato entro 60 giorni dalla data di ricevimento della richiesta da parte dell'Amministrazione autonoma dei Monopoli di Stato e comunque non prima della predetta data del 30 giugno 2001. All'atto del ricevimento della richiesta, il ricevitore ha facolta' di rinunciare ai terminali eccedenti il proprio fabbisogno e sui quali non sara' dovuto il pagamento del contributo una tantum. Il mancato versamento del contributo una tantum nei termini predetti comportera' il ritiro del terminale e l'addebito delle spese sostenute per il ritiro".

### Art. 42. - (Disposizioni in materia di controlli dell'amministrazione finanziaria, di rappresentanza e assistenza dei contribuenti)

1. A decorrere dall'anno 2002 e' esercitato il controllo sostanziale e sistematico dei contribuenti con volume di affari, ricavi o compensi non inferiore a 10 miliardi di lire. Tali controlli saranno esercititi almeno una volta ogni due anni per i contribuenti con volume di affari, ricavi o compensi non inferiore a 50 miliardi di lire, ed almeno una volta ogni quattro anni per gli altri contribuenti. A tale fine e' autorizzato il potenziamento dell'Amministrazione finanziaria nel limite delle risorse disponibili

2. Al terzo comma dell'articolo 63 del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, dopo la parola: "ufficiali" sono inserite le seguenti: "e i sottufficiali".

## DISPOSIZIONI IN MATERIA DI VENDITE DI IMMOBILI E DI ALLOGGI

### Art. 43. - (Dismissione di beni e diritti immobiliari)

1. Al comma 6 dell'articolo 2 della legge 23 dicembre 1999, n. 488, le parole: "Il Ministro del tesoro, del bilancio e della programmazione economica", sono sostituite dalle seguenti: "Il Ministro del lavoro e della previdenza sociale".

2. Al comma 99-bis dell'articolo, 3 della legge 23 dicembre 1996, n. 662, introdotto dall'articolo 4, comma 4, della legge 23 dicembre 1999, n. 488, al primo periodo, le parole: suscettibili di utilizzazione agricola" sono sostituite dalle seguenti: "soggetti ad utilizzazione agricola", e sono soppresse le parole: "che ne cura l'attuazione"; al secondo periodo, le parole: "destinati alla coltivazione" sono sostituite dalle seguenti: "utilizzati per la coltivazione alla data di entrata in vigore della presente disposizione"; il terzo periodo e' sostituito dal seguente: "Ai conduttori degli immobili destinati alla coltivazione e' concesso il diritto di prelazione, le cui modalita' di esercizio sono definite con decreto del Ministro del tesoro, del bilancio e della programmazione economica, di concerto con il Ministro delle politiche agricole e forestali". 3. Il Ministero del tesoro, del bilancio e della programmazione economica definisce e cura l'attuazione di un programma di alienazione degli immobili appartenenti al patrimonio degli enti di cui alla legge 4 dicembre 1956, n. 1404, singolarmente o in uno o piu' lotti anche avvalendosi delle modalita' di vendita di cui all'articolo 3, comma 99, della legge 23 dicembre 1996, n. 662, come modificato dall'articolo 4, comma 3, della legge 23 dicembre 1999, n. 488. 4. Gli enti venditori sono esonerati dalla consegna di documenti relativi alla proprieta' o al diritto sul bene, producendo apposita dichiarazione di titolarita' del diritto. La disposizione non ha effetto per tutti gli immobili per i quali, alla data di entrata in vigore della presente legge, siano in atto controversie con privati od altro ente pubblico, in sede amministrativa, stragiudiziale o giudiziale, sulla proprieta' dei beni stessi. 5. Al comma 11 dell'articolo 1 della legge 24 dicembre 1993, n. 560, e' aggiunto, in fine, il seguente periodo: "Se viene richiesta, da parte dell'acquirente, la rettifica della rendita catastale in diminuzione, a causa della comprovata difformita' di tale rendita tra l'immobile richiesto in cessione ed altro di superficie e caratteristiche analoghe, ubicato nello stesso stabile o in altro ad esso adiacente, l'Ufficio del territorio dovra' provvedere all'eventuale rettifica entro novanta giorni dalla data di ricezione della richiesta". 6. Gli enti pubblici trasformati in societa' per azioni nelle quali lo Stato, le regioni e gli enti locali hanno una partecipazione di controllo, negli atti di trasferimento o conferimento e in ogni atto avente ad oggetto immobili o diritti reali su immobili di loro proprieta', sono esonerati dall'obbligo di comprovare la regolarita' urbanistico-edilizia prevista dagli articoli 17, 18, 40 e 41 della legge 28 febbraio 1985, n. 47. Tali atti possono essere compiuti validamente senza l'osservanza delle norme previste nella citata legge n. 47 del 1985, con il rilascio di una dichiarazione resa ai sensi della legge 4 gennaio 1968, n. 15, e successive modificazioni, attestante, per i fabbricati, la regolarita' urbanistico-edilizia con riferimento alla data delle costruzioni e, per i terreni, la destinazione urbanistica, senza obbligo di allegare qualsiasi documento probatorio. La dichiarazione deve essere resa nell'atto, di alienazione, conferimento o costituzione del diritto reale dal soggetto che, nell'atto stesso, rappresenta la societa' alienante o conferente. 7. ((COMMA ABROGATO DAL D.LGS. 15 MARZO 2010, N. 66)). 8. ((COMMA ABROGATO DAL D.LGS. 15 MARZO 2010, N. 66)). 9. ((COMMA ABROGATO DAL D.LGS. 15 MARZO 2010, N. 66)). 10. ((COMMA ABROGATO DAL D.LGS. 15 MARZO 2010, N. 66)). 11. ((COMMA ABROGATO DAL D.LGS. 15 MARZO 2010, N. 66)). 12. Al fine di favorire l'attuazione dei piani di dismissione dei rispettivi patrimoni immobiliari e la realizzazione dei nuovi modelli gestionali di cui al decreto legislativo 16 febbraio 1996, n. 104, gli enti previdenziali pubblici di cui all'articolo 1, comma 1, del citato decreto legislativo promuovono la definizione del contenzioso in materia immobiliare privilegiando soluzioni transattive o di bonario componimento che comportino l'immediato conseguimento di un apprezzabile risultato economico in relazione al rischio implicito del giudizio, allo stato ed al presumibile costo di esso, nonche' alla possibilita' di effettiva riscossione del credito. 13. Gli enti di cui al comma 12, al fine di accelerare la realizzazione dei piani di dismissione, sono autorizzati a definire bonariamente la posizione debitoria dei conduttori di immobili ad uso abitativo maturata alla data del 30 settembre 2000 purche' questi, previa formale rinuncia a qualsiasi azione, eccezione o pretesa, versino in unica soluzione e senza interessi l'80 per cento delle somme risultanti a loro debito dalle scritture contabili a titolo di morosita' locativa per canone ed oneri accessori, oltre alle eventuali spese legali. 14. ((COMMA ABROGATO DAL D.LGS. 15 MARZO 2010, N. 66)). 15. Al comma 99 dell'articolo 3 della legge 23 dicembre 1996, n. 662, come sostituito dal comma 3 dell'articolo 4 della legge 23 dicembre 1999, n. 488, al primo periodo, dopo le parole: "che ne cura l'attuazione" sono aggiunte le seguenti: "fatto comunque salvo il diritto di prelazione attribuito, relativamente ai beni immobili non destinati ad uso abitativo, in favore dei concessionari e dei conduttori, nonche' in favore di tutti i soggetti che, gia' concessionari, siano comunque ancora nel godimento dell'immobile oggetto di alienazione e che abbiano soddisfatto tutti i crediti richiesti dall'amministrazione competente, limitatamente alle nuove iniziative di vendita avviate a decorrere dal 1° gennaio 2001 che prevederanno la vendita frazionata". 16. ((COMMA ABROGATO DAL D.LGS. 15 MARZO 2010, N. 66)). 17. Dopo il comma 10 dell'articolo 16 della legge 28 luglio 1999, n. 266, e' aggiunto il seguente: "10-bis. Con le stesse modalita' stabilite al comma 10 possono essere alienati gli immobili del patrimonio e del demanio dello Stato concessi in qualita' di alloggi individuali ai dipendenti della Polizia di Stato e ubicati al di fuori o prospicienti le strutture di servizio". 18. Al comma 109 dell'articolo 3 della legge 23 dicembre 1996, n. 662, sono apportate le seguenti modificazioni: a) all'alinea, le parole: "le societa' a prevalente partecipazione pubblica" sono sostituite dalle seguenti: "le societa' derivanti da processi di privatizzazione nelle quali, direttamente o indirettamente, la partecipazione pubblica e' uguale o superiore al 30 per cento del capitale espresso in azioni ordinarie"; b) la lettera c) e' abrogata. 19. I lavoratori, gia' dipendenti degli enti previdenziali, addetti al servizio di portierato o di custodia e vigilanza degli immobili che vengono dismessi, di proprieta' degli enti previdenziali, restano alle dipendenze dell'ente medesimo. Si applica quanto disposto dagli articoli 33 e 34 del decreto legislativo 30 marzo 2001, n. 165. 20. Agli immobili di cui al decreto del Ministro del tesoro, del bilancio e della programmazione economica del 27 marzo 2000, pubblicato nella Gazzetta Ufficiale n. 88 del 14 aprile 2000, e fino all'esaurimento delle relative procedure di dimissione, non si applica il comma 9 dell'articolo 4 della legge 23 dicembre 1999, n. 488. 21. Agli immobili dello Stato oggetto di programmi di dismissione, di cui all'articolo 3, commi 99 e seguenti, della legge 23 dicembre 1996, n. 662, e successive modificazioni, gia' individuati, non si applica l'articolo 4, secondo comma, del decreto del Ministro dell'interno del 10 settembre 1986, pubblicato nella Gazzetta Ufficiale n. 215 del 16 settembre 1986. 22. COMMA ABROGATO DAL D.P.R. 13 SETTEMBRE 2005, N. 296.

### Art. 44. - (Norme in materia di beni immobili oggetto di sequestro o di confisca)

1. Dopo il comma 1 dell'articolo 39 della legge 23 dicembre 1994, n. 724, e successive modificazioni, e' inserito il seguente: "1-bis. Qualora l'amministratore di beni immobili oggetto di sequestro o di confisca ai sensi della legge 31 maggio 1965, n. 575, sia autorizzato dal giudice competente ad alienare taluno di detti beni, il medesimo giudice, sentito il pubblico ministero, puo' altresi' autorizzarlo a riattivare il procedimento di sanatoria sospeso ai sensi del quinto periodo del comma 1. In tal caso, non opera nei confronti dell'amministratore o del terzo acquirente il divieto di concessione in sanatoria di cui al sesto periodo del medesimo comma".

### Art. 45. - (Cessione in proprieta' di alloggi di edilizia residenziale pubblica di proprieta' statale nella regione Friuli-Venezia Giulia)

1. I contratti preliminari e definitivi gia' stipulati, relativi al trasferimento in proprieta' degli alloggi di edilizia residenziale pubblica di proprieta' statale, gestiti dalle aziende territoriali per l'edilizia residenziale pubblica della regione Friuli-Venezia Giulia, sono validi ed efficaci e costituiscono titolo che autorizza gli uffici tavolari a provvedere agli adempimenti di propria competenza in ordine alle operazioni di trascrizione.

2. Le disposizioni del presente articolo non comportano alcun aggravio di spesa per il bilancio dello Stato e per i bilanci delle aziende territoriali per l'edilizia residenziale pubblica della regione Friuli-Venezia Giulia.

3. Il termine per la domanda di cessione di immobili a profughi di cui agli articoli 1, 17 e 18 della legge 4 marzo 1952, n. 137, e successive modificazioni, nonche' di cui all'articolo 1, comma 24, della legge 24 dicembre 1993, n. 560, e' prorogato sino al 30 dicembre 2005. Le disposizioni di cui all'articolo 5 del decreto-legge 23 ottobre 1996, n. 542, convertito, con modificazioni, dalla legge 23 dicembre 1996, n. 649. si applicano a tutti gli immobili destinati ai profughi di cui alla predetta legge 4 marzo 1952, n. 137, e successive modificazioni; tra i predetti immobili sono ricompresi anche quelli realizzati nelle regioni a statuto speciale, o di proprieta' dell'ex Opera Profughi, dell'ex EGAS e dell'ex Ente Nazionale Tre Venezie. Gli immobili citati nel presente comma sono esclusi dall'applicazione delle disposizioni di cui ai commi 1 e 2 del presente articolo.

((3-bis. Tra gli immobili di cui al comma 3 rientrano anche quelli ad uso non abitativo qualora destinati, realizzati, assegnati oppure utilizzati per i profughi di cui al citato comma 3, ed allorche' negli stessi immobili si svolgano o si siano svolte attivita' culturali, sociali, scolastiche e sanitarie. Rientrano altresi' nei predetti immobili quelli destinati allo svolgimento di attivita' commerciali o artigianali, nella misura in cui siano diretti a soddisfare esigenze di primaria necessita', in attuazione degli scopi statutari degli enti soppressi di cui al comma 3))

### Art. 46. - (Trasferimento in proprieta' di alloggi)

1. I comuni nei cui territori sono ubicati, gli alloggi di cui all'articolo 2 della legge 27 dicembre 1997, n. 449, procedono alla richiesta di trasferimento in proprieta' di tali alloggi entro sei mesi dalla data di entrata in vigore della presente legge.

2. Gli alloggi di cui al comma 1 sono trasferiti ai comuni nello stato di fatto e di diritto in cui gli stessi si trovano al momento del passaggio. Lo Stato e' esonerato, relativamente ai beni consegnati ai comuni ai sensi della citata legge n. 449 del 1997, dalle dichiarazioni di cui al secondo comma dell'articolo 40 della legge 28 febbraio 1985, n. 47. 1 comuni hanno 120 giorni di tempo dalla data dell'avvenuta volturazione per provvedere all'accertamento di eventuali difformita' urbanistico-edilizie.

3. Qualora dopo la scadenza del termine di cui al comma 1 i comuni non abbiano esercitato il diritto di cui al medesimo comma, l'Istituto autonomo case popolari comunque denominato competente per territorio puo' presentare, nei successivi sei mesi, richiesta di trasferimento della proprieta' alle medesime condizioni previste dal comma 1 del citato articolo 2 della legge 27 dicembre 1997. n. 449.

4. Gli alloggi costruiti a cura del Dipartimento della protezione civile, di cui all'articolo 2, secondo comma, del decreto-legge 19 marzo 1981, n. 75, convertito, con modificazioni dalla legge 14 maggio 1981, n. 219, possono essere acquisiti al patrimonio disponibile dei comuni ove sono ubicati.

### Art. 47. - (Osservatorio sul patrimonio immobiliare degli enti previdenziali pubblici)

1. Al fine di favorire il completamento dei processi di dismissione dei patrimoni immobiliari degli enti previdenziali pubblici, il termine di durata dell'operativita' dell'Osservatorio sul patrimonio immobiliare degli enti previdenziali pubblici, istituito ai sensi dell'articolo 10 del decreto legislativo 16 febbraio 1996, n. 104, e' differito di ventiquattro mesi. L'osservatorio sul patrimonio immobiliare degli enti previdenziali pubblici svolge attivita' di consulenza e di supporto tecnico da rendere al Ministro del lavoro e della previdenza sociale ed i compiti sono di volta in volta ad esso conferiti dallo stesso Ministro.

## ALTRE DISPOSIZIONI IN MATERIA DI ENTRATA

### Art. 48. - (Rimborso della tassa sulle concessioni governative)

1. L'importo del netto ricavo relativo all'emissione dei titoli pubblici per il prosieguo delle attivita' di rimborso della tassa sulle concessioni governative per l'iscrizione nel registro delle imprese, di cui all'articolo 11 della legge 23 dicembre 1998, n. 448, e' determinato per l'anno 2001 in lire 2.500 miliardi.

2. L'importo di cui al comma 1 e' versato all'entrata del bilancio dello Stato per essere riassegnato ad apposita unita' previsionale di base dello stato di previsione del Ministero delle finanze, che provvedera' a soddisfare gli aventi diritto con le modalita' di cui al comma 6 dell'articolo 11 della legge 23 dicembre 1998, n. 448.

### Art. 49. - (Alienazione dei materiali fuori uso della Difesa, delle Forze di polizia e del Corpo nazionale dei vigili del fuoco)

1. Alla lettera g) del comma 1 dell'articolo 3 della legge 14 gennaio 1994, n. 20, dopo le parole: "attivi, di qualunque importo", sono inserite le seguenti: ", ad eccezione di quelli per i quali ricorra l'ipotesi prevista dall'ultimo commi dell'articolo 19 del regio decreto 18 novembre 1923, n. 2440".

2. Con ((...)) del Ministro competente per l'amministrazione di appartenenza, di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, sono individuati, nell'ambito delle pianificazioni di ammodernamento connesse al nuovo modello organizzativo ((...)) delle Forze di polizia e del Corpo nazionale dei vigili del fuoco, i materiali ed i mezzi suscettibili di alienazione e le procedure, anche in deroga alle norme sulla contabilita' generale dello Stato, nel rispetto della legge 9 luglio 1990, n. 185.

3. Il decreto di cui al comma 2 disciplina le modalita' per la cessione a titolo gratuito ai musei, pubblici o privati, dei materiali o dei mezzi non piu' destinati all'impiego, allo scopo di consentire l'esposizione al pubblico.

4. Le alienazioni, di cui al comma 2 possono avere luogo anche nei confronti delle imprese fornitrici dei materiali e mezzi da alienare, eventualmente a fronte di programmi di ammodernamento predisposti dalle imprese stesse, anche ai fini della relativa esportazione nel rispetto delle norme vigenti.

## ONERI DI PERSONALE

### Art. 50. - (Rinnovi contrattuali)

1. Ai fini di quanto disposto dall'articolo 52 del decreto legislativo 3 febbraio 1993, n. 29, e successive modificazioni, la spesa relativa ai rinnovi contrattuali del personale dipendente del comparto Ministeri, delle aziende ed amministrazioni dello Stato ad ordinamento autonomo e della scuola, e' rideterminata, per ciascuno degli anni 2001 e 2002, in lire 3.047 miliardi, ivi comprese le somme da destinare alla contrattazione integrativa e fermo restando quanto previsto dall'articolo 19, comma 1, ultimo periodo, della legge 23 dicembre 1999, n. 488.

2. Le somme occorrenti per corrispondere i miglioramenti economici al personale di cui all'articolo 2, comma 4, del decreto legislativo 3 febbraio 1993, n. 29, e successive modificazioni, sono rideterminate, per ciascuno degli anni 2001 e 2002, in lire 1.141 miliardi.

3. In aggiunta a quanto previsto dal comma 1, per il personale del comparto scuola, anche allo scopo di favorire il processo di attuazione dell'autonomia scolastica, l'ammodernamento del sistema e il miglioramento della funzionalita' della docenza, e' stanziata, per ciascuno degli anni 2001 e 2002, la somma di lire 1.100 miliardi di cui lire 850 miliardi per l'incremento delle risorse destinate alla contrattazione integrativa del personale docente, lire 200 miliardi destinate alla dirigenza scolastica e lire 50 miliardi per il finanziamento della retribuzione accessoria del personale amministrativo, tecnico ed ausiliario trasferito dagli enti locali allo Stato ai sensi dell'articolo 8 della legge 3 maggio 1999, n. 124. Per il perseguimento, con carattere di continuita', degli obiettivi di valorizzazione professionale della funzione docente e' autorizzata la costituzione di un apposito fondo, da iscrivere nello stato di previsione del Ministero della pubblica istruzione, dell'importo di lire 400 miliardi per l'anno 2002 e di lire 600 miliardi a decorrere dall'anno 2003, da utilizzare in sede di contrattazione integrativa. Il fondo viene ripartito con decreti del Ministro del tesoro, del bilancio e della programmazione economica, su proposta del Ministro della pubblica istruzione. In sede di contrattazione integrativa sono utilizzate anche le somme relative all'anno 2000 destinate alla carriera professionale dei docenti del contratto collettivo nazionale integrativo del comparto scuola per gli anni 1998-2001 sottoscritto il 31 agosto 1999, pubblicato nel supplemento ordinario alla Gazzetta Ufficiale n. 212 del 9 settembre 1999. ((13))

4. In aggiunta a quanto previsto dal comma 1, in relazione al nuovo assetto retributivo del personale dirigente contrattualizzato delle amministrazioni dello Stato, anche ad ordinamento autonomo, e' stanziata, per ciascuno degli anni 2001 e 2002, la somma di lire 100 miliardi finalizzata anche all'incremento e alle perequazioni dei fondi per il trattamento accessorio di cui lire 40 miliardi anche con riferimento all'anno 2000 per i dirigenti incaricati della titolarita' di uffici di livello dirigenziale generale. Tali risorse sono ripartite, sulla base dei criteri perequativi definiti con decreto del Ministro per la funzione pubblica, di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, tra i fondi delle singole amministrazioni. Per le analoghe finalita', e anche al fine di consentire il definitivo completamento del processo di perequazione retributiva previsto dall'articolo 19 della legge 28 luglio 1999, n.266, in aggiunta a quanto previsto dal comma 2 e' stanziata, per ciascuno degli anni 2001 e 2002, la somma di lire 83 miliardi di cui lire 15 miliardi destinati al personale della carriera diplomatica, lire 32 miliardi destinati al personale della carriera prefettizia e lire 36 miliardi ai dirigenti delle Forze armate e delle Forze di polizia. Per analoghi fini perequativi, a decorrere dal 1° gennaio 2001, senza diritto alla corresponsione di arretrati e con assorbimento di ogni anzianita' pregressa, ai magistrati di Cassazione, del Consiglio di Stato, dei Tribunali amministrativi regionali, della Corte dei conti e agli avvocati dello Stato, che non hanno fruito dei riallineamenti stipendiali conseguenti all'applicazione delle norme soppresse dal decreto-legge 11 luglio 1992, n. 333, convertito, con modificazioni, dalla legge 8 agosto 1992, n. 359, e' attribuito, all'atto del conseguimento, rispettivamente, della qualifica di consigliere o di avvocato dello Stato alla terza classe di stipendio, il trattamento economico complessivo annuo pari a quello spettante ai magistrati di Cassazione di cui all'articolo 5 della legge 5 agosto 1998, n. 303. Il nono comma dell'articolo 4 della legge 6 agosto 1984, n. 425, si intende abrogato dalla data di entrata in vigore del citato decreto-legge n. 333 del 1992, convertito, con modificazioni, dalla legge n. 359 del 1992, e perdono ogni efficacia i provvedimenti e le decisioni di autorita' giurisdizionali comunque adottati difformemente dalla predetta interpretazione dopo la data suindicata. In ogni caso non sono dovuti e non possono essere eseguiti pagamenti sulla base dei predetti decisioni o provvedimenti.

5. Per il riconoscimento e l'incentivazione della specificita' e onerosita' dei compiti del personale dei Corpi di polizia e delle Forze armate di cui al decreto legislativo 12 maggio 1995, n. 195, in aggiunta a quanto previsto dal comma 2 e' stanziata, per ciascuno degli ami 2001 e 2002, la somma di lire 920 miliardi da destinare al trattamento accessorio del predetto personale.

6. Per le medesime finalita' di cui al comma 5 e' stanziata, per ciascuno degli anni 2001 e 2002, la somma di lire 10 miliardi, da destinare al trattamento accessorio del personale del Corpo nazionale dei vigili del fuoco.

7. Le somme di cui ai commi 1, 2, 3, 4, 5 e 6, comprensive degli oneri contributivi ai fini previdenziali e dell'imposta regionale sulle attivita' produttive di cui al decreto legislativo 15 dicembre 1997, n. 446, costituiscono l'importo complessivo massimo di cui all'articolo 11, comma 3, lettera h), della legge 5 agosto 1978, n. 468, come sostituito dall'articolo 5 della legge 23 agosto 1988, n. 362.

8. Resta fermo quanto previsto dall'articolo 19. comma 4, della legge 23 dicembre 1999, n. 488.

9. E' stanziata la somma di lire 239.340 milioni per il 2001, 317.000 milioni per il 2002 e 245.000 milioni a decorrere dal 2003, per le finalizzazioni di spesa di cui alle seguenti lettere a), b) e c), nonche' la somma di lire 10.254 milioni per la finalizzazione di cui alla seguente lettera d):

- a) ulteriori interventi necessari a realizzare l'inquadramento dei funzionari della Polizia di Stato nei nuovi ruoli e qualifiche e la conseguente equiparazione del personale direttivo delle altre Forze di polizia e delle Forze armate secondo quanto previsto dai decreti legislativi emanati ai sensi degli articoli 1, 3, 4 e 5 della legge 31 marzo 2000, n. 78;
- b) copertura degli oneri derivanti dall'attuazione dell'articolo 9, comma 1, della legge 31 marzo 2000, n. 78, in deroga a quanto previsto dallo stesso articolo, e copertura degli oneri derivanti dal riordino delle carriere non direttive del Corpo di polizia penitenziaria e del Corpo forestale dello Stato;
- c) allineamento dei trattamenti economici del personale delle Forze di polizia relativamente al personale tecnico, alle bande musicali ed ai servizi prestati presso le rappresentanze diplomatiche o consolari all'estero;
- d) copertura e riorganizzazione degli uffici di cui ai commi 1, 2 e 3 dell'articolo 1, al comma 1 dell'articolo 2 e al comma 3 dell'articolo 3 del decreto legislativo 21 maggio 2000, n. 146, e conseguente adeguamento degli uffici centrali e periferici di corrispondente livello dell'amministrazione penitenziaria. Alle conseguenti variazioni delle tabelle di cui ai commi 1 e 2 dell'articolo 1 del decreto legislativo 21 maggio 2000, n. 146, si provvede ai sensi del comma 6 dello stesso articolo. Si applica l'articolo 4, comma 3, del medesimo decreto legislativo, nonche' la previsione di cui al comma 7 dell'articolo 3 dello stesso decreto.

10. Per il completamento delle iniziative di cui alle lettere a) e b) del comma 9 in relazione alle modifiche organizzative introdotte e ai provvedimenti attuativi della concertazione e contrattazione delle Forze di polizia ad ordinamento civile e militare e delle Forze armate, le spese per consumi intermedi non aventi natura obbligatoria, con esclusione delle spese relative ad armi e armamenti, dei Ministeri della difesa, dell'interno, delle finanze, della giustizia e delle politiche agricole e forestali sono complessivamente ridotte di lire 70 miliardi a decorrere dall'anno 2001, rispettivamente nelle seguenti misure: 43 per cento, 27 per cento, 14 per cento, 14 per cento e 2 per cento. Le spese cosi' ridotte non possono essere incrementate con l'assestamento del bilancio dello Stato per l'anno 2001.

11. Per l'attuazione delle disposizioni del comma 9, lettera a), il Governo puo' provvedere con i decreti di cui all'articolo 7, comma 4, della legge 31 marzo 2000, n. 78; per l'attuazione delle disposizioni del comma 9, lettera b), il termine di cui all'articolo 9, comma 1, della citata legge n. 78 del 2000 e quello previsto per il riordino delle carriere non direttive del Corpo di polizia penitenziaria e del Corpo forestale dello Stato sono prorogati al 28 febbraio 2001; in entrambi i casi il termine per l'espressione del parere sugli schemi di decreto legislativo da parte delle competenti Commissioni della Camera dei deputati e del Senato della Repubblica e' ridotto a trenta giorni.

12. Il contingente degli ausiliari di leva da assumere in sovrannumero a tempo determinato e per il solo periodo di ferma obbligatoria, rispetto alle dotazioni organiche dei ruoli della Polizia penitenziaria di cui alla tabella A allegata al decreto legislativo 30 ottobre 1992, n. 443, come da ultimo sostituita dalla tabella F allegata al decreto legislativo 21 maggio 2000, n. 146, e' fissato in 2.000 unita' a decorrere dall'anno 2002.

------------- AGGIORNAMENTO (13) La L. 28 dicembre 2001, n. 448 ha disposto (con l'art. 16, comma 3) che "Per la prosecuzione delle iniziative dirette alla valorizzazione professionale del personale docente della scuola, ed in aggiunta a quanto previsto dal comma 1, l'apposito fondo costituito ai sensi dell'articolo 50, comma 3, della legge 23 dicembre 2000, n. 388, da utilizzare in sede di contrattazione integrativa, e' incrementato di 108,46 milioni di euro a decorrere dall'anno 2002. Il predetto fondo e' incrementato, per l'anno 2003, di 381,35 milioni di euro e, a decorrere dall'anno 2004, della somma complessiva di 726,75 milioni di euro, subordinatamente al conseguimento delle economie derivanti dal processo attuativo delle disposizioni contenute nei commi 1 e 4 dell'articolo 22 della presente legge".

### Art. 51. - (Programmazione delle assunzioni e norme interpretative)

1. All'articolo 39 della legge 27 dicembre 1997, n. 449, e successive modificazioni, sono apportate le seguenti modifiche:

- a) al comma 2 e' aggiunto, in fine, il seguente periodo: "Per ciascuno degli anni 2002 e 2003 deve essere realizzata un'ulteriore riduzione di personale non inferiore allo 0,5 per cento rispetto a quello in servizio al 31 dicembre 1997";
- b) al comma 18, il secondo periodo e' sostituito dal seguente: "Tale percentuale non puo' essere inferiore al 50 per cento delle assunzioni autorizzate salvo che le corrispondenti riduzioni di spesa siano ugualmente realizzate anche mediante ricorso ad ulteriori tipologie di assunzioni comportanti oneri unitari inferiori rispetto a quelli derivanti dalle ordinarie assunzioni di personale".

2. Ferme restando le disposizioni di cui all'articolo 39, comma 3-ter, della legge 27 dicembre 1997, n. 449, e successive modificazioni, sono abrogate le norme che disciplinano il procedimento di contrattazione collettiva in modo difforme da quanto previsto dalle disposizioni di cui al decreto legislativo 3 febbraio 1993, n. 29, e successive modificazioni. A seguito dell'abrogazione delle norme di cui al primo periodo, i risparmi conseguiti in relazione all'espletamento del servizio di assistenza fiscale ai dipendenti delle Amministrazioni statali, accertati in sede di assestamento del bilancio dello Stato, affluiscono ai fondi destinati all'incentivazione del personale, per le finalita' e nei limiti di cui all'articolo 43, comma 5, della legge 27 dicembre 1997, n. 449, e successive modificazioni.

3. L'articolo 7, comma 1, del decreto-legge 19 settembre 1992, n. 384, convertito, con modificazioni, dalla legge 14 novembre 1992, n. 438, si interpreta nel senso che la proroga al 31 dicembre 1993 della disciplina emanata sulla base degli accordi di comparto di cui alla legge 29 marzo 1983, n. 93, relativi al triennio 1° gennaio 1988-31 dicembre 1990, non modifica la data del 31 dicembre 1990, gia' stabilita per la maturazione delle anzianita' di servizio prescritte ai fini delle maggiorazioni della retribuzione individuale di anzianita'. E' fatta salva l'esecuzione dei giudicati alla data di entrata in vigore della presente legge. ((108))

4. L'articolo 4, comma 2, del decreto legislativo 21 maggio 2000, n. 146, si interpreta nel senso che esso trova applicazione dalla data di entrata in vigore del primo rinnovo contrattuale riferito al personale delle qualifiche dirigenziali appartenente al comparto Ministeri, fermo restando quanto previsto dall'articolo 18, comma 1, del decreto legislativo 30 luglio 1999, n. 300.

5. In caso di ricorso a forme arbitrali di composizione delle controversie di lavoro delle amministrazioni pubbliche, si provvede con le stesse modalita' di bilancio relative alle spese per liti.

6. I comandi in atto del personale dell'ex Ente poste italiane presso le amministrazioni pubbliche, gia' disciplinati dall'articolo 45, comma 10, della legge 23 dicembre 1998, n. 448, sono prorogati al 31 dicembre 2001.

7. Gli inquadramenti del personale di cui al comma 6, che abbia assunto servizio in comando presso l'amministrazione richiedente dopo il 28 febbraio 1998, sono detratti dalla quota di assunzioni che sara' autorizzata per l'amministrazione stessa nell'anno 2001, in applicazione dell'articolo 39 della legge 27 dicembre 1997, n. 449, e successive modificazioni.

8. Ferma restando la validita' ordinaria delle graduatorie, i termini di validita' delle graduatorie gia' prorogati al 31 dicembre 2000, per l'assunzione di personale presso le amministrazioni pubbliche di cui all'articolo 1, comma 2, del decreto legislativo 3 febbraio 1993, n. 29, sono prorogati fino al 30 giugno 2001, purche' i relativi concorsi siano stati banditi dopo il 10 gennaio 1998. Per le Forze armate la validita' delle graduatorie e' disciplinata dalla normativa di settore.

9. Al comma 2, quarto periodo, dell'articolo 110 del testo unico delle leggi sull'ordinamento degli enti locali, approvato con decreto legislativo 18 agosto 2000, n. 267, dopo le parole: "organica dell'ente" sono inserite le seguenti: "arrotondando il prodotto all'unita' superiore".

10. All'articolo 1 della legge 10 marzo 2000, n. 62, dopo il comma 4, e' inserito il seguente: "4-bis. Ai fini di cui al comma 4 il requisito del titolo di abilitazione deve essere conseguito, dal personale in servizio alla data di entrata in vigore della presente legge presso le scuole secondarie che chiedono il riconoscimento, al termine dell'anno accademico in corso alla data di conclusione su tutto il territorio nazionale della prima procedura concorsuale per titoli ed esami che verra' indetta successivamente alla data sopraindicata. Per il personale docente in servizio alla medesima data nelle scuole materne che chiedono il riconoscimento si applica l'articolo 334 del testo unico delle disposizioni legislative vigenti in materia di istruzione, relative alle scuole di ogni ordine e grado, approvato con decreto legislativo 16 aprile 1994, n. 297".

11. Gli enti locali, non dissestati e non strutturalmente deficitari, che, alla data del 30 novembre 2000, utilizzino personale assunto a tempo determinato mediante prove selettive, ai sensi dell'articolo 7 della legge 29 dicembre 1988, n. 554, indette entro il 31 dicembre 1997, nell'ambito dei concorsi pubblici banditi entro sei mesi dalla data di entrata in vigore della presente legge nel rispetto degli atti di programmazione dei fabbisogni di personale, possono riservare il 50 per cento dei posti messi a concorso al predetto personale assunto a tempo determinato.

12. Fermi i limiti della dotazione organica del Consiglio superiore della magistratura, al personale del Ministero della giustizia ivi distaccato alla data del 31 dicembre 1998 si applica la disciplina di cui all'articolo 5, commi da 1 a 3, del decreto legislativo 14 febbraio 2000, n. 37.

13. All'ultimo periodo del comma 23 dell'articolo 45 del decreto legislativo 31 marzo 1998, n. 80, introdotto dall'articolo 89 della legge 21 novembre 2000, n. 342, la parola: "fondamentale" e' sostituita dalla seguente: "complessivo".

------------- AGGIORNAMENTO (108) La Corte Costituzionale, con sentenza 6 dicembre 2023 - 11 gennaio 2024, n. 4 (in G.U. 1ª s.s. 17/01/2024, n. 3), ha dichiarato "l'illegittimita' costituzionale dell'art. 51, comma 3, della legge 23 dicembre 2000, n. 388, recante «Disposizioni per la formazione del bilancio annuale e pluriennale dello Stato (legge finanziaria 2001)»".

## SPESE DELLE AMMINISTRAZIONI PUBBLICHE

### Art. 52.

(Norme per il trasferimento di funzioni statali alle regioni e agli enti locali e relativi costi)

1. Ove alla data del 31 dicembre 2000 non sia stata completata la procedura di mobilita' relativa ai contingenti di personale trasferito ai sensi di uno o piu' dei decreti del Presidente del Consiglio dei ministri emanati in attuazione dell'articolo 7 della legge 15 marzo 1997, n. 59, e nelle more del completamento della predetta procedura, le regioni e gli enti locali possono avvalersi, senza oneri aggiuntivi, per l'esercizio delle funzioni e dei compiti ad essi conferiti ai sensi dell'articolo 1, comma 1, della citata legge n. 59 del 1997, delle strutture delle amministrazioni o degli enti titolari delle funzioni e dei compiti prima del loro conferimento e comunque solo eccezionalmente e per non piu' di un anno.

2. Ove alla data del 31 dicembre 2000 non sia stato completato il processo di aggregazione degli enti locali nelle forme associative, come previsto dall'articolo 3 del decreto legislativo 31 marzo 1998, n. 112, e dalle leggi regionali, le funzioni e i compiti conferiti dallo Stato e dalle regioni agli enti locali, subordinatamente alla loro aggregazione nelle forme associative, sono conferiti in via transitoria alle province. Nel periodo transitorio, che non potra' essere protratto per oltre un anno, le province, d'intesa con le regioni, promuoveranno tutte le iniziative necessarie per favorire il processo di aggregazione degli enti locali.

3. Al fine di accelerare il trasferimento di funzioni statali alle regioni ed agli enti locali, relativamente alla materia concernente la polizia amministrativa regionale e locale di cui al titolo V del decreto legislativo 31 marzo 1998, n. 112, in deroga a quanto previsto dal comma 1, il Governo e' autorizzato ad effettuare il trasferimento, alle regioni ed agli enti locali, delle risorse finanziarie occorrenti, valutate in 6.600 milioni di lire, con corrispondente riduzione dei competenti capitoli dello stato di previsione del Ministero dell'interno.

4. All'articolo 86 del decreto legislativo 31 marzo 1998, n. 112, sono apportate le seguenti modificazioni:

- a) il comma 2 e' sostituito dal seguente: "2. I proventi dei canoni ricavati dalla utilizzazione del demanio idrico sono introitati dalla regione";
- b) il comma 3 e' abrogato.

5. Per il completamento del trasferimento di funzioni alle regioni e agli enti locali ai sensi dell'articolo 7 della legge 15 marzo 1997, n. 59, e' autorizzata la spesa di lire 515 miliardi per l'anno 2001, lire 2.455,7 miliardi per l'anno 2002 e lire 4.238,6 miliardi per l'anno 2003, da iscrivere alla pertinente unita' previsionale di base di conto capitale dello stato di previsione del Ministero del tesoro, del bilancio e della programmazione economica.

6. Le regioni sono autorizzate ad assumere impegni per nuove opere stradali di interesse regionale, a valere sulle risme destinate per il completamento del trasferimento di funzioni alle regioni ed agli enti locali, per i seguenti importi: lire 2.248 miliardi per il 2001, lire 2.242 miliardi per il 2002, lire 1.648 miliardi a decorrere dal 2003. Le assegnazioni di cassa di tali somme alle regioni saranno effettuate con il seguente profilo: lire 1.150 miliardi per il 2001, lire 1.694 miliardi per il 2002, lire 1.648 miliardi a decorrere dal 2003. Pertanto, a titolo di reintegro all'Ente nazionale per le strade (ANAS) di somme gia' impegnate, utilizzate per il predetto trasferimento di, funzioni, e' autorizzata la spesa di lire 550 miliardi per l'anno 2001.

7. Le agevolazioni edilizie e creditizie di cui alla legge 27 maggio, 1975, n. 166, connesse a mutui venticinquennali, il cui ammortamento non abbia superato la durata di venti anni, sono prorogate di cinque anni, a richiesta degli interessati e dell'ente erogante, previa accettazione del Ministero competente.

8. Al fine di favorire il puntuale esercizio da parte di regioni ed enti locali delle funzioni loro conferite ai sensi del capo I della legge 15 marzo 1997, n. 59, e' istituito uno specifico fondo annuo dell'ammontare massimo di lire 65 miliardi, da utilizzare in caso di effettive sopraggiunte esigenze valutate dalla Presidenza del Consiglio dei ministri.

9. Per gli anni 1999 e 2000 la perdita di entrata realizzata dalle regioni a statuto ordinario derivante dalla riduzione dell'accisa sulla benzina a lire 242 al litro, non compensata dal maggior gettito dalle tasse automobilistiche come determinato dall'articolo 17, comma 22, della legge 27 dicembre 1997, n. 449, e' assunta a carico del bilancio dello Stato nella misura complessiva di lire 663.333 milioni annue, secondo gli importi gia' determinati per l'anno 1998.

10. Nelle more dell'entrata in vigore dei decreti del Presidente del Consiglio dei ministri di cui all'articolo 4, comma 1, del decreto legislativo 4 giugno 1997, n. 143, l'importo di lire 540,7 miliardi recato per l'anno 2000 dall'articolo 3, comma 1, della legge 23 dicembre 1999, n. 499, nei limiti del 70 per cento, e' assegnato, con decreto del Ministro del tesoro, del bilancio e della programmazione economica, su proposta del Ministro delle politiche agricole e forestali, previa intesa in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, alle regioni per far fronte agli oneri, debitamente certificati e non finanziati dal Ministero delle politiche agricole e forestali, per attivita' e per servizi di loro competenza svolti o in corso di svolgimento per i quali non e' stato possibile procedere ad erogazioni finanziarie a causa del predetto ritardo.

11. Nell'ambito del fondo per il federalismo amministrativo, una quota di lire 80 miliardi e' destinata al finanziamento, dei contratti di servizio per il trasporto pubblico locale che verranno stipulati dalle singole regioni a statuto ordinario con la societa' Ferrovie dello Stato Spa, a. decorrere dal 1° gennaio 2001, in sostituzione del contratto gia' vigente a livello nazionale, per fare fronte ai maggiori servizi regionali erogati, rispetto agli esercizi precedenti, in conseguenza dell'entrata in esercizio di nuove linee e degli accordi tra lo Stato e le regioni raggiunti in conferenze di servizi per l'alta capacita'. La ripartizione di tale importo e' effettuata tra le regioni interessate con decreto del Ministro del tesoro, del bilancio e della programmazione economica, su proposta del Ministro dei trasporti e della navigazione, acquisito il parere della Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281.

12. Nell'articolo 96, comma 1, della legge 21 novembre 2000, n. 342, dopo il primo periodo e' inserito il seguente: "La quota del fondo di pertinenza delle province autonome di Trento e di Bolzano viene attribuita alle predette province che provvedono all'erogazione dei contributi direttamente in favore dei beneficiari, secondo i criteri stabiliti dal Ministro per la solidarieta' sociale".

### Art. 53.

(Regole di bilancio per le regioni, le province e i comuni)

1. Ai fini del concorso delle autonomie regionali e locali al rispetto degli obblighi comunitari della Repubblica e alla conseguente realizzazione degli obiettivi di finanza pubblica, e salvo quanto disposto dall'articolo 30 della legge 23 dicembre 1999, n. 488, valgono le seguenti disposizioni:

- a) per l'anno 2001 il disavanzo, computato ai sensi del comma 1 dell'articolo 28 della legge 23 dicembre 1998, n. 448, e successive modificazioni, non potra' essere superiore a quello del 1999, al netto delle spese per interessi passivi e di quelle per l'assistenza sanitaria, aumentato del 3 per cento. In sede di formazione del bilancio per il 2001, le regioni, le province e i comuni dovranno approvare, con le stesse procedure di approvazione del bilancio di previsione, i prospetti dimostrativi del computo del disavanzo per gli anni 1999 e 2001; tali prospetti dovranno riguardare sia i dati di competenza che i dati di cassa. I dati di competenza per il 1999 sono ricavati dal bilancio di previsione iniziale; i dati di cassa dovranno essere ricostruiti, per il 1999, sulla base dei conti consuntivi o dei verbali di chiusura; per il 2001 dovranno essere effettuate previsioni di cassa solo sui grandi aggregati di bilancio;
- b) per l'anno 2000 il disavanzo di cui all'articolo 28 della legge 23 dicembre 1998, n. 448, e successive modificazioni, e' calcolato anche al netto delle entrate e delle spese relative all'assistenza sanitaria;
- c) il confronto tra il 1999 e il 2001 e' effettuato escludendo dal computo spese ed entrate per le quali siano intervenute modifiche legislative di trasferimento o attribuzione di nuove funzioni o di nuove entrate proprie.

2. I presidenti delle giunte regionali garantiscono il rispetto dei vincoli derivanti dal patto di stabilita' interno per il sistema regionale e riferiscono collegialmente ogni tre mesi, in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, sull'andamento di spese, entrate e saldi di bilancio. In caso di peggioramento dei saldi rispetto ai valori programmati, le regioni interessate informano tempestivamente il Governo sulle misure individuate per il rispetto del vincolo e adottano i provvedimenti conseguenti.

3. Attraverso le loro associazioni, gli enti locali riferiscono ogni tre mesi in sede di Conferenza Stato-citta' e autonomie locali, sull'andamento di spese, entrate e saldi di bilancio delle province, dei comuni con popolazione superiore a 60.000 abitanti e di un campione rappresentativo dei restanti comuni.

4. Le disposizioni di cui al comma 1 non si applicano ai comuni con popolazione inferiore a 5.000 abitanti.

5. Le regioni a statuto speciale e le province autonome di Trento e di Bolzano concorrono al raggiungimento degli obiettivi di finanza pubblica per il triennio 2001-2003 con le modalita' stabilite dall'articolo 48, comma 2, secondo periodo, della legge 27 dicembre 1997, n. 449.

6. Il comma 2-bis dell'articolo 28 della legge 23 dicembre 1998, n. 448, e successive modificazioni, si applica anche per l'anno 2001. Alla lettera g) del citato comma 2-bis la parola: "2001" e' sostituita dalla seguente: "2002". All'articolo 8, comma 1, lettera d), del decreto-legge 27 ottobre 1995, n. 444, convertito, con modificazioni dalla legge 20 dicembre 1995, n. 539, il numero 4) e' sostituito dai seguenti: "4) anno 2000 per i comuni con popolazione da 3.000 a 4.999 abitanti; 4-bis) anno 2001 per i comuni con popolazione inferiore a 3.000 abitanti".

7. Al comma 1 dell'articolo 30 della legge 23 dicembre 1999. n. 488, sono soppresse le parole: "; l'importo cosi' risultante rimane costante nei tre anni successivi".

8. Al comma 6, primo periodo, dell'articolo 30 della legge 23 dicembre 1999, n. 488, le parole: "Qualora l'obiettivo di cui al comma 1 venga complessivamente conseguito, per l'anno 2000 e' concessa, a partire dall'anno successivo, una riduzione" sono sostituite dalle seguenti: "Qualora nell'anno 2000 l'obiettivo di cui al comma 1 venga distintamente raggiunto per il complesso delle regioni, il complesso delle province e il complesso dei comuni, ai singoli enti e' concessa a partire dall'anno 2001 una riduzione".

9. I trasferimenti erariali per l'anno 2001 di ogni singolo ente locale sono determinati in base alle disposizioni recate dall'articolo 30, comma 9, della legge 23 dicembre 1999, n. 488, ed alle successive disposizioni in materia. L'incremento delle risorse, derivante dall'applicazione del tasso programmato di inflazione per l'anno 2001 alla base di calcolo definita dall'articolo 49, comma 6, della legge 27 dicembre 1997, n. 449, e' distribuito secondo i criteri e le finalita' di cui all'articolo 31, comma 11, della legge 23 dicembre 1998, n. 448. L'applicazione del decreto legislativo 30 giugno 1997, n. 244, e' rinviata al 1° gennaio 2002.

10. A decorrere dall'anno 2001, i trasferimenti erariali agli enti locali di cui al comma 9 sono aumentati di lire 500.000 milioni annue, di cui lire 30.000 milioni destinate alle province, lire 420.000 milioni ai comuni, lire 20.000 milioni alle unioni di comuni e alle comunita' montane per l'esercizio associato delle funzioni e lire 30.000 milioni alle comunita' montane. I maggiori trasferimenti spettanti alle singole province ed ai singoli comuni sono attribuiti in proporzione all'ammontare dei trasferimenti a ciascuno attribuiti per l'anno 2000 a titolo di fondo ordinario, fondo consolidato e fondo perequantivo. Per le comunita' montane i maggiori trasferimenti sono prioritariamente attribuiti alle comunita' montane per le quali sono intervenute dal 1997 al 1999 variazioni in aumento del numero dei comuni membri con territorio montano, in misura pari a lire 20.000 per ciascun nuovo residente nel territorio montano della comunita'. I restanti contributi erariali spettanti alle comunita' montane sono attribuiti in proporzione alla popolazione residente nei territori montani.

11. Il fondo per lo sviluppo degli investimenti degli enti locali di cui all'articolo 28, comma 1, lettera c), del decreto legislativo 30 dicembre 1992, n. 504, risultante a consuntivo per l'anno 2001 e' mantenuto allo stesso livello per l'anno 2002, e' incrementato del tasso di inflazione programmato a decorrere dall'anno 2003 con una utilizzazione nell'ambito della revisione dei trasferimenti degli enti locali ed e' finalizzato all'attribuzione di contributi sulle rate di ammortamento dei mutui ancora in essere. Per l'anno 2002 le restanti risorse disponibili sono destinate per il 50 per cento ad incremento del fondo ordinario e per il restante 50 per cento sono distribuite secondo i criteri e per le finalita' di cui all'articolo 31, comma 11, della legge 23 dicembre 1998, n. 448. Ai fini dell'applicazione dell'articolo 9, comma 3, del decreto legislativo 30 giugno 1997, n. 244, recante riordino del sistema dei trasferimenti agli enti locali, nel calcolo delle risorse e' considerato il fondo perequativo degli squilibri di fiscalita' locale.

12. A titolo di riconoscimento di somme dovute per gli esercizi precedenti, il contributo di cui all'articolo 3, comma 9, secondo periodo, del decreto-legge 27 ottobre 1995, n. 444, convertito, con modificazioni, dalla legge 20 dicembre 1995, n. 539, e' attribuito dallo Stato alle province ed ai comuni interessati nella misura di ulteriori lire 9.993 milioni per l'anno 1999 e di lire 42.000 milioni per l'anno 2000, da ripartire in proporzione ai contributi in precedenza attribuiti e da liquidare in misura uguale negli esercizi 2001 e 2002.

13. A titolo di riconoscimento di somme dovute per gli esercizi precedenti, e' riconosciuto ai comuni che hanno dichiarato lo stato di dissesto finanziario entro il 31 dicembre 1993 ed hanno ottenuto entro il 31 dicembre 1996 l'approvazione, da parte del Ministero dell'interno, dell'ipotesi di bilancio stabilmente riequilibrato, un contributo a fronte degli oneri sostenuti per il trattamento economico di base annuo lordo spettante al personale posto in mobilita'. Il contributo spetta a far data dalla messa in disponibilita' del predetto personale sino al trasferimento presso altro ente o all'avvenuto riassorbimento nella propria pianta organica ai sensi dell'articolo 1, comma 46, della legge 23 dicembre 1996, n. 662, e comunque non oltre il 31 dicembre 1999. Il contributo non spetta per la parte di oneri gia' rimborsati ai sensi dei decreti-legge 7 aprile 1995, n. 106, 10 giugno 1995, n. 224, 3 agosto 1995, n. 323, 2 ottobre 1995, n. 414, 4 dicembre 1995, n. 514, 31 gennaio 1996, n. 38, 4 aprile 1996, n. 188, 3 giugno 1996, n. 309, 5 agosto 1996, n. 409, e 20 settembre 1996, n. 492. I comuni devono attestare gli oneri sostenuti per il personale posto in mobilita' mediante apposita certificazione la cui definizione, modalita' e termini per l'invio sono determinati con decreto del Ministero dell'interno, da emanare entro trenta giorni dalla data di entrata in vigore della presente legge. Ai fini del presente comma e' autorizzata la spesa di lire 86.000 milioni. In caso di insufficienza dello stanziamento il contributo e' attribuito in misura direttamente proporzionale agli oneri sostenuti.

14. A titolo di riconoscimento di somme dovute per gli esercizi precedenti, lo Stato eroga un contributo ai comuni che hanno subito negli anni 1998, 1999 e 2000 minori entrate derivanti dal gettito dell'imposta comunale sugli immobili a seguito dell'attribuzione della rendita catastale ai fabbricati classificati nella categoria catastale D. Il contributo statale e' commisurato alla differenza tra il gettito, derivante dai predetti fabbricati, dell'imposta comunale sugli immobili dell'anno 1993 con l'aliquota del 4 per mille e quello riscosso in ciascuno degli anni 1998, 1999 e 2000, anch'esso calcolato con l'aliquota del 4 per mille. Il contributo e' da intendere al netto del contributo minimo garantito, previsto dall'articolo 36, comma 1, lettera b), del decreto legislativo 30 dicembre 1992, n. 504, per il finanziamento dei servizi indispensabili per le materie di competenza statale delegate o attribuite ai comuni, da considerare per ciascuno degli anni 1998, 1999 e 2000. E' inoltre detratto il contributo erogato ai sensi dell'articolo 31, comma 3, della legge 23 dicembre 1998, n. 448, nei confronti degli enti che ne hanno usufruito. A tale fine e' autorizzata la spesa di lire 42.007 milioni. In caso di insufficienza dello stanziamento il contributo e' attribuito in misura direttamente proporzionale alla perdita del gettito dell'imposta comunale sugli immobili subita da ciascun comune al netto del contributo minimo garantito. Per l'attribuzione del contributo i comuni interessati inviano entro il termine perentorio del 31 marzo 2001 apposita certificazione il cui modello e le cui modalita' di invio sono definiti con decreto del Ministero dell'interno, da emanare entro trenta giorni dalla data di entrata in vigore della presente legge.

15. A titolo di riconoscimento del contributo spettante alle unioni di comuni, ai comuni risultanti da procedure di fusione ed alle comunita' montane svolgenti esercizio associato di funzioni comunali, e' attribuito agli enti interessati, per gli anni 1999 e 2000, un contributo complessivo di lire 20.000 milioni, da ripartire secondo i criteri di cui all'articolo 6, comma 8, della legge 3 agosto 1999, n. 265.

16. Il termine per deliberare le aliquote e le tariffe dei tributi locali, compresa l'aliquota dell'addizionale comunale all'IRPEF di cui all'articolo 1, comma 3, del decreto legislativo 28 settembre 1998, n. 360, recante istituzione di una addizionale comunale all'IRPEF, e successive modificazioni, e le tariffe dei servizi pubblici locali, nonche' per approvare i regolamenti relativi alle entrate degli enti locali, e' stabilito entro la data fissata da norme statali per la deliberazione del bilancio di previsione. I regolamenti sulle entrate, anche se approvati successivamente all'inizio dell'esercizio purche' entro il termine di cui sopra, hanno effetto dal 1 gennaio dell'anno di riferimento. ((99))

17. In deroga a quanto previsto dall'articolo 61, comma 3-bis, del decreto legislativo 15 novembre 1993, n. 507, introdotto dall'articolo 3 della legge 28 dicembre 1995, n. 549, per gli anni 2001 e 2002, ai fini della determinazione del costo di esercizio della nettezza urbana gestito in regime di privativa comunale, i comuni possono, con apposito provvedimento consiliare, considerare l'intero costo dello spazzamento dei rifiuti solidi urbani di cui all'articolo 7 del decreto legislativo 5 febbraio 1997, n. 22.

18. I comuni possono prorogare fino al 31 dicembre 2001, a condizioni piu' vantagiose per l'ente da stabilire tra le parti, i contratti di gestione gia' stipulati ai sensi degli articoli 25 e 52 del decreto legislativo 15 novembre 1993, n. 507, relativi all'affidamento in concessione del servizio di accertamento e riscossione, rispettivamente, dell'imposta comunale sulla pubblicita' e della tassa per l'occupazione di spazi ed aree pubbliche, aventi scadenza anteriormente alla predetta data.

19. Per l'anno 2001 ai comuni con popolazione inferiore a tremila abitanti e' concesso un contributo a carico dello Stato, entro il limite di lire 40 milioni per ciascun ente e per un importo complessivo di lire 167 miliardi, per le medesime finalita' dei contributi attribuiti a valere sul fondo nazionale ordinario per gli investimenti.

20. Il comma 4 dell'articolo 208 del decreto legislativo 30 aprile 1992, n. 285, e' sostituito dal seguente: "4. Una quota pari al 50 per cento dei proventi spettanti agli altri indicati nel comma 1 e' devoluta alle finalita' di cui al comma 2, nonche' al miglioramento della circolazione sulle strade, al potenziamento ed al miglioramento della segnaletica stradale e alla redazione dei piani di cui all'articolo 36, alla fornitura di mezzi tecnici necessari per i servizi di polizia stradale di loro competenza e alla realizzazione di interventi a favore della mobilita' ciclistica nonche', in misura non inferiore al 10 per cento della predetta quota, ad interventi per la sicurezza stradale in particolare a tutela degli utenti deboli: bambini, anziani, disabili pedoni e ciclisti. Gli stessi enti determinano annualmente, con delibera della giunta, le quote da destinare alle predette finalita'. Le determinazioni sono comunicate al Ministro dei lavori pubblici. Per i comuni la comunicazione e' dovuta solo da parte di quelli con popolazione superiore a diecimila abitanti".

21. Fermo restando quanto previsto dall'articolo 61, comma 1, del decreto legislativo 15 dicembre 1997, n. 446, e successive modificazioni, l'ammontare delle riscossioni per l'anno 1999 dell'imposta sulle assicurazioni contro la responsabilita' civile derivante dalla circolazione dei veicoli a motore esclusi i ciclomotori nelle province delle regioni a statuto ordinario e' determinato aumentando l'importo risultante dai dati del Ministero delle finanze di una somma pari a 462 miliardi di lire, forfettariamente calcolata per tenere conto degli importi risultati non incassati dalle province nel primo bimestre dell'anno 1999; tale importo viene ripartito tra ciascuna provincia, ai fini dell'attuazione del predetto articolo 61, comma 1, del decreto legislativo n. 446 del 1997, in proporzione agli incassi risultanti al Ministero delle finanze per il primo bimestre dell'anno 2000. Al fine di consentire un puntuale monitoraggio delle riscossioni le province trasmettono, entro il 28 febbraio 2001, al Ministero dell'interno una certificazione firmata dal Presidente della Giunta attestante le riscossioni mensili relative agli anni 1999 e 2000.

22. Con riferimento all'assegnazione alle province del gettito di imposta sull'assicurazione obbligatoria contro la responsabilita' civile derivante dalla circolazione dei veicoli a motore esclusi i ciclomotori, i concessionari della riscossione provvedono mensilmente ad inviare alle autorita' competenti i relativi allegati esplicativi.

23. Gli enti locali con popolazione inferiore a cinquemila abitanti fatta salva l'ipotesi di cui all'articolo 97, comma 4, lettera d), del testo unico delle leggi sull'ordinamento degli enti locali, approvato con decreto legislativo 18 agosto 2000, n. 267, anche al fine di operare un contenimento della spesa, possono adottare disposizioni regolamentari organizzative, se necessario anche in deroga a quanto disposto all'articolo 3, commi 2, 3 e 4, del decreto legislativo 3 febbraio 1993, n. 29, e successive modificazioni, e all'articolo 107 del predetto testo unico delle leggi sull'ordinamento degli enti locali, attribuendo ai componenti dell'organo esecutivo la responsabilita' degli uffici e dei servizi ed il potere di adottare atti anche di natura tecnica gestionale. Il contenimento della spesa deve essere documentato ogni anno, con apposita deliberazione, in sede di approvazione del bilancio.

--------------- AGGIORNAMENTO (99) La L. 27 dicembre 2019, n. 160 ha disposto (con l'art. 1, comma 779) che "Per l'anno 2020, i comuni, in deroga all'articolo 1, comma 169, della legge 27 dicembre 2006, n. 296, all'articolo 53, comma 16, della legge 23 dicembre 2000, n. 388, e all'articolo 172, comma 1, lettera c), del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, possono approvare le delibere concernenti le aliquote e il regolamento dell'imposta oltre il termine di approvazione del bilancio di previsione per gli anni 2020-2022 e comunque non oltre il 30 giugno 2020. Dette deliberazioni, anche se approvate successivamente all'inizio dell'esercizio, purche' entro il termine innanzi indicato, hanno effetto dal 1° gennaio dell'anno 2020".

### Art. 54.

(Modifica al decreto legislativo 15 dicembre 1997, n. 446 in materia di tariffe, prezzi pubblici e tributi locali)

1. Al decreto legislativo 15 dicembre 1997, n. 446, e successive modificazioni, concernente il termine per l'approvazione delle tariffe e dei prezzi pubblici, sono apportate le seguenti modifiche:

- a) all'articolo 54, dopo il comma 1 e' aggiunto il seguente: "1-bis. Le tariffe ed i prezzi pubblici possono comunque essere modificati; in presenza di rilevanti incrementi nei costi relativi ai servizi stessi, nel corso dell'esercizio finanziario. L'incremento delle tariffe non ha effetto retroattivo";
- b) all'articolo 56, comma 3, e' aggiunto, in fine, il seguente periodo: "L'aumento tariffario interessa le immatricolazioni effettuate e gli atti formati dalla sua decorrenza e, qualora esso sia deliberato con riferimento alla stessa annualita' in cui e' eseguita la notifica prevista dal presente comma, opera dalla data della notifica stessa".

### Art. 55.

(Norme particolari per gli enti locali)

1. Al comma 37 dell'articolo 31 della legge 23 dicembre 1998, n. 448, dopo il primo periodo e' inserito il seguente: "Per il solo anno 2001 la percentuale destinata al Ministero dell'interno e' pari al 30 per cento e il restante 20 per cento e' destinato alla provincia di Varese".

### Art. 56.

(Regole di bilancio per le universita' e gli enti di ricerca)

1. Il sistema universitario concorre alla realizzazione degli obiettivi di finanza pubblica per il triennio 2001-2003, garantendo che il fabbisogno finanziario, riferito alle universita' statali ai policlinici universitari a gestione diretta, ai dipartimenti ed a tutti gli altri centri con autonomia finanziaria e contabile, da esso complessivamente generato in ciascun anno non sia superiore al fabbisogno determinato a consuntivo nell'esercizio precedente incrementato del 4 per cento per ciascun anno.

2. Il Consiglio nazionale delle ricerche, l'Agenzia spaziale italiana, l'Istituto nazionale di fisica nucleare, l'Istituto nazionale di fisica della materia, l'Ente per le nuove tecnologie, l'energia e l'ambiente concorrono alla realizzazione degli obiettivi di finanza pubblica per il triennio 2001-2003, garantendo che il fabbisogno finanziario da essi complessivamente generato in ciascun anno non sia superiore al fabbisogno determinato a consuntivo nell'esercizio precedente incrementato del 5 per cento per ciascun anno.

3. Il fabbisogno finanziario di cui ai commi 1 e 2 e' incrementato degli effetti derivanti dall'approvazione di nuove disposizioni normative nel triennio 2001-2003.

4. La determinazione del fabbisogno finanziario per ciascun ateneo e per ciascun ente di ricerca e' effettuata con le modalita' di cui all'articolo 51, commi 1 e 2, della legge 27 dicembre 1997, n. 449.

5. Il Ministro dell'universita' e della ricerca scientifica e tecnologica, tenuto conto delle esigenze finanziarie rappresentate nei programmi triennali presentati dalle Scuole superiori ad ordinamento speciale, determina annualmente, con proprio decreto, sentito il Comitato nazionale per la valutazione del sistema universitario, le risorse da riassegnare a ciascuna Scuola sul fondo di finanziamento ordinario, sul fondo per l'edilizia universitaria e sul fondo per la programmazione. In sede di prima applicazione del presente comma, il finanziamento ordinano aggiuntivo di importo complessivo non superiore a lire 22 miliardi nel triennio 2001-2003, da destinare alle Scuole superiori ad ordinamento speciale, ivi comprese quelle di Catania, Lecce e Pavia in via di costituzione, viene assicurato nell'ambito degli stanziamenti relativi al fondo di finanziamento ordinario delle universita' in ragione di lire 7 miliardi per ciascuno degli anni 2001 e 2002 e di lire 8 miliardi per l'anno 2003.

6. I consorzi per l'istruzione universitaria a distanza, di cui al comma 3 dell'articolo 11 della legge 19 novembre 1993, n. 341, sono assimilati ai cosorzi universitari a tutti gli effetti, anche ai fini del loro finanziamento ordinario di funzionamento a valere sull'apposito stanziamento dello stato di previsione del Ministero dell'universita' e della ricerca scientifica e tecnologica.

### Art. 57.

(Finanza di progetto)

1. Al fine di garantire il raggiungimento degli obiettivi fissati dal Documento di programmazione economico-finanziaria per gli anni 2001-2004 in coerenza con gli orientamenti programmatici definiti dal CIPE, le amministrazioni statali, in fase di pianificazione ed attuazione dei programmi di spesa per la realizzazione di infrastrutture, acquisiscono le valutazioni dell'unita' tecnica-finanza di progetto, di cui all'articolo 7 della legge 17 maggio 1999, n. 144, secondo modalita' e parametri definiti con deliberazione del CIPE, da emanare entro novanta giorni dalla data di entrata in vigore della presente legge, sentita la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281. Con deliberazione del CIPE, da emanare entro novanta giorni dalla data di entrata in vigore della presente legge, sentita la medesima Conferenza unificata, saranno individuate ulteriori modalita' di incentivazione all'utilizzo dello strumento della finanza di progetto. Le amministrazioni regionali e locali possono ricorrere alle valutazioni dell'unita' tecnica-finanza di progetto secondo le modalita' previste dal presente articolo.

### Art. 58.

(Consumi intermedi)

1. Ai sensi di quanto previsto dall'articolo 26, comma 3, della legge 23 dicembre 1999, n. 488, per pubbliche amministrazioni si intendono quelle definite dall'articolo 1 del decreto legislativo 3 febbraio 1993, n. 29. Le convenzioni di cui al citato articolo 26 sono stipulate dalla Concessionaria servizi informatici pubblici (CONSIP) Spa, per conto del Ministero del tesoro, del bilancio e della programmazione economica, ovvero di altre pubbliche amministrazioni di cui al presente comma, e devono indicare, anche al fine di tutelare il principio della libera concorrenza e dell'apertura dei mercati, i limiti massimi dei beni e dei servizi espressi in termini di quantita'. Le predette convenzioni indicano altresi' il loro periodo di efficacia.

2. All'articolo 26, comma 1, della legge 23 dicembre 1999, n. 488, dopo le parole: "amministrazioni dello Stato" sono inserite le seguenti: "anche con il ricorso alla locazione finanziaria".

3. Con uno o piu' regolamenti da emanare ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400, sono stabiliti i criteri per la standardizione e l'adeguamento dei sistemi contabili delle pubbliche amministrazioni, anche attraverso strumenti elettronici e telematici, finalizzati anche al monitoraggio della spesa e dei fabbisogni.

4. Con uno o piu' regolamenti da emanare ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400, sono stabiliti i tempi e le modalita' di pagamento dei corrispettivi relativi alle forniture di beni e servizi nonche' i relativi sistemi di collaudo o atti equipollenti.

5. Con uno o piu' regolamenti da emanare ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400, sono definite le procedure di scelta del contraente e le modalita' di utilizzazione degli strumenti elettronici ed informatici che le amministrazioni aggiudicatrici possono utilizzare ai fini dell'acquisizione di beni e servizi, assicurando la parita' di condizioni dei partecipanti, nel rispetto dei principi di trasparenza e di semplificazione della procedura.

6. Ai fini della razionalizzazione della spesa per l'acquisto di beni mobili durevoli, gli stanziamenti di conto capitale destinati a tale scopo possono essere trasformati in canoni di locazione finanziaria. Il Ministro del tesoro, del bilancio e della programmazione economica autorizza la trasformazione e certifica l'equivalenza dell'onere finanziario complessivo.

### Art. 59.

(Acquisto di beni e servizi a rilevenza regionale degli enti decentrati di spesa)

1. ((COMMA ABROGATO DALLA L. 27 DICEMBRE 2006, N. 296)).

2. ((COMMA ABROGATO DALLA L. 27 DICEMBRE 2006, N. 296)).

3. ((. . .)) per lo svolgimento delle attivita' strumentali e di supporto alla didattica e alla ricerca, una o piu' universita' possono ((. . .)) costituire fondazioni di diritto privato con la partecipazione di enti ed amministrazioni pubbliche e soggetti privati. Con regolamento adottato ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400, sono stabiliti i criteri e le modalita' per la costituzione e il funzionamento delle predette fondazioni, con individuazione delle tipologie di attivita' e di beni che possono essere conferiti alle medesime nell'osservanza del criterio della strumentalita' rispetto alle funzioni istituzionali, che rimangono comunque riservate all'universita'.

4. ((COMMA ABROGATO DALLA L. 27 DICEMBRE 2006, N. 296)).

5. ((COMMA ABROGATO DALLA L. 27 DICEMBRE 2006, N. 296)).

6. ((COMMA ABROGATO DALLA L. 27 DICEMBRE 2006, N. 296)).

### Art. 60.

(Analisi dei mercati dei prodotti acquistati dalla pubblica amministrazione)

1. Al fine di massimizzare l'efficacia delle convenzioni e della collaborazione da fornire alle aggregazioni di enti e aziende definite all'articolo 59, la CONSIP Spa si avvale della collaborazione della Commissione tecnica per la spesa pubblica e dell'Istituto di studi e analisi economica (ISAE) per la definizione di un'appropriata classificazione merceologica delle principali voci di acquisto della pubblica amministrazione, per la individuazione dell'area di interesse delle convenzioni da predisporre, in relazione alle diverse caratteristiche e condizioni:

- a) dei beni oggetto delle convenzioni, distinguendo in particolare tra beni preesistenti, beni forniti appositamente su richiesta e beni prodotti esclusivamente in mercati locali;
- b) dell'offerta: monopoli pubblici o privati regolamentati, monopoli privati in mercati contendibili o selezionabili mediante asta, oligopoli nazionali o internazionali, concorrenza;
- c) delle forme e tecniche di aggiudicazione delle forniture a seconda delle tipologie industriali del mercato di riferimento: affidamento diretto, tipi di gara e semplice ricorso al mercato.

### Art. 61.

(Spese per l'energia elettrica, postali e per combustibili)

1. Le regioni, entro sessanta giorni dalla data di entrata in vigore della presente legge, adottano gli specifici atti di programmazione di cui all'articolo 14, comma 2, lettera b), del decreto legislativo 16 marzo 1999, n. 79.

2. Il Ministero del tesoro, del bilancio e della programmazione economica promuove la costituzione dei consorzi di cui all'articolo 25 della legge 23 dicembre 1999, n. 488, ai quali le pubbliche amministrazioni di cui all'articolo 1, comma 2, del decreto legislativo 3 febbraio 1993, n. 29, aderiscono con le modalita' stabilite dalla direttiva del Presidente del Consiglio dei ministri emanata ai sensi dell'articolo 25 della citata legge n. 488 del 1999. Le amministrazioni che non sono in possesso dei requisiti indicati dal decreto legislativo 16 marzo 1999. n. 79, per la partecipazione a tali consorzi adeguano le caratteristiche della fornitura di energia elettrica alle proprie effettive esigenze e, comunque, secondo quanto indicato dal Ministro del tesoro, del bilancio e della programmazione economica con proprio decreto.

3. Con regolamento da emanare ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, e' stabilita l'introduzione di nuove modalita' di invio e consegna dei mezzi di pagamento delle pensioni e degli assegni congeneri a carico del bilancio dello stato, ivi compresi gli assegni di conto corrente postale di serie speciale di cui al decreto del Presidente della Repubblica 8 luglio 1986, n. 429.

4. Al fine di ridurre la spesa per l'approvvigionamento di combustibili e di utilizzare impianti o combustibili a basso impatto ambientale per il riscaldamento degli immobili, le pubbliche amministrazioni provvedono alla riconversione degli impianti di riscaldamento direttamente ovvero mediante le convenzioni di cui agli articoli dal 58 al 60.

5. Entro tre mesi dalla data di entrata in vigore della presente legge, il Ministro dell'ambiente identifica gli impianti ed i combustibili a basso tenore inquinante e a basso costo promuovendone l'utilizzo.

6. Il competente Ministero non procede al recupero di imposta e relativi accessori per quanto attiene ad introiti tributari, a qualunque titolo dovuti e comunque denominati, derivanti dall'esercizio di servizi elettrici gestiti direttamente dai comuni e ceduti a terzi gestori. Gli enti locali interessati ai benefici di cui al precedente periodo devono presentare apposita istanza di estinzione del debito al competente Ministero entro trenta giorni dalla data di entrata in vigore della presente legge.

### Art. 62.

(Affitti passivi)

1. Al comma 1 dell'articolo 24 della legge 23 dicembre 1999, n. 488, le parole da: "II Presidente" fino a: "entrata in vigore della presente legge" sono sostituite dalle seguenti: "Il Ministro del tesoro, del bilancio e della programmazione economica, con il supporto dell'Agenzia del demanio o di apposita struttura individuata dal Ministero del tesoro, del bilancio e della programmazione economica, che puo' avvalersi eventualmente di fornitori esterni specializzati scelti con le modalita' di cui all'articolo 26 della presente legge"; e le parole: "con il supporto dell'Osservatorio sul patrimonio immobiliare degli enti previdenziali," sono soppresse.

2. Al comma 3 dell'articolo 24 della citata legge n. 488 del 1999, le parole: "anche avvalendosi della collaborazione dell'Osservatorio di cui al medesimo comma l" sono sostituite dalle seguenti: "sulla base di piani di razionalizzazione e di ottimizzazione degli immobili in uso, definiti di concerto con l'Agenzia del demanio o con l'apposita struttura di cui al medesimo comma 1".

3. Le altre pubbliche amministrazioni che intendono attuare piani di razionalizzazione e riduzione degli spazi adibiti a pubblici uffici si avvalgono dell'Agenzia del demanio o della struttura di cui al comma 1 dell'articolo 24 della citata legge n. 488 del 1999, come modificato dal comma 1 del presente articolo. L'attuazione dei piani di razionalizzazione avviene in deroga alla normativa vigente in materia di contratti di locazione passiva per le amministrazioni centrali e periferiche dello Stato.

4. ((COMMA ABROGATO DAL D.L. 6 DICEMBRE 2011, N. 201, CONVERTITO CON MODIFICAZIONI DALLA L. 22 DICEMBRE 2011, N. 214)).

5. Entro il 31 dicembre 2001 le amministrazioni centrali e periferiche dello Stato, nonche' le altre pubbliche amministrazioni, devono pervenire al conseguimento di risparmi pari ad almeno il 20 per cento della spesa annua per affitti e locazioni.

### Art. 63.

(Vettovagliamento e approvvigionamento ((...)) della Polizia di Stato, del Corpo, della guardia di finanza e del Corpo nazionale dei vigili del fuoco)

1. Il servizio di vettovagliamento sostituisce le razioni viveri in natura, le quote miglioramento vitto, le integrazioni vitto ed i generi di conforto in speciali condizioni di impiego, nonche' ogni altra forma di fornitura di alimenti a titolo gratuito.

2. Le modalita' di fornitura del servizio di vettovagliamento a favore dei militari e del personale, anche ad ordinamento civile delle Forze di polizia e del Corpo nazionale dei vigili del fuoco ai quali le norme vigenti attribuiscono il diritto ai trattamenti di cui al comma 1 sono stabilite sulla base delle procedure di cui all'articolo 59 con decreto del Ministro competente per l'amministrazione di appartenenza da adottare di concerto con il Ministro del tesoro, del bilancio e della programmazione economica entro il 30 settembre di ogni anno con riferimento all'anno successivo. Con il medesimo decreto sono determinati il valore in denaro delle razioni viveri e del miglioramento vitto, nonche' la composizione dei generi di conforto. ((All'Arma dei carabinieri si applica l'articolo 546 del codice dell'ordinamento militare, emanato con decreto legislativo 15 marzo 2010, n. 66.))

3. Il servizio di vettovagliamento e' assicurato, in relazione alle esigenze operative, logistiche, di dislocazione e di impiego degli enti e reparti, della Polizia di Stato, del Corpo della guardia di finanza e del Corpo nazionale dei vigili del fuoco, nelle seguenti forme:

- a) gestione diretta, ovvero affidata, in tutto od in parte, a privati mediante apposite convenzioni;
- b) fornitura di buoni pasto;
- c) fornitura di viveri speciali da combattimento. La gestione diretta e le eventuali convenzioni sono finanziate mediante utilizzo, anche in modo decentrato, del controvalore in contanti dei trattamenti alimentari determinati con il decreto di cui al comma 2.

4. In sede di prima applicazione il decreto di cui al comma 2, da emanare entro sessanta giorni dalla data di entrata in vigore della presente Legge, stabilisce il termine iniziale di operativita' del nuovo sistema di vettovagliamento. Con effetto da tale termine sono abrogate le disposizioni di cui all'articolo 14, comma 4, della legge 28 luglio 1999, n. 266.

5. Dopo il comma 3 dell'articolo 5 del decreto legislativo 28 dicembre 1998, n. 496, e' aggiunto il seguente: "3-bis. Il ricorso alla NATO Maintenance and Supply Agency previsto dal comma 3 e' esteso agli approvvigionamenti di beni e servizi comunque connessi al sostegno logistico dei contingenti delle Forze armate impiegati in operazioni fuori dal territorio nazionale condotte sotto l'egida dell'ONU o di altri organismi sovranazionali".

6. Il Ministero del tesoro, del bilancio e della programmazione economica provvede alla realizzazione delle attivita', ivi comprese quelle di tipo consulenziale, previste dai precedenti articoli, anche avvalendosi, con apposite convenzioni, di societa', gia' costituite o da costituire, interamente possedute, direttamente o indirettamente. Le predette societa' possono fornire servizi di consulenza a supporto anche di altre attivita' del Ministero.

### Art. 64.

(Determinazione delle rendite catastali e trasferimenti erariali ai comuni)

1. A decorrere dall'anno 2001 i minori introiti relativi all'ICI conseguiti dai comuni per effetto dei minori imponibili derivanti dalla autodeterminazione provvisoria delle rendite catastali dei fabbricati di categoria D, eseguita dai contribuenti secondo quanto previsto dal decreto del Ministro delle finanze 19 aprile 1994, n. 701, sono compensati con corrispondente aumento dei trasferimenti statali se di importo superiore a lire 3 milioni e allo 0,5 per cento della spesa corrente prevista per ciascun anno.

2. Qualora, ai singoli comuni che beneficiano dell'aumento dei maggiori trasferimenti erariali di cui al comma 1 derivino, per effetto della determinazione della rendita catastale definitiva da parte degli uffici tecnici erariali, introiti superiori, almeno del 30 per cento, rispetto a quelli conseguiti prima della autodeterminazione provvisoria delle rendite catastali dei fabbricati classificabili nel gruppo catastale D ai sensi del decreto del Ministro delle finanze 19 aprile 1994, n. 701, i trasferimenti erariali di parte corrente spettanti agli stessi enti sono ridotti in misura pari a tale eccedenza. La riduzione si applica e si intende consolidata a decorrere dall'anno successivo rispetto a quello in cui la determinazione della rendita catastale e' divenuta inoppugnabile anche a seguito della definizione di eventuali ricorsi in merito.

3. Con decreto del Ministro dell'interno, di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, sono stabiliti i criteri e le modalita' per l'applicazione dei commi 1 e 2.

4. Il termine del 31 dicembre 2000 previsto dall'articolo 7, comma 5, della legge 23 dicembre 1999, n. 488, per le variazioni delle iscrizioni in catasto dei fabbricati gia' rurali, e' ulteriormente prorogato al 31 dicembre 2001.

5. Il termine di cui all'articolo, 1, comma 6, del decreto del Presidente della Repubblica 23 marzo 1998, n. 139, come modificato dall'articolo 1, comma 1, lettera c), del decreto del Presidente della Repubblica 30 dicembre 1999, n. 536, fissato al 31 dicembre 2000 e' prorogato al 1° luglio 2001.

### Art. 65.

(Semplificazione di procedure)

1. Ai fini dell'accelerazione e della semplificazione delle procedure di liquidazione degli enti disciolti di cui alla, legge 4 dicembre 1956, n. 1404, con decreto del Ministro del tesoro, del bilancio e della programmazione economica, da emanare entro il 31 marzo 2001, e' adottato un regolamento, ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, nel rispetto del criterio della distinzione tra attivita' di indirizzo politico-amministrativo e funzione di gestione.

2. Il fondo di rotazione di cui all'articolo 5 della legge 16 aprile 1987, n. 183, e' autorizzato, nei limiti delle disponibilita' finanziarie esistenti, ad anticipare, in favore delle amministrazioni centrali dello Stato titolare di interventi comunitari, la quota di acconto prevista dall'articolo 32, paragrafo 2, del regolamento (CE) n. 1260/1999 del Consiglio, del 21 giugno 1999, nonche' le quote di saldo del contributo comunitario connesse con la stipula di convenzioni con le istituzioni comunitarie da parte del Ministero del tesoro, del bilancio e della programmazione economica. Le risorse anticipate dal fondo di rotazione sono reintegrate a valere sulle somme accreditate dall'Unione europea per ciascun intervento.

3. L'articolo 17, comma 3, della legge 17 maggio 1999, n. 144, e' sostituito dal seguente: "3. Le amministrazioni responsabili dell'attuazione degli interventi procedono al recupero, presso gli organismi responsabili, dei contributi comunitari loro trasferiti e non utilizzati nell'ambito dei programmi di rispettiva competenza, unitamente agli interessi legali maturati nel periodo intercorso tra la data di erogazione dei contributi stessi e la data di recupero, nonche' alle differenze di cambio come previsto dall'articolo 59 della legge 22 febbraio 1994, n. 146, versando il relativo importo al fondo di rotazione indicato al comma 2, a titolo di reintegro delle anticipazioni effettuate ai sensi del medesimo comma 2, ovvero ad apposito capitolo dell'entrata del bilancio dello Stato per le anticipazioni di cui al comma 1".

4. All'articolo 2, comma 2, lettera c), della legge 11 febbraio 1994, n. 109, e successive modificazioni, le parole: "edifici destinati a scopi amministrativi. ed edifici industriali" sono sostituite dalle seguenti: "edifici destinati a funzioni pubbliche amministrative". La disposizione di cui alla citata lettera c), come modificata dal primo periodo, si applica anche ai lavori eseguiti nell'ambito degli strumenti di programmazione negoziata in corso di attuazione.

5. Al comma 2 dell'articolo 26 del decreto del Presidente della Repubblica 25 gennaio 2000, n. 34, le parole: "; per le classifiche inferiori e' ammesso anche il possesso del diploma di geometra" sono sostituite dalle seguenti: ", di diploma di perito industriale edile o di geometra; per le classifiche inferiori e' ammesso anche il possesso del diploma di geometra e di perito industriale edile".

6. Il comma 3 dell'articolo 31 del decreto del Presidente della Repubblica 25 gennaio 2000, n. 34, e' abrogato.

7. A decorrere dalla data di entrata in vigore della presene legge, l'articolo 8, comma 8, della legge 11 febbraio 1994, n. 109, e successive modificazioni, si applica anche alle regioni, eccetto che per gli albi istituiti nel settore agricolo-forestale.

### Art. 66.

(Controllo dei flussi finanziari degli enti pubblici e norme sulla tesoreria unica)

1. Per gli anni 2001 e 2002 conservano validita' le disposizioni che disciplinano la riduzione delle giacenze di cui all'articolo 47 comma 1, della legge 27 dicembre 1997, n. 449. Per gli enti locali le disposizioni si applicano a tutte le province e ai comuni con popolazione superiore a 50.000 abitanti.

2. Per gli anni 2001 e 2002 i soggetti destinatari della norma di cui all'articolo 8, comma 3, del decreto-legge 31 dicembre 1996, n. 669, convertito, con modificazioni, dalla legge 28 febbraio 1997, n. 30, non possono effettuare prelevamenti dai rispettivi conti aperti presso la tesoreria dello Stato superiori all'importo cumulativamente prelevato alla fine di ciascun bimestre dell'anno precedente aumentato del 2 per cento. Continua ad applicarsi la disposizione di cui all'articolo 47, comma 4, della legge 27 dicembre 1997, n. 449.

3. All'articolo 1, comma 3, della legge 27 dicembre 1997, n. 449, dopo le parole: "intervento di banche" sono inserite le seguenti: "o della societa' Poste Italiane Spa".

4. Per l'anno 2001 le erogazioni di cassa a favore delle scuole ed istituti di ogni ordine e grado, nonche' delle istituzioni educative, sono disposte con l'obiettivo di assicurare che per l'anno 2001 i pagamenti delle istituzioni scolastiche non risultino globalmente superiori a quelli rilevati nel conto consuntivo 1999, incrementati del 6 per cento. Per l'anno 2002 i predetti pagamenti non dovranno superare l'obiettivo previsto per l'anno precedente incrementato di un punto in piu' del tasso di inflazione programmato. Nei decreti attuativi si terra' conto dell'intervenuta autonomia delle istituzioni scolastiche.

5. A decorrere dal 1° marzo 2001 le regioni sono incluse nella tabella A annessa alla legge 29 ottobre 1984, n. 720, e successive modificazioni.

6. Le entrate costituite da assegnazioni, contributi, devoluzioni o compartecipazioni di tributi erariali e quant'altro proveniente dal bilancio dello Stato a favore delle regioni devono essere versate nelle contabilita' speciali infruttifere che devono essere aperte presso le competenti sezioni di tesoreria provinciale dello Stato. Tra le predette entrate sono comprese quelle provenienti da operazioni di indebitamento assistite, in tutto o in parte, da interventi finanziari dello Stato sia in conto capitale che in conto interessi. Le entrate relative ai finanziamenti comunitari continuano ad affluire nel conto corrente infruttifero intestato a ciascun ente ed aperto presso la tesoreria centrale dello Stato.

7. Si applicano le disposizioni contenute nei commi 3, 4, 5 e 6 dell'articolo 7 del decreto legislativo 7 agosto 1997, n. 279.

8. Ferme restando le disposizioni contenute nel decreto del Ministro del tesoro, del bilancio e della programmazione economica del 24 marzo 1998, pubblicato nella Gazzetta Ufficiale n. 71 del 26 marzo 1998, l'imposta regionale sulle attivita' produttive (IRAP) e' riversata alle contabilita' speciali di cui al comma 6; l'addizionale regionale all'IRPEF e' versata mensilmente dalla tesoreria centrale dello Stato sui conti correnti accesi da ciascuna regione presso il proprio tesoriere.

9. Sino all'apertura delle contabilita' speciali di cui al comma 6, per l'IRAP e l'addizionale regionale all'IRPEF continuano ad applicarsi le vigenti disposizioni che disciplinano il riversamento alle regioni delle somme a tale titolo riscosse.

10. Le quote dell'accisa, sulle benzine continuano ad essere versate ai tesorieri delle regioni con le modalita' di cui all'articolo 8, comma 1, lettera a), del decreto legislativo 7 agosto 1997, n. 279.

11. A decorrere dal 1° marzo 2001 le disposizioni di cui all'articolo 7 del decreto legislativo 7 agosto 1997, n. 279, si estendono alle province e ai comuni con popolazione inferiore a 10.000 abitanti.

12. Per le regioni a statuto speciale e le province autonome di Trento e di Bolzano, alla revisione delle procedure e delle modalita' di gestione dei flussi di cassa, di cui ai commi da 5 a 10 del presente articolo, si provvede con norme di attuazione adottate secondo quanto previsto dai rispettivi statuti di autonomia.

13. Per garantire la necessaria autonomia della Cassa depositi e prestiti, ai fini del raccordo con le esigenze di funzionamento degli enti locali e delle altre autonomie e con quelle di controllo dei flussi finanziari degli enti pubblici, al comma 1 dell'articolo 5 del decreto legislativo 30 luglio 1999, n. 284, il secondo ed il terzo periodo sono sostituiti dalle seguenti parole: ", anche per il personale del proprio ruolo dirigenziale, ivi compreso il suo reclutamento. Per le materie non disciplinate dall'autonomo ordinamento si applica il decreto legislativo 3 febbraio 1993, n. 29, e successive modificazioni".

14. Al fine di favorire la puntuale realizzazione dei programmi di gestione faunistico-ambientale sul territorio nazionale da parte delle regioni, degli enti locali e delle altre istituzioni delegate ai sensi della legge 11 febbraio 1992, n. 157, o successive modificazioni, a decorrere dall'anno 2004 il 50 per cento dell'introito derivante dalla tassa erariale di cui all'articolo 5 della tariffa annessa al decreto del Presidente della Repubblica 26 ottobre 1972, n. 641, come sostituita dal decreto del Ministro delle finanze del 28 dicembre 1995, pubblicato nella Gazzetta Ufficiale n. 303 del 30 dicembre 1995, e' trasferito alle regioni. Per la realizzazione degli stessi programmi, in via transitoria, per ciascuno degli anni 2001, 2002 e 2003, e' stanziata la somma di 10 miliardi di lire. Il Ministro delle finanze provvede alla ripartizione delle risorse disponibili, di intesa con la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano.

### Art. 67.

(Compartecipazione al gettito IRPEF per i comuni per l'anno 2002)

1. I decreti di cui all'articolo 1, comma 2, del decreto legislativo 28 settembre 1998, n. 360, e successive modificazioni, relativi all'aliquota di compartecipazione dell'addizionale provinciale e comunale all'imposta sul reddito delle persone fisiche, per la parte specificata nel comma 3-bis dell'articolo 2 del citato decreto legislativo, ovvero relativamente alla parte non connessa all'effettivo trasferimento di compiti e funzioni, ai sensi dell'articolo 7 della legge 15 marzo 1997, n. 59, sono emanati entro il 30 novembre 2002.

2. All'articolo 1, comma 2, del decreto legislativo 28 settembre 1998, n. 360, sono apportate le seguenti modificazioni:

- a) nel primo periodo, dopo le parole: "conseguentemente determinata" sono inserite le seguenti: " , con i medesimi decreti,";
- b) nel primo periodo, dopo le parole: "con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917", sono aggiunte le seguenti: " , nonche' eventualmente la percentuale dell'acconto dell'imposta sul reddito delle persone fisiche relativamente al periodo di imposta da cui decorre la suddetta riduzione delle aliquote".

3. Per gli anni 2002 e 2003 e' istituita per i comuni una compartecipazione al gettito dell'imposta sul reddito delle persone fisiche in una misura pari al 4,5 per cento del riscosso in conto competenza affluente al bilancio dello Stato, per l'esercizio finanziario precedente, quali entrate derivanti dall'attivita' ordinaria di gestione iscritte al capitolo 1023. Il gettito della compartecipazione, attribuito ad un apposito capitolo di spesa dello stato di previsione del Ministero dell'interno, e' ripartito dallo stesso Ministero a ciascun comune in proporzione all'ammontare, fornito dal Ministero dell'economia e delle finanze sulla base dei dati disponibili, dell'imposta netta, dovuta dai contribuenti, distribuito territorialmente in funzione del domicilio fiscale risultante presso l'anagrafe tributaria. Per l'anno 2002, il gettito e' ripartito tra i comuni sulla base dei dati statistici piu' recenti forniti dal Ministero dell'economia e delle finanze entro il 30 giugno 2002. ((25))

4. I trasferimenti erariali sono ridotti a ciascun comune in misura pari al gettito spettante dalla compartecipazione di cui al comma 3. Nel caso in cui il livello dei trasferimenti spettanti ai singoli enti risulti insufficiente a consentire il recupero integrale della compartecipazione, la compartecipazione stessa e' corrisposta al singolo ente nei limiti dei trasferimenti spettanti per l'anno.

5. Ai fini del riparto del gettito, relativamente all'anno 2003, il Ministero dell'economia e delle finanze, entro il 30 luglio 2002, provvede a comunicare al Ministero dell'interno i dati previsionali relativi all'ammontare del gettito della compartecipazione di cui al comma 3, ripartito per ciascun comune in base ai criteri di cui al medesimo comma 3. Entro il 30 ottobre 2002 il Ministero dell'interno comunica ai comuni l'importo previsionale del gettito della compartecipazione spettante e il correlato ammontare previsto di riduzione dei trasferimenti erariali. L'importo del gettito della compartecipazione di cui al comma 3 e' erogato dal Ministero dell'interno, nel corso dell'anno 2003, in quattro rate di uguale importo. Le prime due rate sono erogate sulla base dei dati previsionali anzidetti; la terza e la quarta rata sono calcolate sulla base dei dati di consuntivo relativi all'esercizio finanziario 2002 comunicati dal Ministero dell'economia e delle finanze entro il 30 maggio 2003 al Ministero dell'interno e da questo ai comuni, e su tali rate sono operati i dovuti conguagli rispetto alle somme gia' erogate.

6. Per i comuni ((e le province)) delle regioni a statuto speciale, all'attuazione del comma 3 si provvede in conformita' alle disposizioni contenute nei rispettivi statuti, anche al fine della regolazione dei rapporti finanziari tra Stato, regioni ((, province e comuni.))

------------- AGGIORNAMENTO (25) La L. 27 dicembre 2002, n. 289 ha disposto (con l'art. 31, comma 8) che "Per l'anno 2003 l'aliquota di compartecipazione dei comuni al gettito dell'IRPEF di cui all'articolo 67, comma 3, della legge 23 dicembre 2000, n. 388, come sostituito dall'articolo 25, comma 5, della legge 28 dicembre 2001, n. 448, e' stabilita nella misura del 6,5 per cento".

## INTERVENTI IN MATERIA PREVIDENZIALE E SOCIALE

### Art. 68. - (Gestioni previdenziali)

1. L'adeguamento dei trasferimenti dovuti dallo Stato, rispettivamente ai sensi dell'articolo 37, comma 3, lettera c), della legge 9 marzo 1989, n. 88, e successive modificazioni, e ai sensi dell'articolo 59, comma 34, della legge 27 dicembre 1997, n. 449, e' stabilito per l'anno 2001:

- a) in lire 1.044 miliardi in favore del Fondo pensioni lavoratori dipendenti, delle gestioni dei lavoratori autonomi, della gestione speciale minatori, nonche' in favore dell'Ente nazionale di previdenza e di assistenza per i lavoratori dello spettacolo (ENPALS);
- b) in lire 258 miliardi in favore del Fondo pensioni lavoratori dipendenti, ad integrazione dei trasferimenti di cui alla lettera a), della gestione esercenti attivita' commerciali e della gestione artigiani.

2. Conseguentemente a quanto previsto al comma 1 gli importi complessivamente dovuti dallo Stato sono determinati per l'anno 2001 in lire 26.431 miliardi per le gestioni di cui al comma 1, lettera a), e in lire 6.531 miliardi per le gestioni di cui al comma 1, lettera b).

3. I medesimi complessivi importi di cui ai commi 1 e 2 sono ripartiti tra le gestioni interessate con il procedimento di cui all'articolo 14 della legge 7 agosto 1990, n. 241, e successive modificazioni, al netto, per quanto attiene al trasferimento di cui alla lettera a) del comma 1, della somma di lire 2.255 miliardi attribuita alla gestione per i coltivatori diretti, mezzadri e coloni a completamento dell'integrale assunzioni a carico dello Stato dell'onere relativo a trattamenti pensionistici liquidati anteriormente al 1° gennaio 1989; nonche' al netto delle somme di lire 4 miliardi e di lire 92 miliardi di pertinenza, rispettivamente, della gestione speciale minatori e dell'ENPALS.

4. Con effetto dal 1° gennaio 2003 e' soppresso il contributo di cui all'articolo 37 del testo unico approvato con decreto del Presidente della Repubblica 29 dicembre 1973, n. 1032, dovuto dai dipendenti iscritti alla gestione speciale presso l'Istituto postelegrafonici, soppressa ai sensi dell'articolo 53, comma 6, della legge 27 dicembre 1997, n. 449. Per gli anni 2001 e 2002 il predetto contributo e' rispettivamente stabilito nella misura dell'1,75 per cento e dell'1 per cento.

5. L'articolo 3, comma 6, del decreto legge 30 ottobre 1984, n. 726, convertito, con modificazioni, dalla legge 19 dicembre 1984, n. 863, e successive modificazioni, si interpreta nel senso che ai contratti di formazione e lavoro non si applicano le disposizioni in materia di fiscalizzazione degli oneri sociali.

6. L'articolo 8, comma 2, della legge 23 luglio 1991, n. 223, si interpreta nel senso che il beneficio contributivo ivi previsto non si applica ai premi INAIL.

7. Il comma 3 dell'articolo 41 della legge 23 dicembre 1999, n. 488, si interpreta nel senso che ciascuna rata annuale del contributo straordinario va ripartita tra i datori di lavoro i quali, alla fine del mese antecedente la scadenza del pagamento delle rate medesime, abbiano in servizio lavoratori che risultavano gia' iscritti al 31 dicembre 1996 ai Fondi speciali soppressi, in misura proporzionale al numero dei lavoratori stessi, ponderato con le relative anzianita' contributive medie risultanti a detta data.

8. Al fine di migliorare la trasparenza delle gestioni previdenziali l'eventuale differenza tra l'indennita' di buonuscita, spettante ai dipendenti della societa' Poste italiane spa maturata fino al 27 febbraio 1998 da un lato e l'ammontare dei contributi in atto posti a carico dei lavoratori, delle risorse dovute dall'INPDAP e delle risorse derivanti dalla chiusura della gestione commissariale dell'IPOST, dall'altro, e' posta a carico del bilancio dello Stato.

### Art. 69. - (Disposizioni relative al sistema pensionistico)

1. A decorrere dal 1° gennaio 2001 l'indice di rivalutazione automatica delle pensioni e' applicato, secondo il meccanismo stabilito dall'articolo 34, comma 1, della legge 23 dicembre 1998, n. 448:

- a) nella misura del 100 per cento per le fasce di importo dei trattamenti pensionistici fino a tre volte il trattamento minimo INPS;
- b) nella misura del 90 per cento per le fasce di importo dei trattamenti pensionistici comprese tra tre e cinque volte il trattamento minimo INPS;
- c) nella misura del 75 per cento per le fasce di importo dei trattamenti pensionistici superiori a cinque volte il predetto trattamento minimo.

2. All'articolo 59, comma 13, terzo periodo, della legge 27 dicembre 1997, n. 449, le parole: "tre anni" sono sostituite dalle seguenti: "due anni".

3. A decorrere dal 1° gennaio 2001:

- a) la misura della maggiorazione sociale dei trattamenti pensionistici di cui all'articolo 1, comma 2, della legge 29 dicembre 1988, n. 544, e' elevata di lire 80.000 mensili per i titolari di pensione con eta' inferiore a settantacinque anni e di lire 100.000 mensili per i titolari di pensione con eta' pari o superiore a settantacinque anni;
- b) la misura della maggiorazione sociale dei trattamenti pensionistici di cui all'articolo 1, comma 12, della legge 29 dicembre 1988, n. 544, e' elevata di lire 20.000 mensili.

4. A decorrere dalla medesima data di cui al comma 1 le maggiorazioni sociali di cui al comma 3, come modificate dal presente articolo, sono concesse, alle medesime condizioni previste dalla citata disposizione della legge n. 544 del 1988, anche ai titolari di pensioni a carico delle forme esclusive e sostitutive dell'assicurazione generale obbligatoria.

5. I contributi versati dal 1° gennaio 1952 al 31 dicembre 2000 nell'assicurazione facoltativa di cui al titolo IV del regio decreto-legge 4 ottobre 1935, n. 1827, convertito, con modificazioni, dalla legge 6 , aprile 1936, n. 1155, nonche' quelli versati dal 13 ottobre 1963 al 31 dicembre 2000, a titolo di "Mutualita' pensioni" di cui alla legge 5 marzo 1963, n. 389, sono rivalutati, per i periodi antecedenti la liquidazione della pensione e secondo l'anno di versamento, in base ai coefficienti utili ai fini della rivalutazione delle retribuzioni pensionabili, di cui all'articolo 3 della legge 29 maggio 1982, n. 297, e dal 1° gennaio 2001 decorrono gli aumenti dei relativi trattamenti pensionistici. Dal 1° gennaio 2001 i contributi versati alla medesima assicurazione facoltativa e quelli versati a titolo di "Mutualita' pensioni" sono rivalutati annualmente con le modalita' previste dal presente comma. Non sono rivalutati i contributi versati a titolo di "Mutualita' pensioni" afferenti i periodi successivi al 31 dicembre 1996, che siano computati nel calcolo della pensione secondo il sistema contributivo, ai sensi dell'articolo 4 del decreto legislativo 16 settembre 1996, n. 565.

6. Ai fini dell'esercizio del diritto di opzione di cui all'articolo 1, comma 23, della legge 8 agosto 1995, n. 335, l'ente previdenziale erogatore rilascia a richiesta due schemi di calcolo della liquidazione del trattamento pensionistico rispettivamente con il sistema contributivo e con il sistema retributivo.

7. L'articolo 7 del decreto-legge 12 settembre 1983, n. 463, convertito, con modificazioni, dalla legge 11 novembre 1983, n. 638, non si applica ai lavoratori della piccola pesca marittima e delle acque interne soggetti alla legge 13 marzo 1958, n. 250. (13)

8. I provvedimenti concernenti le pensioni di reversibilita' alle vedove ed agli orfani dei cittadini italiani, che siano stati perseguitati nelle circostanze di cui all'articolo 1 della legge 10 marzo 1955, n. 96, e successive modificazioni, ed ai quali la commissione di cui all'articolo 8 della predetta legge n. 96 del 1955, e successive modificazioni, ha gia' riconosciuto l'assegno vitalizio, sono attribuiti alla competenza esclusiva dei dipartimenti provinciali del Ministero del tesoro, del bilancio e della programmazione economica. Restano attribuite alla direzione centrale degli uffici locali e dei servizi del predetto Ministero le competenze relative alla liquidazione degli assegni vitalizi riconosciuti dalla competente commissione ai perseguitati politici antifascisti e razziali.

9. Per favorire la continuita' della copertura assicurativa previdenziale nel caso dei lavori discontinui e negli altri casi previsti dalle disposizioni del capo II del decreto legislativo 16 settembre 1996, n. 564, e successive modificazioni, nonche' dei lavoratori iscritti alla Gestione di cui all'articolo 2, comma 26, della legge 8 agosto 1995, n. 335, e successive modificazioni, attraverso il concorso agli oneri contributivi previsti in caso di riscatto ovvero prosecuzione volontaria, e' istituito, presso l'Istituto nazionale della previdenza sociale (INPS), un apposito Fondo. Il Fondo e' alimentato con il contributo di solidarieta' di cui all'articolo 37, comma 1, della legge 23 dicembre 1999, n. 488, nonche' da un importo pari a lire 70 miliardi per l'anno 2001, lire 50 miliardi per l'anno 2002 e lire 27 miliardi a decorrere dall'anno 2003 a carico del bilancio dello Stato.

10. Dopo il comma 2 dell'articolo 5 del decreto legislativo 30 aprile 1997, n. 184, e' inserito il seguente: "2-bis. L'autorizzazione alla prosecuzione volontaria e' altresi' concessa in presenza dei requisiti di cui al terzo comma dell'articolo 1 della legge 18 febbraio 1983, n. 47".

11. Con decreto del Ministro del lavoro e della previdenza sociale, di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, sono stabiliti modalita', condizioni e termini del concorso di cui al comma 9 agli oneri a carico del lavoratore, in materia di copertura assicurativa per periodi non coperti da contribuzione, previsti dal citato capo il del decreto legislativo 16 settembre 1996, n. 564, e successive modificazioni, nonche' dell'applicazione delle predette disposizioni, in quanto compatibili, anche ai periodi non coperti da contribuzione dei lavoratori iscritti alla citata Gestione di cui all'articolo 2, comma 26, della legge 8 agosto 1995, n. 335, e successive modificazioni.

12. L'articolo 37, comma 2, della legge 23 dicembre 1999, n. 488, e' abrogato.

13. L'articolo 9, comma 3, della legge 24 giugno 1997, n. 196, e' sostituito dal seguente: "3. Con decreto del Ministro del lavoro e della previdenza sociale, di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, e' stabilita la misura di retribuzione convenzionale in riferimento alla quale i lavoratori assunti ai sensi dell'articolo 3, comma 1, possono versare la differenza contributiva per i periodi in cui abbiano percepito una retribuzione inferiore rispetto a quella convenzionale ovvero abbiano usufruito dell'indennita' di disponibilita' di cui all'articolo. 4, comma 3, e fino a concorrenza della medesima misura".

14. A decorrere dal 1° gennaio 2001 la gestione finanziaria e patrimoniale dell'Istituto nazionale di previdenza per i dipendenti dell'amministrazione pubblica (INPDAP) e' unica, ed e' unico il bilancio dell'Istituto, per tutte le attivita' relative alle gestioni ad esso affidate, le quali conservano autonoma rilevanza economico-patrimoniale nell'ambito della gestione complessiva dell'Istituto stesso. Conseguentemente, dalla stessa data, viene meno la competenza in materia di predisposizione dei bilanci da parte dei comitati di vigilanza di cui all'articolo 4, comma 3, del decreto legislativo 30 giugno 1994, n. 479, e successive modificazioni.

15. Le movimentazioni tra le gestioni dell'INPDAP di cui al comma 14 sono evidenziate con regolazioni e non determinano oneri od utili. ((94))

16. Gli enti pubblici, che gestiscono forme di previdenza e assistenza obbligatorie, affidano l'attivita' di consulenza legale, difesa e rappresentanza alle avvocature istituite presso ciascun ente. Nei casi di insufficienza o mancanza di avvocature interne la predetta attivita' puo' essere assicurata dalle avvocature esistenti presso altri enti del comparto, mediante convenzioni onerose, che disciplinano i relativi aspetti organizzativi, normativi ed economici. Il trattamento giuridico ed economico degli appartenenti alle avvocature costituite presso gli enti e' disciplinato dai rispettivi contratti collettivi nazionali di lavoro e comunque senza oneri aggiuntivi per il bilancio dello Stato.

17. Per il finanziamento degli oneri derivanti dall'articolo 59, comma 31, della legge 27 dicembre 1997, n. 449, e' autorizzata per l'anno 2001 la spesa di lire 3 miliardi, da iscrivere in apposita unita' previsionale di base dello stato di previsione del Ministero del tesoro, del bilancio e della programmazione economica. I fondi pensione possono acquisire a titolo gratuito partecipazioni della societa' per azioni costituita ai sensi della medesima disposizione.

18. I pescatori autonomi di cui alla legge 13 marzo 1958, n. 250, che hanno effettuato versamenti mensili utilizzando bollettini di conto corrente postale prestampati predisposti dall'INPS, recanti importi inferiori a quelli successivamente accertati come dovuti, possono, in deroga alle disposizioni previste dall'articolo 3, comma 9, della legge 8 agosto 1995, n. 335, effettuare i versamenti ad integrazione delle somme gia' versate e fino a concorrenza di quanto effettivamente dovuto.

19. Al fine di sopperire alle necessita' della gestione del Fondo credito per i dipendenti postali gestito dall'Istituto Postelegrafonici (IPOST) a decorrere dal 1 agosto 1994, e' disposto, entro novanta giorni dalla data di entrata in vigore della presente legge, il trasferimento della somma di lire 100 miliardi dall'Istituto nazionale di previdenza per i dipendenti dell'amministrazione pubblica (INPDAP), gestore del Fondo credito per i dipendenti delle pubbliche amministrazioni, all'IPOST.

------------- AGGIORNAMENTO (13) La L. 28 dicembre 2001, n. 448 ha disposto (con l'art. 43, comma 3) che "La disposizione di cui al comma 7 dell'articolo 69 della legge 23 dicembre 2000, n. 388, si applica a decorrere dalla data di entrata in vigore della legge 11 novembre 1983, n. 638". ------------- AGGIORNAMENTO (94) La L. 27 dicembre 2017, n. 205 ha disposto (con l'art. 1, comma 185) che "La disposizione di cui all'articolo 69, comma 15, della legge 23 dicembre 2000, n. 388, si applica a tutte le gestioni amministrate dall'INPS".

### Art. 70. - (Maggiorazioni)

1. A decorrere dal 1° gennaio 2001, e' concessa ai titolari dell'assegno sociale di cui all'articolo 3, comma 6, della legge 8 agosto 1995, n. 335, una maggiorazione di importo pari a lire 25.000 mensili per i titolari con eta' inferiore a settantacinque anni e a lire 40.000 mensili per i titolari con eta' pari o superiore a settantacinque anni. ((13))

2. La maggiorazione di cui al comma 1 e' corrisposta a condizione che la persona:

- a) non possieda redditi propri per un importo pari o superiore all'ammontare annuo complessivo dell'assegno sociale e della maggiorazione di cui al comma 1;
- b) non possieda, se coniugata, redditi propri per un importo pari o superiore a quello di cui alla lettera a), ne' redditi cumulati con quelli del coniuge, per un importo pari o superiore al limite costituito dalla somma dell'ammontare annuo dell'assegno sociale comprensivo della maggiorazione di cui al comma 1 e dell'ammontare annuo del trattamento minimo delle pensioni a carico del Fondo pensioni lavoratori dipendenti. Non si procede al cumulo dei redditi con quelli del coniuge legalmente ed effettivamente separato.

3. Qualora i redditi posseduti risultino inferiori ai limiti di cui alle lettere a) o b) del comma 2, l'aumento e' corrisposto in misura tale da non comportare il superamento dei limiti stessi. Agli effetti dell'aumento di cui al comma 1, si tiene conto dei redditi di qualsiasi natura, compresi i redditi esenti da imposta e quelli soggetti a ritenuta alla fonte a titolo di imposta o ad imposta sostitutiva, eccetto quelli derivanti dai trattamenti di famiglia.

4. Per i titolari della pensione sociale di cui all'articolo 26 della legge 30 aprile 1969, n. 153, il beneficio di cui al comma 1 e' concesso ad incremento della misura di cui all'articolo 2 della legge 29 dicembre 1988, n. 544.

5. Per i soggetti titolari dei trattamenti trasferiti all'INPS, ai sensi dell'articolo 10 della legge 26 maggio 1970, n. 381, e dell'articolo 19 della legge 30 marzo 1971, n. 118, e per i ciechi civili con eta' pari o superiore a sessantacinque anni titolari dei relativi trattamenti pensionistici, i benefici di cui ai commi 1 e 4 del presente articolo sono corrisposti tenendo conto dei medesimi criteri economici adottati per l'accesso e per il calcolo dei predetti benefici.

6. A decorrere dal 1° gennaio 2001 e' concessa una maggiorazione di lire 20.000 mensili per tredici mensilita' della pensione ovvero dell'assegno di invalidita' a favore di invalidi civili, ciechi civili e sordomuti con eta' inferiore a sessantacinque anni, a condizione che la persona titolare:

- a) non possieda redditi propri per un importo pari o superiore all'ammontare annuo complessivo dell'assegno sociale e della predetta maggiorazione;
- b) non possieda, se coniugata, redditi propri per un importo pari o superiore a quello di cui alla lettera a), ne' redditi, cumulati con quelli del coniuge, per un importo pari o superiore al limite costituito dalla somma dell'ammontare annuo dell'assegno sociale comprensivo della predetta maggiorazione e dell'ammontare annuo del trattamento minimo delle pensioni a carico del Fondo pensioni lavoratori dipendenti. Non si procede al cumulo dei redditi con quelli del coniuge legalmente ed effettivamente separato.

7. A decorrere dall'anno 2001, a favore dei soggetti che siano titolari di uno o piu' trattamenti pensionistici a carico dell'assicurazione generale obbligatoria e delle forme sostitutive, esclusive ed esonerative della medesima, nonche' delle forme pensionistiche obbligatorie gestite dagli enti di cui al decreto legislativo 30 giugno 1994, n. 509, e successive modificazioni, il cui complessivo annuo, al netto dei trattamenti di famiglia, non superi il trattamento minimo annuo del Fondo pensioni lavoratori dipendenti, e' corrisposto un importo aggiuntivo pari a lire 300.000 annue. Tale importo aggiuntivo e' corrisposto dall'INPS in sede di erogazione della tredicesima mensilita' ovvero dell'ultima mensilita' corrisposta nell'anno e spetta a condizione che il soggetto:

- a) non possieda un reddito complessivo individuale assoggettabile all'imposta sul reddito delle persone fisiche (IRPEF) relativo all'anno stesso superiore a una volta e mezza il predetto trattamento minimo;
- b) non possieda, se coniugato, un reddito complessivo individuale assoggettabile all'IRPEF relativo all'anno stesso superiore a una volta e mezza il predetto trattamento minimo, ne' redditi, cumulati con quelli del coniuge, per un importo superiore a tre volte il medesimo trattamento minimo. Non si procede al cumulo dei redditi con quelli del coniuge legalmente ed effettivamente separato.

8. Nei confronti dei soggetti che soddisfano le condizioni di cui al comma 7 e per i quali l'importo complessivo annuo dei trattamenti pensionistici risulti superiore al trattamento minimo di cui al comma 7 e inferiore al limite costituito dal medesimo trattamento minimo incrementato di lire 300.000 annue, l'importo aggiuntivo viene corrisposto fino a concorrenza del predetto limite.

9. Qualora i soggetti di cui al comma 7 non risultino beneficiari di prestazioni presso l'INPS, il casellario centrale dei pensionati istituto con decreto del Presidente della Repubblica 31 dicembre 1971, n. 1388, e successive modificazioni, provvede ad individuare l'ente incaricato dell'erogazione dell'importo aggiuntivo di cui al comma 7, che provvede negli stessi termini e con le medesime modalita' indicati nello stesso comma.

10. L'importo aggiuntivo di cui al comma 7 non costituisce reddito ne' ai fini fiscali ne' ai fini della corresponsione di prestazioni previdenziali ed assistenziali.

------------- AGGIORNAMENTO (13) La L. 28 dicembre 2001, n. 448 ha disposto (con l'art. 38, comma 1, lettera b)) che "A decorrere dal 1 gennaio 2002 e' incrementata, a favore dei soggetti di eta' pari o superiore a settanta anni e fino a garantire un reddito proprio pari a 516,46 euro al mese per tredici mensilita', la misura delle maggiorazioni sociali dei trattamenti pensionistici di cui: b) all'articolo 70, comma 1, della legge 23 dicembre 2000, n. 388, con riferimento ai titolari dell'assegno sociale di cui all'articolo 3, comma 6, della legge 8 agosto 1995, n. 335".

### Art. 71.

((ARTICOLO ABROGATO DAL D. LGS. 2 FEBBRAIO 2006, N. 42))

### Art. 72. - (Cumulo tra pensione e reddito da lavoro)

1. A decorrere dal 1° gennaio 2001 le pensioni di vecchiaia e le pensioni liquidate con anzianita' contributiva pari o superiore a 40 anni a carico dell'assicurazione generale obbligatoria e delle forme sostitutive, esclusive ed esonerative della medesima, anche se liquidate anteriormente alla data di entrata in vigore della presente legge, sono interamente cumulabili con i redditi da lavoro autonomo e dipendente.

2. A decorrere dal 1° gennaio 2001 le quote delle pensioni dirette di anzianita', di invalidita' e degli assegni diretti di invalidita' a carico dell'assicurazione generale obbligatoria e delle forme sostitutive, esclusive ed esonerative della medesima, eccedenti l'ammontare del trattamento minimo del Fondo pensioni lavoratori dipendenti, sono cumulabili con i redditi da lavoro autonomo nella misura del 70 per cento. Le relative trattenute non possono, in ogni caso, superare il valore pari al 30 per cento dei predetti redditi. Per i trattamenti liquidati in data precedente al 1° gennaio 2001 si applica la relativa previgente disciplina se piu' favorevole.

### Art. 73. - (Revisione della normativa in materia di cumulo tra rendita INAIL e trattamento di reversibilita' INPS)

1. A decorrere dal 1° luglio 2001, il divieto di cumulo di cui all'articolo 1, comma 43, della legge 8 agosto 1995, n. 335, non opera tra il trattamento di reversibilita' a carico dell'assicurazione generale obbligatoria per l'invalidita', la vecchiaia ed i superstiti, nonche' delle forme esclusive, esonerative e sostitutive della medesima, e la rendita ai superstiti erogata dall'Istituto nazionale per l'assicurazione contro gli infortuni sul lavoro (INAIL) spettante in caso di decesso del lavoratore conseguente ad infortunio sul lavoro o malattia professionale ai sensi dell'articolo 85 del decreto del Presidente della Repubblica 30 giugno 1965, n. 1124. Le disposizioni di cui al presente comma si applicano alle rate di pensione di reversibilita' successive alla data del 30 giugno 2001, anche se la pensione stessa e' stata liquidata in data anteriore.

2. L'autorizzazione di spesa di cui all'articolo 66, comma 1, della legge 17 maggio 1999, n. 144, e' ridotta di lire 58 miliardi per l'anno 2001 e di lire 70 miliardi per ciascuno degli anni 2002 e 2003.

3. All'articolo 13, comma 2, del decreto legislativo 23 febbraio 2000, n. 38, le parole da: "In caso di danno biologico" a "denunciati" sono sostituite dalle seguenti: "In caso di danno biologico, i danni conseguenti ad infortuni sul lavoro verificatisi, nonche' a malattie professionali denunciate".

### Art. 74. - (Previdenza complementare dei dipendenti pubblici)

1. Per fare fronte all'obbligo della pubblica amministrazione, ai sensi dell'articolo 8, comma 1, del decreto legislativo 21 aprile 1993, n. 124, di contribuire, quale datore di lavoro, al finanziamento dei fondi gestori di previdenza complementare dei dipendenti delle amministrazioni dello Stato anche ad ordinamento autonomo, in corrispondenza delle risorse contrattualmente definite eventualmente destinate dai lavoratori allo stesso fine, sono assegnate le risorse previste dall'articolo 26, comma 18, della legge 23 dicembre 1998, n. 448, nonche' lire 100 miliardi annue a decorrere dall'anno 2001. Per gli anni successivi al 2003, alla determinazione delle predette risorse si provvede ai sensi dell'articolo 11, comma 3, lettera d), della legge 5 agosto 1978, n. 468, e successive modificazioni.

2. ((COMMA ABROGATO DALLA L. 30 DICEMBRE 2018, N. 145)).

3. In fase di prima attuazione, la quota di trattamento di fine rapporto che i dipendenti gia' occupati alla data del 31 dicembre 1995 e quelli assunti nel periodo dal 1° gennaio 1996 al 31 dicembre 2000 che hanno esercitato l'opzione di cui all'articolo 59, comma 56, della legge 27 dicembre 1997, n. 449, possono destinare ai fondi pensione, non puo' superare il 2 per cento della retribuzione base di riferimento per il calcolo del trattamento di fine rapporto. Successivamente la predetta quota del trattamento di fine rapporto e' definita dalle parti istitutive con apposito accordo.

4. Al comma 8 dell'articolo 2 della legge 8 agosto 1995, n. 335, sono aggiunti, in fine, i seguenti periodi: "Per il personale degli enti, il cui ordinamento del personale rientri nella competenza propria o delegata della regione Trentino-Alto Adige, delle province autonome di Trento e di Bolzano nonche' della regione Valle d'Aosta, la corresponsione del trattamento di fine rapporto avviene da parte degli enti di appartenenza e contemporaneamente cessa ogni contribuzione previdenziale in materia di trattamento di fine servizio comunque denominato in favore dei competenti enti previdenziali ai sensi della normativa statale in vigore. Per il personale di cui ai commi 2 e 3 dell'articolo 1 del testo unificato approvato decreto del Presidente della Repubblica 10 febbraio 1983, n. 89, e successive modificazioni, e' considerata ente di appartenenza la provincia di Bolzano. Con norme emanate ai sensi dell'articolo 107 del testo unico delle leggi costituzionali concernenti lo Statuto speciale per il Trentino-Alto Adige, approvato con decreto del Presidente della Repubblica 31 agosto 1972, n. 670, e dell'articolo 48-bis dello Statuto speciale per la Valle d'Aosta, approvato con legge costituzionale 26 febbraio 1948, n. 4, sono disciplinate le modalita' di attuazione di quanto previsto dal terzo e quarto periodo del presente comma, garantendo l'assenza di oneri aggiuntivi per la finanza pubblica".

5. Al decreto legislativo 21 aprile 1993 n. 124, e successive modificazioni, sono apportate le seguenti modifiche:

- a) all'articolo 4, il comma 7 e' sostituito dal seguente: "7. La COVIP disciplina le ipotesi di decadenza dall'autorizzazione quando il fondo pensione non abbia iniziato la propria attivita', ovvero quando, per i fondi di cui all'articolo 3, non sia stata conseguita la base associativa minima prevista dal fondo stesso";
- b) all'articolo 5, comma 1, il secondo periodo e' sostituito dai seguenti: "I componenti dei primi organi collegiali sono nominati in sede di atto costitutivo. Per la successiva individuazione dei rappresentanti dei lavoratori e' previsto il metodo elettivo secondo modalita' e criteri definiti dalle fonti costitutive";
- c) all'articolo 6, comma 4-bis, primo periodo, dopo le parole: "i competenti organismi di amministrazione dei fondi" sono inserite le seguenti: "individuati ai sensi dell'articolo 5, comma 1, terzo periodo".

### Art. 75.

((ARTICOLO ABROGATO DALLA L. 23 AGOSTO 2004, N. 243))

### Art. 76. - (Previdenza giornalisti)

1. L'articolo 38 della legge 5 agosto 1981, n. 416, e' sostituito dal seguente: "Art. 38. - (INPGI). - 1. L'Istituto nazionaie di previdenza dei giornalisti italiani "Giovanni Amendola" (INPGI) ai sensi delle leggi 20 dicembre 1951, n. 1564, 9 novembre 1955, n. 1122, e 25 febbraio 1987, n. 67, gestisce in regime di sostitutivita' le forme di previdenza obbligatoria nei confronti dei giornalisti professionisti e praticanti e provvede, altresi', ad analoga gestione anche in favore dei giornalisti pubblicisti di cui all'articolo 1, commi secondo e quarto, della legge 3 febbraio 1963, n. 69, titolari di un rapporto di lavoro subordinato di natura giornalistica. I giornalisti pubblicisti possono optare per il mantenimento dell'iscrizione presso l'Istituto nazionale della previdenza sociale. Resta confermata per il personale pubblicista l'applicazione delle vigenti disposizioni in materia di fiscalizzazione degli oneri sociali e di sgravi contributivi. 2. L'INPGI provvede a corrispondere ai propri iscritti: a) il trattamento straordinario di integrazione salariale previsto dall'articolo 35; b) la pensione anticipata di vecchiaia prevista dall'articolo 37. 3. Gli oneri derivanti dalle prestazioni di cui al comma 2 sono a totale carico dell'INPGI. 4. Le forme previdenziali gestite dall'INPGI devono essere coordinate con le norme che regolano il regime delle prestazioni e dei contributi delle forme di previdenza sociale obbligatoria, sia generali che sostitutive".

2. L'opzione di cui all'articolo 38 della legge 5 agosto 1981, n. 416, come sostituito dal comma 1 del presente articolo, deve essere esercitata entro sei mesi dalla data di entrata in vigore della presente legge.

### Art. 77. - (Norme in materia di gestione e di bilanci degli enti previdenziali)

1. Per ottimizzare i costi organizzativi e gestionali e migliorare la qualita' del servizio, gli istituti gestori di forme obbligatorie di assicurazione sociale realizzano modalita' di integrazione dei processi di acquisizione delle risorse professionali nonche' dei beni e servizi occorrenti per l'esercizio dell'assicurazione.

2. Al fine di cui al comma 1, gli enti, secondo i criteri generali fissati con decreto del Ministro per la funzione pubblica ed in base a piani triennali congiuntamente definiti dagli organi di indirizzo politico, stipulano convenzioni ai sensi e per gli effetti della legge 7 agosto 1990, n. 241, finalizzate, fra l'altro, a:

- a) esperire in comune procedure di selezione di personale delle varie qualifiche;
- b) utilizzare, nei limiti di efficacia previsti dalle vigenti disposizioni, graduatorie di idonei in prove di selezione effettuate da uno degli enti;
- c) concertare l'acquisto di beni e servizi, anche al fine di ottimizzare l'utilizzazione di strumenti gia' messi a disposizione delle pubbliche amministrazioni dalla vigente normativa;
- d) prevedere, per procedure di gara di uno degli enti, la possibilita' di integrare, entro i limiti previsti dalle vigenti normative, la fornitura in favore di altro ente.

3. Con le stesse finalita' di cui al comma 2, i piani definiscono obiettivi di cooperazione al servizio dell'utenza, in termini di utilizzazione comune di strutture funzionali e tecnologiche nella prospettiva di integrazione con i servizi sociali regionali e territoriali.

4. In sede di prima applicazione i piani per il triennio 2001-2003 sono approvati dagli organi competenti entro il 30 aprile 2001.

5. Il periodo intercorrente dal 1° gennaio alla data di approvazione del bilancio e' assoggettato alla disciplina normativa dell'esercizio provvisorio.

### Art. 78. - (Interventi urgenti in materia di ammortizzatori sociali, di previdenza e di lavori socialmente utili)

1. La data di presentazione della domanda di ammissione alla contribuzione volontaria di cui all'articolo 10, comma 1, del decreto legislativo 28 febbraio 2000, n. 81, e' differita al 30 aprile 2001, fermo restando il possesso, alla data del 31 dicembre 1999, dei relativi requisiti.

2. Ferma restando la possibilita' di stipulare convenzioni ai sensi dell'articolo 8, comma 1, del citato decreto legislativo n. 81 del 2000, tenendo conto dei conguagli derivanti dall'applicazione dell'articolo 45, comma 6, della legge 17 maggio 1999, n. 144, il Ministero del lavoro e della previdenza sociale e' autorizzato a stipulare, nei limiti delle risorse preordinate allo scopo nell'ambito del Fondo per l'occupazione, convenzioni con le regioni in riferimento a situazioni straordinarie che non consentono, entro il 30 giugno 2001, di esaurire il bacino regionale dei soggetti di cui all'articolo 2, comma 1, del citato decreto legislativo n. 81 del 2000; conseguentemente, a tal fine, il termine del 30 aprile 2001, di cui all'articolo 8, comma 3, del citato decreto legislativo n. 81 del 2000 e' differito al 30 giugno 2001 e il rinnovo di cui all'articolo 4, comma 2, del citato decreto legislativo potra' avere una durata massima di otto mesi. In particolare le convenzioni prevedono:

- a) la realizzazione, da parte della Regione, di programmi di stabilizzazione dei soggetti di cui all'articolo 2, comma 1, del citato decreto legislativo n. 81 del 2000, con l'indicazione di una quota predeterminata di soggetti da avviare alla stabilizzazione che, per il primo anno, non potra' essere inferiore al 30 per cento del numero dei soggetti appartenenti al bacino regionale; le convenzioni possono essere annualmente rinnovate, a condizione che vengano definiti, anche in base ai risultati raggiunti, gli obiettivi di stabilizzazione dei soggetti di cui al citato articolo 2, comma 1;
- b) le risorse finanziarie necessarie ad assicurare a tutti i soggetti non stabilizzati entro il 31 dicembre 2000, ad esclusione di quelli impegnati in attivita' progettuali interregionali di competenza nazionale e dei soggetti che maturino il cinquantesimo anno di eta' entro il 31 dicembre 2000, anche la copertura dell'erogazione della quota di cui all'articolo 4, comma 2, del citato decreto legislativo n. 81 del 2000, pari al 50 per cento dell'assegno per prestazioni in attivita' socialmente utili e dell'intero ammontare dell'assegno al nucleo familiare, che le regioni si impegnano a versare all'INPS; nonche', nell'ambito delle risorse disponibili a valere sul Fondo per l'occupazione, un ulteriore stanziamento di entita' non inferiore al precedente finalizzato ad incentivare la stabilizzazione dei soggetti interessati da situazione di straordinarieta'; a tale scopo per l'anno 2001 verranno utilizzate le risorse destinabili alle regioni, ai sensi dell'articolo 8, commi 1 e 2, del decreto legislativo n. 81 del 2000, tenendo conto dei conguagli derivanti dall'applicazione dell'articolo 45, comma 6, della citata legge n. 144 del 1999, che saranno erogati a seguito della stipula delle convenzioni;
- c) la possibilita', nei limiti delle risorse preordinate allo scopo nell'ambito del Fondo per l'occupazione, per i soggetti, di cui all'articolo 2, comma 1, del citato decreto legislativo n. 81 del 2000, che abbiano compiuto, alla data del 31 dicembre 2000, il cinquantesimo anno di eta', di continuare a percepire in caso di prosecuzione delle attivita' da parte degli enti utilizzatori, l'assegno per prestazioni in attivita' socialmente utili e l'assegno per nucleo familiare, nella misura del 100 per cento, a partire dal 1° gennaio 2001 e sino al 31 dicembre 2001;
- d) la possibilita' di impiego, da parte delle regioni, delle risorse del citato Fondo per l'occupazione, destinate alle attivita' socialmente utili e non impegnate per il pagamento di assegni, per misure aggiuntive di stabilizzazione e di politica attiva del lavoro e per il sostegno delle situazioni di maggiore difficolta'. (31) (36) (43) (49) (99) (101) (103) (106) (107) (111) ((115))

3. A seguito dell'attivazione delle convenzioni di cui al comma 2, sono trasferite alle regioni le responsabilita' di programmazione e di destinazione delle risorse finanziarie, ai sensi del medesimo comma 2, e rese applicabili le misure previste dal citato decreto legislativo n. 81 del 2000 fino al 31 dicembre 2001. Ai fini del rinnovo delle convenzioni di cui al comma 2, lettera a), saranno previste, a partire dall'anno 2002, apposite risorse a tale scopo preordinate, nell'ambito delle disponibilita' del Fondo per l'occupazione, per i soggetti di cui all'articolo 2, comma 1, del decreto legislativo n. 81 del 2000, di pertinenza del bacino regionale, inclusi i soggetti di cui al comma 2, lettera c), non stabilizzati entro il 31 dicembre 2001.

4. All'articolo 9, comma 11, del decreto-legge 1° ottobre 1996, n. 510, convertito, con modificazioni, dalla legge 28 novembre 1996, n. 608, e' soppressa la parola "assicurativi".

5. I soggetti impegnati in prestazioni di attivita' socialmente utili, ai sensi della lettera d) del comma 2 dell'articolo 1 del decreto legislativo 1° dicembre 1997, n. 468, che abbiano effettivamente maturato dodici mesi di permanenza in tali attivita' nel periodo tra il 1° gennaio 1998 e il 31 dicembre 1999 e che a quest'ultima data siano esclusi da ogni trattamento previdenziale, se in possesso, dei requisiti di ammissione alla contribuzione volontaria di cui alla lettera a), comma 5, dell'articolo 12 del decreto legislativo 1 dicembre 1997, n. 468, e successive modificazioni, possono presentare la relativa domanda intesa ad ottenere il solo beneficio di cui alla medesima lettera a) bei limiti e condizioni ivi previsti, e nei limiti delle risorse stabilite nel predetto comma 5 entro i termini di cui al comma 1 del presente articolo.

6. In deroga a quanto disposto dall'articolo 12, comma 4, del decreto legislativo 1 dicembre 1997, n. 468, e limitatamente agli anni 2001, 2002 e 2003, le regioni e gli altri enti locali che hanno vuoti in organico e nell'ambito delle disponibilita' finanziarie possono, relativamente alle qualifiche di cui all'articolo 16 della legge 28 febbraio 1987, n. 56, effettuare assunzioni di soggetti collocati in attivita' socialmente utili. L'incentivo previsto all'articolo 7, comma 1, del citato decreto legislativo n. 81 del 2000, e' esteso agli enti locali e agli enti pubblici dotati di autonomia finanziaria, per le assunzioni ai sensi dell'articolo 12, comma 4, del citato decreto legislativo n. 468 del 1997.

7. Resta ferma la facolta' di cui all'articolo 45, comma 5, della legge 17 maggio 1999, n. 144.

8. In attesa della definizione, tra le parti sociali, dei criteri di attuazione della normativa di cui al decreto legislativo 11 agosto 1993, n. 374, recante benefici per le attivita' usuranti, e successive modificazioni, e' riconosciuto, entro i limiti delle disponibilita' di cui al comma 13, il beneficio della riduzione dei requisiti di eta' anagrafica e contributiva previsti dall'articolo 2, comma 1, del decreto legislativo 11 agosto 1993, n. 374, e successive modificazioni, e dall'articolo 1, commi 36 e 37, della legge 8 agosto 1995, n. 335, agli assicurati che:

- a) per il periodo successivo alla data di entrata in vigore del predetto decreto legislativo n. 374 del 1993, risultino avere svolto prevalentemente mansioni particolarmente usuranti, per le caratteristiche di maggior gravita' dell'usura che queste presentano, individuate dall'articolo 2 del decreto del Ministro del lavoro e della previdenza sociale 19 maggio 1999, pubblicato nella Gazzetta Ufficiale n. 208 del 4 settembre 1999;
- b) entro il 31 dicembre 2001 potrebbero far valere: 1) i requisiti per il pensionamento di anzianita' tenendo conto della riduzione dei limiti di eta' anagrafica e di anzianita' contributiva previsti rispettivamente dall'articolo 1, comma 36, della legge 8 agosto 1995, n. 335, e dal secondo periodo del comma 1 dell'articolo 2 del decreto legislativo 11 agosto 1993, n. 374, come introdotto dall'articolo 1, comma 35, della citata legge n. 335 del 1995; 2) i requisiti per il pensionamento di vecchiaia nel regime retributivo o misto tenendo conto della riduzione dei limiti di eta' pensionabile e di anzianita' contributiva previsti dall'articolo 2, comma 1, del decreto legislativo 11 agosto 1993, n. 374, e successive modificazioni; 3) i requisiti per il pensionamento di vecchiaia nel regime contributivo con la riduzione del limite di eta' pensionabile prevista dall'articolo 1, comma 37, della legge 8 agosto 1995, n. 335.

9. All'articolo 5, comma 2, primo periodo, della legge 12 marzo 1999, n. 68, e' soppressa la parola: "pubblico";

10. Per coloro che, potendo far valere i requisiti di cui all'articolo 1 della legge 29 dicembre 1988, n. 544, come modificato dai commi 3 e 4 dell'articolo 69, presentino domanda entro il 30 giugno 2001, la maggiorazione decorre dal 1° gennaio 2001 o dal mese successivo a quello del compimento dell'eta' prevista, qualora quest'ultima ipotesi si verifichi in data successiva.

11. Con decreto del Ministro del lavoro e della previdenza sociale, di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, da emanare entro 180 giorni dalla data di entrata in vigore della presente legge, sono stabilite le modalita' di attestazione dello svolgimento, da parte dei lavoratori, delle attivita' di cui al citato decreto del Ministro del lavoro e della previdenza sociale 19 maggio 1999 nonche' i criteri per il riconoscimento del beneficio di cui al comma 8 nella misura determinata dai limiti dello stanziamento di cui al comma 13.

12. La domanda per il riconoscimento del beneficio di cui al comma 8 deve essere presentata dagli interessati all'ente previdenziale di appartenenza entro 90 giorni dalla data di entrata in vigore del decreto di cui al comma 11, a pena di decadenza.

13. All'onere derivante dal riconoscimento di cui al comma 8, corrispondente all'incremento delle aliquote contributive di cui all'articolo 1 del decreto del Ministro del lavoro e della previdenza sociale 19 maggio 1999, si provvede mediante utilizzo delle disponibilita' di cui all'autorizzazione di spesa di cui all'articolo 1, comma 38, della legge 8 agosto 1995, n. 335.

14. All'articolo 8, comma 1-bis, del decreto legislativo 21 aprile 1993, n. 124, introdotto dall'articolo 17, comma 1, lettera d), del decreto legislativo 18 febbraio 2000, n. 47, sono apportate le seguenti modificazioni:

- a) dopo le parole: "acquisti effettuati tramite moneta elettronica" sono inserite le seguenti: "o altro mezzo di pagamento";
- b) le parole: "con il titolare della moneta elettronica e" sono soppresse;
- c) al terzo periodo, dopo le parole: "fondo pensione" e' inserita la seguente: "complementare".

15. Nei limiti delle risorse rispettivamente indicate a carico del Fondo di cui all'articolo 1, comma 7, del decreto-legge 20 maggio 1993, n. 148, convertito, con modificazioni, dalla legge 19 luglio 1993, n. 236, per l'anno 2001:

- a) sono prorogati, in attesa della riforma degli ammortizzatori sociali e comunque non oltre il 31 dicembre 2001, i trattamenti di cassa integrazione guadagni straordinaria e di mobilita' di cui all'articolo 62, comma 1, lettera g), della legge 23 dicembre 1999, n. 488, limitatamente alle imprese esercenti attivita' commerciali con piu' di cinquanta addetti. L'onere differenziale tra prestazioni, ivi compresa la contribuzione figurativa, e gettito contributivo e' pari a lire 50 miliardi;
- b) all'articolo 1, comma 1, del decreto-legge 20 gennaio 1998, n. 4, convertito, con modificazioni, dalla legge 20 marzo 1998, n. 52, come modificato dall'articolo 62, comma 5, della legge 23 dicembre 1999, n. 488, le parole: "31 dicembre 2000" sono sostituite dalle seguenti: "31 dicembre 2001" e le parole: "per ciascuno degli anni 1999 e 2000" sono sostituite dalle seguenti: "per ciascuno degli anni 1999, 2000 e 2001". L'onere derivante dalla presente disposizione e' pari a lire 9 miliardi;
- c) all'articolo 1, comma 2, del decreto-legge 20 gennaio 1998, n. 4, convertito, con modificazioni, dalla legge 20 marzo 1998, n. 52, le parole: "31 dicembre 2000" sono sostituite dalle seguenti: "31 dicembre 2001". All'onere derivante dalla presente disposizione si provvede entro il limite massimo di lire 40 miliardi;
- d) il comma 5 dell'articolo 16 della legge 7 agosto 1997, n. 266, e' sostituito dal seguente: "5. A decorrere dal 10 gennaio 1999 all'articolo 49, comma 1, lettera a), della legge 9 marzo 1989, n. 88, dopo le parole: "trasporti e comunicazioni" sono inserite le seguenti: ""delle lavanderie industriali""; e) le disposizioni previste dall'articolo 7, comma 5, della legge 23 luglio 1991, n. 223, si applicano anche nei casi in cui i lavoratori licenziati beneficiano del trattamento di cui all'articolo 11 della citata legge n. 223 del 1991. L'onere derivante dalla presente disposizione e' pari a lire 2 miliardi. 16. I piani di inserimento professionale di cui all'articolo 15 del decreto-legge 16 maggio 1994, n. 299, convertito, con modificazioni, dalla legge 19 luglio 1994, n. 451, e successive modificazioni, avviati alla data del 30 giugno 2001, possono essere comunque conclusi entro il termine previsto dagli stessi piani. La relativa dotazione finanziaria per l'anno 2001 e' pari a lire 50 miliardi, a valere sul Fondo di cui al comma 15. 17. In relazione a quanto disposto al comma 15, lettera d), restano comunque validi agli effetti previdenziali e assistenziali i versamenti contributivi effettuati sulla base dell'articolo 2, comma 215, della legge 23 dicembre 1996, n. 662. L'onere derivante dalla disposizione di cui al comma 15, lettera d), e' pari a lire 525 milioni. 18. All'articolo 68, comma 4, lettera a), della legge 17 maggio 1999, n. 144, le parole: "e fino a lire 590 miliardi a decorrere dall'anno 2001" sono sostituite dalle seguenti: ", lire 562 miliardi per il 2001 e fino a lire 590 miliardi a decorrere dall'anno 2002,". 19. In attesa della riforma degli ammortizzatori sociali, la percentuale di commisurazione alla retribuzione dell'indennita' ordinaria di disoccupazione con requisiti normali, di cui all'articolo 19, primo comma, del regio decreto-legge 14 aprile 1939, n. 636, convertito, con modificazioni, dalla legge 6 luglio 1939, n. 1272, e successive modificazioni, e' elevata al 40 per cento dal 1 gennaio 2001 e per i soggetti con eta' anagrafica pari o superiore a 50 anni e' estesa fino a nove mesi. Tali incrementi non si applicano ai trattamenti di disoccupazione agricoli, ordinari e speciali, ne' all'indennita' ordinaria con requisiti ridotti di cui all'articolo 7, comma 3, del decreto-legge 21 marzo 1988, n. 86, convertito, con modificazioni, dalla legge 20 maggio 1988, n. 160. 20. Per il periodo dal 1° gennaio 2001 al 30 giugno 2001, il divieto di cumulo di cui all'articolo 1, comma 43, della legge 8 agosto 1995, n. 335, non opera tra il trattamento di reversibilita' a carico dell'assicurazione generale obbligatoria per l'invalidita', la vecchiaia e i superstiti, nonche' delle forme esclusive, esonerative e sostitutive della stessa, e la rendita ai superstiti erogata dall'Istituto nazionale per l'assicurazione contro gli infortuni sul lavoro spettante in caso di decesso del lavoratore conseguente ad infortunio sul lavoro o malattia professionale ai sensi dell'articolo 85 del decreto del Presidente della Repubblica 30 giugno 1965, n. 1124, recante, testo unico delle disposizioni per l'assicurazione obbligatoria contro gli infortuni sul lavoro e le malattie professionali, e successive modificazioni. Le disposizioni di cui al presente comma si applicano alle rate di pensione di reversibilita' successive alla data del 31 dicembre 2000, anche se la pensione stessa e' stata liquidata in data anteriore. 21. L'autorizzazione di spesa di cui all'articolo 66, comma 1, della legge 17 maggio 1999, n. 144, e' ridotta di lire 227 miliardi per l'anno 2001 e di lire 317 miliardi a decorrere dall'anno 2002. 22. La contribuzione figurativa accreditata per i periodi successivi al 31 dicembre 2000 per i quali e' corrisposto il trattamento speciale di disoccupazione per i lavoratori licenziati da imprese edili ed affini e' utile ai fini del conseguimento del diritto e della determinazione della misura del trattamento pensionistico, compreso quello di anzianita'. 23. Per i lavoratori gia' impegnati in lavori di sottosuolo presso miniere, cave e torbiere, la cui attivita' e' venuta a cessare a causa della definitiva chiusura delle stesse, e che non hanno maturato i benefici previsti dall'articolo 18 della legge 30 aprile 1969, n. 153, il numero delle settimane coperto da contribuzione obbligatoria relativa ai periodi di prestazione lavorativa ai fini del conseguimento delle prestazioni pensionistiche e' moltiplicato per un coefficiente pari a 1,2 se l'attivita' si e' protratta per meno di cinque anni, a 1,225 se l'attivita' si e' protratta per meno di dieci anni e a 1,25 se superiore a tale limite. 24. Il comma 6 dell'articolo 36 del decreto legislativo 26 febbraio 1999, n. 46, e' sostituito dal seguente: "6. Le disposizioni contenute nell'articolo 25 si applicano ai contributi e premi non versati e agli accertamenti notificati successivamente alla data del 1° gennaio 2001". 25. Le risorse finanziarie comunque derivanti dagli effetti dell'applicazione della decisione 2000/128/CE della Commissione delle Comunita' europee dell'11 maggio 1999 in materia di contratti di formazione e lavoro, pubblicata nella Gazzetta Ufficiale delle Comunita' europee n. L042 del 15 febbraio 2000, da accertare con decreto del Ministro del lavoro e della previdenza sociale di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, sono assegnate al Fondo per l'occupazione di cui all'articolo 1, comma 7, del decreto-legge 20 maggio 1993, n. 148, convertito, con modificazioni, dalla legge 19 luglio 1993, n. 236, per essere destinate, nei limiti delle medesime risorse, con decreto del Ministro del lavoro e della previdenza sociale, di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, ad interventi in materia di ammortizzatori sociali, con particolare riferimento all'incremento dell'indennita' di disoccupazione previsto dal comma 19, in caso di indennita' di disoccupazione con requisiti ridotti. 26. Alla legge 17 maggio 1999, n. 144, sono apportate le seguenti modifiche: a) all'articolo 45, comma 1, lettera a), numero 2 sono aggiunte, in fine, le seguenti parole: "con revisione e razionalizzazione del collocamento ordinario, nel rispetto di quanto previsto dal decreto legislativo 23 dicembre 1997, n. 469, in funzione del miglioramento dell'incontro tra domanda e offerta di lavoro e con valorizzazione degli strumenti di informatizzazione"; b) all'articolo 55, comma 2, quinto periodo, le parole: "entro un anno" sono sostituite dalle seguenti: "entro due anni". 27. Agli agenti temporanei, in servizio presso gli organismi dell'Unione europea, che hanno chiesto, anteriormente al 13 maggio 1981, data di entrata in vigore del decreto del Ministro del lavoro e della previdenza sociale del 19 febbraio 1981, pubblicato nel supplemento ordinario alla Gazzetta Ufficiale n. 129 del 13 maggio 1981, emanato in attuazione dell'articolo 13 della legge 12 agosto 1962, n. 1338, il trasferimento dell'equivalente attuariale delle posizioni assicurative al Fondo per le pensioni CE in base alle disposizioni del regolamento (CEE, Euratom, CECA) n. 259/68 del Consiglio, del 29 febbraio 1968, e successive modificazioni, si applica il coefficiente attuariale rideterminato sulla base delle tariffe del citato decreto del Ministero del lavoro e della previdenza sociale del 19 febbraio 1981. Lo Stato concorre alla copertura degli oneri derivanti dalla presente disposizione e di quella di cui al comma 28 nel limite massimo di lire 15 miliardi per l'anno 2001; la quota differenziale dei medesimi oneri e' a carico degli organismi di cui al presente comma. 28. Per il calcolo delle quote di pensione relative alle posizioni assicurative di cui al comma 27, le retribuzioni di riferimento determinate per ciascun anno solare sono rivalutate in misura corrispondente alle variazioni dell'articolo 3, undicesimo comma, della legge 29 maggio 1982, n. 297, per le liquidazioni delle pensioni aventi decorrenza nell'anno 1983. 29. All'articolo 1, comma 14, del decreto-legge 24 novembre 2000, n. 346, sono apportate le seguenti modifiche: a) le parole: "entro il 14 febbraio 2000" sono sostituite dalle seguenti: "entro il 31 dicembre 2000"; b) le parole: "centoquarantacinque unita' e nel limite di lire 7 miliardi e 240 milioni" sono sostituite dalle seguenti: "duecentottantanove unita' e nel limite di lire 14 miliardi". 30. Agli oneri derivanti dalle disposizioni di cui al comma 16 e ai commi da 22 a 29, valutati in lire 76,5 miliardi per l'anno 2001, in lire 7,4 miliardi per l'anno 2002 e in lire 12,4 miliardi a decorrere dall'anno 2003, si provvede, per gli anni 2002 e 2003, a valere sulle disponibilita' del Fondo per l'occupazione di cui all'articolo 1, comma 7, del decreto-legge 20 maggio 1993, n. 148, convertito, con modificazioni, dalla legge 19 luglio 1993, n. 236. 31. Ai fini della stabilizzazione dell'occupazione dei soggetti impegnati in progetti di lavori socialmente utili presso gli istituti scolastici, sono definite, in base ai criteri stabiliti ai sensi dell'articolo 10, comma 2, del decreto legislativo 28 febbraio 2000, n. 81, mediante decreto del Ministro della pubblica istruzione, di concerto con il Ministro del lavoro e della previdenza sociale e il Ministro del tesoro, del bilancio e della programmazione economica, procedure di terziarizzazione, ai sensi della normativa vigente, secondo criteri e modalita' che assicurino la trasparenza e la competitivita' degli affidamenti. A tal fine e' autorizzata la spesa di lire 287 miliardi per l'anno 2001 e di lire 575 miliardi per l'anno 2002. Al relativo onere si provvede, quanto a lire 249 miliardi per l'anno 2002, mediante riduzione dell'autorizzazione di spesa di cui all'articolo 66, comma 1, della legge 17 maggio 1999, n. 144. 32. Per l'integrazione dei servizi informativi catastale e ipotecario e la costituzione dell'Anagrafe dei beni immobiliari, previsti dall'articolo 64 del decreto legislativo 30 luglio 1999, n. 300, da realizzare attraverso un piano pluriennale di attivita' straordinarie finalizzate all'implementazione e all'integrazione dei dati presenti negli archivi, anche al fine di favorire il processo di decentramento di cui al decreto legislativo 31 marzo 1998, n. 112, il Ministero delle finanze e l'agenzia del territorio, a decorrere dalla data di trasferimento a quest'ultima delle funzioni del Dipartimento del territorio, possono provvedere, in attesa di una definitiva stabilizzazione e nei limiti delle risorse assegnate ai sensi dell'articolo 3, comma 193, della legge 28 dicembre 1995, n. 549, e dell'articolo 12, comma 1, del decreto-legge 28 marzo 1997, n. 79, convertito, con modificazioni, dalla legge 28 maggio 1997, n. 140, entro quattro mesi dalla data di entrata in vigore della presente legge, alla stipulazione di contratti per l'assunzione a tempo determinato, anche parziale, per dodici mesi, anche rinnovabili, e fino ad un massimo di 1650 unita', dei soggetti impiegati nei lavori socialmente utili relativi al progetto denominato "Catasto urbano". 33. Restano validi gli atti ed i provvedimenti adottati e sono fatti salvi gli effetti prodottisi e i rapporti giuridici sorti sulla base del decreto-legge 24 novembre 2000, n. 346. La presente disposizione acquista efficacia a decorrere dal 27 gennaio 2001.

------------- AGGIORNAMENTO (31) La L. 24 dicembre 2003,n. 350 ha disposto (con l'art. 3, comma 77) che "In presenza delle convenzioni di cui al comma 76 il termine di cui all'articolo 78, comma 2, alinea, della legge 23 dicembre 2000, n. 388, e' prorogato al 31 dicembre 2004". ------------- AGGIORNAMENTO (36) La L. 30 dicembre 2004, n. 311 ha disposto (con l'art. 1, comma 262) che in presenza delle convenzioni di cui all'art. 1, comma 262 della suddetta legge il termine di cui all'articolo 78, comma 2, della legge 23 dicembre 2000, n. 388, e' prorogato al 31 dicembre 2005. ------------- AGGIORNAMENTO (43) La L. 23 dicembre 2006, n. 266 ha disposto (con l'art. 1, comma 430) che in presenza delle convenzioni di cui all'art. 1, comma 430 della suddetta legge il termine di cui all'articolo 78, comma 2, della legge 23 dicembre 2000, n. 388, e' prorogato al 31 dicembre 2006". ------------- AGGIORNAMENTO (49) La L. 27 dicembre 2006, n. 296, ha disposto (con l'art. 1, comma 1166) che in presenza delle convenzioni previste dal comma 1166 dell'art. 1 della suddetta legge, il termine di cui al comma 2 del presente articolo e' prorogato al 31 dicembre 2007. ------------- AGGIORNAMENTO (99) La L. 27 dicembre 2019, n. 160, ha disposto (con l'art. 1, comma 162) che "Le convenzioni stipulate ai sensi dell'articolo 78, comma 2, della legge 23 dicembre 2000, n. 388, per l'utilizzazione di lavoratori socialmente utili di cui all'articolo 2, comma 1, del decreto legislativo 28 febbraio 2000, n. 81, sono prorogate al 31 dicembre 2020 nei limiti della spesa gia' sostenuta e senza nuovi o maggiori oneri a carico della finanza pubblica". -------------- AGGIORNAMENTO (101) La L. 27 dicembre 2019, n. 160, come modificata dalla L. 30 dicembre 2020, n. 178, ha disposto (con l'art. 1, comma 162) che "Le convenzioni stipulate ai sensi dell'articolo 78, comma 2, della legge 23 dicembre 2000, n. 388, per l'utilizzazione di lavoratori socialmente utili di cui all'articolo 2, comma 1, del decreto legislativo 28 febbraio 2000, n. 81, sono prorogate al 31 dicembre 2021 nei limiti della spesa gia' sostenuta e senza nuovi o maggiori oneri a carico della finanza pubblica". -------------- AGGIORNAMENTO (103) La L. 27 dicembre 2019, n. 160, come modificata dal D.L. 30 dicembre 2021, n. 228, convertito con modificazioni dalla L. 25 febbraio 2022, n. 15, ha disposto (con l'art. 1, comma 162) che "Le convenzioni stipulate ai sensi dell'articolo 78, comma 2, della legge 23 dicembre 2000, n. 388, per l'utilizzazione di lavoratori socialmente utili di cui all'articolo 2, comma 1, del decreto legislativo 28 febbraio 2000, n. 81, sono prorogate al 31 dicembre 2022 nei limiti della spesa gia' sostenuta e senza nuovi o maggiori oneri a carico della finanza pubblica". --------------- AGGIORNAMENTO (106) La L. 27 dicembre 2019, n. 160, come modificata dal D.L. 29 dicembre 2022, n. 198, ha disposto (con l'art. 1, comma 162) che "Le convenzioni stipulate ai sensi dell'articolo 78, comma 2, della legge 23 dicembre 2000, n. 388, per l'utilizzazione di lavoratori socialmente utili di cui all'articolo 2, comma 1, del decreto legislativo 28 febbraio 2000, n. 81, sono prorogate al 31 dicembre 2023 nei limiti della spesa gia' sostenuta e senza nuovi o maggiori oneri a carico della finanza pubblica". --------------- AGGIORNAMENTO (107) La L. 27 dicembre 2019, n. 160, come modificata dal D.L. 30 dicembre 2023, n. 215 ha disposto (con l'art. 1, comma 162) che "Le convenzioni stipulate ai sensi dell'articolo 78, comma 2, della legge 23 dicembre 2000, n. 388, per l'utilizzazione di lavoratori socialmente utili di cui all'articolo 2, comma 1, del decreto legislativo 28 febbraio 2000, n. 81, sono prorogate al 30 giugno 2024 nei limiti della spesa gia' sostenuta e senza nuovi o maggiori oneri a carico della finanza pubblica". --------------- AGGIORNAMENTO (111) La L. 27 dicembre 2019, n. 160, come modificata dal D.L. 7 maggio 2024, n. 60, convertito con modificazioni dalla L. 4 luglio 2024, n. 95, ha disposto (con l'art. 1, comma 162) che "Le convenzioni stipulate ai sensi dell'articolo 78, comma 2, della legge 23 dicembre 2000, n. 388, per l'utilizzazione di lavoratori socialmente utili di cui all'articolo 2, comma 1, del decreto legislativo 28 febbraio 2000, n. 81, sono prorogate al 31 dicembre 2024 nei limiti della spesa gia' sostenuta e senza nuovi o maggiori oneri a carico della finanza pubblica". --------------- AGGIORNAMENTO (115) La L. 27 dicembre 2019, n. 160, come modificata dalla L. 30 dicembre 2024, n. 207, ha disposto (con l'art. 1, comma 162) che "Le convenzioni stipulate ai sensi dell'articolo 78, comma 2, della legge 23 dicembre 2000, n. 388, per l'utilizzazione di lavoratori socialmente utili di cui all'articolo 2, comma 1, del decreto legislativo 28 febbraio 2000, n. 81, sono prorogate al 31 dicembre 2025 nei limiti della spesa gia' sostenuta e senza nuovi o maggiori oneri a carico della finanza pubblica".

### Art. 79. - (Norme in materia di ENPALS)

1. Al fine di consentire all'ENPALS di adeguare la propria struttura istituzionale, ordinamentale ed operativa rispetto all'obiettivo del recupero del lavoro sommerso, anche con riferimento alla convenzione gia' sottoscritta tra l'ENPALS e la SIAE relativamente agli obblighi contributivi di competenza del predetto ente, il competente organo dell'ENPALS puo' proporre le modifiche dello statuto e dei regolamenti in coerenza con i principi della legge 9 marzo 1989, n. 88, e del decreto legislativo 3 febbraio 1993, n. 29, e successive modificazioni. Su tali proposte si esprimera' il Ministero del lavoro e della previdenza sociale di concerto con il Ministero del tesoro, del bilancio e della programmazione economica entro sessanta giorni dal loro ricevimento.

2. Entro il 28 febbraio 2001 l'INPS stipula con la SIAE apposita convenzione, per lo scambio, anche mediante collegamento telematico, dei dati presenti nei rispettivi archivi e per l'acquisizione di informazioni utili all'accertamento ed alla riscossione dei contributi. Per l'acquisizione delle informazioni di cui al periodo precedente, nonche' per l'acquisizione di quelle previste nella convenzione sottoscritta tra l'ENPALS e la SIAE, agli agenti della SIAE con contratto di lavoro a tempo indeterminato con la medesima societa' e' consentito raccogliere e verificare dichiarazioni del lavoratore e documentazioni riferite al relativo rapporto di lavoro.

### Art. 80. - (Disposizioni in materia di politiche sociali)

1. Nei limiti di lire 350 miliardi per l'anno 2001 e di lire 430 miliardi per l'anno 2002 e fino alla data del 31 dicembre 2002, ovvero fino alla conclusione dei processi attuativi della sperimentazione e comunque non oltre il 30 giugno 2007, fermi restando gli stanziamenti gia' previsti:

- a) i comuni individuati ai sensi dell'articolo 4 del decreto legislativo 18 giugno 1998, n. 237, sono autorizzati, nell'ambito della disciplina prevista dal predetto decreto legislativo. a proseguire l'attuazione dell'istituto del reddito minimo di inserimento;
- b) la disciplina dell'istituto del reddito minimo di inserimento di cui al citato decreto legislativo n. 237 del 1998 si applica anche ai comuni compresi nei territori per i quali sono stati approvati, alla data del 30 giugno 2000, i patti territoriali di cui all'articolo 2, comma 203, della legge 23 dicembre 1996, n. 662, e successive modificazioni, che i medesimi comuni hanno sottoscritto o ai quali hanno aderito e che comprendono comuni gia' individuati o da individuare ai sensi dell'articolo 4 del medesimo decreto legislativo n. 237 del 1998.

2. Dopo il comma 4 dell'articolo 4 della legge 8 marzo 2000, n. 53, e' aggiunto il seguente: "4-bis. La lavoratrice madre o, in alternativa, il lavoratore padre, anche adottivi, o, dopo la loro scomparsa, uno dei fratelli o delle sorelle conviventi di soggetto con handicap in situazione di gravita' di cui all'articolo 3, comma 3, della legge 5 febbraio 1992, n. 104, accertata ai sensi dell'articolo 4, comma 1, della legge medesima da almeno cinque anni e che abbiano titolo a fruire dei benefici di cui all'articolo 33, commi 1, 2 e 3, della predetta legge n. 104 del 1992 per l'assistenza del figlio, hanno diritto a fruire del congedo di cui al comma 2 del presente articolo entro sessanta giorni dalla richiesta. Durante il periodo di congedo, il richiedente ha diritto a percepire un'indennita' corrispondente all'ultima retribuzione e il periodo medesimo e' coperto da contribuzione figurativa; l'indennita' e la contribuzione figurativa spettano fino ad un importo complessivo massimo di lire 70 milioni annue per il congedo di durata annuale. Detto importo e' rivalutato annualmente, a decorrere dall'anno 2002, sulla base della variazione dell'indice ISTAT dei prezzi al consumo per le famiglie di operai e impiegati. L'indennita' e' corrisposta dal datore di lavoro secondo le modalita' previste per la corresponsione dei trattamenti economici di maternita'. I datori di lavoro privati, nella denuncia contributiva, detraggono l'importo dell'indennita' dall'ammontare dei contributi previdenziali dovuti all'ente previdenziale competente. Per i dipendenti dei predetti datori di lavoro privati, compresi quella per i quali non e' prevista l'assicurazione per le prestazioni di maternita', l'indennita' di cui al presente comma e' corrisposta con le modalita' di cui all'articolo 1 del decreto-legge 30 dicembre 1979, n. 663, convertito, con modificazioni, dalla legge 29 febbraio 1980, n. 33. Il congedo fruito ai sensi del presente comma alternativamente da entrambi i genitori, anche adottivi, non puo' superare la durata complessiva di due anni; durante il periodo di congedo entrambi i genitori non possono fruire dei benefici di cui all'articolo 33 della legge 5 febbraio 1992, n. 104, fatte salve le disposizioni di cui ai commi 5 e 6 del medesimo articolo".

3. A decorrere dall'anno 2002, ai lavoratori sordomuti di cui all'articolo 1 della legge 26 maggio 1970, n. 381, nonche' agli invalidi per qualsiasi causa, ai quali e' stata riconosciuta un'invalidita' superiore al 74 per cento o ascritta alle prime quattro categorie della tabella A allegata al testo unico delle norme in materia di pensioni di guerra, approvato con decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, come sostituita dalla tabella A allegata al decreto del Presidente della Repubblica 30 dicembre 1981, n. 834, e successive modificazioni, e' riconosciuto, a loro richiesta, per ogni anno di servizio presso pubbliche amministrazioni o aziende private ovvero cooperative effettivamente svolto, il beneficio di due mesi di contribuzione figurativa utile ai soli fini del diritto alla pensione e dell'anzianita' contributiva, il beneficio e' riconosciuto fino al limite massimo di cinque anni di contribuzione figurativa.

4. Il comma 3 dell'articolo 65 della legge 23 dicembre 1998, n. 448, e' sostituito dal seguente: "3. L'assegno di cui al comma 1 e' corrisposto integralmente, per un ammontare di 200.000 lire mensili e per tredici mensilita', per i valori dell'ISE del beneficiario inferiori o uguali alla differenza tra il valore dell'ISE di cui al comma 1 e il predetto importo dell'assegno su base annua. Per valori dell'ISE del beneficiario compresi tra la predetta differenza e il valore dell'ISE di cui al comma 1 l'assegno e' corrisposto in misura pari alla differenza tra l'ISE di cui al comma 1 e quello del beneficiario, e per importi annui non inferiori a 20.000 lire".

5. L'assegno di cui all'articolo 65 della legge 23 dicembre 1998, n. 448, e successive modificazioni, come ulteriormente modificato dal presente articolo, e come interpretato ai sensi del comma 9, e' concesso, nella misura e alle condizioni previste dal medesimo articolo 65 e dalle relative norme di attuazione, ai nuclei familiari di cui al decreto legislativo 31 marzo 1998, n. 109. e successive modificazioni, nei quali siano presenti il richiedente, cittadino italiano o comunitario, residente nel territorio dello Stato, e tre minori di anni 18 conviventi con il richiedente, che siano figli del richiedente medesimo o del coniuge o da essi ricevuti in affidamento preadottivo.

6. Le disposizioni di cui ai commi 4 e 5 sono efficaci per gli assegni da concedere per l'anno 2001 e successivi.

7. La potesta' concessiva degli assegni di cui agli articoli 65 e 66 della legge 23 dicembre 1998, n. 448, e successive modificazioni, puo' essere esercitata dai comuni anche in forma associata o mediante un apposito servizio comune, ovvero dall'INPS, a seguito della stipula di specifici accordi tra i comuni e l'Istituto medesimo; nell'ambito dei suddetti accordi, sono definiti, tra l'altro, i termini per la conclusione del procedimento, le modalita' dell'istruttoria delle domande e dello scambio, anche in via telematica, dei dati relativi al nucleo familiare e alla situazione economica dei richiedenti, nonche' le eventuali risorse strumentali e professionali che possono essere destinate in via temporanea dai comuni all'INPS per il piu' efficiente svolgimento dei procedimenti concessori.

8. Le regioni possono prevedere che la potesta' concessiva dei trattamenti di invalidita' civile di cui all'articolo 130 del decreto legislativo 31 marzo 1998, n. 112, e successive modificazioni, puo' essere esercitata dall'INPS a seguito della stipula di specifici accordi tra le regioni medesime ed il predetto Istituto. Negli accordi possono essere definiti, tra l'altro, i rapporti conseguenti all'eventuale estensione della potesta' concessiva ai benefici aggiuntivi disposti dalle regioni con risorse proprie, nonche' la destinazione all'INPS, per il periodo dell'esercizio della potesta' concessiva da parte dell'Istituto, di risorse derivanti dai provvedimenti attuativi dell'articolo 7 del predetto decreto legislativo n. 112 del 1998.

9. Le disposizioni dell'articolo 65 della legge 23 dicembre 1998, n. 448, si interpretano nel senso che il diritto a percepire l'assegno spetta al richiedente convivente con i tre figli minori, che ne abbia fatta annualmente domanda nei termini previsti dalle disposizioni di attuazione.

10. COMMA ABROGATO DAL D.LGS. 26 MARZO 2001, N. 151.

11. COMMA ABROGATO DAL D.LGS. 26 MARZO 2001, N. 151.

12. La disposizione di cui al comma 16, quarto periodo, dell'articolo 59 della legge 27 dicembre 1997, n. 449, si interpreta nel senso che l'estensione ivi prevista della tutela relativa alla maternita' e agli assegni al nucleo familiare avviene nelle forme e con le modalita' previste per il lavoro dipendente.

13. Il Fondo nazionale per le politiche sociali, di cui all'articolo 59, comma 44, della legge 27 dicembre 1997, n. 449, e successive modificazioni, e' incrementato di lire 350 miliardi per l'anno 2001 e di lire 430 miliardi per l'anno 2002.

14. Una quota del Fondo di cui al comma 13, nel limite massimo di lire 10 miliardi annue, e' destinata al sostegno dei servizi di telefonia rivolti alle persone anziane, attivati da associazioni di volontariato e da altri organismi senza scopo di lucro con comprovata esperienza nel settore dell'assistenza agli anziani, che garantiscano un servizio continuativo per tutto l'anno e l'assistenza alle persone anziane per la fruizione degli interventi e dei servizi pubblici presenti nel territorio. Una quota del medesimo Fondo, nel limite massimo di lire 3 miliardi, viene destinata alle famiglie nel cui nucleo siano comprese una o piu' persone anziane titolari di assegno di accompagnamento, totalmente immobili, costrette a letto e bisognose di assistenza continuativa di cui la famiglia si fa carico. Un'ulteriore quota del medesimo Fondo, nel limite massimo di lire 20 miliardi, e' destinata al cofinanziamento delle iniziative sperimentali, promosse dagli enti locali entro il 30 settembre 2000, per la realizzazione di specifici servizi di informazione sulle attivita' e sulla rete dei servizi attivati nel territorio in favore delle famiglie. Il Ministro per la solidarieta' sociale, sentite le competenti Commissioni parlamentati, con propri decreti definisce i criteri, i requisiti, le modalita' e i termini per la concessione, l'erogazione e la revoca dei contributi di cui al presente comma, nonche' per la verifica delle attivita' svolte.

15. Nell'anno 2001, al fondo di cui all'articolo 17, comma 2, della legge 3 agosto 1998, n. 269, e' attribuita una somma di 20 miliardi di lire, ad incremento della quota prevista dal citato comma 2, per il finanziamento di specifici programmi di prevenzione, assistenza e recupero psicoterapeutico dei minori vittime dei reati ivi previsti. Il Ministro per la solidarieta' sociale, sentiti i Ministri dell'interno, della giustizia e della sanita', provvede con propri decreti, sulla base delle risorse disponibili, alla definizione dei programmi di cui al citato articolo 17, comma 2, della legge 3 agosto 1998, n. 269, delle condizioni e modalita' per l'erogazione dei finanziamenti, e per la verifica degli interventi.

16. I comuni di cui all'articolo 1, comma 2, secondo periodo, della legge 28 agosto 1997, n. 285, successivamente all'attribuzione delle quote del Fondo nazionale per l'infanzia e l'adolescenza loro riservate, sono autorizzati a disporre sui fondi assegnati anticipazioni fino al 40 per cento del costo dei singoli interventi attuati in convenzione con terzi.

17. Con effetto dal 1° gennaio 2001 il Fondo nazionale per le politiche sociali di cui all'articolo 59, comma 44, della legge 27 dicembre 1997, n. 449, e successive modificazioni, e' determinato dagli stanziamenti previsti per gli interventi disciplinari dalle seguenti disposizioni legislative, e successive modificazioni:

- a) testo unico approvato con decreto del Presidente della Repubblica 9 ottobre 1990, n. 309;
- b) legge 19 luglio 1991, n. 216;
- c) legge 11 agosto 1991, n. 266;
- d) legge 5 febbraio 1992, n. 104;
- e) decreto-legge 27 maggio 1994, n. 318, convertito, con modificazioni, dalla legge 27 luglio 1994, n. 465;
- f) legge 28 agosto 1997, n. 284;
- g) legge 28 agosto 1997, n. 285;
- h) legge 23 dicembre 1997, n. 451;
- i) articolo 59, comma 47, della legge 27 dicembre 1997, n. 449;
- l) legge 21 maggio 1998, n. 162;
- m) decreto legislativo 25 luglio 1998, n. 286, ad esclusione delle somme stanziate dall'articolo 18;
- n) legge 3 agosto 1998, n. 269;
- o) legge 15 dicembre 1998, n. 438;
- p) articoli 65 e 66 della legge 23 dicembre 1998, n. 448;
- q) legge 31 dicembre 1998, n. 476;
- r) legge 18 febbraio 1999, n. 45;
- r-bis) legge 8 marzo 2000, n. 53, articolo 28;
- r-ter) legge 7 dicembre 2000, n. 383, articolo 13.

18. Le risorse afferenti alle disposizioni indicate al comma 17, lettere a), d), f), g), h), l), m), r), sono ripartite in unica soluzione, sulla base della vigente normativa, fra le regioni e le province autonome di Trento e di Bolzano con decreto annuale del Ministro per la solidarieta' sociale.

19. Ai sensi dell'articolo 41 del decreto legislativo 25 luglio 1998, n. 286, l'assegno sociale e le provvidenze economiche che costituiscono diritti soggettivi in base alla legislazione vigente in materia di servizi sociali sono concesse alle condizioni previste dalla legislazione medesima, agli stranieri che siano titolari di carta di soggiorno; per le altre prestazioni e servizi sociali l'equiparazione con i cittadini italiani e' consentita a favore degli stranieri che siano almeno titolari di permesso di soggiorno di durata non inferiore ad un anno. Sono fatte salve le disposizioni previste dal decreto legislativo 18 giugno 1998, n. 237, e dagli articoli 65 e 66 della legge 23 dicembre 1998, n. 448, e successive modificazioni. (55) (58) (63) (68) (78) (83) ((87))

20. I comuni indicati dall'articolo 6 della legge 9 dicembre 1998, n. 431, possono destinare fino al 10 per cento delle somme ad essi attribuite sul Fondo di cui all'articolo 11 della medesima legge alla locazione di immobili per inquilini assoggettati a procedure esecutive di sfratto che hanno nel nucleo familiare ultrasessantacinquenni, o handicappati gravi, e che non dispongano di altra abitazione o di redditi sufficienti ad accedere all'affitto di una nuova casa. Al medesimo fine i comuni medesimi possono utilizzare immobili del proprio patrimonio, ovvero destinare ulteriori risorse proprie ad integrazione del Fondo anzidetto.

21. Ai fini dell'applicazione del comma 20 i comuni predispongono graduatorie degli inquilini per cui vengano accertate le condizioni di cui al medesimo comma 20. Nella prima applicazione le graduatorie sono predisposte entro centottanta giorni dalla data di entrata in vigore della presente legge.

22. Fino alla scadenza del termine di cui al comma 21 sono sospese le procedure esecutive di sfratto iniziate contro gli inquilini che si trovino nelle condizioni di cui al comma 20. (7)

23. Le disponibilita' finanziarie stanziate dal decreto-legge 3 aprile 1985, n. 114, convertito, con modificazioni, dalla legge 30 maggio 1985, n. 211, come individuate dall'articolo 23 del decreto-legge 23 giugno 1995, n. 244, convertito, con modificazioni, dalla legge 8 agosto 1995, n. 341, trasferite al comune di Napoli, possono essere utilizzate, in misura non superiore al 30 per cento, oltre che per l'acquisto di alloggi ad incremento del patrimonio alloggiativo dello stesso comune di Napoli, anche per la riduzione del costo di acquisto della prima casa da parte dei nuclei familiari sfrattati o interessati dalla mobilita' abitativa per piani di recupero. Ai fini dell'assegnazione dei contributi il comune procede ai sensi dell'articolo 5, comma 1, lettera b), del decreto-legge 29 ottobre 1986, n. 708, convertito, con modificazioni, dalla legge 23 dicembre 1986, n. 899.

24. Il contributo in conto capitale di cui al comma 23 puo' essere maggiorato fino al 50 per cento del limite massimo di mutuo agevolato ammissibile per ciascuna delle fasce di reddito prevista dalla normativa della regione Campania. In ogni caso, il contributo per l'acquisto di ciascun alloggio non puo' superare l'importo di 50 milioni di lire.

25. In caso di rinuncia all'azione giudiziaria promossa da parte dei lavoratori esposti all'amianto aventi i requisiti di cui alla legge 27 marzo 1992, n. 257, e cessati dall'attivita' lavorativa antecedentemente all'entrata in vigore della predetta legge, la causa si estingue e le spese e gli onorari relativi alle attivita' antecedenti all'estinzione sono compensati. Non si da' luogo da parte dell'INPS al recupero dei relativi importi oggetto di ripetizione di indebito nei confronti dei titolari di pensione interessati.

------------- AGGIORNAMENTO (7) Il D.L. 2 luglio 2001, n. 247, convertito senza modificazioni dalla legge 4 agosto 2001, n. 332, ha disposto (con l'art. 1, comma 1) che "La sospensione delle procedure esecutive di rilascio di immobili adibiti ad uso abitativo, gia' disposta ai sensi dell'articolo 80, comma 22, della legge 23 dicembre 2000, n. 388, iniziate nei confronti degli inquilini in possesso dei requisiti indicati al comma 20 del medesimo articolo 80, e' differita fino al 31 dicembre 2001". ------------- AGGIORNAMENTO (55) La Corte Costituzionale, con sentenza 29-30 luglio 2008, n. 306 (in G.U. 1a s.s. 06/08/2008, n. 33) ha dichiarato l'illegittimita' costituzionale del comma 19 del presente articolo " nella parte in cui escludono che l'indennita' di accompagnamento, di cui all'art. 1 della legge 11 febbraio 1980, n. 18, possa essere attribuita agli stranieri extracomunitari soltanto perche' essi non risultano in possesso dei requisiti di reddito gia' stabiliti per la carta di soggiorno ed ora previsti, per effetto del decreto legislativo 8 gennaio 2007, n. 3 (Attuazione della direttiva 2003/109/CE relativa allo status di cittadini di Paesi terzi soggiornanti di lungo periodo) per il permesso di soggiorno CE per soggiornanti di lungo periodo". ------------- AGGIORNAMENTO (58) La Corte Costituzionale, con sentenza 14-23 gennaio 2009, n. 11 (in G.U. 1a s.s. 28/01/2009, n. 4) ha dichiarato l'illegittimita' costituzionale del comma 19 del presente articolo "nella parte in cui esclude che la pensione di inabilita', di cui all'art. 12 della legge 30 marzo 1971, n. 118 (Conversione in legge del d.l. 30 gennaio 1971, n. 5 e nuove norme in favore dei mutilati ed invalidi civili), possa essere attribuita agli stranieri extracomunitari soltanto perche' essi non risultano in possesso dei requisiti di reddito gia' stabiliti per la carta di soggiorno ed ora previsti, per effetto del D.Lgs. n. 3 del 2007, per il permesso di soggiorno CE per soggiornanti di lungo periodo". ------------- AGGIORNAMENTO (63) La Corte Costituzionale, con sentenza 26 - 28 maggio 2010, n. 187 (in G.U. 1a s.s. 03/06/2010, n. 22), ha dichiarato l'illegittimita' costituzionale del comma 19 del presente articolo, "nella parte in cui subordina al requisito della titolarita' della carta di soggiorno la concessione agli stranieri legalmente soggiornanti nel territorio dello Stato dell'assegno mensile di invalidita' di cui all'art. 13 della legge 30 marzo 1971, n. 118 (Conversione in legge del decreto-legge 30 gennaio 1971, n. 5 e nuove norme in favore dei mutilati ed invalidi civili)". ------------- AGGIORNAMENTO (68) La Corte Costituzionale, con sentenza 12 - 16 dicembre 2011, n. 329 (in G.U. 1a s.s. 21/12/2011, n. 53) ha dichiarato "l'illegittimita' costituzionale dell'art. 80, comma 19, della legge 23 dicembre 2000, n. 388 (Disposizioni per la formazione del bilancio annuale e pluriennale dello Stato - legge finanziaria 2001), nella parte in cui subordina al requisito della titolarita' della carta di soggiorno la concessione ai minori extracomunitari legalmente soggiornanti nel territorio dello Stato della indennita' di frequenza di cui all'art. 1 della legge 11 ottobre 1990, n. 289 (Modifiche alla disciplina delle indennita' di accompagnamento di cui alla legge 21 novembre 1988, n. 508, recante norme integrative in materia di assistenza economica agli invalidi civili, ai ciechi civili ed ai sordomuti e istituzione di un'indennita' di frequenza per i minori invalidi)". ------------- AGGIORNAMENTO (78) La Corte Costituzionale, con sentenza 11 - 15 marzo 2013 n. 40 (in G.U. 1a s.s. 20/3/2013, n. 12), ha dichiarato "l'illegittimita' costituzionale dell'articolo 80, comma 19, della legge 23 dicembre 2000, n. 388 (Disposizioni per la formazione del bilancio annuale e pluriennale dello Stato - legge finanziaria 2001) nella parte in cui subordina al requisito della titolarita' della carta di soggiorno la concessione agli stranieri legalmente soggiornanti nel territorio dello Stato della indennita' di accompagnamento di cui all'art. 1 della legge 11 febbraio 1980, n. 18 (Indennita' di accompagnamento agli invalidi civili totalmente inabili) e della pensione di inabilita' di cui all'art. 12 della legge 30 marzo 1971, n. 118 (Conversione in legge del decreto-legge 30 gennaio 1971, n. 5 e nuove norme in favore di mutilati ed invalidi civili)". ------------- AGGIORNAMENTO (83) La Corte Costituzionale, con sentenza 27 gennaio - 27 febbraio 2015, n. 22 (in G.U. 1a s.s 4/3/2015, n. 9), ha dichiarato "l'illegittimita' costituzionale dell'art. 80, comma 19, della legge 23 dicembre 2000, n. 388 (Disposizioni per la formazione del bilancio annuale e pluriennale dello Stato - legge finanziaria 2001), nella parte in cui subordina al requisito della titolarita' della carta di soggiorno la concessione agli stranieri legalmente soggiornanti nel territorio dello Stato della pensione di cui all'art. 8 della legge 10 febbraio 1962, n. 66 (Nuove disposizioni relative all'Opera nazionale per i ciechi civili) e dell'indennita' di cui all'art. 3, comma 1, della legge 21 novembre 1988, n. 508 (Norme integrative in materia di assistenza economica agli invalidi civili, ai ciechi civili ed ai sordomuti)". ------------- AGGIORNAMENTO (87) La Corte Costituzionale, con sentenza 7 ottobre - 11 novembre 2015, n. 230 (in G.U. 1ª s.s. 18/11/2015, n. 46), ha dichiarato "l'illegittimita' costituzionale dell'art. 80, comma 19, della legge 23 dicembre 2000, n. 388 (Disposizioni per la formazione del bilancio annuale e pluriennale dello Stato - legge finanziaria 2001), nella parte in cui subordina al requisito della titolarita' della carta di soggiorno la concessione agli stranieri legalmente soggiornanti nel territorio dello Stato della pensione di invalidita' civile per sordi e della indennita' di comunicazione".

### Art. 81. - (Interventi in materia di solidarieta' sociale)

1. Ai fini del finanziamento di un programma di interventi svolti da associazioni di volontariato e da altri organismi senza scopo di lucro con comprovata esperienza nel settore dell'assistenza ai soggetti con handicap grave di cui all'articolo 3, comma 3, della legge 5 febbraio 1992, n. 104, per la cura e l'assistenza di detti soggetti successiva alla perdita dei familiari che ad essi provvedevano, il Fondo nazionale per le politiche sociali, di cui al comma 44 dell'articolo 59 della legge 27 dicembre 1997, n. 449, e' integrato per l'anno 2001 di un importo pari a 100 miliardi di lire.

2. Entro trenta giorni dalla data di entrata in vigore della presente legge, con decreto del Ministro per la solidarieta' sociale emanato ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, sono dettate le disposizioni per l'attuazione del presente articolo, con la definizione dei criteri e delle modalita' per la concessione dei finanziamenti e per la relativa erogazione, nonche' le modalita' di verifica dell'attuazione delle attivita' svolte e la disciplina delle ipotesi di revoca dei finanziamenti concessi.

3. All'articolo 13-bis, comma 1, lettera c), quarto periodo, del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, come sostituito dall'articolo 8, comma 1, della legge 27 dicembre 1997, n. 449, le parole: "54, comma 1, lettere a), c) ed f)", sono sostituite dalle seguenti: "54, comma 1, lettere a), c), f) ed m)".

### Art. 82. - (Disposizioni in favore delle vittime del terrorismo e della criminalita' organizzata)

1. Al personale di cui all'articolo 3 della legge 13 agosto 1980, n. 466, ferito nell'adempimento del dovere a causa di azioni criminose, ed ai superstiti dello stesso personale, ucciso nelle medesime circostanze, nonche' ai destinatari della legge 20 ottobre 1990, n. 302, e' assicurata, a decorrere dal 1° gennaio 1990, l'applicazione dei benefici previsti dalla citata legge n. 302 del 1990 e dalla legge 23 novembre 1998, n. 407. ((30))

2. Non sono ripetibili le somme gia' corrisposte dal Ministero dell'interno a titolo di risarcimento dei danni, in esecuzione di sentenze, anche non definitive, in favore delle persone fisiche costituitesi nei procedimenti penali riguardanti il gruppo criminale denominato "Banda della Uno bianca". Il Ministero dell'interno e' autorizzato, fino al limite complessivo di 6.500 milioni di lire, a definire consensualmente, anche in deroga alle disposizioni di legge in materia, ogni altra lite in corso con le persone fisiche danneggiate dai fatti criminosi commessi dagli appartenenti al medesimo gruppo criminale.

3. Il Ministero della difesa e' autorizzato, fino al limite complessivo di 10 miliardi di lire, in ragione di 5 miliardi di lire per ciascuno degli anni 2001 e 2002, a definire consensualmente, anche in deroga alle disposizioni di legge in materia, ogni lite in corso con le persone fisiche che hanno subito danni a seguito del naufragio della nave "Kaider I Rades A451" avvenuto nel canale di Otranto il 28 marzo 1997.

4. Gli importi gia' corrisposti a titolo di speciale elargizione di cui alla legge 13 agosto 1980, n. 466, e successive modificazioni ai superstiti di atti di terrorismo, che per effetto di ferite o lesioni abbiano subito una invalidita' permanente non inferiore all'80 per cento della capacita' lavorativa o che comunque abbia comportato la cessazione dell'attivita' lavorativa, sono soggetti a riliquidazione tenendo conto dell'aumento previsto dall'articolo 2 della legge 20 ottobre 1990, n. 302. I benefici di cui alla medesima legge n. 302 del 1990, spettanti ai familiari delle vittime di atti di terrorismo, in assenza dei soggetti indicati al primo comma dell'articolo 6 della legge 13 agosto 1980, n. 466, e successive modificazioni, competono; nell'ordine, ai seguenti soggetti in quanto unici superstiti: orfani, fratelli o sorelle o infine ascendenti in linea retta, anche se non conviventi e non a carico.

5. I benefici previsti dalla legge 20 ottobre 1990, n. 302, e dalla legge 23 novembre 1998, n. 407, in favore delle vittime del terrorismo e della criminalita' organizzata, si applicano a decorrere dal 1° gennaio 1967.

6. Per la concessione di benefici alle vittime della criminalita' organizzata si applicano le norme vigenti in materia per le vittime del terrorismo, qualora piu' favorevoli.

7. All'articolo 11 della legge 20 ottobre 1990, n. 302, al comma 1, dopo le parole: "l'eventuale involontario concorso" sono inserite le seguenti: ", anche di natura colposa,".

8. Le disposizioni della legge 20 ottobre 1990, n. 302, si applicano anche in presenza di effetti invalidanti o letali causati da attivita' di tutela svolte da corpi dello Stato in relazione al rischio del verificarsi dei fatti delittuosi indicati nei commi 1 e 2 dell'articolo 1 della legge medesima.

9. Alla legge 23 novembre 1998, n. 407, sono apportate le seguenti modificazioni:

- a) all'articolo 2, comma 1, dopo le parole: "nonche' ai superstiti delle vittime di azioni terroristiche" sono inserite le seguenti: "e della criminalita' organizzata";
- b) all'articolo 4, comma 1, dopo le parole: "nonche' agli orfani e ai figli delle vittime del terrorismo" sono inserite le seguenti: "e della criminalita' organizzata".

------------- AGGIORNAMENTO (30) Il D.L. 28 novembre 2003, n. 337, convertito con modificazioni dalla L. 24 dicembre 2003, n. 369, ha disposto (con l'art. 3, comma 1) che "Il comma 1 dell'articolo 82 della legge 23 dicembre 2000, n. 388, si interpreta nel senso che al personale di cui all'articolo 3 della legge 13 agosto 1980, n. 466, compreso il personale appartenente agli organismi di informazione e sicurezza, ovvero ai superstiti dello stesso personale, le disposizioni di cui alla legge 20 ottobre 1990, n. 302, e alla legge 23 novembre 1998, n. 407, si applicano anche per eventi occorsi al di fuori del territorio nazionale".

## INTERVENTI NEL SETTORE SANITARIO

### Art. 83. - (Norme attuative dell'accordo Governo-regioni)

1. La lettera g) del comma 1 dell'articolo 10 della legge 13 maggio 1999, n. 133, e' abrogata. Con decorrenza dal 1° gennaio 2001, il vincolo di destinazione delle risorse destinate al finanziamento del Servizio sanitario nazionale, previsto dall'articolo 8, comma 1, del decreto legislativo 18 febbraio 2000, n. 56, e' soppresso. Ciascuna regione e' tenuta, per il triennio 2001 - 2003, a destinare al finanziamento della spesa sanitaria regionale risorse non inferiori alle quote che risultano dal riparto dei fondi destinati per ciascun anno al finanziamento del Servizio sanitario nazionale.

2. Alla lettera a) del comma 1 dell'articolo 10 della citata legge n. 133 del 1999 le parole: "delle attivita' degli istituti di ricovero e cura," sono soppresse. All'articolo 1, comma 2, del decreto legislativo 18 febbraio 2000, n. 56, le parole: "di quelle spettanti agli Istituti di ricovero e cura a carattere scientifico per le prestazioni e funzioni assistenziali rese nell'anno 2000 strettamente connesse all'attivita' di ricerca corrente e finalizzata di cui al programma di ricerca sanitaria previsto dall'articolo 12-bis, comma 3, del decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni," sono soppresse. L'ultimo periodo del comma 3 dell'articolo 1 del citato decreto legislativo n. 56 del 2000 e' abrogato.

3. L'importo di lire 30.000 miliardi di cui all'articolo 20, comma 1, della legge 11 marzo 1988, n. 67, e' elevato a lire 34.000 miliardi.

4. Nel rispetto degli adempimenti assunti dal Paese con l'adesione al patto di stabilita' e crescita, a decorrere dall'anno 2001, le singole regioni, contestualmente all'accertamento dei conti consuntivi sulla spesa sanitaria da effettuare entro il 30 giugno dell'anno successivo, sono tenute a provvedere alla copertura degli eventuali disavanzi di gestione, attivando nella misura necessaria l'autonomia impositiva con le procedure e modalita' di cui ai commi 5, 6 e 7.

5. I Ministri della sanita', del tesoro, del bilancio e della programmazione economica e delle finanze, previa intesa in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, procedono sulla base delle risultanze delle gestioni sanitarie ad accertare gli eventuali disavanzi delle singole regioni, ad individuare le basi imponibili dei rispettivi tributi regionali e a determinare le variazioni in aumento di una o piu' aliquote dei tributi medesimi, in misura tale che l'incremento di gettito copra integralmente il predetto disavanzo.

6. Entro il 31 ottobre di ciascun anno le regioni interessate deliberano, con decorrenza dal 1° gennaio dell'anno successivo, l'aumento delle aliquote dei tributi di spettanza nei termini stabiliti in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano.

7. In caso di inerzia delle amministrazioni regionali nell'adozione delle misure di cui al comma 6, il Governo, previa diffida alle regioni interessate a provvedere agli adempimenti di competenza entro trenta giorni, adotta, entro e non oltre i successivi trenta giorni, le forme d'intervento sostitutivo previste dalla normativa vigente.

8. All'articolo 28, comma 14, della legge 23 dicembre 1998, n. 448, il secondo periodo e' abrogato.

### Art. 84. - (Eliminazione progressiva dei ticket sanitari)

1. Alla realizzazione degli obiettivi di spesa programmati nell'accordo Governo-regioni concorrono le disposizioni contenute negli articoli 85, 86, 87 e 88.

2. In vista della progressiva eliminazione della partecipazione degli assistiti al costo delle prestazioni sanitarie erogate dal Servizio sanitario nazionale, e' sospesa l'efficacia delle seguenti disposizioni del decreto legislativo 29 aprile 1998, n. 124:

- a) articolo 1, comma 2, e comma 3, lettera a);
- b) articolo 2, comma 1, lettere c) ed e);
- c) articolo 3, comma l; comma 2, ad eccezione dell'ultimo periodo; comma 3, primo e secondo periodo; commi 4, 5, 6, 7 e 8; comma 9, primo periodo;
- d) articoli 4 e 6;
- e) articolo 7, comma 1, lettera b), limitatamente alle parole: "sia alla situazione economica del nucleo famigliare, sia" e comma 2;
- f) articolo 8, comma 4.

3. Fatto salvo quanto previsto dall'articolo 85, sono confermate le modalita' di partecipazione al costo delle prestazioni sanitarie stabilite dall'articolo 8, comma 15, della legge 24 dicembre 1993, n. 537, e successive modificazioni, e dagli articoli 68 e 70 della legge 23 dicembre 1998, n. 448, nonche' le esenzioni in relazione al reddito stabilite dallo stesso articolo 8 della citata legge n. 537 del 1993.

### Art. 85. - (Riduzione dei ticket e disposizioni in materia di spesa farmaceutica)

1. A decorrere dal 1 luglio 2001, e' soppressa la classe di cui all'articolo 8, comma 10, lettera b), della legge 24 dicembre 1993, n. 537. Entro il 31 gennaio 2001 e con effetto dal 1 luglio 2001, la Commissione unica del farmaco provvede ad inserire, per categorie terapeutiche omogenee, nelle classi di cui all'articolo 8, comma 10, lettera a) e lettera c), della legge 24 dicembre 1993, n. 537, i medicinali attualmente inseriti nella classe di cui alla lettera b) dello stesso comma 10, sulla base della valutazione della loro efficacia terapeutica e delle loro caratteristiche prevalenti.

2. A decorrere dal 1 gennaio 2001 e' abolita ogni forma di partecipazione degli assistiti al costo delle prestazioni farmaceutiche relative ai medicinali collocati nelle classi

- a) e
- b) di cui all'articolo 8, comma 10, della legge 24 dicembre 1993, n. 537, con esclusione di quelle previste dal comma 26 del presente articolo.

3. ((COMMA ABROGATO DALLA L. 27 DICEMBRE 2002, N. 289)).

4. A decorrere dal 1 gennaio 2001, fermo restando quanto previsto dall'articolo 1, comma 4, lettera a), del decreto legislativo 29 aprile 1998, n. 124, e secondo le indicazioni del Piano sanitario nazionale, sono escluse dalla partecipazione al costo e, quindi, erogate senza oneri a carico dell'assistito al momento della fruizione, le seguenti prestazioni specialistiche e di diagnostica strumentale e di laboratorio, finalizzate alla diagnosi precoce dei tumori dell'apparato genitale femminile, del carcinoma e delle precancerosi del colon retto:

- a) mammografia, ogni due anni, a favore delle donne in eta' compresa tra quarantacinque e sessantanove anni e tutte le prestazioni di secondo livello qualora l'esame mammografico lo richieda;
- b) esame citologico cervico-vaginale (PAP test), ogni tre anni, a favore delle donne in eta' compresa tra venticinque e sessantacinque anni;
- c) colonscopia, ogni cinque anni, a favore della popolazione di eta' superiore a quarantacinque anni e della popolazione a rischio individuata secondo criteri determinati con decreto del Ministro della sanita'.

5. Sono altresi' erogati senza oneri a carico dell'assistito gli accertamenti diagnostici e strumentali specifici per le patologie neoplastiche nell'eta' giovanile in soggetti a rischio di eta' inferiore a quarantacinque anni, individuati secondo criteri determinati con decreto del Ministro della sanita'.

6. Le risorse disponibili per il Servizio sanitario nazionale sono aumentate di lire 1.900 miliardi per l'anno 2001, di lire 1.875 miliardi per l'anno 2002, di lire 2.375 miliardi per l'anno 2003 e di lire 2.165 miliardi a decorrere dall'anno 2004.

7. Per ciascuno degli anni 2002 e 2003 le politiche proposte dalle regioni, i comportamenti prescrittivi dei medici di medicina generale e dei pediatri di libera scelta del distretto relativamente alle prestazioni farmaceutiche, diagnostiche, specialistiche e ospedaliere, nonche' la politica dei prezzi dei farmaci e delle prestazioni convenzionate, dovranno contenere la crescita della spesa sanitaria nella misura pari, per il 2002, almeno all'1,3 per cento della spesa relativa nel preconsuntivo nell'anno 2000, ad almeno il 2,3 per cento per il 2003 e ad almeno il 2,5 per cento per il 2004.

8. Per effetto delle disposizioni di cui ai commi da 1 a 7 le previsioni programmatiche della spesa sanitaria previste per gli anni 2002, 2003 e 2004 sono rideterminate, rispettivamente, nella misura del 3,5, del 3,45 e del 2,9 per cento.

9. A decorrere dal 30 marzo 2002, sulla base dei risultati del monitoraggio e' verificato mensilmente l'andamento della spesa sanitaria. Qualora tale andamento si discosti dall'effettivo conseguimento degli obiettivi previsti ai commi 7 e 8, la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano propone criteri e strumenti idonei a finanziare lo scostamento. Per la parte dello scostamento imputabile a responsabilita' regionali, le regioni adottano le deliberazioni per il reintegro dei ticket soppressi ovvero le altre misure di riequilibrio previste dall'articolo 83, comma 6. In caso di inerzia delle amministrazioni regionali il Governo, previa diffida alle regioni interessate a provvedere agli adempimenti di competenza entro trenta giorni, adotta, entro e non oltre i successivi trenta giorni le forme di intervento sostitutivo previste dalla normativa vigente.

10. Agli oneri derivanti dall'attuazione del presente articolo si provvede, quanto a lire 120 miliardi per l'anno 2002 e a lire 830 miliardi per l'anno 2003, mediante utilizzo delle maggiori entrate tributarie connesse alle minori detrazioni conseguenti alla progressiva abolizione dei ticket di cui ai commi 2, 3 e 4.

11. All'articolo 19, comma 14, della legge 11 marzo 1988, n. 67, e successive modificazioni, le parole: "nella misura dell'80 per cento" sono sostituite dalle seguenti: "nella misura del 40 per cento". La disposizione si applica a decorrere dal periodo di imposta in corso al 31 dicembre 2000.

12. Entro il 31 gennaio 2001 la Commissione unica del farmaco provvede a individuare le categorie di medicinali destinati alla cura delle patologie di cui al decreto del Ministro della sanita' 28 maggio 1999, n. 329, e il loro confezionamento ottimale per ciclo di terapia, prevedendo standard a posologia limitata per l'avvio delle terapie e standard che assicurino una copertura terapeutica massima di 28-40 giorni. Il provvedimento e' pubblicato nella Gazzetta Ufficiale. Sono collocati nella classe di cui all'articolo 8, comma 10, lettera c), della legge 24 dicembre 1993, n. 537, i medicinali le cui confezioni non sono adeguate ai predetti standard, entro sei mesi dalla data di pubblicazione del provvedimento della Commissione unica del farmaco. A decorrere dal settimo mese successivo a quello della data predetta, la prescrivibilita' con oneri a carico del Servizio sanitario nazionale di medicinali appartenenti alle categorie individuate dalla Commissione unica del farmaco e' limitata al numero massimo di due pezzi per ricetta. Le regioni e le aziende unita' sanitarie locali provvedono all'attivazione di specifici programmi di informazione relativi agli obiettivi e alle modalita' prescrittive delle confezioni ottimali, rivolti ai medici del Servizio sanitario nazionale, ai farmacisti e ai cittadini.

13. All'articolo 29, comma 4, della legge 23 dicembre 1999, n. 488, le parole: "e' ridotto del 5 per cento" sono sostituite dalle seguenti: "e' ridotto del 10 per cento in due anni, con riduzione del 5 per cento a decorrere dal 31 gennaio di ciascuno degli anni 2000 e 2001". Allo stesso comma 4 e' aggiunto il seguente periodo: "Dalla riduzione di prezzo decorrente dal 31 gennaio 2001, sono esclusi i medicinali con prezzo non superiore a lire 10.000".

14. COMMA ABROGATO DALLA L. 1 MARZO 2002, N. 39.

15. All'articolo 68, comma 9, primo periodo, della legge 23 dicembre 1998, n. 448, dopo le parole: "onere a carico del Servizio sanitario nazionale" sono inserite le seguenti: "nonche' i dati presenti sulla ricetta leggibili otticamente relativi al codice del medico, al codice dell'assistito ed alla data di emissione della prescrizione".

16. Con decreto del Ministro della sanita', previa intesa in sede di Conferenza permanente per i rapporti tra lo Stato le regioni e le province autonome di Trento e di Bolzano, sono individuate procedure standard per il controllo delle prescrizioni farmaceutiche, anche ai fini degli adempimenti di cui all'articolo 1, comma 4, del decreto-legge 20 giugno 1996, n. 323, convertito, con modificazioni, dalla legge 8 agosto 1996, n. 425. Ai fini dell'applicazione delle predette procedure, sono organizzati corsi di formazione per funzionari regionali, a cura del Dipartimento competente per la valutazione dei farmaci e la farmacovigilanza del Ministero della sanita', nei limiti delle disponibilita' di bilancio.

17. Il Ministero della sanita' trasmette periodicamente alle regioni i risultati delle valutazioni dell'Osservatorio nazionale sull'impiego dei medicinali relative al controllo di cui al comma 16.

18. Entro il 28 febbraio 2001 il Ministro della sanita' fissa, con proprio decreto, le modalita' per la rilevazione e la contabilizzazione in forma automatica, in ciascuna farmacia convenzionata con il Servizio sanitario nazionale, dell'erogazione di ossigeno terapeutico e della fornitura dei prodotti dietetici di cui al decreto del Ministro della sanita' 1 luglio 1982, pubblicato nella Gazzetta Ufficiale n. 217 del 9 agosto 1982, dei dispositivi protesici monouso di cui al decreto del Ministro della sanita' 27 agosto 1999, n. 332, dei prodotti per soggetti affetti da diabete mellito di cui al decreto del Ministro della sanita' 8 febbraio 1982, pubblicato nella Gazzetta Ufficiale n. 46 del 17 febbraio 1982, ed i conseguenti obblighi cui sono tenuti i farmacisti.

19. Le disposizioni sulla contrattazione dei prezzi previste dall'articolo 1, comma 41, della legge 23 dicembre 1996, n. 662, si applicano sino al 31 dicembre 2002 anche ai medicinali autorizzati in Italia secondo la procedura del mutuo riconoscimento.

20. La Commissione unica del farmaco puo' stabilire, con particolare riferimento ai farmaci innovativi di cui al regolamento (CEE) n. 2309/93 del Consiglio, del 22 luglio 1993, che la collocazione di un medicinale nella classe di cui all'articolo 8, comma 10, lettera a), della legge 24 dicembre 1993, n. 537, sia limitata ad un determinato periodo di tempo e che la conferma definitiva della sua erogabilita' a carico del Servizio sanitario nazionale sia subordinata all'esito favorevole della verifica, da parte della stessa Commissione, della sussistenza delle condizioni dalla medesima indicate.

21. La commissione per la spesa farmaceutica, prevista dall'articolo 36, comma 16, della legge 27 dicembre 1997, n. 449, e' ricostituita con il compito di monitorare l'andamento della spesa farmaceutica pubblica e privata e di formulare proposte per il governo della spesa stessa. La commissione puo' essere sentita dal Ministro della sanita' sui provvedimenti generali che incidono sulla spesa farmaceutica pubblica e svolge le ulteriori funzioni consultive attribuite dallo stesso Ministro. Con decreto del Ministro della sanita' sono definiti la composizione e le modalita' di funzionamento della commissione, le specifiche funzioni alla stessa demandate, nonche' i termini per la formulazione dei pareri e delle proposte. Nella composizione della commissione e' comunque assicurata la presenza di un rappresentante degli uffici di livello dirigenziale e generale competenti nella materia dei medicinali e della programmazione sanitaria del Ministero della sanita', nonche' di rappresentanti del Ministero del tesoro, del bilancio e della programmazione economica, delle regioni, dei produttori farmaceutici, dei grossisti, dei farmacisti, della federazione nazionale dell'ordine dei medici. La commissione per la spesa farmaceutica si avvale, per lo svolgimento delle funzioni ad essa attribuite, dei dati e' delle elaborazioni forniti dall'Osservatorio nazionale sull'impiego dei medicinali.

22. Per specifici progetti di ricerca scientifica e sorveglianza epidemiologica, tesi a garantire una migliore definizione della sicurezza d'uso di medicinali di particolare rilevanza individuati con provvedimento della Commissione unica del farmaco, il Ministro della sanita', per un periodo definito e limitato, e relativamente alla dispensazione di medicinali con onere a carico del Servizio sanitario nazionale, puo' concordare con le organizzazioni maggiormente rappresentative delle farmacie e dei distributori intermedi che alle cessioni di tali medicinali non si applichino le quote di spettanza dei grossisti e delle farmacie ne' lo sconto a carico delle farmacie, previsti dall'articolo 1, comma 40, della legge 23 dicembre 1996, n. 662, e successive modificazioni. L'accordo e' reso esecutivo con decreto del Ministro della sanita' da pubblicare nella Gazzetta Ufficiale. Le cessioni di cui al presente comma non sono soggette al contributo di cui all'articolo 5, secondo comma, del decreto-legge 4 maggio 1977, n. 187, convertito, con modificazioni, dalla legge 11 luglio 1977, n. 395, ed al contributo previsto dall'articolo 15 della convenzione farmaceutica resa esecutiva con decreto del Presidente della Repubblica 8 luglio 1998, n. 371.

23. Decorsi quarantacinque giorni dalla presentazione della domanda diretta ad ottenere l'autorizzazione alla pubblicita' di un medicinale di automedicazione ai sensi dell'articolo 6, comma 1, del decreto legislativo 30 dicembre 1992, n. 541, la mancata comunicazione all'interessato del provvedimento del Ministero della sanita' di accoglimento o di reiezione della domanda medesima equivale a tutti gli effetti al rilascio dell'autorizzazione richiesta. Nell'ipotesi prevista dal precedente periodo, l'indicazione del numero dell'autorizzazione del Ministero della sanita' prevista dall'articolo 6, comma 8, del decreto legislativo 30 dicembre 1992, n. 541, e' sostituita, ad ogni effetto, dall'indicazione degli estremi della domanda di autorizzazioni con decreto non regolamentare del Ministro della sanita', su proposta della Commissione di esperti di cui all'articolo 6, commi 2 e 3, del decreto legislativo 30 dicembre 1992, n. 541, sono approvati criteri e direttive per la corretta formulazione dei messaggi pubblicitari concernenti medicinali di automedicazione, ad integrazione di quanto disciplinato dagli articoli 2, 3, 4 e 5 del citato decreto legislativo.

24. Il Ministro della sanita', di concerto con il Ministro dell'Industria, del commercio e dell'artigianato, sentite le organizzazioni maggiormente rappresentative delle farmacie e dei produttori di medicinali di automedicazione, con proprio decreto da emanare entro il 10 luglio 2001, stabilisce criteri per meglio definire le caratteristiche dei medicinali di automedicazione e meccanismi concorrenziali per i prezzi ed individua misure per definire un ricorso corretto ai medicinali di automedicazione in farmacia, anche attraverso campagne informative rivolte a cittadini ed operatori sanitari.

25. Le variazioni dei prezzi dei medicinali collocati nella classe c) di cui all'articolo 8, comma 10, della legge 24 dicembre 1993, n. 537, devono essere comunicate al Ministero della sanita', al CEPE e alla Federazione degli ordini dei farmacisti italiani almeno quindici giorni prima della data di applicazione dei nuovi prezzi da indicare nella comunicazione medesima.

26. A decorrere dal 1 luglio 2001, i medicinali non coperti da brevetto aventi uguale composizione in principi attivi, nonche' forma farmaceutica, via di somministrazione, modalita' di rilascio, numero di unita' posologiche e dosi unitarie uguali, sono rimborsati al farmacista dal Servizio sanitario nazionale fino a concorrenza del prezzo medio ponderato dei medicinali aventi prezzo non superiore a quello massimo attribuibile al generico secondo la legislazione vigente. Ai fini del presente comma sono considerate equivalenti tutte le forme farmaceutiche solide orali. Qualora il medico prescriva un medicinale avente prezzo maggiore del prezzo rimborsabile dal Servizio sanitario nazionale ai sensi del presente comma, la differenza fra i due prezzi e' a carico dell'assistito; il medico e', in tale caso, tenuto ad informare il paziente circa la disponibilita' di medicinali integralmente rimborsabili dal Servizio sanitario nazionale e della loro bioequivalenza con la specialita' medicinale prescritta. Il Ministero della sanita', di concerto con il Ministero del tesoro, del bilancio e della programmazione economica e il Ministero dell'industria, del commercio e dell'artigianato verifica gli effetti della disposizione di cui al presente comma e propone le eventuali modifiche al sistema di rimborso da attuare a decorrere dal 1 settembre 2003. (6)

27. I medici che prescrivono farmaci a carico del Servizio sanitario nazionale tengono conto, nella scelta del medicinale, di quanto previsto dal comma 26.

28. Entro il 15 aprile 2001, il Ministero della sanita', previo accertamento, da parte della Commissione unica del farmaco, della bioequivalenza dei medicinali rimborsabili ai sensi del comma 26 e previa verifica della loro disponibilita' in commercio, pubblica nella Gazzetta Ufficiale l'elenco dei medicinali ai quali si applica la disposizione del medesimo comma, con indicazione dei relativi prezzi, nonche' del prezzo massimo di rimborso. L'elenco e' aggiornato ogni sei mesi. L'aggiornamento entra in vigore dal primo giorno del mese successivo a quello di pubblicazione.

29. Le risorse disponibili per il Servizio sanitario nazionale sono aumentate di lire 28 miliardi per l'anno 2001 e di lire 56 miliardi a decorrere dall'anno 2002.

30. Il Ministero della sanita' adotta idonee iniziative per informare i medici prescrittori, i farmacisti e gli assistiti delle modalita' di applicazione delle disposizioni di cui ai commi 26 e 28 e delle finalita' della nuova disciplina.

31. Sono abrogati il secondo e terzo periodo del comma 16 e il comma 16-bis dell'articolo 36 della legge 27 dicembre 1997, n. 449, e successive modificazioni. Sono altresi' abrogati il comma 1 e il primo, secondo e terzo periodo del comma 2 dell'articolo 29 della legge 23 dicembre 1999, n. 488.

32. Il termine del 31 dicembre 2001 previsto dall'articolo 7, comma 1, del decreto legislativo 17 marzo 1995 n. 185, come modificato dall'articolo 2, comma 2, della legge 8 ottobre 1997, n. 347, e dall'articolo 5, comma 2, della legge 14 ottobre 1999, n. 362, e' differito al 31 dicembre 2003.

33. Il comma 2 dell'articolo 7 del decreto legislativo, 17 marzo 1995, n. 185, e' sostituito dal seguente: "2. Alla scadenza del termine di cui al comma 1, si applica a tutti i medicinali omeopatici la cui presenza sul mercato italiano alla data del 6 giugno 1995 sia stata notificata al Ministero della sanita' ai sensi del comma 1, in sede di primo rinnovo, la procedura semplificata di registrazione di cui all'articolo S. Le domande di rinnovo di autorizzazione, da presentare al Ministero della sanita' non oltre il novantesimo giorno precedente la data di scadenza, devono essere accompagnate da una dichiarazione del legale rappresentante della societa' richiedente, attestante che presso la stessa e' disponibile la documentazione di cui all'articolo 5, comma 2, e dall'attestazione dell'avvenuto versamento delle somme derivanti dalle tariffe di cui all'allegato 2, lettera A), numeri 1, 2 e 3, annesso al decreto del Ministro della sanita' del 22 dicembre 1997, pubblicato nella Gazzetta Ufficiale n. 33 del 10 febbraio 1998. Qualora si tratti di medicinali omeopatici importati da uno Stato membro dell'Unione europea in cui sia gia' stata concessa la registrazione o l'autorizzazione, la suddetta dichiarazione del legale rappresentante della societa' richiedente deve attestare che presso la stessa e' disponibile la documentazione di registrazione originale. Decorsi novanta giorni dalla presentazione della domanda senza che il Ministero della sanita' abbia comunicato al richiedente le sue motivate determinazioni, il rinnovo si intende accordato. Il rinnovo ha durata quinquennale".

34. Entro centoventi giorni dalla data di entrata in vigore della presente legge, le imprese che hanno provveduto a presentare la documentazione al Ministero della sanita' ai sensi dell'articolo 7, comma 1, del decreto legislativo 17 marzo 1995, n. 185, e successive modificazioni, devono versare a favore del Ministero della sanita' la somma di lire quarantamila per ogni medicinale omeopatico notificato, individuato ai sensi dell'allegato 2, lettera A), numeri 1, 2, 3, annesso al citato decreto del Ministro della sanita' del 22 dicembre 1997, a titolo di contributo per l'attivita' di gestione e di controllo del settore omeopatico.

------------- AGGIORNAMENTO (6) Il D.L.30 giugno 2001, n. 246, convertito con modificazioni dalla L. 4 agosto 2001, n. 330, ha disposto (con l'art. 4, comma 2) che "Il termine del 1° luglio 2001 previsto dall'articolo 85, comma 26, della legge 23 dicembre 2000, n. 388, e' differito al 1° settembre 2001".

### Art. 86. - (Dotazione finanziaria complessiva dei medici e medicina generale, dei pediatri di libera scelta, degli specialisti ambulatoriali e convenzionati e dei medici di continuita' assistenziale del distretto)

1. Ciascuna regione individua, entro il 30 giugno 2001, nell'ambito del proprio territorio, uno o piu' distretti, ai quali assegnare, in via sperimentale, in accordo con l'azienda sanitaria interessata, la dotazione finanziaria di cui al presente articolo.

2. La regione assegna al distretto una dotazione finanziaria virtuale, calcolata sulla base del numero di abitanti moltiplicato per la parte della quota capitaria concernente le spese per prestazioni farmaceutiche, diagnostiche, specialistiche, ospedaliere e residenziali, che si presumono indotte dall'attivita' prescrittiva dei medici di medicina generale nonche' dei pediatri di libera scelta, degli specialisti ambulatoriali e convenzionati e dei medici di continuita' assistenziale.

3. La regione comunica ai Ministeri della sanita' e del tesoro, del bilancio e della programmazione economica la metodologia ed i criteri utilizzati per l'individuazione della quota di spesa indotta di cui al comma 2.

4. La sperimentazione e' costantemente seguita da un comitato di monitoraggio, composto da un rappresentante regionale, dal responsabile del distretto e da un rappresentante di ciascuna delle cinque categorie mediche interessate nominato dalle organizzazioni sindacali maggiormente rappresentative a livello aziendale. Il comitato procede trimestralmente alla verifica delle spese indotte dai medici di medicina generale, dai pediatri di libera scelta, dagli specialisti ambulatoriali e convenzionati e dai medici di continuita' assistenziale, e trasmette, entro trenta giorni dalla verifica, ai Ministeri della sanita' e del tesoro, del bilancio e della programmazione economica, alla regione e all'azienda unita' sanitaria locale competente, una relazione sull'andamento della spesa rilevata e sulla compatibilita' tra la proiezione di spesa e la dotazione finanziaria complessiva annua.

5. La sperimentazione ha durata di dodici mesi, con decorrenza dalla data individuata dalla regione e resa nota a tutti i soggetti interessati anche tramite le organizzazioni sindacali. A conclusione della sperimentazione la regione destina il 60 per cento delle minori spese indotte dai medici di medicina generale, dai pediatri di libera scelta, dagli specialisti ambulatoriali e convenzionati e dai medici di continuita' assistenziale rispetto alla dotazione finanziaria complessiva individuata anche con riferimento a valori di spesa coerenti con gli obiettivi di cui all'accordo Governo-regioni, all'erogazione di servizi per i medici di medicina generale, i pediatri di libera scelta, gli specialisti ambulatoriali e convenzionati e i medici di continuita' assistenziale, con esclusione di incentivi di carattere pecuniario. Qualora le spese siano superiori alla dotazione finanziaria complessiva, la regione e l'azienda unita' sanitaria locale competente ne verificano le cause ed attivano, in caso di accertamento di comportamenti irregolari, le misure previste dagli accordi collettivi nazionali e regionali, fatto salvo il procedimento disciplinare di cui al regolamento approvato con decreto del Presidente della Repubblica 5 aprile 1950, n. 221.

6. Sono fatte comunque salve le autonome iniziative regionali in materia di sperimentazione di dotazione finanziaria, che siano gia' in corso.

### Art. 87. - (Monitoraggio delle prescrizioni mediche, farmaceutiche, specialistiche e ospedaliere)

1. Nel quadro delle competenze di governo della spesa da parte del Ministero del tesoro, del bilancio e della programmazione economica, di garanzia verso il cittadino di appropriatezza ed efficacia delle prestazioni di cura da parte del Ministero della sanita', e nel rispetto dei compiti attribuiti alle regioni in materia sanitaria, al fine di migliorare il monitoraggio della spesa sanitaria nelle sue componenti farmaceutica, diagnostica e specialistica, e di semplificare le transazioni tra il cittadino, gli operatori e le istituzioni preposte, e' introdotta la gestione informatizzata delle prescrizioni relative alle prestazioni farmaceutiche, diagnostiche, specialistiche e ospedaliere, erogate da soggetti pubblici e privati accreditati. Tutte le procedure informatiche devono garantire l'assoluto anonimato del cittadino che usufruisce delle prestazioni, rispettando la normativa a tutela della riservatezza. Ai dati oggetto della gestione informatizzata possono avere accesso solo gli operatori da identificare secondo quanto disposto dal decreto legislativo 30 luglio 1999, n. 282.

2. Il sistema di monitoraggio interconnette i medici e gli altri operatori sanitari di cui al comma 1, il Ministero della sanita', il Ministero del tesoro, del bilancio e della programmazione economica, le regioni, la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, le aziende sanitarie locali e dispone, per la consultazione in linea e ai diversi livelli di competenza, delle informazioni relative:

- a) ai farmaci del Servizio sanitario nazionale;
- b) alle diverse prestazioni farmaceutiche, diagnostiche e specialistiche erogabili;
- c) all'andamento dei consumi dei farmaci e delle prestazioni;
- d) all'andamento della spesa relativa.

3. Entro novanta giorni dalla data di entrata in vigore della presente legge il Ministero della sanita', di concerto con il Ministero del tesoro, del bilancio e della programmazione economica, e sentita la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, emana i regolamenti e i decreti attuativi, individuando le risorse finanziarie nell'ambito di quelle indicate dall'articolo 103, definendo le modalita' operative e i relativi adempimenti, le modalita' di trasmissione dei dati ed il flusso delle informazioni tra i diversi organismi di cui al comma 2.

4. Le soluzioni adottate dovranno rispettare le norme sulla sicurezza e sulla riservatezza dei dati secondo le leggi vigenti e risultare coerenti con le linee generali del processo di evoluzione dell'utilizzo dell'informatica nell'amministrazione.

5. Entro il 1 gennaio 2002 o le diverse date stabilite con i decreti attuativi di cui al comma 3, tutte le prescrizioni citate dovranno essere trasmissibili e monitorabili per via telematica.

((

5-bis. Le regioni adottano le necessarie iniziative per attivare, nel proprio territorio, il monitoraggio delle prescrizioni mediche, farmaceutiche, specialistiche ed ospedaliere previsto dal presente articolo, assicurando la tempestiva disponibilita' delle informazioni, anche per via telematica, ai Ministeri della salute e dell'economia e delle finanze, nonche' alla Presidenza del Consiglio dei Ministri - Dipartimento per gli affari regionali.

5-ter. Le regioni garantiscono la standardizzazione dei dati e l'interoperabilita' delle soluzioni tecnologiche adottate con quelle che verranno definite nell'ambito del nuovo sistema informativo nazionale del Ministero della salute.

5-quater. Le regioni determinano le modalita' e gli strumenti del monitoraggio. Le regioni determinano, inoltre, le sanzioni da applicare a carico dei soggetti che abbiano omesso gli adempimenti connessi al monitoraggio o che abbiano effettuato prescrizioni in misura superiore al livello appropriato.

))

6. Per l'avvio del nuovo sistema informativo nazionale del Ministero della sanita', nonche' per l'estensione dell'impiego sperimentale della carta sanitaria prevista dal progetto europeo "NETLINK" e' autorizzata per l'anno 2001 la spesa, rispettivamente, di lire 10 miliardi e di lire 4 miliardi.

7. All'articolo 38, quarto comma, del regolamento per il servizio farmaceutico, approvato con regio decreto 30 settembre 1938, n. 1706, le parole: "I farmacisti debbono conservare per la durata di cinque anni copia di tutte le ricette spedite" sono sostituite dalle seguenti: "I farmacisti debbono conservare per sei mesi le ricette spedite concernenti preparazioni estemporanee".

### Art. 88. - (Disposizioni per l'appropriatezza nell'erogazione dell'assistenza sanitaria)

1. Nella definizione delle tariffe delle prestazioni di assistenza ospedaliera, le regioni ove siano assicurati adeguati programmi di assistenza domiciliare integrata e centri residenziali per le cure palliative inseriscono un valore soglia di durata della degenza per i ricoveri ordinari nei reparti di lungodegenza, oltre il quale si applica una riduzione della tariffa giornaliera, fatta salva la garanzia della continuita' dell'assistenza. Il valore soglia e' fissato in un massimo di sessanta giorni di degenza; la riduzione tariffaria e' pari ad almeno il 30 per cento della tariffa giornaliera piena.

((

2. Al fine di realizzare gli obiettivi di economicita' nell'utilizzazione delle risorse e di verifica della qualita' dell'assistenza erogata, secondo criteri di appropriatezza, le regioni assicurano, per ciascun soggetto erogatore, un controllo analitico annuo di almeno il 10 per cento delle cartelle cliniche e delle corrispondenti schede di dimissione, in conformita' a specifici protocolli di valutazione. L'individuazione delle cartelle e delle schede deve essere effettuata secondo criteri di campionamento rigorosamente casuali. Tali controlli sono estesi alla totalita' delle cartelle cliniche per le prestazioni ad alto rischio di inappropriatezza individuate delle regioni tenuto conto di parametri definiti con decreto del Ministro del lavoro, della salute e delle politiche sociali, d'intesa con il Ministero dell'economia e delle finanze.

))

3. Le regioni applicano abbattimenti sulla remunerazione complessiva dei soggetti erogatori presso i quali si registrino frequenze di ricoveri inappropriati superiori agli standard stabiliti dalla regione stessa.

### Art. 89.

((ARTICOLO ABROGATO DAL D.LGS. 7 SETTEMBRE 2005, N. 209))

### Art. 90. - (Sperimentazioni gestionali)

1. Sino al ((30 giugno 2002)) il trasferimento di beni, anche di immobili e di aziende, a favore di fondazioni di diritto privato e di enti pubblici, ivi compresi gli enti disciplinati dal decreto legislativo 4 dicembre 1997, n. 460, e successive modificazioni, effettuato nell'ambito delle sperimentazioni gestionali previste dall'articolo 4, comma 6, della legge 30 dicembre 1991, n. 412, nonche' dall'articolo 9-bis del decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni, limitatamente agli atti sottoposti a registrazione durante il periodo di durata della sperimentazione, nonche' il trasferimento disposto nell'ambito degli accordi e forme associative di cui all'articolo 10 del decreto legislativo 20 ottobre 1998, n. 368, ((ovvero di processi di ristrutturazione del sistema sanitario regionale finalizzati alla razionalizzazione e al contenimento della spesa sanitaria)) non da' luogo, ai fini delle imposte sui redditi, a realizzo o distribuzione di plusvalenze, ricavi e minusvalenze, compreso il valore di avviamento, non costituisce presupposto per la tassazione di sopravvenienze attive nei confronti del cessionario, non e' soggetto ad alcuna imposta sui trasferimenti ne' comporta obbligo di affrancare riserve e fondi in sospensione d'imposta.

### Art. 91. - (Disposizioni per l'assolvimento dei compiti del Ministero della sanita')

1. Al fine di consentire al dipartimento competente per la valutazione dei medicinali e la farmacovigilanza del Ministero della sanita' e all'Osservatorio nazionale sull'impiego dei medicinali l'espletamento delle funzioni connesse alle attivita' di promozione, valutazione e controllo disposte dagli articoli 85 e 87, nonche' di permettere l'attiva partecipazione dell'Italia, quale Paese di riferimento, alle procedure autorizzative e ispettive nel settore dei medicinali previste dalla normativa dell'Unione europea, il Ministero della sanita' e' autorizzato ad avvalersi, per gli anni 2001, 2002 e 2003, del personale non appartenente alla pubblica amministrazione, in servizio presso lo stesso dipartimento alla data del 30 settembre 2000, entro il limite massimo di cinquanta unita' di medici, chimici, farmacisti, economisti, informatici, amministrativi. La misura dei compensi per i predetti incarichi e' determinata con decreto del Ministro della sanita', di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, tenuto conto della professionalita' richiesta. Ai relativi oneri, che non possono eccedere lire cinque miliardi per anno, si fa fronte mediante corrispondente riduzione dell'autorizzazione di spesa di cui all'articolo 36, comma 14, della legge 27 dicembre 1997, n. 449.

2. Per l'effettuazione delle ispezioni alle officine farmaceutiche e di quelle concernenti le sperimentazioni cliniche dei medicinali, nonche' per altri specifici adempimenti di alta qualificazione tecnico-scientifica previsti dalla normativa dell'Unione europea, il Ministero della sanita' puo' stipulare specifiche convenzioni con l'Agenzia europea per la valutazione dei medicinali (EMEA) con istituti di ricerca, societa' o associazioni scientifiche, di verifica o di controllo di qualita' o altri organismi nazionali e internazionali operanti nel settore farmaceutico, nonche' con esperti di elevata professionalita'. Agli oneri derivanti dall'attuazione del presente comma, che non possono eccedere l'importo di due miliardi di lire per anno, si fa fronte mediante corrispondente riduzione dell'autorizzazione di spesa di cui all'articolo 68, comma 11, della legge 23 dicembre 1998, n. 448.

### Art. 92. - (Interventi vari di interesse sanitario)

1. Ai fini della realizzazione del Centro nazionale di adroterapia oncologica e' istituito un ente non commerciale dotato di personalita' giuridica di diritto privato con la partecipazione di enti di ricerca, individuati con decreto del Ministro della sanita', di concerto con il Ministro dell'universita' e della ricerca scientifica e tecnologica, e soggetti pubblici e privati. Al predetto ente e' assegnato un contributo di lire 20 miliardi per ciascuno degli anni 2001 e 2002. (13)

2. Per l'attivita' del Centro nazionale per i trapianti e' autorizzata la spesa complessiva di lire 1.500 milioni per ciascuno degli anni 2001, 2002 e 2003. Lo stanziamento e' utilizzabile anche per la stipula di contratti con personale di alta qualificazione, con le modalita' previste dall'articolo 15-septies del decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni. All'articolo 8, comma 7, della legge 1° aprile 1999, n. 91, le parole: ", di cui lire 240 milioni per la copertura delle spese relative al direttore generale e lire 500 milioni per le spese di funzionamento" sono soppresse.

3. Per l'attivazione e la gestione, ivi comprese l'acquisizione o l'utilizzazione di specifiche risorse umane e strumentali, del sistema informativo per la formazione continua, per l'attribuzione dei crediti formativi e per l'accreditamento delle societa' scientifiche e dei soggetti pubblici e privati che svolgono attivita' formative di cui all'articolo 16-ter del decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni, nonche' della sperimentazione della formazione a distanza del personale dirigente del Servizio sanitario nazionale, e' autorizzata la spesa di lire 20 miliardi per l'anno 2001.

4. E' istituito un fondo dell'ammontare di lire 20 miliardi per ciascuno degli anni 2001, 2002 e 2003, da destinare alla ricerca sulle cellule staminali e sui vaccini e al cofinanziamento con il settore privato per lo sviluppo di progetti specifici di ricerca di interesse pubblico, che saranno individuati con decreti del Ministero della salute.

5. I soggetti pubblici e privati e le societa' scientifiche che chiedono, ai sensi dell'articolo 16-ter del decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni, il loro accreditamento per lo svolgimento di attivita' di formazione continua ovvero l'accreditamento di specifiche attivita' formative promosse o organizzate dagli stessi ai fini dell'attribuzione dei crediti formativi sono tenuti al preventivo versamento all'entrata del bilancio dello Stato di un contributo alle spese fissato dalla Commissione nazionale per la formazione continua di cui al citato articolo 16-ter, nella misura da un minimo di lire 500.000 ad un massimo di lire 5.000.000, in base a criteri oggettivi determinati con decreto del Ministro della sanita' su proposta della Commissione stessa. Il contributo per l'accreditamento dei soggetti e delle societa' e' annuale. Tali somme sono riassegnate ad apposita unita' previsionale di base dello stato di previsione del Ministero della sanita' per essere utilizzate per il funzionamento della Commissione, ivi compresi i compensi ai componenti ed il rimborso delle spese sostenute dagli stessi per la partecipazione ai lavori della Commissione, nonche' per far fronte alle spese per l'acquisto di apparecchiature informatiche e' per lo svolgimento, anche attraverso l'utilizzazione di esperti esterni, dell'attivita' di verifica della sussistenza dei requisiti da parte dei soggetti accreditati e di valutazione e monitoraggio degli eventi formativi e dei programmi di formazione.

6. Per l'attuazione di un programma nazionale di ricerche sperimentali e cliniche sulle cellule staminali umane post-natali e' istituito un fondo dell'ammontare di lire 5 miliardi per ciascuno degli anni 2001, 2002 e 2003. Il programma nazionale sulle cellule staminali e' gestito secondo le modalita' del programma di ricerca sulla terapia dei tumori di cui all'articolo 5 del decreto-legge 30 ottobre 1987, n. 443, convertito, con modificazioni, dalla legge 29 dicembre 1987, n. 531.

7. Per consentire all'Istituto superiore di sanita' di fare fronte, con i propri dipendenti, ai compiti inerenti il coordinamento delle attivita' di ricerca per la tutela della salute pubblica, la sorveglianza dei fattori critici che incidono sulla salute, nonche' la gestione dei registri nazionali, e' autorizzato lo stanziamento di lire 15 miliardi per gli anni 2001 e 2002. ((62))

8. Al fine di potenziare l'azione di monitoraggio e sorveglianza dei coadiutori veterinari sul territorio nazionale a seguito dell'epidemia di "lingua blu" sulla specie ovina e' autorizzato lo stanziamento di lire 3 miliardi per ciascuno degli anni 2001 e 2002.

9. Al fine di garantire l'erogazione, da parte del Servizio sanitario nazionale, di medicinali essenziali non altrimenti reperibili, tenuto conto dei compiti attribuiti allo Stabilimento chimico-farmaceutico militare, il Ministro della sanita', di concerto con il Ministro della difesa, emana, entro il 30 giugno 2001, un decreto che stabilisce le modalita' e le procedure connesse alla produzione, all'autorizzazione all'immissione in commercio e alla distribuzione dei medicinali predetti. Al finanziamento delle attivita' necessarie al conseguimento degli obbiettivi di cui al presente comma, quantificato in 5 miliardi di lire, si provvede mediante l'utilizzazione di quota parte degli introiti delle tariffe per le domande di autorizzazione all'immissione in commercio previste dal decreto legislativo 18 febbraio 1997, n. 44.

10. Le specifiche tecniche, le progettazioni e le procedure finalizzate alla realizzazione della tessera sanitaria di cui all'articolo 59, comma 50, lettera i), della legge 27 dicembre 1997, n. 449, sono utilizzate ai fini della predisposizione della carta d'identita' elettronica con le opzioni di carattere sanitario di cui all'articolo 2, comma 10, della legge 15 maggio 1997, n. 127, e successive modificazioni. Sono conseguentemente abrogati l'articolo 59, comma 50, lettera i), della legge 27 dicembre 1997, n. 449, e il comma 1 dell'articolo 2 del decreto-legge 28 dicembre 1998, n. 450, convertito, con modificazioni, dalla legge 26 febbraio 1999, n. 39.

11. Al fine di provvedere al finanziamento degli interventi di cui ai commi precedenti, ad eccezione del comma 9, sono utilizzate le disponibilita' di cui all'autorizzazione di spesa recata dall'articolo 2, comma 1, penultimo periodo, del decreto-legge 28 dicembre 1998, n. 450, convertito, con modificazioni, dalla legge 26 febbraio 1999, n. 39.

12. I benefici di cui all'articolo 7 della legge 14 ottobre 1999, n. 362, previsti per i dipendenti non appartenenti al ruolo sanitario di livello dirigenziale del Ministero della sanita', sono estesi anche al personale in servizio presso l'Istituto superiore di sanita' e l'Istituto superiore per la prevenzione e la sicurezza del lavoro. Agli oneri derivanti dall'attuazione del presente comma si fa fronte con le economie di gestione e le quote delle entrate di cui all'articolo 5, comma 12, della legge 29 dicembre 1990, n. 407, dell'Istituto superiore di sanita' e dell'Istituto superiore per la prevenzione e la sicurezza del lavoro, di rispettiva pertinenza, a valere dall'esercizio 2000.

13. Per le attrezzature dei centri di riferimento interregionali per i trapianti e' autorizzata la spesa di lire 10 miliardi annue per gli anni 2001 e 2002; le somme sono suddivise con decreto del Ministro della sanita' in proporzione ai rispettivi bacini di utenza.

14. A decorrere dal 1° gennaio 2001 le disposizioni di cui all'articolo 14 della legge 30 aprile 1962, n. 283, e successive modificazioni, e agli articoli 37, 39, 40 e 41 del regolamento approvato con decreto del Presidente della Repubblica 26 marzo 1980, n. 327, non si applicano al personale saltuariamente impiegato dagli organizzatori di sagre, fiere e manifestazioni a carattere religioso, benefico o politico.

15. Con decreto del Ministro del tesoro, del bilancio e della programmazione economica, di concerto con il Ministro della sanita', al Ministero della sanita' e' attribuita, per l'anno 2001, la somma di lire 3 miliardi, per il finanziamento di un programma di tutela sanitaria dei consumatori, concernente:

- a) indagini dell'Istituto superiore di sanita' in merito ad eventuali effetti cumulativi sull'organismo umano, derivanti dalle sinergie tra diverse sostanze attive dei prodotti fitosanitari, a causa della presenza simultanea di residui di due o piu' sostanze attive in uno stesso alimento o bevanda, con particolare riferimento agli alimenti destinati alla prima infanzia, di cui all'articolo 17, comma 4, lettera c), del decreto legislativo 17 marzo 1995, n. 194;
- b) indagini, coordinate dall'Istituto superiore di sanita', in merito ad eventuali effetti derivanti dall'utilizzazione dei prodotti fitosanitari sulla salute degli operatori e della popolazione, con particolare riferimento alla fascia di eta' compresa tra zero e diciotto anni, a seguito dell'esposizione a residui di sostanze attive di prodotti fitosanitari negli alimenti, nelle bevande e nell'ambiente, di cui all'articolo 17, comma 4, lettera a), del decreto legislativo 17 marzo 1995, n. 194;
- c) la valutazione del rischio di esposizione della popolazione a quantita', superiori alla dose giornaliera accettabile, di residui negli alimenti o nelle bevande di sostanze attive di prodotti fitosanitari, o di eventuali loro metaboliti, impurezze o prodotti di degradazione o di reazione, tenuto conto della vulnerabilita' della popolazione differenziata per diverse fasce di eta' e con particolare riferimento alla fascia di eta' compresa tra zero e diciotto anni;
- d) la pubblicazione dei risultati degli studi di cui alle lettere a), b), e c), quale base scientifica per iniziative del Ministero della sanita' finalizzate a una corretta informazione degli operatori e dei consumatori nonche' ad incentivare i produttori agricoli e le industrie alimentari ad intraprendere iniziative di informazione dei consumatori in merito ai trattamenti con i prodotti fitosanitari subiti dagli alimenti prima della loro immissione in commercio e ai residui di prodotti fitosanitari negli alimenti immessi in commercio.

16. Il termine di cui all'articolo 8-septies, comma 1, secondo periodo, del decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni, per la erogabilita' di prestazioni sanitarie in regime di assistenza indiretta, e' prorogato al 31 dicembre 2001 con l'esclusione delle prestazioni assistenziali erogate in regime di attivita' libero-professionale extramuraria.

17. Per l'attivazione o la realizzazione delle strutture di cui all'articolo 1, comma 1, del decreto-legge 28 dicembre 1998, n. 450, convertito, con modificazioni, dalla legge 26 febbraio 1999, n. 39, le regioni possono stipulare convenzioni con istituzioni e organismi a scopo non lucrativo che dispongano di strutture dedicate all'assistenza palliativa e di supporto prioritariamente per i pazienti affetti da patologia neoplastica terminale. Alla assegnazione delle risorse finanziarie previste dal decreto del Ministro della sanita' 28 settembre 1999, pubblicato nella Gazzetta Ufficiale n. 55 del 7 marzo 2000, in applicazione del predetto decreto-legge n. 450 del 1998, convertito, con modificazioni, dalla citata legge n. 39 del 1999, sono ammessi anche i progetti presentati da istituzioni e organismi a scopo non lucrativo che svolgono attivita' nel settore dell'assistenza sanitaria e socio-sanitaria. In entrambi i casi, i finanziamenti assegnati alle regioni possono essere finalizzati alla realizzazione, alla ristrutturazione e all'adeguamento di strutture con vincolo di destinazione trentennale agli scopi di cui al primo periodo.

------------- AGGIORNAMENTO (13) La L. 28 dicembre 2001, n. 448 ha disposto (con l'art. 52, comma 8) che "L'autorizzazione di spesa prevista per l'anno 2002 dall'articolo 92, comma 1, della legge 23 dicembre 2000, n. 388, e' soppressa e il relativo importo costituisce economia di bilancio". ------------- AGGIORNAMENTO (62) Il D.L. 30 dicembre 2009, n. 194, convertito con modificazioni dalla L. 26 febbraio 2010, n. 25, ha disposto (con l'art. 6, comma 7) che "Il termine per lo svolgimento delle attivita' di cui all'articolo 92, comma 7, della legge 23 dicembre 2000, n. 388, e' prorogato al 31 dicembre 2010".

### Art. 93. - (Ridefinizione di alcune misure di medicina preventiva)

1. Al fine di razionalizzare alcuni interventi di medicina preventiva e di uniformare la legislazione italiana a quella degli altri Stati membri dell'Unione europea, a decorrere dalla data di entrata in vigore del regolamento di cui al comma 2 sono abrogati: l'articolo 10, comma 1, della legge 14 dicembre 1970, n. 1088; all'articolo 22, primo comma, le parole da: "eseguire le reazioni" fino a: della scuola media", nonche' l'articolo 49 del regolamento approvato con decreto del Presidente della Repubblica 22 dicembre 1967, n. 1518; l'articolo 5 ed il capo I del titolo III del decreto del Presidente della Repubblica 27 ottobre 1962, n. 2056; l'articolo 2, quarto comma, del decreto del Presidente della Repubblica 7 settembre 1965, n. 1301; l'articolo 1 del decreto del Capo del Governo 2 dicembre 1926, pubblicato nella Gazzetta Ufficiale n. 287 del 14 dicembre 1926. Sono altresi' abrogate le disposizioni di cui all'articolo 7 della legge 25 luglio 1956, n. 837, che prevedono l'obbligatorieta' dell'esecuzione dell'accertamento sierologico della lue ai fini del rilascio del certificato di sana e robusta costituzione e di altri adempimenti amministrativi.

2. Con un regolamento da emanare entro il 30 giugno 2001 ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400, sono individuate, in relazione alle mutate condizioni sanitarie del Paese, le condizioni nelle quali e' obbligatoria la vaccinazione contro la tubercolosi nonche' le modalita' di esecuzione delle rivaccinazioni della vaccinazione antitetanica.

3. Le regioni possono, nei casi di riconosciuta necessita' e sulla base della situazione epidemiologica locale, disporre l'esecuzione della vaccinazione antitifica in specifiche categorie professionali.

### Art. 94. - (Disposizioni in materia di oneri di utilita' sociale)

1. All'articolo 65, comma 2, del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e successive modificazioni, concernente oneri di utilita' sociale, dopo la lettera c-decies), introdotta dall'articolo 6 della presente legge, e' aggiunta la seguente: "c-undecies) le erogazioni liberali in denaro a favore dello Stato, delle regioni, degli enti territoriali, di enti o istituzioni pubbliche, di fondazioni e di associazioni legalmente riconosciute, per la realizzazione di programmi di ricerca scientifica nel settore della sanita' autorizzate dal Ministro della sanita' con apposito decreto che individua annualmente, sulla base di criteri che saranno definiti sentita la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, i soggetti che possono beneficiare delle predette erogazioni liberali. Il predetto decreto determina altresi', fino a concorrenza delle somme allo scopo indicate, l'ammontare delle erogazioni deducibili per ciascun soggetto erogatore, nonche' definisce gli obblighi di informazione da parte dei soggetti erogatori e dei soggetti beneficiari. Il Ministero della sanita' vigila sull'impiego delle erogazioni e comunica, entro il 31 marzo dell'anno successivo a quello di riferimento, al centro informativo del Dipartimento delle entrate del Ministero delle finanze, l'elenco dei soggetti erogatori e l'ammontare delle erogazioni liberali deducibili da essi effettuate".

2. Le disposizioni di cui al comma 1 si applicano a decorrere dal periodo di imposta in corso al 31 dicembre 2001.

3. Ai fini di quanto previsto al comma 1, il Ministro della sanita' determina l'ammontare delle erogazioni deducibili in misura complessivamente non superiore a 50 miliardi di lire per l'anno 2001 e a 200 miliardi di lire a decorrere dall'anno 2002.

### Art. 95. - (Disposizioni in materia di tutela sanitaria degli infortuni sul lavoro)

1. Per realizzare l'effettiva garanzia, di cui all'articolo 57 della legge 23 dicembre 1978, n. 833, per gli infortunati sul lavoro ed i tecnopatici di compiuto recupero della integrita' psico-fisica, comprensiva degli aspetti dinamico-relazionali, ai sensi degli articoli 86 ed 89 del testo unico delle disposizioni per l'assicurazione obbligatoria contro gli infortuni sul lavoro e le malattie professionali, approvato con decreto del Presidente della Repubblica 30 giugno 1965, n. 1124, e dell'articolo 13 del decreto legislativo 23 febbraio 2000, n. 38, le regioni possono definire con l'INAIL convenzioni per disciplinare la tempestiva erogazione delle cure sanitarie necessarie ed utili, nel rispetto del principio di continuita' assistenziale previsto dalla normativa del Servizio sanitario nazionale.

2. Le convenzioni, stipulate secondo uno schema tipo approvato dal Ministero della sanita' di concerto con il Ministero del lavoro e della previdenza sociale, su proposta dell'INAIL e della Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, inquadrano l'erogazione delle prestazioni di cui al comma 1 nell'ambito della programmazione sanitaria, nazionale e regionale, garantendo la piena integrazione fra i livelli di tutela a carico del Servizio sanitario nazionale e quelli a carico dell'INAIL, ferme restando la non duplicazione delle strutture sanitarie e la disciplina dell'autorizzazione e dell'accreditamento per i servizi sanitari.

### Art. 96. - (Potenziamento delle strutture di radioterapia)

1. Al fine di consentire la prosecuzione di quanto previsto dall'articolo 28, comma 12, della legge 23 dicembre 1999, n. 488, per le strutture di radioterapia e' riservato, nell'ambito dei programmi previsti dal citato articolo, un finanziamento di lire 20 miliardi per ciascuno degli anni 2001 e 2002.

2. Al fine di consentire al Centro internazionale radio-medico (CIRM), di cui al decreto del Presidente della Repubblica 29 aprile 1950, n. 553, lo svolgimento dei propri compiti istituzionali e il potenziamento dell'attivita' svolta, e' autorizzata la concessione al CIRM di un contributo di lire 360 milioni annue a decorrere dal 2001.

### Art. 97. - (Interventi a favore dei cittadini affetti dal morbo di Hansen e dalla sindrome di Down nonche' disabili)

1. A decorrere dal 1° gennaio 2001, le misure del sussidio spettante ai cittadini affetti dal morbo di Hansen, previste dall'articolo 1, comma 1, della legge 27 ottobre 1993, n. 433, sono rideterminate con decreto del Ministro della sanita', di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, entro i limiti delle autorizzazioni di spesa recate dalla stessa legge n. 433 del 1993 e dalle leggi 31 marzo 1980, n. 126, e 24 gennaio 1986, n. 31.

2. ((PERIODO SOPPRESSO DAL D.L. 24 GIUGNO 2014, N. 90, CONVERTITO, CON MODIFICAZIONI, DALLA L. 11 AGOSTO 2014, N. 114)). Con decreto del Ministro dell'economia e delle finanze, di concerto con il Ministro della salute, sono individuate, senza ulteriori oneri per lo Stato, le patologie e le menomazioni rispetto alle quali sono esclusi gli accertamenti di controllo e di revisione ed e' indicata la documentazione sanitaria, da richiedere agli interessati o alle commissioni mediche delle aziende sanitarie locali qualora non acquisita agli atti, idonea a comprovare la minorazione.

3. In attuazione dell'articolo 24 della legge 8 novembre 2000, n. 328, a favore delle persone con disabilita' fisica, psichica o sensoriale associata alla sindrome di Down, e' istituito il Fondo per il riordino dell'indennita' di accompagnamento. Per l'anno 2001 e' autorizzata la spesa di lire 30 miliardi.

### Art. 98. - (Interventi per la tutela della saluto mentale)

1. Per l'anno 2001, al fine di promuovere la realizzazione del progetto obiettivo "Tutela salute mentale 1998-2000", approvato con decreto del Presidente della Repubblica 10 novembre 1999, pubblicato nella Gazzetta Ufficiale n. 274 del 22 novembre 1999, e' istituito presso il Ministero della sanita' un fondo di lire tre miliardi per la realizzazione di un programma nazionale, adottato dal Ministro della sanita' previa intesa in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, per la realizzazione in ciascuna regione o provincia autonoma di progetti di prevenzione per la salute mentale, aventi ad oggetto, in particolare, interventi in ambiente scolastico e interventi di promozione per la collaborazione stabile tra medici di base e dipartimenti di salute mentale.

2. Per l'anno 2001, il fondo di cui al comma 1 e' integrato di lire un miliardo per la realizzazione di un programma nazionale di comunicazione e di informazione contro lo stigma e il pregiudizio sulla salute mentale.

3. All'articolo 3, comma 5, della legge 23 dicembre 1994, n. 724, e successive modificazioni, il secondo, il terzo e il quarto periodo sono sostituiti dai seguenti: "I beni mobili e immobili degli ex ospedali psichiatrici, gia' assegnati o da destinare alle aziende sanitarie locali o alle aziende ospedaliere, sono da esse a loro volta destinati alla produzione di reddito attraverso la vendita anche parziale degli stessi, con diritto di prelazione per gli enti pubblici, o la locazione. I redditi prodotti sono utilizzati prioritariamente per la realizzazione di strutture territoriali, in particolare residenziali, nonche' di centri diurni con attivita' riabilitative destinate ai malati mentali in attuazione degli interventi previsti dal piano sanitario nazionale 1998-2000, approvato con decreto del Presidente della Repubblica 23 luglio 1998, pubblicato nella Gazzetta Ufficiale n. 288 del 10 dicembre 1998, e dal progetto obiettivo tutela della salute mentale 1998-2000" approvato con decreto del Presidente della Repubblica 10 novembre 1999, pubblicato nella Gazzetta Ufficiale n. 274 del 22 novembre 1999. Qualora risultino disponibili ulteriori somme, dopo l'attuazione di quanto previsto dal terzo periodo del presente comma, le aziende sanitarie potranno utilizzare per altre attivita' di carattere sanitario".

### Art. 99. - (Misure per la profilassi internazionale)

1. Per l'assolvimento dei maggiori compiti di profilassi internazionale, il Ministero della sanita' e' autorizzato ad avvalersi, fino al 30 giugno 2002, delle unita' di personale medico, tecnico-sanitario ed amministrativo di cui all'articolo 12, comma 2, della legge 16 dicembre 1999, n. 494. All'onere derivante dall'attuazione del presente comma, nel limite massimo di lire 7.200 milioni, si provvede mediante la quota dello stanziamento previsto dal comma 4 dell'articolo 12 della citata legge n. 494 del 1999, non ancora utilizzata alla data del 30 giugno 2001.

### Art. 100. - (Provvidenze in favore degli allevamenti ovini e degli impianti avicoli)

1. La dotazione finanziaria del Fondo sanitario nazionale relativa all'applicazione delle misure di cui alla legge 2 giugno 1988, n. 218, e' incrementata di lire 25 miliardi per l'anno 2001 al fine di fare fronte ai danni provocati dalla malattia della "lingua blu" negli allevamenti ovini e dell'influenza aviaria negli impianti avicoli.

### Art. 101. - (Attribuzione di risorse alla regione Friuli-Venezia Giulia)

1. l fine di adeguare le risorse attribuite alla regione Friuli-Venezia Giulia con le disposizioni di cui all'articolo 1, commi 144, 145, 146 e 147, della legge 23 dicembre 1996, n. 662, al maggiore fabbisogno della spesa sanitaria, e' attribuita alla regione medesima la somma di lire 25 miliardi a decorrere dal 2002, aumentabili di 25,82 milioni di euro annui per ogni anno fino al raggiungimento dell'importo di 206,58 milioni di euro a titolo di anticipazione sulle maggiori compartecipazioni a tributi statali che, a tale scopo, saranno devolute con provvedimento legislativo al raggiungimento del predetto importo di 206,58 milioni di euro. Utilizzando la proiezione pluriennale di tale somma la regione e' autorizzata a contrarre mutui di durata decennale. ((24)) ------------- AGGIORNAMNETO (24) La L. 27 dicembre 2002, n. 289 ha disposto (con l'art. 30, comma 8) che "Per la copertura del maggiore fabbisogno della spesa sanitaria di cui all'articolo 101 della legge 23 dicembre 2000, n. 388, come modificato dall'articolo 52, comma 3, della legge 28 dicembre 2001, n. 448, quantificato in 196 milioni di euro annui, alla regione Friuli Venezia Giulia e' riconosciuta, a decorrere dall'anno 2003, una maggiore compartecipazione ai tributi statali di pari importo".

## STRUMENTI DI GESTIONE DEL DEBITO PUBBLICO

### Art. 102. - (Cartolarizzazione dei crediti e altre misure)

1. L'articolo 15 della legge 23 dicembre 1998, n. 448, come modificato dall'articolo 2 del decreto-legge 6 settembre 1999, n. 308, convertito, con modificazioni, dalla legge 5 novembre 1999, n. 402, e' sostituito dal seguente: "Art. 15. - (Societa' per l'acquisto e la cartolarizzazione dei crediti). - 1. Il Ministero del tesoro, del bilancio e della programmazione economica e' autorizzato a costituire una societa' per azioni, con capitale sociale iniziale di 200 milioni di lire, avente ad oggetto esclusivo l'acquisto e la cartolarizzazione dei crediti d'imposta e contributivi maturati e maturandi dallo Stato e dagli enti pubblici previdenziali. 2. Alle operazioni di cessione e di cartolarizzazione dei crediti nonche' alla societa' di cui al comma 1 si applicano le disposizioni dell'articolo 13. I richiami ivi contenuti all'INPS devono intendersi riferiti, in quanto compatibili, al Ministero delle finanze e agli enti pubblici previdenziali cedenti i crediti. Nel caso di cessione di crediti di imposta, i richiami ai decreti interministeriali ivi contenuti, devono intendersi riferiti ad uno o piu' decreti del Ministro del tesoro, del bilancio e della programmazione economica, di concerto con il Ministro delle finanze. 3. Il ricavo delle operazioni di cessione dei crediti di imposta viene destinato al rimborso dei debiti di imposta o in alternativa secondo modalita' da definire con decreto del Ministro del tesoro, del bilancio e della programmazione economica, di concerto con il Ministro delle finanze".

2. Il comma 3 dell'articolo 48 della legge 23 dicembre 1999, n. 488, e' sostituito dal seguente: "3. Fatti comunque salvi accordi tra le parti conformi alle condizioni economiche normalmente definite sul mercato, a decorrere dal 1° gennaio 2000, su tutte le somme di pertinenza dello Stato o di altri enti pubblici, affidate in gestione o depositate a qualsiasi titolo presso un istituto di credito, deve essere corrisposto un interesse pari al tasso ufficiale di riferimento pubblicato dalla Banca d'Italia ai sensi dell'articolo 2 del decreto legislativo 24 giugno 1998, n. 213".

3. A decorrere dalla data di entrata in vigore della presente legge, cessa per gli enti cessionari la facolta' prevista dall'articolo 1, comma 9, del decreto-legge 2 dicembre 1985, n. 688, convertito, con modificazioni, dalla legge 31 gennaio 1986, n. 11, di trasferire i crediti ad essi ceduti al Ministero del tesoro, del bilancio e della programmazione economica, a conguaglio delle anticipazioni di cui all'articolo 16 della legge 12 agosto 1974, n. 370.

4. All'articolo 13, comma 1, terzo periodo, della legge 23 dicembre 1998, n. 448, e successive modificazioni, sono soppresse le seguenti parole: "tra primarie societa' operanti in esclusiva nel settore del monitoraggio e della valutazione".

5. Il Ministro del tesoro, del bilancio e della programmazione economica, di concerto con il Ministro del lavoro e della previdenza sociale, concorda con l'INAIL appropriate forme di remunerazione dei proventi della cartolarizzazione dei crediti del medesimo istituto nei limiti delle eventuali maggiori economie rispetto alle previsioni iniziali per il 2001.

## DISPOSIZIONI PER AGEVOLARE L'INNOVAZIONE

### Art. 103. - (Utilizzo dei proventi derivanti dalle licenze UMTS e norme in materia di carta di credito formativa e di commercio elettronico)

1. Nello stato di previsione del Ministero del tesoro, del bilancio e della programmazione economica e' istituito un fondo destinato al finanziamento della ricerca scientifica nel quadro del Programma nazionale della ricerca ed anche con riferimento al settore delle tecnologie dell'informazione e della comunicazione (ICT) ed al progetto "Genoma", nonche' per il finanziamento di progetti per lo sviluppo della societa' dell'informazione relativi all'introduzione delle nuove tecnologie nella pubblica amministrazione, all'informatizzazione della pubblica amministrazione, compreso il monitoraggio della spesa, allo sviluppo tecnologico delle imprese, alla formazione all'utilizzo dei relativi strumenti, alla riduzione delle emissioni elettromagnetiche, alla alfabetizzazione informatica e delle nuove tecnologie, alle ricerche e studi nel settore delle telecomunicazioni. La dotazione del fondo e' determinata in misura pari al 10 per cento dei proventi derivanti dal rilascio delle licenze individuali per i sistemi di comunicazioni mobili di terza generazione. Alla ripartizione del fondo tra le diverse finalizzazioni, fermo restando quanto previsto dal comma 3 del presente articolo e dall'articolo 112 provvede il Consiglio dei ministri, su proposta del Presidente del Consiglio dei ministri, sentita la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281.

2. Con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro competente, d'intesa con il Ministro del tesoro, del bilancio e della programmazione economica, sentite la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, e le competenti Commissioni parlamentari, sono determinati procedure, modalita' e strumenti per l'utilizzo dei fondi assegnati.

3. Una quota del fondo di cui al comma 1, pari a lire 50 miliardi nell'anno 2001, e' destinata all'istituzione della carta di credito formativa per i cittadini italiani che compiono diciotto anni nel corso del 2001. Il Ministro delle attivita' produttive, sentito il Ministro per l'innovazione e le tecnologie, promuove la stipula di una convenzione tra le imprese del settore delle tecnologie della informazione e della comunicazione, le imprese del credito bancario e il Ministero delle attivita' produttive e il Dipartimento per l'innovazione e le tecnologie della Presidenza del Consiglio dei ministri, al fine di ottenere le migliori possibili condizioni di utilizzo della carta di credito formativa per l'acquisto, con particolare riguardo alle iniziative economiche in forma associativa, di beni e servizi nel settore delle tecnologie della informazione e della comunicazione e di corsi di formazione a distanza, per un ammontare pari a 2.500 euro, da effettuare entro il 2005. La convenzione identifica i prodotti e servizi ammissibili all'acquisto, e prevede le condizioni di rimborso della somma utilizzata. La convenzione prevede inoltre che lo Stato sia garante di ultima istanza delle imprese emittenti di fronte ai casi di insolvenza nei limiti delle somme che siano annualmente destinate a tale fine dalla legge finanziaria. Con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro del tesoro, del bilancio e della programmazione economica, sono determinate le procedure e le modalita' per l'esercizio delle funzioni di garanzia di cui al periodo precedente.

4. COMMA ABROGATO DALLA L. 27 DICEMBRE 2002, N. 289. 5.((COMMA ABROGATO DAL D.L. 22 GIUGNO 2012, N. 83, CONVERTITO, CON MODIFICAZIONI, DALLA L. 7 AGOSTO 2012, N. 134)).((71)) 6.((COMMA ABROGATO DAL D.L. 22 GIUGNO 2012, N. 83, CONVERTITO, CON MODIFICAZIONI, DALLA L. 7 AGOSTO 2012, N. 134)).((71))

------------- AGGIORNAMENTO (13) La L. 28 dicembre 2001, n. 448 ha disposto (con l'art. 59, comma 1) che "La somma di lire 110 miliardi di cui all'articolo 103, comma 6, della legge 23 dicembre 2000, n. 388, e' aumentata per l'anno 2002 di 1,50 milioni di euro, e per l'anno 2003 di 1 milione di euro, interamente finalizzati alla concessione di contributi in conto capitale nei limiti degli aiuti de minimis per il settore produttivo tessile, dell'abbigliamento e calzaturiero". ------------- AGGIORNAMENTO (44) Il D.L. 30 dicembre 2005,n. 273, convertito con modificazioni dalla L. 23 febbraio 2006, n. 51, ha disposto (con l'art. 23, comma 5-bis) che "I termini scaduti nel 2005 per la presentazione delle domande di liquidazione degli interventi per le finalita' di cui all'articolo 103, comma 5, della legge 23 dicembre 2000, n. 388, sono prorogati fino al 31 marzo 2006". ------------- AGGIORNAMENTO (71) Il D.L. 22 giugno 2012, n. 83, convertito, con modificazioni, dalla L. 7 agosto 2012, n. 134, ha disposto (con l'art. 23, comma 11) che "I procedimenti avviati in data anteriore a quella di entrata in vigore del presente decreto-legge sono disciplinati, ai fini della concessione e dell'erogazione delle agevolazioni e comunque fino alla loro definizione, dalle disposizioni delle leggi di cui all'Allegato 1 e dalle norme di semplificazione recate dal presente decreto-legge".

### Art. 104. - (Fondo per gli investimenti della ricerca di base e norme sul programma Antartide)

1. Al fine di favorire l'accrescimento delle competenze scientifiche del Paese e di potenziarne la capacita' competitiva a livello internazionale, e' istituito presso il Ministero dell'universita' e della ricerca scientifica e tecnologica, a decorrere dall'esercizio 2001, il Fondo per gli investimenti della ricerca di base (FIRB). ((71))

2. Il FIRB finanzia, in particolare:

- a) progetti di potenziamento delle grandi infrastrutture di ricerca pubbliche o pubblico-private;
- b) progetti di ricerca di base di alto contenuto scientifico o tecnologico, anche a valenza internazionale, proposti da universita', istituzioni pubbliche e private di ricerca, gruppi di ricercatori delle stesse strutture;
- c) progetti strategici di sviluppo di tecnologie pervasive e multisettoriali;
- d) costituzione, potenziamento e messa in rete di centri di alta qualificazione scientifica, pubblici o privati, anche su scala internazionale. ((71))

3. Con decreto del Ministro dell'universita' e della ricerca scientifica e tecnologica, da emanare entro sessanta giorni dalla data di entrata in vigore della presente legge, sono stabiliti i criteri e le modalita' procedurali per l'assegnazione delle relative risorse finanziarie. ((71))

4. Gli oneri di cui al presente articolo gravano sulle disponibilita' del Fondo per le agevolazioni alla ricerca (FAR) di cui all'articolo 5 del decreto legislativo 27 luglio 1999, n. 297, come sostituito dall'articolo 105 della presente legge, nella misura di lire 20 miliardi per l'esercizio 2001, 25 miliardi per l'esercizio 2002 e 30 miliardi per l'esercizio 2003. ((71))

5. All'articolo 5, comma 3, quarto periodo, della legge 7 agosto 1997, n. 266, e successive modificazioni, le parole da: "fermi restando" fino a: "sono rideterminati" sono sostituite dalle seguenti: "sono rideterminati il soggetto o i soggetti incaricati dell'attuazione, le strutture operative, nonche'".

------------- AGGIORNAMENTO (71) Il D.L. 22 giugno 2012, n. 83, convertito, con modificazioni, dalla L. 7 agosto 2012, n. 134 ha disposto (con l'art. 63, comma 1, lettera a)) che "A decorrere dalla data di entrata in vigore del decreto di cui all'articolo 62, comma 2, sono abrogati: a) l'articolo 104 della legge 23 dicembre 2000, n. 388, a eccezione del comma 5; [...]".

### Art. 105. - (Modifiche ai decreti legislativi 27 luglio 1999, n. 297 e 29 ottobre 1999, n. 419)

1. Al decreto legislativo 27 luglio 1999 n. 297, sono apportate le seguenti modifiche:

- a) all'articolo 2, comma 1, lettera f), dopo le parole: "enti di ricerca" sono inserite le seguenti: "anche a carattere regionale" e sono aggiunte, in fine, le parole: "e per attivita', proposte in collaborazione con i soggetti di cui alle lettere a), b), c), d), e), di ricerca e di alta formazione tecnologica finalizzate agli obiettivi di cui all'articolo 1, comma 1";
- b) all'articolo 2, comma 1, e' aggiunta, in fine, la seguente lettera: "f-bis) i parchi scientifici e tecnologici istituiti con legge regionale";
- c) l'articolo 5, comma 1, e' sostituito dal seguente: "1. Le attivita' di cui all'articolo 3 sono sostenute mediante gli strumenti di cui all'articolo 4 a valere sul Fondo per le agevolazioni alla ricerca (FAR), a carattere rotativo, che opera con le modalita' contabili di cui al soppresso Fondo speciale per la ricerca applicata. La gestione del FAR e' articolata in una sezione relativa agli interventi nel territorio nazionale e in una sezione relativa ad interventi nelle aree depresse. Al FAR affluiscono, a decorrere dall'anno 2000, gli stanziamenti iscritti nello stato di previsione del Ministero dell'universita' e della ricerca scientifica e tecnologica all'unita' previsionale di base 4.2.1.2. "Ricerca applicata"". 2. All'articolo 5, comma 1, del decreto legislativo 29 ottobre 1999, n. 419, le parole da: "mediante" fino a: "a rete" sono sostituite dalla seguente: "strutturale" e le parole da: "decreti legislativi" fino a: "coerenza" sono sostituite dalle seguenti: "regolamenti da emanare ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400, nel rispetto dei principi generali indicati dall'articolo 14, comma 1, della legge 15 marzo 1997, n. 59, ed in coerenza, per quanto compatibili,". 3. All'articolo 5, comma 2, del decreto legislativo 29 ottobre 1999, n. 419, all'alinea, le parole da: "degli enti" fino a: "statuti" sono sostituite dalle seguenti: "della o delle strutture derivanti dalla fusione o unificazione, anche mediante inserimento in sistema strutturato a rete, degli istituti ed enti operanti nel campo della ricerca storica, sono determinati".

### Art. 106.

((ARTICOLO ABROGATO DAL D.L. 22 GIUGNO 2012, N. 83, CONVERTITO, CON MODIFICAZIONI, DALLA L. 7 AGOSTO 2012, N. 134)) ((71))

------------- AGGIORNAMENTO (71) Il D.L. 22 giugno 2012, n. 83, convertito, con modificazioni, dalla L. 7 agosto 2012, n. 134, ha disposto (con l'art. 23, comma 11) che "I procedimenti avviati in data anteriore a quella di entrata in vigore del presente decreto-legge sono disciplinati, ai fini della concessione e dell'erogazione delle agevolazioni e comunque fino alla loro definizione, dalle disposizioni delle leggi di cui all'Allegato 1 e dalle norme di semplificazione recate dal presente decreto-legge".

### Art. 107. - (Informatizzazione della normativa vigente)

1. E' istituito presso la Presidenza del Consiglio dei ministri un fondo destinato al finanziamento di iniziative volte a promuovere l'informatizzazione e la classificazione della normativa vigente al fine di facilitarne la ricerca e la consultazione gratuita da parte dei cittadini, nonche' di fornire strumenti per l'attivita' di riordino normativo. A favore del fondo e' autorizzata la spesa di lire 25 miliardi per il quinquennio 2001-2005 nella misura di lire 5 miliardi per ciascuno degli anni dal 2001 al 2005. Il programma, le forme organizzative e le modalita' di funzionamento del fondo sono determinati con decreto del Presidente del Consiglio dei ministri, previa intesa con il Presidente del Senato della Repubblica e con il Presidente della Camera dei deputati. Ulteriori finanziamenti possono essere attribuiti al fondo da soggetti pubblici e privati, con le modalita' stabilite dallo stesso decreto.

### Art. 108. - (Misure a sostegno degli investimenti in ricerca e sviluppo nelle imprese industriali)

1. ((COMMA ABROGATO DALLA L. 12 DICEMBRE 2002, N. 273)).

2. ((COMMA ABROGATO DALLA L. 12 DICEMBRE 2002, N. 273)).

3. ((COMMA ABROGATO DALLA L. 12 DICEMBRE 2002, N. 273)).

4. ((COMMA ABROGATO DALLA L. 12 DICEMBRE 2002, N. 273)).

5. ((COMMA ABROGATO DALLA L. 12 DICEMBRE 2002, N. 273)).

6. ((COMMA ABROGATO DALLA L. 12 DICEMBRE 2002, N. 273)).

7. Il Ministro dell'universita', e della ricerca scientifica e tecnologica provvede, con le modalita' previste dal presente articolo, in relazione alle spese di ricerca effettuate in strutture situate nel territorio dello Stato o in progetti di collaborazione internazionale a maggioranza italiana. Gli oneri di cui al presente articolo gravano sul Fondo previsto dall'articolo 14 della legge 17 febbraio 1982 n. 46, nonche' sul Fondo di cui al decreto legislativo 27 luglio 1999, n. 297, ai quali e' conferita, rispettivamente, per ciascuno degli anni 2001, 2002 e 2003, la somma di lire 90 miliardi.

## INTERVENTI IN MATERIA AMBIENTALE

### Art. 109. - (Interventi in materia di promozione dello sviluppo sostenibile)

1. Al fine di incentivare misure ed interventi di promozione dello sviluppo sostenibile e' istituito presso il Ministero dell'ambiente un apposito fondo, con dotazione complessiva di lire 150 miliardi per l'anno 2001, 50 miliardi per l'anno 2002 e 50 miliardi per l'anno, 2003. Per le annualita' successive si provvede ai sensi dell'articolo 11, comma 3, lettera f), della legge 5 agosto 1978, n. 468, come modificata dalla legge 25 giugno 1999, n. 208.

2. Le risorse del fondo di cui al comma 1 sono prioritariamente destinate al finanziamento di misure ed interventi nelle seguenti materie:

- a) riduzione della quantita' e della pericolosita' dei rifiuti;
- b) raccolta differenziata dei rifiuti, loro riuso e riutilizzo;
- c) minore uso delle risorse naturali non riproducibile nei processi produttivi;
- d) riduzione del consumo di risorsa idrica e sua restituzione, dopo il processo di depurazione, con caratteristiche che ne consentano il riutilizzo;
- e) minore consumo energetico e maggiore utilizzo di fonti energetiche riproducibili e non derivanti dal consumo di combustibile fossili, e per quanto concerne i finanziamenti relativi a risparmi energetici riferiti ad attivita' produttive, tenendo in particolare conto le richieste delle aziende la cui attivita' si svolge nei territori interessati dai patti territoriali approvati;
- f) innovazione tecnologica finalizzata alla protezione dell'ambiente;
- g) azioni di sperimentazione della contabilita' ambientale territoriale;
- h) promozione presso i comuni, le province e le regioni dell'adozione delle procedure e dei programmi denominati Agende XXI ovvero certificazioni di qualita' ambientale territoriale;
- i) attivita' agricole multifunzionali e di forestazione finalizzate alla promozione dello sviluppo sostenibile;
- l) interventi per il miglioramento della qualita' dell'ambiente urbano;
- m) promozione di tecnologie ed interventi per la mitigazione degli impatti prodotti dalla navigazione e dal trasporto marittimi sugli ecosistemi marini;
- m-bis) elaborazione ed attuazione di piani di sostenibilita' in aree territoriali di particolare interesse dal punto di vista delle relazioni fra i settori economico, sociale e ambientale.

3. Entro il 31 gennaio di ciascun anno, il Ministro dell'ambiente e della tutela del territorio definisce, previa approvazione del Comitato interministeriale per la programmazione economica, il programma annuale di utilizzazione del fondo di cui al comma 1, elaborato anche sulla base delle proposte fatte pervenire dalle altre amministrazioni interessate. In tale programma sono individuati:

- a) le specifiche tipologie di azione da finanziare;
- b) i settori prioritari di intervento, con particolare riferimento a quelli indicati nel comma 2;
- c) i fondi attribuibili alle singole misure ed interventi programmati, in relazione alle risorse finanziarie disponibili per l'anno di riferimento;
- d) le condizioni e le modalita' per l'attribuzione e l'erogazione delle forme di sostegno, anche mediante credito di imposta;
- e) le priorita' territoriali e tematiche;
- f) le categorie di soggetti beneficiari;
- g) le modalita' di verifica della corretta e tempestiva attuazione delle iniziative e di valutazione dei risultati conseguiti)).

### Art. 110. - (Fondo per la riduzione delle emissioni in atmosfera e per la promozione dell'efficienza energetica e delle fonti sostenibili di energia)

1. Per il finanziamento degli interventi attuativi del protocollo di Kyoto sui cambiamenti climatici di cui alla deliberazione del Comitato interministeriale per la programmazione economica (CIPE) del 3 dicembre 1997, pubblicata nella Gazzetta Ufficiale n. 18 del 23 gennaio 1998, e successive modificazioni, e' istituito, a decorrere dall'anno 2001, nell'ambito di apposita unita' previsionale di base dello stato di previsione del Ministero dell'ambiente, un fondo per la riduzione delle emissioni in atmosfera e per la promozione dell'efficienza energetica e delle fonti sostenibili di energia.

2. Ai fini del comma 1, una quota di risorse pari al 3 per cento delle entrate derivanti dall'applicazione delle disposizioni di cui all'articolo 8, commi da 1 a 9, della legge 23 dicembre 1998, n. 448, accertate al 31 dicembre di ciascun anno, a decorrere dal 2001, e' destinata al fondo di cui al comma 1. La predetta quota affluisce annualmente al fondo stesso.

3. Le disponibilita' finanziarie del fondo di cui al comma 1 sono destinate al finanziamento di programmi di rilievo nazionale e regionale finalizzati alla riduzione delle emissioni in atmosfera, alla promozione dell'efficienza energetica ed alla diffusione delle fonti rinnovabili di energia, definiti ai sensi della citata deliberazione del CIPE del 3 dicembre 1997, nonche' al finanziamento di programmi agricoli e forestali finalizzati all'assorbimento dell'anidride carbonica, e sono ripartite, con deliberazione dello stesso Comitato, su proposta del Ministro dell'ambiente, sentita la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281.

4. Fra i programmi di rilievo nazionale da sottoporre alla deliberazione del Comitato di cui al comma 3, e' inserito, su proposta del Ministro dell'ambiente, un piano di installazione con priorita' nel Mezzogiorno di pannelli solari, che preveda, in una logica sistemica integrata e per il superamento della dipendenza dalla tecnologia estera:

- a) l'incentivazione, mediante finanziamenti nella misura dell'80 per cento dei costi totali, alla installazione di pannelli solari in abitazioni private;
- b) il sostegno allo sviluppo tecnologico delle imprese nazionali di produzione di collettori solari;
- c) la predisposizione da parte dell'ENEA di parametri tecnici di standardizzazione dei collettori e delle attrezzature ad essi collegate, nonche' la revisione e il raccordo con le iniziative in atto di formazione di tecnici per l'installazione e la manutenzione degli impianti solari termici nell'ambito del progetto interregionale "Comune solarizzato".

### Art. 111. - (Contributo straordinario all'ENEA)

1. L'Ente per le nuove tecnologie, l'energia e l'ambiente (ENEA) anche in cooperazione con altri soggetti, attua un programma di ricerca, sviluppo e produzione dimostrativa alla scala industriale di energia elettrica a partire dall'energia solare utilizzata come sorgente di calore ad alta temperatura. L'ENEA attua altresi' un programma di ricerca per lo sviluppo delle tecnologie delle celle combustibili ad alto rendimento, al fine di sviluppare e di sperimentare, in collaborazione con produttori di impianti, con produttori di energia e con soggetti utilizzatori della stessa, prototipi a scala industriale e per le applicazioni stazionarie.

2. ((Per le finalita' di cui al comma 1, e' assegnato all'ENEA un contributo straordinario nella misura di 25.822.844 euro per l'anno 2002 e di 20.658.275 euro per l'anno 2003 da impiegare, in misura pari almeno ad un terzo, per la realizzazione degli interventi nel settore dell'uso efficiente dell'energia, definiti da un apposito accordo di programma tra il Ministro delle attivita' produttive e l'ENEA.)) Il programma puo' beneficiare degli incentivi previsti dalla legislazione vigente in materia di ricerca scientifica e tecnologica e di produzione di energia rinnovabile. Il costo complessivo degli investimenti realizzati nell'ambito del programma puo' essere coperto sino e non oltre il 40 per cento con il contributo di cui al presente comma. L'ENEA presenta entro il 31 agosto 2001 al Ministero dell'industria, del commercio e dell'artigianato il progetto di massima che definisce le caratteristiche tecniche dell'impianto, la localizzazione e la stima dei costi di realizzazione e di gestione dello stesso impianto e indica, altresi', i soggetti con i quali sara' sviluppato il programma.

3. Il Ministro dell'industria, del commercio e dell'artigianato, sentito il Ministro dell'ambiente, valuta il progetto di massima, liquida l'importo di 30 miliardi di lire quale corrispettivo per il progetto di massima e liquida il contributo residuo entro il 30 settembre per l'anno 2001 ed entro il 31 luglio per gli anni 2002 e 2003. L'ENEA presenta ogni sei mesi una relazione sull'andamento delle attivita' di ricerca, sperimentazione, progettazione, esecuzione del progetto e profittabilita' della gestione.

4. L'ENEA e' tenuto a predisporre un piano di ristrutturazione della propria organizzazione e della propria attivita' finalizzato alla concentrazione su un numero limitato di rilevanti progetti di ricerca, di sviluppo tecnologico e di trasferimento dell'innovazione.

### Art. 112. - (Disposizioni in materia di inquinamento elettromagnetico)

1. Una quota non inferiore al 10 per cento della dotazione del fondo di cui all'articolo 103 e' destinata alla prevenzione ed alla riduzione dell'inquinamento elettromagnetico con particolare riferimento alle seguenti finalita':

- a) sostegno ad attivita' di studio e di ricerca per approfondire la conoscenza dei rischi connessi all'esposizione a campi elettrici, magnetici ed elettromagnetici;
- b) realizzazione del catasto nazionale delle sorgenti fisse di campi elettrici, magnetici ed elettromagnetici, nonche' adeguamento delle strutture e formazione del personale degli istituti pubblici addetti ai controlli sull'inquinamento elettromagnetico;
- c) incentivi per la promozione di nuove tecnologie a basso impatto ambientale in grado di minimizzare le esposizioni e di raggiungere gli obiettivi di qualita' previsti dal decreto del Ministro dell'ambiente 10 settembre 1998, n. 381.

### Art. 113. - (Compartecipazione degli enti locali ai tributi erariali con finalita' ambientale)

1. Entro centottanta giorni dalla data di entrata in vigore della presente legge, il Governo definisce, d'intesa con la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, le compartecipazioni ai tributi erariali con finalita' ambientale da parte degli enti locali sedi di impianti di produzione e di stoccaggio di prodotti assoggettati ai suddetti tributi, e adotta le, conseguenti iniziative, anche legislative, di propria competenza.

2. L'entita' delle compartecipazioni e' commisurata agli oneri degli enti locali interessati, necessari per la gestione del territorio compatibile con la utilizzazione industriale.

3. Le entrate degli enti locali derivanti dalle compartecipazioni non hanno carattere di compensazione del rischio ambientale e sanitario, e sono utilizzabili per programmi di salvaguardia e di sviluppo ecocompatibile del territorio. Sono fatti salvi tutti gli obblighi di protezione della salute e dell'ambiente e di rispetto della sicurezza, posti a carico delle aziende.

### Art. 114. - (Disinquinamento, bonifica e ripristino ambientale)

1. All'articolo 18 della legge 8 luglio 1986, n. 349, dopo il comma 9, sono aggiunti i seguenti: "9-bis. Le somme derivanti dalla riscossione dei crediti in favore dello Stato per il risarcimento del danno di cui al comma 1, ivi comprese quelle derivanti dall'escussione di fideiussioni a favore dello Stato, assunte a garanzia del risarcimento medesimo, sono versate all'entrata del bilancio dello Stato, per essere riassegnate, con decreto del Ministro del tesoro, del bilancio e della programmazione economica, ad un fondo di rotazione da istituire nell'ambito di apposita unita' previsionale di base dello stato di previsione del Ministero dell'ambiente, al fine di finanziare, anche in via di anticipazione: a) interventi urgenti di perimetrazione, caratterizzazione e messa in sicurezza dei siti inquinati, con priorita' per le aree per le quali ha avuto luogo il risarcimento del danno ambientale; b) interventi di disinquinamento, bonifica e ripristino ambientale delle aree per le quali abbia avuto luogo il risarcimento del danno ambientale; c) interventi di bonifica e ripristino ambientale previsti nel programma nazionale di bonifica e ripristino ambientale dei siti inquinati di cui all'articolo 1, comma 3, della legge 9 dicembre 1998, n. 426. 9-ter. Con decreto del Ministro dell'ambiente, adottato di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, sono disciplinate le modalita' di funzionamento e di accesso al predetto fondo di rotazione, ivi comprese le procedure per il recupero delle somme concesse a titolo di anticipazione".

2. Il decreto di cui al comma 9-ter dell'articolo 18 della legge 8 luglio 1986, n. 349, introdotto dal comma 1 del presente articolo, e' emanato entro centoventi giorni dalla data di entrata in vigore della presente legge.

3. L'accantonamento per gli oneri a fronte degli interventi di bonifica ai sensi dell'articolo 9 del decreto del Ministro dell'ambiente 25 ottobre 1999, n. 471, costituisce un onere pluriennale da ammortizzare, ai soli fini civilistici, in un periodo non superiore a dieci anni. Restano fermi i tempi di realizzazione delle bonifiche previsti nel progetto approvato ed i criteri per la deducibilita' dei costi sostenuti, anche se non imputati a conto economico. 4.((COMMA ABROGATO DAL D.L. 22 GIUGNO 2012, N. 83, CONVERTITO, CON MODIFICAZIONI, DALLA L. 7 AGOSTO 2012, N. 134)).((71)) 5. All'articolo 27 del decreto del Presidente della Repubblica 9 aprile 1959, n. 128, e successive modificazioni, al primo comma, dopo le parole: "laureato in ingegneria" sono inserite le seguenti: "ovvero in geologia" e al secondo comma, dopo le parole: "in Ingegneria Ambiente - Risorse" sono inserite le seguenti: "ovvero in geologia". 6.((COMMA ABROGATO DAL D.L. 22 GIUGNO 2012, N. 83, CONVERTITO, CON MODIFICAZIONI, DALLA L. 7 AGOSTO 2012, N. 134)).((71)) 7. Chiunque abbia adottato o adotti le procedure di cui all'articolo 17 del decreto legislativo 5 febbraio 1997, n. 22, e successive modificazioni, e di cui al decreto del Ministro dell'ambiente 25 ottobre 1999, n. 471, o che abbia stipulato o stipuli accordi di programma previsti nell'ambito delle medesime normative, non e' punibile per i reati diretta mente connessi all'inquinamento del sito posti in essere anteriormente alla data di entrata in vigore del citato decreto legislativo n. 22 del 1997 che siano accertati a seguito dell'attivita' svolta, su notifica dell'interessato, ai sensi dell'articolo 17 del medesimo decreto legislativo n. 22 del 1997, e successive modificazioni, qualora la realizzazione e il completamento degli interventi ambientali si realizzino in conformita' alle predette procedure o ai predetti accordi di programma ed alla normativa vigente in materia. 8. La disposizione di cui al comma 7 non e' applicabile quando i fatti di inquinamento siano stati commessi a titolo di dolo o comunque nell'ambito di attivita' criminali organizzate volte a realizzare illeciti guadagni in violazione delle norme ambientali. 9. Per costi sopportabili di cui al comma 6 dell'articolo 17 del decreto legislativo 5 febbraio 1997, n. 22, e di cui alle lettere f) ed i) del comma 1 dell'articolo, 2 del decreto del Ministro dell'ambiente 25 ottobre 1999, n. 471, si intendono, con riferimento ad impianti in esercizio, quelli derivanti da una bonifica che non comporti un arresto prolungato delle attivita' produttive o che comunque non siano sproporzionati rispetto al fatturato annuo prodotto dall'impianto in questione. 10. Al fine di conservare e valorizzare anche per finalita' sociali e produttive, i siti e i beni dell'attivita' mineraria con rilevante valore storico, culturale ed ambientale, e' assegnato un finanziamento di lire 3 miliardi per l'anno 2001 e di lire 6 miliardi a decorrere dall'anno 2002 al Parco geominerario della Sardegna, istituito entro sessanta giorni dalla data di entrata in vigore della presente legge, con decreto del Ministro dell'ambiente, di concerto con il Ministro dell'industria, del commercio e dell'artigianato, e con il Ministro dell'universita' e della ricerca scientifica e tecnologica e di intesa con la regione Sardegna e gestito da un consorzio assimilato agli enti di cui alla legge 9 maggio 1989, n. 168, costituito dai Ministeri dell'ambiente, dell'industria, del commercio e dell'artigianato e dell'universita' e della ricerca scientifica e tecnologica, dalla regione Sardegna, dai comuni interessati ed, eventualmente, da altri soggetti interessati. Al fine di garantire la tutela, la conoscenza e la valorizzazione, anche per finalita' sociali e occupazionali, dei parchi e dei musei sommersi aventi rilevante valore ambientale, storico, archeologico e culturale, e' assegnato un finanziamento di lire 2 miliardi a decorrere dall'anno 2001 per i parchi sommersi ubicati nelle acque di Baia nel golfo di Pozzuoli e di Gaiola nel golfo di Napoli, istituiti con decreto del Ministro dell'ambiente, di concerto con i Ministri per i beni e le attivita' culturali, dei trasporti e della navigazione e delle politiche agricole e forestali e di intesa con la regione Campania, e affidati in gestione, con decreto del Ministro dell'ambiente e della tutela del territorio, di concerto con il Ministro per i beni e le attivita' culturali, sentiti la regione e gli enti locali territorialmente interessati, ad enti pubblici, istituzioni scientifiche o associazioni ambientaliste riconosciute, anche consorziati tra loro. I decreti istitutivi di cui ai periodi precedenti stabiliscono altresi' le attivita' incompatibili con le finalita' previste dal presente comma, alla cui violazione si applicano le sanzioni previste dall'articolo 30 della legge 6 dicembre 1991, n. 394. 11. E' istituito con decreto del Ministero dell'ambiente, d'intesa con il Ministero per i beni e le attivita' culturali, con il Ministero delle politiche agricole e forestali, con le regioni Abruzzo, Basilicata, Campania, Lazio, Molise e Puglia, nonche' con gli Enti parco nazionali interessati, il coordinamento nazionale dei tratturi e della civilta' della transumanza, all'interno del programma d'azione per lo sviluppo sostenibile dell'Appennino, denominato "Appennino Parco d'Europa". In tale intesa sono individuati:

- a) i siti, gli itinerari le attivita' antropiche e i beni che hanno rilevanza naturale, ambientale, storica, culturale, archeologica, economica, sociale e connessi con la civilta' della transumanza;
- b) gli obiettivi per il recupero, la tutela e la valorizzazione dei siti e dei beni di cui alla lettera a) anche ai fini dello sviluppo integrato sostenibile delle aree del coordinamento di cui al presente comma. 12. Il coordinamento nazionale di cui al comma 11 e' gestito da un consorzio formato, dai Ministeri, dalle regioni e dagli enti parco di cui al medesimo comma 11, nonche' dalle province, dai comuni e dalle comunita' montane interessati. Alle attivita' di promozione e programmazione dello sviluppo del coordinamento partecipano soggetti pubblici e privati, quali universita', associazioni ambientalistiche e culturali, enti economici e di volontariato, organizzazioni sociali. 13. L'istituzione e il funzionamento del coordinamento di cui ai commi 11 e 12 sono finanziati nei limiti massimi di spesa di lire 1.000 milioni nel 2001, di lire 1.000 milioni nel 2002 e di lire 1.000 milioni nel 2003. 14. Al fine di conservare e valorizzare, anche per finalita' sociali e produttive, i siti e i beni dell'attivita' mineraria con rilevante valore storico, culturale e ambientale, e' assegnato un finanziamento di lire un miliardo per ciascuno degli anni 2001, 2002 e 2003 al Parco tecnologico ed archeologico delle colline metallifere grossetane e al Parco museo delle miniere dell'Amiata, istituiti con decreto del Ministro dell'ambiente, d'intesa con il Ministro per i beni e le attivita' culturali e con la regione Toscana e gestito da un consorzio costituito dal Ministero dell'ambiente, dal Ministero per i beni e le attivita' culturali, dalla regione Toscana e dagli enti locali. Al fine di consentire la realizzazione di opere di recupero e di ripristino della ufficiosita' del fiume Sile e' autorizzata la spesa di lire 2 miliardi per l'anno 2001 a favore dell'Ente parco naturale del fiume Sile. 15. Al fine di conservare e valorizzare gli antichi siti di escavazione ed i beni di rilevante testimonianza storica, culturale e ambientale connessi con l'attivita' estrattiva, e' assegnato un finanziamento di lire 500 milioni per ciascuno degli anni 2001, 2002 e 2003 al Parco archeologico delle Alpi Apuane, istituito con decreto del Ministro dell'ambiente,, d'intesa con il Ministro per i beni e le attivita' culturali e con la regione Toscana e gestito da un consorzio costituito dal Ministero dell'ambiente, dal ministero per i beni e le attivita' culturali, dalla regione Toscana, dagli enti locali e dall'Ente parco delle Alpi Apuane. Nell'intesa, previo parere dei comuni interessati, sono individuati: a) i siti ed i beni che hanno rilevante valenza di testimonianza storica, culturale e ambientale connessi con l'attivita' estrattiva; b) gli obiettivi per il recupero, la conservazione e la valorizzazione dei siti e dei beni di cui alla lettera a). 16. I siti ed i beni di cui alla lettera a) del comma 15 compresi nell'area del Parco regionale delle Alpi Apuane e gli obiettivi di cui alla lettera b) dello stesso comma 15 ad essi correlati sono individuati dal Ministero dell'ambiente, d'intesa con il Ministero per i beni e le attivita' culturali e con l'Ente parco delle Alpi Apuane. 17. Con decreto del Ministro dell'ambiente, emanato di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, e' approvato, entro sessanta giorni dalla data di entrata in vigore della presente legge, sentite le competenti Commissioni parlamentari, il piano di completamento della bonifica e del recupero ambientale dell'area industriale di Bagnoli. Il piano e' predisposto, entro trenta giorni dalla data di entrata in vigore della presente legge, dal soggetto attuatore previsto dall'articolo 1, comma 1, del decreto-legge 20 settembre 1996, n. 486, convertito, con modificazioni, dalla legge 18 novembre 1996, n. 582, sulla base e nel rispetto degli strumenti urbanistici vigenti relativi all'area interessata e comprende il completamento delle azioni gia' previste dal citato articolo 1, comma 1, del decreto-legge n. 486 del 1996, convertito, con modificazioni, dalla legge n. 582 del 1996, nonche' la conservazione degli elementi di archeologia industriale previsti dagli ultimi due periodi del predetto articolo 1, comma 1, introdotti dall'articolo 31, comma 43, della legge 23 dicembre 1998, n. 448. Al piano, che fissa un termine per la conclusione dei lavori finanziati, sono allegati una relazione tecnico-economica sullo stato degli interventi gia' realizzati ed un cronoprogramma relativo alla esecuzione dei lavori futuri, nonche' un motivato parere del comune di Napoli. A tale fine e' autorizzata la spesa di lire 50.000 milioni per ciascuno degli anni 2001-2003. 18. Sono abrogati i commi 1, da 3 a 13 e 15 dell'articolo 1 del citato decreto-legge n. 486 del 1996, convertito, con modificazioni, dalla legge n. 582 del 1996. 19. Il Comitato di coordinamento di alta vigilanza e la commissione per il controllo ed il monitoraggio di cui all'articolo 1, comma 4, del citato decreto-legge n. 486 del 1996, convertito, con modificazioni, dalla legge n. 582 del 1996, cessano le loro funzioni alla data di entrata in vigore del decreto del Ministro dell'ambiente di cui al comma 17, con la presentazione di un documento conclusivo riepilogativo delle opere effettuate e dei costi sostenuti. La funzione di vigilanza e controllo sulla corretta e tempestiva attuazione del piano di recupero di Bagnoli e' attribuita al Ministero dell'ambiente, il quale, in caso di inosservanza delle prescrizioni e dei tempi stabiliti nel piano stesso, puo', previa diffida a conformarsi alle previsioni entro congruo termine, disporre l'affidamento a terzi per l'esecuzione dei lavori in danno, ai sensi dell'articolo 17, commi 2, 9, 10 e 11, del decreto legislativo 5 febbraio 1997, n. 22, e successive modificazioni. Il Ministro dell'ambiente presenta annualmente al Parlamento una relazione sullo stato di avanzamento delle attivita' di cui all'articolo 1, comma 1, del citato decreto-legge n. 486 del 1996, convertito, con modificazioni, dalla legge n. 582 del 1996. In considerazione del pubblico interesse alla bonifica, al recupero ed alla valorizzazione dell'area di Bagnoli, e' attribuita facolta' al comune di Napoli, entro il 31 dicembre 2001, di acquisire la proprieta' delle aree oggetto degli interventi di bonifica anche attraverso una societa' di trasformazione urbana. In tale caso possono partecipare al capitale sociale, fino alla completa acquisizione della proprieta' delle aree al patrimonio della societa' medesima, esclusivamente il comune di Napoli, la provincia di Napoli e la regione Campania. Il comune di Napoli, a seguito del trasferimento di proprieta', subentra nelle attivita' di bonifica attualmente gestite dalla societa' Bagnoli spa con il trasferimento dei contratti in essere, dei finanziamenti specifici ad essi riferiti e di quelli non ancora utilizzati, ivi compresi i finanziamenti per il completamento della bonifica, gli affidamenti dei lavori avverranno secondo le norme vigenti per la pubblica amministrazione con riferimento alla legge 11 febbraio 1994, n. 109, e successive modificazioni, e altresi' secondo modalita' e procedure che assicurino il mantenimento dell'occupazione dei lavoratori dipendenti della societa' Bagnoli spa nelle attivita' di bonifica. Ai fini dell'acquisizione da parte del comune di Napoli della proprieta' delle aree oggetto dei progetti di bonifica, il corrispettivo e' calcolato dall'ufficio tecnico erariale in base al valore effettivo dei terreni e degli immobili che, secondo il progetto di completamento approvato, devono rimanere nell'area oggetto di cessione; dall'importo cosi' determinato e' detratto, ai fini dell'ottenimento della cifra di cessione, il 30 per cento dell'intervento statale utilizzato sino al momento della cessione nelle attivita' di bonifica. In caso di rinuncia esplicita da parte del comune di Napoli all'acquisto delle aree soggette ad interventi di bonifica, l'IRI o altro proprietario, entro nove mesi dalla data di entrata in vigore della presente legge, provvede all'alienazione mediante asta pubblica, il cui prezzo base e' determinato dall'ufficio tecnico erariale secondo i criteri di cui al periodo precedente, senza alcuna detrazione. Dal prezzo di aggiudicazione e' detratto a favore dello Stato il valore delle migliorie apportate alle aree interessate sino al momento della cessione. 20. Il decreto di cui al comma 17 dovra' indicare un elenco di aree industriali prioritarie, ivi comprese quelle ex estrattive minerarie, rientranti in un piano straordinario per la bonifica e il recupero ambientale, nonche' le modalita' per la redazione dei relativi piani di recupero. Per la realizzazione del piano straordinario per la bonifica e il recupero ambientale e' autorizzata la spesa di lire 10.000 milioni per ciascuno degli anni 2001, 2002 e 2003. 21. Salvo quanto disposto dai commi 17 e 19 del presente articolo, con regolamento da emanare ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1998, n. 400, entro il medesimo termine di cui al comma 17, sentito il parere delle competenti Commissioni parlamentari, e' dettata la disciplina per l'acquisizione delle aree oggetto di risanamento ambientale da parte dei comuni nelle aree interessate al piano straordinario per la bonifica e il recupero ambientale, con l'obiettivo di attribuire al comune la facolta' di acquisire, entro un termine definito, la proprieta' delle aree oggetto degli interventi di bonifica e, in caso di rinuncia esplicita da parte del comune stesso, di alienare le aree stesse mediante asta pubblica con assunzione da parte del nuovo proprietario degli oneri di completamento della bonifica. 22. Al fine di migliorare, incrementare ed adeguare agli standard europei, alle migliori tecnologie disponibili ed alle migliori pratiche ambientali la progettazione in materia di rifiuti e bonifiche e di tutela delle acque interne, nonche' programmare iniziative di supporto alle azioni in tali settori delle amministrazioni pubbliche per aumentare l'efficienza dei relativi interventi, anche sotto il profilo della capacita' di utilizzazione delle risorse derivanti da cofinanziamenti dell'Unione europea, sono istituite presso il Servizio per la gestione dei rifiuti e per le bonifiche e il Servizio per la tutela delle acque interne del Ministero dell'ambiente apposite segreterie tecniche composte ciascuna da non piu' di dodici esperti di elevata qualificazione nominati con decreto del Ministro dell'ambiente, di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, con il quale ne e' stabilito il funzionamento. Per la costituzione e il funzionamento delle predette segreterie e' autorizzata la spesa di lire 1.800 milioni annue per gli anni 2001 e 2002. 23. Al comma 6-bis dell'articolo 23 del decreto legislativo 11 maggio 1999, n. 152, introdotto dall'articolo 7 del decreto legislativo 18 agosto 2000, n. 258, le parole: "31 dicembre 2000" sono sostituite dalle seguenti: "30 giugno 2001". 24. Ferme restando le disposizioni di cui al decreto-legge 20 settembre 1996, n. 486, convertito, con modificazioni, dalla legge 18 novembre 1996, n. 582, all'articolo 1, comma 4, della legge 9 dicembre 1998, n. 426, sono aggiunte, in fine, le seguenti lettere: "p-bis) Sesto San Giovanni (aree industriali e relative discariche); p-ter) Napoli Bagnoli-Coroglio (aree industriali)". 25. All'articolo 1, comma 4, della legge 9 dicembre 1998, n. 426, e' aggiunta, in fine, la seguente lettera: "p-quater) Pioltello e Rodano". 26. All'articolo 29 del regio decreto 13 febbraio 1933, n. 215, e' aggiunto, in fine, il seguente comma: "Il trasferimento della proprieta' e degli altri diritti reali sui beni oggetto di assegnazione ha natura costitutiva ed estingue qualsiasi altro diritto reale incidente sui beni stessi. Resta salva la possibilita' prevista dal penultimo comma dell'articolo 28 per coloro che dimostrino in giudizio la titolarita', sui beni assegnati, di diritti reali diversi da quelle contemplati nel piano di riordinamento di vedere tali diritti accertati dall'autorita' giudiziaria.". 27. Al fine di completare la bonifica e la realizzazione del Parco naturale Molentargius-Saline, istituito con la legge della regione Sardegna 26 febbraio 1999, n. 5, i beni immobili compresi nelle saline di Cagliari gia' in uso all'Amministrazione autonoma del monopoli di Stato, previa intesa con la regione autonoma della Sardegna, sono trasferiti a titolo gratuito al demanio regionale. 28. All'articolo 43, comma 1, della legge 17 maggio 1999, n. 144, dopo le parole: "Malpensa 2000", sono inserite le seguenti: "nonche' alla realizzazione di attivita' di monitoraggio ambientale e di interventi di delocalizzazione o finalizzati alla compensazione e mitigazione ambientale degli effetti conseguenti alle attivita' di Malpensa 2000".

------------- AGGIORNAMENTO (71) Il D.L. 22 giugno 2012, n. 83, convertito, con modificazioni, dalla L. 7 agosto 2012, n. 134, ha disposto (con l'art. 23, comma 11) che "I procedimenti avviati in data anteriore a quella di entrata in vigore del presente decreto-legge sono disciplinati, ai fini della concessione e dell'erogazione delle agevolazioni e comunque fino alla loro definizione, dalle disposizioni delle leggi di cui all'Allegato 1 e dalle norme di semplificazione recate dal presente decreto-legge".

### Art. 115. - (Ente geopaleontologico di Pietraroia)

1. E' istituito, con decreto del Ministero dell'ambiente, d'intesa con il Ministero per i beni e le attivita' culturali e con la regione Campania, l'Ente geopaleontologico di Pietraroia, in provincia di Benevento; nell'ambito di tale intesa sono individuati i siti geologici, paleontologici, naturalistici e paesaggistici che hanno rilevante valenza di testimonianza scientifica, culturale ed ambientale connessi con l'attivita' di ricerca scientifica e gli obiettivi di conservazione e valorizzazione del geosito e di sviluppo socioeconomico in termini ecosostenibili.

2. L'Ente di cui al comma 1 e' gestito da un consorzio formato dai Ministeri di cui al medesimo comma 1, dalla regione Campania, dalla provincia di Benevento, dal comune di Pietraroia, dall'universita' del Sannio, dall'universita' "Federico II" di Napoli e dalle associazioni locali e ambientali interessate ai sensi della legge 9 maggio 1989, n. 168.

3. Ai fini di cui al presente articolo e' autorizzata una spesa nel limite massimo di lire 500 milioni annue a decorrere dall'anno 2001.

## INTERVENTI IN MATERIA DI LAVORO

### Art. 116. - (Misure per favorire l'emersione del lavoro irregolare)

1. Alle imprese che recepiscono, entro un anno dalla decisione assunta dalla Commissione delle Comunita' europee sul regime di aiuto di Stato n. 236/A/2000, contratti di riallineamento regolati ai sensi e alle condizioni dell'articolo 5 del decreto-legge 1° ottobre 1996, n. 510, convertito, con modificazioni, dalla legge 28 novembre 1996, n. 608, e successive modificazioni, e' concesso, per la durata del programma di riallineamento e, comunque, per un periodo non superiore a cinque anni, uno sgravio contributivo nelle misure di cui al comma 2 per i lavoratori individuati secondo le modalita' di cui al comma 3-sexies dell'articolo 5 del citato decreto-legge n. 510 del 1996, introdotto dall'articolo 75 della legge 23 dicembre 1998, n. 448, mai denunciati agli enti previdenziali.

2. Lo sgravio contributivo di cui al comma 1, determinato sulle retribuzioni corrisposte, e' fissato nella misura del 100 per cento per il primo anno, dell'80 per cento per il secondo anno, del 60 per cento per il terzo anno, del 40 per cento per il quarto anno e del 20 per cento per il quinto anno.

3. Per i lavoratori gia' denunciati agli enti previdenziali e interessati dai contratti di riallineamento di cui al comma 1 per periodi e retribuzioni non denunciate, e' concesso uno sgravio contributivo pari alla meta' delle misure di cui al comma 2.

4. Le disposizioni di cui ai commi 1, 2 e 3 trovano applicazione anche nei confronti delle imprese che hanno in corso, alla data di entrata in vigore della presente legge, il programma di riallineamento ai sensi dell'articolo 5 del citato decreto-legge n. 510 del 1996, e successive modificazioni, secondo le seguenti modalita':

- a) per il periodo successivo secondo le annualita' e con le entita' dello sgravio previste dai commi 1, 2 e 3;
- b) per il periodo del contratto di riallineamento antecedente, lo sgravio si applica sotto forma di conguaglio sulle spettanze contributive gia' versate per i lavoratori interessati al contratto stesso nelle misure di cui ai commi 1, 2 e 3. L'importo del conguaglio cosi' determinato, usufruibile entro il termine del periodo di riallineamento e, comunque, entro il periodo di fruizione dello sgravio di cui alla lettera a), e' utilizzato secondo le modalita' fissate dagli enti previdenziali, a valere anche sulle regolarizzazioni in corso di cui al comma 3-sexies dell'articolo 5 del citato decreto-legge n. 510 del 1996, introdotto dall'articolo 75 della legge 23 dicembre 1998, n. 448.

5. Agli oneri derivanti dai commi da 1 a 4, valutati nel limite massimo di lire 200 miliardi per ciascuno degli anni 2001, 2002 e 2003, e di lire 100 miliardi per ciascuno degli anni 2004, 2005 e 2006, si provvede mediante l'utilizzo delle risorse del Fondo per l'occupazione di cui all'articolo 1, comma 7, del decreto-legge 20 maggio 1993, n. 148, convertito, con modificazioni dalla legge 19 luglio 1993, n. 236.

6. All'articolo 63 della legge 23 dicembre 1999, n. 488, il comma 3 e' abrogato.

7. All'articolo 78 della legge 23 dicembre 1998, n. 448, sono apportate le seguenti modificazioni:

- a) al comma 3, la parola: "nove" e' sostituita dalla seguente: "dieci", dopo le parole: "della programmazione economica," e' inserita la seguente: "due" ed e' aggiunto, in fine, il seguente periodo: "Per il funzionamento del Comitato e' autorizzata la spesa di lire 1000 milioni a decorrere dall'anno 2001";
- b) al comma 4, dopo il primo periodo, e' inserito il seguente: "A tale fine le commissioni possono affidare l'incarico di durata non superiore a quindici mesi, rinnovabile una sola volta per una durata non superiore a quella iniziale e comunque non oltre il 31 dicembre 2003, a soggetto dotato di idonea professionalita', previo parere favorevole espresso dal Comitato di cui al comma 3 che provvede, altresi' a verificare e valutare periodicamente l'attivita' svolta dal tutore, segnalandone l'esito alla rispettiva commissione per l'adozione delle conseguenti determinazioni; per la relativa attivita' e' autorizzata la spesa di lire 5 miliardi per ciascuno degli anni 2001, 2002 e 2003; qualora la commissione non sia costituita od operante, all'affidamento dell'incarico e all'adozione di ogni altra relativa determinazione provvede direttamente il Comitato di cui al comma 3";
- c) e' aggiunto, in fine, il seguente comma: "5-bis. All'onere per il funzionamento del Comitato di cui al comma 3 e a quello relativo agli incarichi di tutore di cui al comma 4 si provvede mediante riduzione dell'autorizzazione di spesa di cui all'articolo 66, comma 1, della legge 17 maggio 1999, n. 144. Le somme occorrenti sono attribuite in conformita' agli indirizzi e criteri determinati dal Ministro del lavoro e della previdenza sociale".

8. I soggetti che non provvedono entro il termine stabilito al pagamento dei contributi o premi dovuti alle gestioni previdenziali ed assistenziali, ovvero vi provvedono in misura inferiore a quella dovuta, sono tenuti:

- a) nel caso di mancato o ritardato pagamento di contributi o premi, il cui ammontare e' rilevabile dalle denunce e/o registrazioni obbligatorie, al pagamento di una sanzione civile, in ragione d'anno, pari al tasso ufficiale di riferimento maggiorato di 5,5 punti; se il pagamento dei contributi o premi e' effettuato entro centoventi giorni, in unica soluzione, spontaneamente prima di contestazioni o richieste da parte degli enti impositori, la maggiorazione non trova applicazione; la sanzione civile non puo' essere superiore al 40 per cento dell'importo dei contributi o premi non corrisposti entro la scadenza di legge; (109)
- b) in caso di evasione connessa a registrazioni, denunce o dichiarazioni obbligatorie omesse o non conformi al vero, poste in essere con l'intenzione specifica di non versare i contributi o premi mediante l'occultamento di rapporti di lavoro in essere, retribuzioni erogate o redditi prodotti, ovvero di fatti o notizie rilevanti per la determinazione dell'obbligo contributivo, al pagamento di una sanzione civile, in ragione d'anno, pari al 30 per cento, fermo restando che la sanzione civile non puo' essere superiore al 60 per cento dell'importo dei contributi o premi non corrisposti entro la scadenza di legge. Se la denuncia della situazione debitoria e' effettuata spontaneamente prima di contestazioni o richieste da parte degli enti impositori e comunque entro dodici mesi dal termine stabilito per il pagamento dei contributi o premi, i soggetti sono tenuti al pagamento di una sanzione civile pari, in ragione d'anno, al tasso ufficiale di riferimento maggiorato di 5,5 punti, se il versamento in unica soluzione dei contributi o premi sia effettuato entro trenta giorni dalla denuncia. Il tasso ufficiale di riferimento e' maggiorato di 7,5 punti, se il versamento in unica soluzione dei contributi o premi e' effettuato entro novanta giorni dalla denuncia. La sanzione civile non puo', in ogni caso, essere superiore al 40 per cento dell'importo dei contributi o premi, non corrisposti entro la scadenza di legge. In caso di pagamento in forma rateale, l'applicazione della misura di cui al secondo e terzo periodo e' subordinata al versamento della prima rata. Si applicano le disposizioni dell'articolo 2, comma 11, del decreto-legge 9 ottobre 1989, n. 338, convertito, con modificazioni, dalla legge 7 dicembre 1989, n. 389. In caso di mancato ovvero di insufficiente o tardivo versamento di una delle successive rate accordate si applica la misura di cui al primo periodo della presente lettera; (109)
- b-bis) in caso di situazione debitoria rilevata d'ufficio dagli enti impositori ovvero a seguito di verifiche ispettive, al versamento della sanzione civile di cui al primo periodo delle lettere a) e b) nella misura del 50 per cento, se il pagamento dei contributi e premi e' effettuato, in unica soluzione, entro trenta giorni dalla notifica della contestazione. In caso di pagamento in forma rateale, l'applicazione della misura di cui al primo periodo e' subordinata al versamento della prima rata. Si applicano le disposizioni dell'articolo 2, comma 11, del decreto-legge 9 ottobre 1989, n. 338, convertito, con modificazioni, dalla legge 7 dicembre 1989, n. 389. In caso di mancato ovvero di insufficiente o tardivo versamento di una delle successive rate accordate, si applica la misura di cui al primo periodo delle lettere a) e b). (109) (111)

9. Dopo il raggiungimento del tetto massimo delle sanzioni civili nelle misure previste alle lettere a) e b) del comma 8 senza che si sia provveduto all'integrale pagamento del dovuto, sul debito contributivo maturano interessi nella misura degli interessi di mora di cui all'articolo 30 del decreto del Presidente della Repubblica 29 settembre 1973, n. 602, come sostituito all'articolo 14 del decreto legislativo 26 febbraio 1999, n. 46. (107) (111)

10. Nei casi di mancato o ritardato pagamento di contributi o premi derivanti da oggettive incertezze connesse a contrastanti orientamenti giurisprudenziali o amministrativi sulla ricorrenza dell'obbligo contributivo, successivamente riconosciuto in sede giudiziale o amministrativa, sempreche' il versamento dei contributi o premi sia effettuato entro il termine fissato dagli enti impositori, sono dovuti gli interessi legali di cui all'articolo 1284 del codice civile. (109)

11. Nelle amministrazioni centrali e periferiche dello Stato e negli enti locali il dirigente responsabile e' sottoposto a sanzioni disciplinari ed e' tenuto al pagamento delle sanzioni e degli interessi di cui ai commi 8, 9 e 10.

12. Ferme restando le sanzioni penali, sono abolite tutte le sanzioni amministrative relative a violazioni in materia di previdenza e assistenza obbligatorie consistenti nell'omissione totale o parziale del versamento di contributi o premi o dalle quali comunque derivi l'omissione totale o parziale del versamento di contributi o premi, ai sensi dell'articolo 35, commi secondo e terzo, della legge 24 novembre 1981, n. 689, nonche' a violazioni di norme sul collocamento di carattere formale.

13. Nei casi di tardivo pagamento dei contributi o premi dovuti alle gestioni previdenziali ed assistenziali per i quali non si fa luogo all'applicazione delle sanzioni civili e degli interessi di mora di cui al comma 8 del presente articolo e di cui alla previgente normativa in materia sanzionatoria, non possono essere richiesti gli interessi previsti dall'articolo 1282 del codice civile.

14. I pagamenti effettuati per contributi sociali obbligatori ed accessori a favore degli enti gestori di forme obbligatorie di previdenza ed assistenza non sono soggetti all'azione revocatoria di cui all'articolo 67 delle disposizioni approvate con regio decreto 16 marzo 1942, n. 267.

15. Fermo restando l'integrale pagamento dei contributi e dei premi dovuti alle gestioni previdenziali e assistenziali, i consigli di amministrazione degli enti impositori, sulla base di apposite direttive emanate dal Ministro del lavoro e della previdenza sociale, di concerto con il Ministro dell'economia e delle finanze fissano criteri e modalita' per la riduzione delle sanzioni civili di cui al comma 8 fino alla misura degli interessi legali, in caso di:

- a) oggettive incertezze connesse a contrastanti ovvero sopravvenuti diversi orientamenti giurisprudenziali o determinazioni amministrative sulla ricorrenza dell'obbligo contributivo successivamente riconosciuto in sede giurisdizionale o amministrativa in relazione alla particolare rilevanza delle incertezze interpretative che hanno dato luogo alla inadempienza e nei casi di mancato o ritardato pagamento di contributi o premi, derivanti da fatto doloso del terzo denunciato, entro il termine di cui all'articolo 124, primo comma, del codice penale, all'autorita' giudiziaria;
- b) crisi, riconversione o ristrutturazione aziendale per i quali siano stati adottati i provvedimenti di concessione del trattamento di integrazione salariale straordinario e comunque in tutti i casi di crisi che presentino particolare rilevanza sociale ed economica in relazione alla situazione occupazionale locale ed alla situazione produttiva del settore e che rendono probabile l'insolvenza.

15-bis. Per le aziende agricole colpite da eventi eccezionali, ivi comprese le calamita' naturali dichiarate ai sensi del comma 2 dell'articolo 2 della legge 14 febbraio 1992, n. 185, e le emergenze di carattere sanitario, la riduzione delle sanzioni civili di cui al comma 8 e' fissata con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, in misura non inferiore al tasso di interesse legale.

16. In attesa della fissazione da parte dei medesimi consigli di amministrazione dei criteri e delle modalita' di riduzione delle sanzioni civili di cui al comma 8 per i casi di cui alle lettere a) e b) del comma 15, resta fermo quanto stabilito dall'articolo 3, commi da 1 a 3, del decreto-legge 29 marzo 1991 n. 103, convertito con modificazioni, dalla legge 1° giugno 1997, n. 166 e successive modificazioni. Resta altresi' fermo quanto stabilito dall'articolo 1, commi 220 e 2121, della legge 23 dicembre 1996, n. 662, in materia di riduzione delle sanzioni civili di cui al comma 8 rispettivamente nelle ipotesi di procedure concorsuali e nei casi di omesso o ritardato pagamento dei contributi o premi da parte di enti non economici e di enti, fondazioni e associazioni non aventi fini di lucro.

17. Nei casi previsti dal comma 15, lettera a), il pagamento rateale di cui all'articolo 2, comma 11, del decreto-legge 9 ottobre 1989, n. 338, convertito, con modificazioni, dalla legge 7 dicembre 1989, n. 389, puo' essere consentito fino a sessanta mesi, previa autorizzazione del Ministro del lavoro e della previdenza sociale, di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, e sulla base dei criteri di eccezionalita' ivi previsti. ((112))

17-bis. Nei casi di particolare eccezionalita', individuati con decreto del Ministro del lavoro e delle politiche sociali di concerto con il Ministro dell'economia e delle finanze tra quelli previsti dal comma 15-bis, il pagamento rateale di cui all'articolo 2, comma 11, del decreto-legge 9 ottobre 1989, n. 338, convertito, con modificazioni, dalla legge 7 dicembre 1989, n. 389, puo' essere consentito fino a quaranta rate trimestrali costanti.

18. Per i crediti in essere e accertati al 30 settembre 2000 le sanzioni sono dovute nella misura e secondo le modalita' fissate dai commi 217, 218, 219, 220, 221, 222, 223 e 224 dell'articolo 1 della legge 23 dicembre 1996, n. 662. Il maggiore importo versato, pari alla differenza fra quanto dovuto ai sensi dei predetti commi del citato articolo 1 della legge 23 dicembre 1996, n. 662, e quanto calcolato in base all'applicazione dei commi da 8 a 17 del presente articolo, costituisce un credito contributivo nei confronti dell'ente previdenziale che potra' essere posto a conguaglio ratealmente nell'arco di un anno, tenendo conto delle scadenze temporali previste per il pagamento dei contributi e premi assicurativi correnti, secondo modalita' operative fissate da ciascun ente previdenziale.

19. L'articolo 37 della legge 24 novembre 1981, n. 689, e' sostituito dal seguente: "Art. 37 - (Omissione o falsita' di registrazione o denuncia obbligatoria) - 1. Salvo che il fatto costituisca piu' grave reato, il datore di lavoro che, al fine di non versare in tutto o in parte contributi e premi previsti dalle leggi sulla previdenza e assistenza obbligatorie, omette una o piu' registrazioni o denunce obbligatorie, ovvero esegue una o piu' denunce obbligatorie in tutto o, in, parte, non conformi al vero, e' punito con la reclusione fino a due anni quando dal fatto deriva l'omesso versamento di contributi e premi previsti dalle leggi sulla previdenza e assistenza obbligatorie per un importo mensile non inferiore al maggiore importo fra cinque milioni mensili e il cinquanta per cento dei contributi complessivamente dovuti. 2. Fermo restando l'obbligo dell'organo di vigilanza di riferire al pubblico ministero la notizia di reato, qualora l'evasione accertata formi oggetto di ricorso amministrativo o giudiziario il procedimento penale e' sospeso dal momento dell'iscrizione della notizia di reato nel registro di cui all'articolo 335 del codice di procedura penale, fino al momento della decisione dell'organo amministrativo o giudiziario di primo grado. 3. La regolarizzazione dell'inadempienza accertata, anche attraverso dilazione, estingue il reato. 4. Entro novanta giorni l'ente impositore e' tenuto a dare comunicazione all'autorita' giudiziaria dell'avvenuta regolarizzazione o dell'esito del ricorso amministrativo o giudiziario".

20. Il pagamento della contribuzione previdenziale, effettuato in buona fede ad un ente previdenziale pubblico diverso dal titolare, ha effetto liberatorio nei confronti del contribuente. Conseguentemente, l'ente che ha ricevuto il pagamento dovra' provvedere al trasferimento delle somme incassate, senza aggravio di interessi, all'ente titolare della contribuzione.

------------ AGGIORNAMENTO (103) Il D.L. 30 dicembre 2021, n. 228 ha disposto (con l'art. 9, comma 4) che le disposizioni di cui ai commi 8 e 9 dell'articolo 116 della legge 23 dicembre 2000, n. 388, non si applicano fino al 31 dicembre 2022 agli obblighi relativi alle contribuzioni di previdenza e di assistenza sociale obbligatoria di cui al comma 10-bis dell'articolo 3 della legge 8 agosto 1995, n. 335, come modificato dal comma 3 del presente articolo, e al comma 10-ter del medesimo articolo 3 della legge n. 335 del 1995, introdotto dal comma 3 del presente articolo. Non si fa luogo a rimborso di quanto gia' versato. ------------ AGGIORNAMENTO (107) Il D.L. 30 dicembre 2021, n. 228, convertito con modificazioni dalla L. 25 febbraio 2022, n. 15, come modificato dal D.L. 30 dicembre 2023, n. 215, ha disposto (con l'art. 9, comma 4) che "Le disposizioni di cui ai commi 8 e 9 dell'articolo 116 della legge 23 dicembre 2000, n. 388, non si applicano fino al 31 dicembre 2024 agli obblighi relativi alle contribuzioni di previdenza e di assistenza sociale obbligatoria di cui al comma 10-bis dell'articolo 3 della legge 8 agosto 1995, n. 335, come modificato dal comma 3 del presente articolo, e al comma 10-ter del medesimo articolo 3 della legge n. 335 del 1995, introdotto dal comma 3 del presente articolo. Non si fa luogo a rimborso di quanto gia' versato". ------------ AGGIORNAMENTO (109) Il D.L. 2 marzo 2024, n. 19, convertito con modificazioni dalla L. 29 aprile 2024, n. 56 ha disposto (con l'art. 30, commi 1 e 2) che le modifiche ai commi 8 e 10 del presente articolo si applicano a decorrere dal 1° settembre 2024. --------------- AGGIORNAMENTO (111) Il D.L. 30 dicembre 2021, n. 228, convertito con modificazioni dalla L. 25 febbraio 2022, n. 15, come modificato dal D.L. 27 dicembre 2024, n. 202, ha disposto (con l'art. 9, comma 4) che "Le disposizioni di cui ai commi 8 e 9 dell'articolo 116 della legge 23 dicembre 2000, n. 388, non si applicano fino al 31 dicembre 2025 agli obblighi relativi alle contribuzioni di previdenza e di assistenza sociale obbligatoria di cui al comma 10-bis dell'articolo 3 della legge 8 agosto 1995, n. 335, come modificato dal comma 3 del presente articolo, e al comma 10-ter del medesimo articolo 3 della legge n. 335 del 1995, introdotto dal comma 3 del presente articolo. Non si fa luogo a rimborso di quanto gia' versato". ------------ AGGIORNAMENTO (112) La L. 13 dicembre 2024, n. 203, ha disposto (con l'art. 23, comma 2) che "A decorrere dal 1° gennaio 2025, il comma 17 dell'articolo 116 della legge 23 dicembre 2000, n. 388, cessa di applicarsi all'Istituto nazionale della previdenza sociale (INPS) e all'Istituto nazionale per l'assicurazione contro gli infortuni sul lavoro".

### Art. 117. - (Disposizioni in materia di Lavoro temporaneo. Modifiche all'articolo 10 del decreto legislativo 23 dicembre 1997, n. 469)

1. Alla legge 24 giugno 1997, n. 196, sono apportate le seguenti modificazioni:

- a) all'articolo 2, comma 2: 1) alla lettera a), sono aggiunte, in fine, le parole: "o di altro Stato membro dell'Unione europea"; 2) alla lettera c), dopo le parole: "dipendenza nel territorio nazionale" sono inserite le seguenti: "o di altro Stato membro dell'Unione, europea";
- b) all'articolo 9, dopo il comma 3 sono aggiunti i seguenti: "3-bis. Nel caso in cui i contratti collettivi prevedano la fornitura, a persone fisiche o a nuclei familiari di lavoratori temporanei domestici, i contributi previdenziali ed assicurativi sono dovuti secondo le misure previste dall'articolo 5 del decreto del Presidente della Repubblica 31 dicembre 1971, n. 1403, e successive modificazioni. L'Istituto nazionale della previdenza sociale determina le modalita' ed i termini di versamento. 3-ter. Le imprese fornitrici autorizzate ai sensi dell'articolo 2 non sono tenute, a decorrere dal 1° gennaio 2001, al versamento dell'aliquota contributiva di cui all'articolo 25, quarto comma, della legge 21 dicembre 1978, n. 845";
- c) all'articolo 10, comma 2, secondo periodo, le parole: "a tempo indeterminato" sono sostituite dalle seguenti: "a tempo determinato"; ((46))
- d) all'articolo 16, comma 3, secondo periodo, le parole "derivanti dal contributo di cui all'articolo 5, comma 1" sono sostituite dalle seguenti: "da preordinare allo scopo, a valere sul Fondo di cui all'articolo 1, comma 7, del decreto-legge 20 maggio 1993, n. 148, convertito, con modificazioni, dalla legge 19 luglio 1993, n. 236".

2. All'articolo 2751-bis del codice civile, dopo il numero 5-bis) e' aggiunto il seguente: "5-ter. i crediti delle imprese fornitrici di lavoro temporaneo di cui alla legge 24 giugno 1997, n. 196, per gli oneri retributivi e previdenziali addebitati alle imprese utilizzatrici".

3. All'articolo 10 del decreto legislativo 23 dicembre 1997, n.469, sono apportate le seguenti modifiche:

- a) al comma 1, dopo le parole: "idonee strutture organizzative" sono aggiunte le seguenti: "nonche' le modalita' di accreditamento dell'attivita' di ricerca e selezione del personale e di supporto alla ricollocazione professionale";
- b) dopo il comma 1, sono inseriti i seguenti: "1 -bis. Per mediazione tra domanda ed offerta di lavoro si intende l'attivita', anche estesa all'inserimento lavorativo dei disabili e delle fasce svantaggiate, di: raccolta di curricula dei potenziali lavoratori, preselezione e costituzione di relativa banca dati; orientamento professionale dei lavoratori; ricerca e selezione dei lavoratori; promozione e gestione dell'incontro tra domanda ed offerta di lavoro anche nella ricollocazione professionale; effettuazione, su richiesta dell'azienda, di tutte le comunicazioni conseguenti alle assunzioni avvenute a seguito dell'iniziativa della stessa societa' di mediazione; gestione di attivita' dei servizi all'impiego a seguito di convenzioni con le pubbliche istituzioni preposte, per il cui svolgimento il possesso dell'autorizzazione alla mediazione costituisce criterio preferenziale. 1-ter. Per ricerca e selezione del personale si intende l'attivita' effettuata su specifico ed esclusivo incarico di consulenza ottenuto dal datore di lavoro cliente, consistente nel ricercare, selezionare e valutare i candidati sulla base del profilo professionale e con le modalita' concordate con il datore di lavoro cliente, approntando i mezzi ed i supporti idonei allo scopo. 1-quater. Per supporto alla ricollocazione professionale si intende l'attivita' effettuata su specifico ed esclusivo incarico del datore di lavoro cliente, ovvero in base ad accordi sindacali da soggetti surroganti il datore di lavoro, al fine di facilitare la rioccupazione nel mercato di prestatori di lavoro, singoli o collettivi, attraverso la preparazione, l'accompagnamento della persona e l'affiancamento della stessa nell'inserimento della nuova attivita'.";
- c) al comma 2, e' aggiunto, in fine il seguente periodo: "Fermo restando forme societarie anche non di capitali, per lo svolgimento di attivita' di ricerca e selezione nonche' di supporto alla ricollocazione professionale, il limite di capitale versato ammonta a lire 50 milioni.";
- d) al comma 3, sono aggiunte, in fine, le seguenti parole: ", ovvero l'attivita' di ricerca e selezione ovvero di supporto alla ricollocazione professionale, ciascuna attraverso la specifica procedura di cui al comma 4";
- e) il comma 4 e' sostituito dal seguente: "4. Il Ministero del lavoro e della previdenza sociale rilascia, entro novanta giorni dalla richiesta e previo accertamento della sussistenza dei requisiti di cui ai commi 2 e 7, l'autorizzazione all'esercizio dell'attivita' di mediazione nonche' l'accreditamento per le attivita' di ricerca e selezione e di supporto alla ricollocazione professionale, provvedendo contestualmente all'iscrizione delle societa' nei rispettivi elenchi.";
- f) al comma 5, dopo le parole: "di autorizzazione" sono inserite le seguenti: "ovvero di accreditamento", la parola: "trenta", ovunque ricorra, e' sostituita dalla seguente: "quindici" e, in fine, sono aggiunte le seguenti parole: "ovvero dell'accreditamento";
- g) al comma 6, all'alinea, dopo le parole: "dell'autorizzazione" sono inserite le seguenti: "ovvero dell'accreditamento" e alle lettere a) e c) sono premesse le seguenti parole: "con riferimento alle societa' di mediazione,";
- h) al comma 7, lettera a), dopo la parola: "biennale" sono aggiunte le seguenti: ", ovvero da titoli di studio adeguati";
- i) ai commi 8 e 10, la parola: "mediazione" e' sostituita dalle seguenti: "cui ai commi da 1 a 1-ter";
- l) al comma 11, la parola: "mediazione" e' sostituita dalle seguenti: "cui ai commi da 1 a 1-ter" e dopo la parola: "autorizzazione" sono inserite le seguenti: "ovvero dell'accreditamento";
- m) al comma 12, alla lettera b) dopo la parola: "autorizzazione" sono inserite le seguenti: "ovvero dell'accreditamento" e alla lettera d) sono premesse le parole: "con riferimento alle societa' di mediazione,";
- n) al comma 13, le parole: "alla mediazione di manodopera" sono sostituite dalle seguenti: "ovvero accreditati";

4. Il Ministro del lavoro e della previdenza sociale emana entro sessanta giorni dalla data di entrata in vigore della presente legge il decreto di cui all'articolo 10, comma 12, del decreto legislativo 23 dicembre 1997, n. 469, come modificato dal comma 3 del presente articolo, relativamente ai criteri per l'accreditamento. I soggetti che esercitano, alla data di entrata in vigore della presente legge, attivita' di ricerca e selezione nonche' di supporto alla ricollocazione professionale possono svolgere la medesima alle condizioni di cui al comma 13 dell'articolo 10 del citato decreto n. 469 del 1997, fino ad un massimo di centoventi giorni dalla data di entrata in vigore del decreto del Ministro del lavoro e della previdenza sociale cui al presente comma, formulando una domanda contenente la dichiarazione circa il rispetto degli impegni delle condizioni di cui ai commi 6 e 7 del predetto articolo 10.

5. Al fine di potenziare lo sviluppo dei servizi per l'impiego assicurando l'esercizio delle funzioni esplicitate nell'Accordo in materia di standard minimi di funzionamento dei servizi per l'impiego tra il Ministero del lavoro e della previdenza sociale, le regioni, le province, le province autonome, i comuni e le comunita' montane sancito il 16 dicembre 1999 dalla Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, e' stanziata, nell'esercizio finanziario 2001, la somma di lire 100 miliardi, a far carico sul Fondo per l'occupazione, ai sensi dell'articolo 1, comma 7, del decreto-legge 20 maggio 1993, n. 148, convertito, con modificazioni, dalla legge 19 luglio 1993, n. 236.

------------- AGGIORNAMENTO (46) La Corte costituzionale, con sentenza 6-16 febbraio 2006, n. 58 (in G.U. 1a s.s. 22/2/2006, n. 8 ) ha dichiarato l' illegittimita' costituzionale del comma 1, lettera c), del presente articolo.

### Art. 118. - (Interventi in materia di formazione professionale nonche' disposizioni in materia di attivita' svolte in fondi comunitari e di Fondo sociale europeo)

1. Al fine di promuovere, in coerenza con la programmazione regionale e con le funzioni di indirizzo attribuite in materia al Ministero del lavoro e delle politiche sociali, lo sviluppo della formazione professionale continua e dei percorsi formativi o di riqualificazione professionale per soggetti disoccupati o inoccupati, in un'ottica di competitivita' delle imprese e di garanzia di occupabilita' dei lavoratori, possono essere istituiti, per ciascuno dei settori economici dell'industria, dell'agricoltura, del terziario e dell'artigianato, nelle forme di cui al comma 6, fondi paritetici interprofessionali nazionali per la formazione continua, nel presente articolo denominati "fondi". Gli accordi interconfederali stipulati dalle organizzazioni sindacali dei datori di lavoro e dei lavoratori maggiormente rappresentative sul piano nazionale possono prevedere l'istituzione di fondi anche per settori diversi, nonche', all'interno degli stessi, la costituzione di un'apposita sezione relativa ai dirigenti. I fondi relativi ai dirigenti possono essere costituiti mediante accordi stipulati dalle organizzazioni sindacali dei datori di lavoro e dei dirigenti comparativamente piu' rappresentative, oppure come apposita sezione all'interno dei fondi interprofessionali nazionali. ((Inoltre, con accordo interconfederale stipulato dalle organizzazioni territoriali delle organizzazioni sindacali dei datori di lavoro e dei lavoratori maggiormente rappresentative sul piano nazionale, nelle province autonome di Trento e di Bolzano puo' essere istituito un fondo territoriale intersettoriale)). I fondi, previo accordo tra le parti, si possono articolare regionalmente o territorialmente e possono altresi' utilizzare parte delle risorse a essi destinati per misure di formazione a favore di apprendisti e collaboratori a progetto. I fondi possono finanziare in tutto o in parte: 1) piani formativi aziendali, territoriali, settoriali o individuali concordati tra le parti sociali; 2) eventuali ulteriori iniziative propedeutiche e comunque direttamente connesse a detti piani concordate tra le parti; 3) piani di formazione o di riqualificazione professionale previsti dal Patto di formazione di cui all'articolo 8, comma 2, del decreto-legge 28 gennaio 2019, n. 4. ((I fondi possono altresi' finanziare, in tutto o in parte, piani formativi aziendali di incremento delle competenze dei lavoratori destinatari di trattamenti di integrazione salariale in costanza di rapporto di lavoro ai sensi degli articoli 11, 21, comma 1, lettere a), b) e c), e 30 del decreto legislativo 14 settembre 2015, n. 148)).I piani aziendali, territoriali o settoriali sono stabiliti sentite le regioni e le province autonome territorialmente interessate. I progetti relativi ai piani individuali ed alle iniziative propedeutiche e connesse ai medesimi sono trasmessi alle regioni ed alle province autonome territorialmente interessate, affinche' ne possano tenere conto nell'ambito delle rispettive programmazioni. Ai fondi afferiscono, secondo le disposizioni di cui al presente articolo, le risorse derivanti dal gettito del contributo integrativo stabilito dall'articolo 25, quarto comma, della legge 21 dicembre 1978, n. 845, e successive modificazioni, relative ai datori di lavoro che aderiscono a ciascun fondo. Nel finanziare i piani formativi di cui al presente comma, i fondi si attengono al criterio della redistribuzione delle risorse versate dalle aziende aderenti a ciascuno di essi, ai sensi del comma 3.

2. L'attivazione dei fondi e' subordinata al rilascio di autorizzazione da parte del Ministero del lavoro e delle politiche sociali, previa verifica della conformita' alle finalita' di cui al comma 1 dei criteri di gestione delle strutture di funzionamento dei fondi medesimi, della professionalita' dei gestori, nonche' dell'adozione di criteri di gestione improntati al principio di trasparenza. La vigilanza sulla gestione dei fondi e' esercitata dall'ANPAL, istituita dal decreto legislativo 14 settembre 2015, n. 150, che ne riferisce gli esiti al Ministero del lavoro e delle politiche sociali anche ai fini della revoca dell'autorizzazione e del commissariamento dei fondi nel caso in cui vengano meno le condizioni per il rilascio dell'autorizzazione. Il presidente del collegio dei sindaci e' nominato dal Ministero del lavoro e delle politiche sociali. Presso lo stesso Ministero e' istituito, con decreto ministeriale, senza oneri aggiuntivi a carico del bilancio dello Stato, l'"Osservatorio per la formazione continua" con il compito di elaborare proposte di indirizzo attraverso la predisposizione di linee-guida e di esprimere pareri e valutazioni in ordine alle attivita' svolte dai fondi, anche in relazione all'applicazione delle suddette linee-guida. Tale Osservatorio e' composto da due rappresentanti del Ministero del lavoro e delle politiche sociali, dal consigliere di parita' componente la Commissione centrale per l'impiego, da quattro rappresentanti delle regioni designati dalla Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, nonche' da un rappresentante di ciascuna delle confederazioni delle organizzazioni sindacali dei datori di lavoro e delle organizzazioni sindacali dei lavoratori maggiormente rappresentative sul piano nazionale. Tale Osservatorio si avvale dell'assistenza tecnica dell'Istituto per lo sviluppo della formazione professionale dei lavoratori (ISFOL). Ai componenti dell'Osservatorio non compete alcun compenso ne' rimborso spese per l'attivita' espletata.

3. I datori di lavoro che aderiscono ai fondi effettuano il versamento del contributo integrativo, di cui all'articolo 25 della legge n. 845 del 1978, e successive modificazioni, all'INPS, che provvede a trasferirlo, per intero, una volta dedotti i meri costi amministrativi, al fondo indicato dal datore di lavoro. L'adesione ai fondi e' fissata entro il 31 ottobre di ogni anno, con effetti dal 1 gennaio successivo; le successive adesioni o disdette avranno effetto dal 1 gennaio di ogni anno. L'INPS, entro il 31 gennaio di ogni anno, a decorrere dal 2005, comunica al Ministero del lavoro e delle politiche sociali e ai fondi la previsione, sulla base delle adesioni pervenute, del gettito del contributo integrativo, di cui all'articolo 25 della legge n. 845 del 1978, e successive modificazioni, relativo ai datori di lavoro aderenti ai fondi stessi nonche' di quello relativo agli altri datori di lavoro, obbligati al versamento di detto contributo, destinato al Fondo per la formazione professionale e per l'accesso al Fondo sociale europeo (FSE), di cui all'articolo 9, comma 5, del decreto-legge 20 maggio 1993, n. 148, convertito, con modificazioni, dalla legge 19 luglio 1993, n. 236. Lo stesso Istituto provvede a disciplinare le modalita' di adesione ai fondi interprofessionali e di trasferimento delle risorse agli stessi mediante acconti bimestrali nonche' a fornire, tempestivamente e con regolarita', ai fondi stessi, tutte le informazioni relative alle imprese aderenti e ai contributi integrativi da esse versati. Al fine di assicurare continuita' nel perseguimento delle finalita' istituzionali del Fondo per la formazione professionale e per l'accesso al FSE, di cui all'articolo 9, comma 5, del decreto-legge 20 maggio 1993, n. 148, convertito, con modificazioni, dalla legge 19 luglio 1993, n. 236, rimane fermo quanto previsto dal secondo periodo del comma 2 dell'articolo 66 della legge 17 maggio 1999, n. 144.

4. Nei confronti del contributo versato ai sensi del comma 3, trovano applicazione le disposizioni di cui al quarto comma dell'articolo 25 della citata legge n. 845 del 1978, e successive modificazioni.

5. Resta fermo per i datori di lavoro che non aderiscono ai fondi l'obbligo di versare all'INPS il contributo integrativo di cui al quarto comma dell'articolo 25 della citata legge n. 845 del 1978, e successive modificazioni, secondo le modalita' vigenti prima della data di entrata in vigore della presente legge.

6. Ciascun fondo e' istituito, sulla base di accordi interconfederali stipulati dalle organizzazioni sindacali dei datori di lavoro e dei lavoratori maggiormente rappresentative sul piano nazionale, alternativamente:

- a) come soggetto giuridico di natura associativa ai sensi dell'articolo 36 del codice civile;
- b) come soggetto dotato di personalita' giuridica ai sensi degli articoli 1 e 9 del regolamento di cui al decreto del Presidente della Repubblica 10 febbraio 2000, n. 361, concessa con decreto del Ministro del lavoro e delle politiche sociali.

7. COMMA ABROGATO DALLA L. 27 DICEMBRE 2002, N. 289.

8. In caso di omissione, anche parziale, del contributo integrativo di cui all'articolo 25 della legge n. 845 del 1978, il datore di lavoro e' tenuto a corrispondere il contributo omesso e le relative sanzioni, che vengono versate dall'INPS al fondo prescelto.

9. Con decreto del Ministro del lavoro e della previdenza sociale sono determinati, entro centoventi giorni dalla data di entrata in vigore della presente legge, modalita', termini e condizioni per il concorso al finanziamento di progetti di ristrutturazione elaborati dagli enti di formazione entro il limite massimo di lire 100 miliardi per l'anno 2001, nell'ambito delle risorse preordinate allo scopo nel Fondo per l'occupazione di cui all'articolo 1, comma 7, del decreto-legge 20 maggio 1993, n. 148, convertito, con modificazioni, dalla legge 19 luglio 1993, n. 236. Le disponibilita' sono ripartite su base regionale in riferimento al numero degli enti e dei lavoratori interessati dai processi di ristrutturazione, con proprieta' per i progetti di ristrutturazione finalizzati a conseguire i requisiti previsti per l'accreditamento delle strutture formative ai sensi dell'accordo sancito in sede di conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano del 18 febbraio 2000, e sue eventuali modifiche. (13)

10. A decorrere dall'anno 2001 e' stabilita al 20 per cento la quota del gettito complessivo da destinare ai fondi a valere sul terzo delle risorse derivanti dal contributo integrativo di cui all'articolo 25 della legge 21 dicembre 1978, n. 845, destinato al Fondo di cui all'articolo medesimo. Tale quota e' stabilita al 30 per cento per il 2002 e al 50 per cento per il 2003.

11. Con decreto del Ministro del lavoro e della previdenza sociale sono determinati le modalita' ed i criteri di destinazione al finanziamento degli interventi di cui all'articolo 80, comma 4, della legge 23 dicembre 1998, n. 448, dell'importo aggiuntivo di lire 25 miliardi per l'anno 2001.

12. Gli importi previsti per gli anni 1999 e 2000 dall'articolo 66, comma 2, della legge 17 maggio 1999, n. 144, sono:

- a) per il 75 per cento assegnati al Fondo di cui ai citato articolo 25 della legge n. 845 del 1978, per finanziare, in via prioritaria, i piani formativi aziendali, territoriali o settoriali concordati tra le parti sociali;
- b) per il restante 25 per cento accantonati per essere destinati ai fondi, a seguito della loro istituzione. Con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, sono determinati i termini ed i criteri di attribuzione delle risorse di cui al presente comma ed al comma 10.

13. Per le annualita' di cui al comma 12, l'INPS continua ad effettuare il versamento stabilito dall'articolo 1, comma 72, della legge 28 dicembre 1995, n. 549, al Fondo di rotazione per l'attuazione delle politiche comunitarie di cui all'articolo 5 della legge 16 aprile 1987, n. 183, ed il versamento stabilito dall'articolo 9, comma 5, del citato decreto-legge n. 148 del 1993, convertito, con modificazioni, dalla legge n. 236 del 1993, al Fondo di cui al medesimo comma.

14. Nell'esecuzione di programmi o di attivita', i cui oneri ricadono su fondi comunitari, gli enti pubblici di ricerca sono autorizzati a procedere ad assunzioni o ad impiegare personale a tempo determinato per tutta la durata degli stessi, anche mediante proroghe dei relativi contratti di lavoro, anche in deroga ai limiti quantitativi previsti dall'articolo 1, comma 1, del decreto legislativo 6 settembre 2001, n. 368. La presente disposizione si applica anche ai programmi o alle attivita' di assistenza tecnica in corso di svolgimento alla data di entrata in vigore della presente legge.

15. Gli avanzi finanziari derivanti dalla gestione delle risorse del Fondo sociale europeo, amministrate negli esercizi antecedenti la programmazione comunitaria 1989-1993 dei Fondi strutturali dal Ministero del lavoro e della previdenza sociale tramite la gestione fuori bilancio del Fondo di rotazione istituito dall'articolo 25 della legge 21 dicembre 1978, n. 845, e successive modificazioni, possono essere destinati alla copertura di oneri derivanti dalla responsabilita' sussidiaria dello Stato membro ai sensi della normativa comunitaria in materia.

16. Il Ministero del lavoro e della previdenza sociale, con proprio decreto, destina nell'ambito delle risorse di cui all'articolo 68, comma 4, lettera a), della legge 17 maggio 1999, n. 144, una quota fino a lire 200 miliardi, per l'anno, di 100 milioni di euro per ciascuno degli anni 2003, 2004, 2005, 2006 e 2007 e di 80 milioni di euro per ciascuno degli anni 2008 e 2009 , nonche' di 100 milioni di euro per ciascuno degli anni 2010 e 2011, di cui il 20 per cento destinato prioritariamente all' attuazione degli articoli 48 e 50 del decreto legislativo 10 settembre 2003, n. 276, e successive modificazioni, per le attivita' di formazione nell'esercizio dell'apprendistato anche se svolte oltre il compimento del diciottesimo anno di eta', secondo le modalita' di cui all'articolo 16 della legge 24 giugno 1997, n. 196. (25)

------------- AGGIORNAMENTO (13) La L. 28 dicembre 2001, n. 448 ha disposto (con l'art. 52, comma 19) che sono prorogati per l'anno 2002 gli interventi previsti dal comma 9 del presente articolo entro il limite massimo di 21 milioni di euro. ------------ AGGIORNAMENTO (25) Successivamente la Corte Costituzionale, con sentenza 13 - 28 gennaio 2005, n.51 (in G.U. 1a s.s. 02/02/2005, n. 5), ha dichiarato l'illegittimita' costituzionale dell'art. 48 della L. 27 dicembre 2002, n. 289 (che ha modificato i commi 1, 2, 3, 6, 8 e 12 e ha abrogato il comma 7) "nella parte in cui non prevede strumenti idonei a garantire una leale collaborazione fra Stato e Regioni".

### Art. 119. - (Potenziamento dell'attivita' ispettiva del Ministero del lavoro e della previdenza sociale)

1. Al fine di potenziare l'attivita' ispettiva nelle materie di competenza con particolare riferimento alle disposizioni concernenti la sicurezza e salute dei lavoratori sui luoghi di lavoro, il Ministero del lavoro e della previdenza sociale, in deroga a quanto previsto dall'articolo 39 della legge 27 dicembre 1997, n. 449, e successive modificazioni, e' autorizzato ad assumere mille unita' di personale nei ruoli ispettivi di cui seicento nel 2001 e quattrocento nel 2002.

2. E' prorogata di ulteriori dodici mesi la validita' della graduatoria del concorso espletato dal Ministero del lavoro e della previdenza sociale di cui al decreto dirigenziale 3 giugno 1997 per il profilo professionale di ispettore del lavoro.

3. L'articolo 79, comma 2, della legge 23 dicembre 1998, n. 448, e' sostituito dal seguente: "2. Al medesimo fine di cui al comma 1 una quota pari al 10 per cento dell'importo proveniente dalla riscossione delle sanzioni penali e amministrative comminate dalle Direzioni provinciali del lavoro - servizio ispezione del lavoro per le violazioni delle leggi sul lavoro e' destinata per il 50 per cento a corsi di formazione e di aggiornamento del personale da assegnare al predetto servizio e per l'acquisto dei dispositivi di protezione individuale, delle attrezzature, degli strumenti e degli apparecchi indispensabili per lo svolgimento dell'attivita' ispettiva e delle relative procedure ad essa connesse. Il restante 50 per cento della quota predetta e' destinato all'incremento del Fondo unico di amministrazione, di cui al contratto collettivo integrativo di lavoro relativo al personale del Ministero del lavoro e della previdenza sociale, per l'incentivazione dell'attivita' ispettiva di controllo sulle condizioni di lavoro nelle aziende".

4. La tenuta dei libri matricola e paga puo' altresi' avvenire mediante l'utilizzo di fogli mobili. Le condizioni e le modalita' di detta tenuta sono stabilite con apposito decreto del Ministro del lavoro e della previdenza sociale.

### Art. 120. - (Riduzione degli oneri sociali)

1. Nell'ambito del processo di armonizzazione delle forme di contribuzione e della disciplina relative alle prestazioni temporanee a carico della gestione di cui all'articolo 24 della legge 9 marzo 1989, n. 88, e in attuazione del programma di riduzione del costo del lavoro stabilito dal Patto sociale per lo sviluppo e l'occupazione del dicembre 1998, a decorrete dal 1° febbraio 2001 e' riconosciuto ai datori di lavoro un esonero dal versamento dei contributi sociali per assegni per il nucleo familiare dovuti dai medesimi alla predetta gestione pari a 0,8 punti percentuali.

2. In via aggiuntiva rispetto a quanto riconosciuto in applicazione del comma 1, nei confronti dei datori di lavoro operanti nei settori per i quali l'aliquota contributiva per assegni per il nucleo familiare e' dovuta in misura inferiore a 0,8 punti percentuali, e' riconosciuto un ulteriore esonero nella misura di 0,4 punti percentuali a valere sui versamenti di altri contributi sociali dovuti dai medesimi datori di lavoro alla gestione di cui al medesimo comma 1, prioritariamente considerando i contributi per maternita' e per disoccupazione. In ogni caso il complessivo esonero non puo' superare la misura di 0,8 punti percentuali.

3. All'articolo 3, comma 9, della legge 23 dicembre 1998, n. 448, le parole: "31 dicembre 2000" sono sostituite dalle seguenti: "31 dicembre 2001".

## INTERVENTI IN MATERIA DI AGRICOLTURA

### Art. 121. - (Interventi per la ristrutturazione delle imprese agricole in difficolta')

1. A favore delle imprese agricole, singole ed associate e cooperative, iscritte nel registro delle imprese di cui all'articolo 8 della legge 29 dicembre 1993, n. 580, danneggiate da calamita' o da eventi eccezionali conseguenti a gravi crisi di mercato ovvero in difficolta', e' istituito un programma di interventi per il salvataggio e la ristrutturazione in grado di favorire il ripristino della redditivita', in conformita' con gli orientamenti comunitari sugli aiuti di Stato per il salvataggio e la ristrutturazione di imprese in difficolta' di cui alla comunicazione della Commissione delle Comunita' europee 97/C283/02, pubblicata nella Gazzetta Ufficiale delle Comunita' europee C283 del 19 settembre 1997, e successive modificazioni.

2. Alle imprese di cui al comma 1 e' concesso il concorso nel pagamento degli interessi, nella misura massima del 3 per cento ed entro il limite di impegno di lire 40 miliardi, sui mutui di ammortamento a quindici anni, di cui tre di preammortamento, contratti per il salvataggio e la ristrutturazione delle imprese medesime, anche in relazione ad esposizioni debitorie verso enti pubblici operanti nei settori dell'assistenza e della previdenza.

3. I mutui di cui al comma 2 sono considerati operazioni di credito agrario ai sensi dell'articolo 43 del decreto legislativo 1° settembre 1993, n. 385, e possono essere assistiti dalla garanzia fideiussoria della sezione speciale del Fondo interbancario di garanzia di cui all'articolo 45 dello stesso decreto legislativo, ad integrazione delle garanzie ritenute idonee dalle banche mutuanti. Detta garanzia fideiussoria potra' impegnare una quota non superiore all'80 per cento delle dotazioni finanziarie della sezione speciale.

4. I mutui sono concessi a condizione che il richiedente presenti alla banca un piano finalizzato al ripristino della redditivita' dell'impresa, e che comprenda i seguenti elementi: riorganizzazione, razionalizzazione e riqualificazione delle attivita' aziendali, con abbandono di quelle non redditizie; riduzione delle produzioni soggette il ritiro; riconversione verso produzioni di qualita' che tutelino e migliorino l'ambiente naturale.

5. L'importo dei mutui puo' essere ragguagliato all'intera spesa ritenuta ammissibile dalla banca a seguito della compiuta istruttoria. Gli interessi di preammortamento vengono capitalizzati e corrisposti unitamente alle singole rate di ammortamento.

6. Gli interventi per la ristrutturazione delle imprese agricole, nei limiti dello stanziamento di cui al comma 2, possono assumere, inoltre, le seguenti forme finalizzate, in ogni caso, ad assicurare ai beneficiari prospettive di redditivita' a lungo termine:

- a) conferimenti di capitale, cancellazione di esposizioni debitorie, erogazione di crediti, ovvero concessioni di garanzie su operazioni creditizie, secondo criteri e modalita' stabiliti con decreto del Ministro delle politiche agricole e forestali;
- b) riduzione della base imponibile ai fini dell'imposta sul reddito delle persone fisiche e dell'imposta sul reddito delle persone giuridiche nella misura del 30 per cento;
- c) esonero parziale dal pagamento dei contributi previdenziali e assistenziali nella misura del 30 per cento.

7. Nel caso di imprese individuali, nel valutare lo stato della difficolta' finanziaria, si tiene conto di tutti i beni appartenenti ai soggetti che esercitano l'attivita' di impresa, anche quando tali beni non riguardino l'esercizio di attivita' agricola.

8. Nei confronti delle imprese di cui al comma 1, sono sospesi, sino alla stipula dei mutui ovvero della concessione delle misure di ristrutturazione, i termini, di pagamento delle rate delle operazioni creditizie in scadenza entro il 30 giugno 2001.

### Art. 122. - (Interventi per agevolare la raccolta di prodotti agricoli)

1. In sede di sperimentazione e per un periodo non superiore a due anni, i coltivatori diretti iscritti agli elenchi provinciali possono avvalersi per la raccolta di prodotti agricoli, in deroga alla normativa vigente, di collaborazioni occasionali di parenti ed affini entro il quinto grado per un periodo complessivo nel corso dell'anno non superiore a tre mesi.

### Art. 123. - (Promozione e sviluppo delle aziende agricole e zootecniche biologiche)

1. All'articolo 59 della legge 23 dicembre 1999, n. 488, sono apportate le seguenti modificazioni:

- a) il comma 1 e' sostituito dai seguenti: "1. Al fine di promuovere lo sviluppo di una produzione agricola di qualita' ed eco-compatibile e di perseguire l'obiettivo prioritario di riduzione dei rischi per la salute degli uomini e degli animali e per l'ambiente, a decorrere dal 1° gennaio 2001 e' istituito un contributo annuale per la sicurezza alimentare nella misura del 2 per cento del fatturato dell'anno precedente relativo alla vendita di prodotti fitosanitari, autorizzati ai sensi degli articoli 5, 8 e 10 del decreto legislativo 17 marzo 1995, n. 194, dei fertilizzanti da sintesi, da individuare con i decreti di cui al presente comma, e dei presidi sanitari di cui all'articolo 1 del regolamento approvato con decreto del Presidente della Repubblica 3 agosto 1968, n. 1255, ed etichettati con le sigle: R62, R60, R50, R49, R45, R40, R33, R28, R27, R26, R25, R24, R23. Con decreti dei Ministri della sanita' e delle politiche agricole e forestali, da emanare entro il 31 dicembre di ciascun anno, e' determinato ed aggiornato l'elenco dei prodotti di cui al presente comma. 1-bis. Sono tenuti al versamento del contributo di cui al comma 1 i titolari delle autorizzazioni all'immissione in commercio dei prodotti di cui al medesimo comma 1, in base al relativo fatturato di vendita. 1-ter. E' vietata la somministrazione agli animali da allevamento di mangimi contenenti proteine derivanti da tessuti animali incompatibili con l'alimentazione naturale ed etologica delle singole speci. Negli allevamenti ittici e' consentita la somministrazione di mangimi contenenti proteine di pesce. Con decreto del Ministro della sanita', di concerto. con il Ministro delle politiche agricole e forestali, da emanare entro tre mesi dalla data di entrata in vigore della presente disposizione, sono definiti i criteri e le disposizioni per l'attuazione del presente comma";
- b) il comma 2 e' sostituito dai seguenti: "2. E' istituito il fondo per lo sviluppo dell'agricoltura biologica e di qualita', alimentato dalle entrate derivanti dai contributi di cui al comma 1, nonche' da un contributo statale pari a lire 15 miliardi per ciascun anno del triennio 2001-2003. Detto fondo e' finalizzato al finanziamento di programmi annuali, nazionali e regionali, concernenti: a) il sostegno allo sviluppo della produzione agricola biologica mediante incentivi agli agricoltori e agli allevatori che attuano la riconversione del metodo di produzione, nonche' mediante adeguate misure di assistenza tecnica e codici di buona pratica agri cola per un corretto uso dei prodotti fitosanitari; il Ministro delle politiche agricole e forestali, con decreto da emanare entro sessanta giorni dalla data di entrata in vigore della presente disposizione, determina le modalita' di erogazione degli incentivi e la tipologia delle spese ammissibili; b) il potenziamento dell'attivita' di ricerca e di sperimentazione in materia di agricoltura biologica, nonche' in materia di sicurezza e salubrita' degli alimenti; c) l'informazione dei consumatori sugli alimenti ottenuti con metodi di produzione biologica, sugli alimenti tipici e tradizionali, nonche' su quelli a denominazione di origine protetta. 2-bis. Il fondo di cui al comma 2 e' ripartito annualmente, entro il 31 dicembre di ciascun anno, con decreto del Ministro delle politiche agricole e forestali, sentiti gli assessori all'agricoltura delle regioni nell'ambito di un'apposita conferenza di servizi, ai sensi dell'articolo 14 della legge 7 agosto 1990, n. 241, e successive modificazioni, sulla base: a) delle proposte di programmi regionali che gli assessori all'agricoltura possono presentare al Ministero delle politiche agricole e forestali entro il 30 ottobre di ciascun anno; b) delle priorita' stabilite al comma 2";
- c) dopo il comma 3 sono inseriti i seguenti: "3-bis. Le attivita' di ricezione e di ospitalita', compresa la degustazione dei prodotti aziendali e l'organizzazione di attivita' ricreative, culturali e didattiche svolte da aziende agricole nell'ambito della diffusione di prodotti agricoli biologici o di qualita', possono essere equiparate ai sensi di legge alle attivita' agrituristiche di cui all'articolo 2 della legge 5 dicembre 1985, n. 730, secondo i principi in essa contenuti e secondo le disposizioni emanate dalle regioni o dalle province autonome. 3-ter. In deroga alle disposizioni vigenti e' consentita ai produttori di prodotti a denominazione di origine protetta (DOP), a indicazione geografica protetta (IGP) e con attestazione di specificita' (AS), di cui ai regolamenti (CEE) n. 2081/92 e n. 2082/92 del Consiglio, del 14 luglio 1992, ivi compresi i prodotti ammessi a tutela provvisoria, la presentazione, la degustazione e la vendita, anche per via telematica, secondo disposizioni emanate dalle regioni o dalle province autonome. Al comma 8 dell'articolo 10 della legge 21 dicembre 1999, n. 526, dopo le parole "la vendita diretta" sono inserite le seguenti: "anche per via telematica""; d) dopo il comma 4 e' inserito il seguente: "4-bis. Presso il Ministero delle politiche agricole e forestali e' istituito un comitato per la valorizzazione e la tutela del patrimonio alimentare italiano, con il compito di censire le lavorazioni alimentari tipiche italiane, nonche' di tutelarle, valorizzarle e diffonderne la conoscenza in Italia e nel mondo. Del comitato fanno parte esperti di settore, rappresentanti delle categorie produttive, delle regioni e delle amministrazioni interessate. Con decreto del Ministro delle politiche agricole e forestali sono dettate le regole relative alla composizione ed al funzionamento del Comitato, che svolge anche le funzioni e le attivita' del comitato di cui ai commi 3, 4 e 5 dell'articolo 8 del decreto legislativo 30 aprile 1998, n. 173, che e' soppresso".

2. In sede di prima applicazione il primo decreto di cui al comma 1, secondo periodo, dell'articolo 59 della legge 23 dicembre 1999, n. 488, come sostituito dal comma 1, lettera a), del presente articolo, e' emanato entro trenta giorni dalla data di entrata in vigore della presente legge.

### Art. 124. - (Patti territoriali specializzati nei settori dell'agricoltura e della pesca)

1. Il Ministero del tesoro, del bilancio e della programmazione economica approva i patti territoriali specializzati nei settori dell'agricoltura e della pesca pervenuti entro la scadenza del bando del 15 maggio 2000, che hanno positivamente superato l'istruttoria, e ne finanzia le iniziative imprenditoriali nell'ambito delle risorse per le aree depresse e per le intese istituzionali di programma. Le regioni possono finanziare le iniziative infrastrutturali proposte negli stessi patti. ((Per tali patti, per i quali sia stato emanato il decreto di approvazione da parte del Ministro competente, il finanziamento pubblico riguarda tutte le iniziative imprenditoriali ed infrastrutturali previste da ciascun patto, anche se le stesse sono attuabili parzialmente all'esterno delle aree classificate depresse)).

### Art. 125. - (Disposizioni per il settore agricolo)

1. All'articolo 4, comma 11, del decreto-legge 7 settembre 1987, n. 370, convertito, con modificazioni, dalla legge 4 novembre 1987, n. 460, e successive modificazioni, il secondo periodo e' sostituito dai seguenti: "L'inosservanza dell'obbligo di consegna del vino alla distillazione previsto dall'articolo 39 del regolamento (CEE) n. 822/87, del Consiglio, del 16 marzo 1987, e dal regolamento (CEE) n. 854/96 della Commissione, del 24 marzo 1986, e successive modificazioni, comporta, a decorrere dalla campagna 1988-1989, l'applicazione della sanzione amministrativa di lire diciottomila per quintale, o frazione di quintale, di vino da avviare alla distillazione obbligatoria. Gli importi della sanzione di cui al periodo precedente possono essere versati in non piu' di dieci rate semestrali. Nell'ambito delle risorse recuperate. ai sensi del periodo precedente, e comunque nel limite massimo di un onere per il bilancio dello Stato non superiore a lire 5 miliardi, ai produttori di vino che, non avendo conferito alla distillazione obbligatoria i quantitativi cui erano tenuti, hanno pagato le sanzioni in misura maggiore del citato importo di lire diciottomila, sono restituite le somme versate in eccedenza, maggiorate degli interessi legali. Non si da' seguito alle riscossioni coattive su ruoli esattoriali e i pignoramenti in essere, derivanti da precedenti sanzioni comminate ma non pagate, qualora il produttore versi la predetta sanzione, ai sensi del presente comma".

2. All'articolo 53, comma 18, della legge 24 aprile 1998, n. 128, come sostituito dall'articolo 14 della legge 21 dicembre 1999, n. 526, le parole: "un anno" sono sostituite dalle seguenti: "due anni".

### Art. 126. - (Garanzie a favore di cooperative agricole)

1. A titolo di riconoscimento di somme gia' maturate e dovute per le finalita' di cui all'articolo 1, comma 1-bis, del decreto-legge 20 maggio 1993, n. 149, convertito, con modificazioni, dalla legge 19 luglio 1993, n. 237, e' autorizzata la spesa di lire 230 miliardi per l'anno 2001, fermo restando lo stanziamento finanziario gia' previsto dal citato articolo 1, comma 1-bis.

2. Il pagamento da parte dello Stato delle garanzie ammesse per le finalita' di cui all'articolo 1, comma 1-bis, del decreto-legge 20 maggio 1993, n. 149, convertito, con modificazioni, dalla legge 19 luglio 1993, n. 237, e' effettuato secondo l'ordine stabilito nell'elenco n. 1 di cui al decreto del Ministero delle risorse agricole, alimentari e forestali 18 dicembre 1995, pubblicato nel supplemento ordinario n. 1 alla Gazzetta Ufficiale n. 1 del 2 gennaio 1996, e sulla base dei criteri contenuti nel decreto del Ministero delle risorse agricole, alimentari e forestali 2 febbraio 1994, pubblicato nella Gazzetta Ufficiale n. 39 del 17 febbraio 1994, salve le successive modifiche conseguenti a pronunce definitive in sede amministrativa o giurisdizionale.

3. L'intervento dello Stato, ai sensi dell'articolo 1, comma 1-bis, del decreto-legge 20 maggio 1993, n. 149, convertito, con modificazioni, dalla legge 19 luglio 1993, n. 237, nei confronti di soci, come individuati ai sensi del comma 2 del presente articolo, che abbiano rilasciato garanzie, individualmente o in solido con altri soci di una stessa cooperativa, determina la liberazione di tutti i soci garanti.

((3-bis. Resta salvo il diritto dello Stato di ripetere quanto corrisposto a seguito dell'intervento, nei confronti dei soci che abbiano comunque contribuito alla insolvenza della cooperativa o che in ogni caso non abbiano titolo a beneficiare dell'intervento, subentrando nelle relative garanzie))

4. Le procedure esecutive nei confronti dei soci garanti, inseriti nell'elenco di cui al comma 2, per l'escussione delle garanzie sono sospese sino alla comunicazione da parte dell'amministrazione della messa a disposizione della somma spettante.

5. Subordinatamente alle cooperative ammesse a godere dei benefici previsti dall'articolo 1, comma 1-bis, del decreto-legge 20 maggio 1993, n. 149, convertito, con modificazioni, dalla legge 19 luglio 1993, n. 237, possono essere ammessi a godere degli stessi benefici le cooperative ed i consorzi tra cooperative che alla data del 19 luglio 1993 si trovavano nelle condizioni previste dal suddetto articolo, che abbiano presentato domanda entro i termini previsti dalla citata legge, per i quali sia intervenuta, almeno in primo grado, la pronuncia da parte del tribunale attestante lo stato di insolvenza oppure che si trovino in stato di liquidazione. Le procedure esecutive nei confronti dei soci garanti per l'escussione delle garanzie sono sospese sino alla comunicazione da parte dell'amministrazione della messa a disposizione della somma spettante.

### Art. 127. - (Nuove norme procedurali in materia di assicurazioni agricole agevolate)

1. COMMA ABROGATO DAL D.LGS. 29 MARZO 2004, N. 102.

2. I contratti di assicurazione di cui all'articolo 1 del decreto del Presidente della Repubblica 17 maggio 1996, n. 324, che possono essere stipulati anche da cooperative e loro consorzi, autorizzate dalle regioni in cui hanno la sede legale, possono riguardare anche la copertura della produzione complessiva aziendale danneggiata dall'insieme delle avversita' atmosferiche. I consorzi, le cooperative e loro consorzi nei limiti delle previsioni statutarie, possono istituire fondi rischi di mutualita' ed assumere iniziative per azioni di mutualita' e solidarieta' da attivare in caso di danni alle produzioni degli associati. Il concorso dello Stato per la costituzione e la dotazione finanziaria annuale del fondo e' contenuto nei limiti dei parametri contributivi stabiliti per i contratti assicurativi, applicati ai valori delle produzioni garantite dal fondo stesso e non deve superare l'importo versato dal socio aderente alle azioni di mutualita' e solidarieta'. Le modalita' operative e gestionali del fondo sono stabilite con decreto del Ministro delle politiche agricole e forestali, d'intesa con la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano. Entro il 31 gennaio di ogni anno il Ministro delle politiche agricole e forestali, d'intesa con la medesima Conferenza permanente, con proprio decreto, stabilisce la quota di stanziamento per la copertura dei rischi agricoli da destinare alle azioni di mutualita' e solidarieta'.

3. I valori delle produzioni assicurabili con polizze agevolate sono stabiliti con decreto del Ministro delle politiche agricole e forestali, da adottare entro il 31 dicembre di ogni anno, per l'anno successivo sulla base delle rilevazioni dei prezzi unitari di mercato alla produzione, effettuate dall'Istituto per studi, ricerche e informazioni sul mercato agricolo (ISMEA). Al fine di sostenere la competitivita' delle imprese e favorire la riduzione delle conseguenze dei rischi atmosferici, e' istituito presso l'ISMEA un fondo per la riassicurazione dei rischi. Con decreto del Ministro delle politiche agricole e forestali, sentita la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, sono fissate le modalita' operative del fondo. ((54))

4. COMMA ABROGATO DAL D.LGS. 29 MARZO 2004, N. 102.

5. COMMA ABROGATO DAL D.LGS. 29 MARZO 2004, N. 102.

6. COMMA ABROGATO DAL D.LGS. 29 MARZO 2004, N. 102.

7. COMMA ABROGATO DAL D.LGS. 29 MARZO 2004, N. 102.

8. COMMA ABROGATO DAL D.LGS. 29 MARZO 2004, N. 102.

9. Le spese derivanti dall'attuazione del presente articolo, sono comprese nell'ambito degli stanziamenti annuali di cui alla legge 14 febbraio 1992, n. 185.

------------- AGGIORNAMENTO (54) Il D.Lgs. 18 aprile 2008, n. 82 ha disposto (con l'art. 2, comma 1) che "Al fine di sostenere la competitivita' delle imprese agricole e di favorire la riduzione delle conseguenze derivanti dai rischi atmosferici e di mercato, la dotazione del fondo di cui all'articolo 127, comma 3, della legge 23 dicembre 2000, n. 388, e' incrementata, per l'anno 2008, della somma di 30 milioni di euro".

### Art. 128. - (Disposizioni in materia di credito agrario)

1. Il comma 3 dell'articolo 5 del decreto legislativo 30 aprile 1998, n. 173, e' sostituito dal seguente: "3. I mutui di miglioramento agrario e fondiari stipulati alla data di entrata in vigore del presente decreto legislativo a favore di imprese agricole singole o associate, cooperative, consorzi ed associazioni di produttori costituite nelle forme giuridiche societarie, e per i quali siano trascorsi almeno cinque anni di ammortamento, continuano a beneficiare delle rate di concorso sul pagamento degli interessi non maturati, anche in fase di estinzione anticipata dell'operazione. E' facolta' del mutuatario richiedere la rinegoziazione dei mutui senza effetti novativi, con la riduzione dell'ipoteca originaria, ovvero l'estinzione anticipata all'istituto mutuante. Quest'ultimo, all'accoglimento dell'istanza, assicura al mutuatario la ricontrattazione con il beneficio della attualizzazione delle rate di concorso non ancora scadute. Il contributo in conto interessi gia' accreditato agli istituti mutuanti in forma attualizzata al sensi del decreto del Presidente del Consiglio dei Ministri 29 novembre 1985, pubblicato nella Gazzetta Ufficiale n. 284 del 3 dicembre 1985, sara' comunque riconosciuto al mutuatario nella misura residuata a suo credito. Per i suddetti contratti, il periodo vincolativo della destinazione d'uso dei beni immobili oggetto del finanziamento e' stabilito in cinque anni. Il valore massimo del tasso da prendere in considerazione, nella procedura di attualizzazione o di ricontrattazione, e' quello di riferimento, vigente per le operazioni a lungo termine al momento dell'estinzione anticipata o della ricontrattazione del mutuo".

2. Per le operazioni di finanziamento in essere della Cassa per la formazione della proprieta' contadina e per i finanziamenti concessi ai sensi della legge 19 dicembre 1983, n. 700, e successive modificazioni, per i quali sia iniziato il periodo di ammortamento, il tasso e le condizioni applicati, a valere sulle rate di ammortamento in scadenza successivamente al 1° gennaio 1999, sono quelli stabiliti per le nuove operazioni.

3. A favore delle imprese di cui al comma 3 dell'articolo 5 del decreto legislativo 30 aprile 1998, n. 173, come sostituito dal comma 1 del presente articolo, e di quelle agro-alimentari danneggiate da avversita' atmosferiche dichiarate eccezionali a decorrere dal 1990, ai sensi delle leggi 15 ottobre 1981, n. 590, e 14 febbraio 1992, n. 185, e' prorogato di ventiquattro mesi il pagamento delle rate in scadenza dovute per il rimborso delle esposizioni debitorie relative all'esercizio dell'attivita' aziendale e sono sospese per il medesimo periodo le procedure di riscossione delle rate gia' scadute e non pagate alla data di entrata in vigore della presente legge. Il tasso di interesse rinegoziato si applica anche alle rate prorogate.

4. Le rate gia' assistite dal concorso pubblico nel pagamento degli interessi conservano l'agevolazione anche nel periodo di proroga e di sospensione. L'onere finanziario e' coperto dalle economie accertate nella rinegoziazione dei tassi e comunque nel limite di queste, senza ulteriore onere per il bilancio dello Stato.

5. Le regioni possono deliberare il consolidamento delle posizioni debitorie delle aziende di cui al comma 3 scadute e non pagate, gia' assistite dal concorso pubblico nel pagamento degli interessi, nel limite delle economie derivanti dalla rinegoziazione dei tassi, senza oneri ulteriori a carico dei bilanci regionali. La durata delle operazioni di consolidamento e' variabile in relazione alle disponibilita' finanziarie.

6. Entro ((il 31 marzo 2003)), il Ministro del tesoro, del bilancio e della programmazione economica, di concerto con il Ministro delle politiche agricole e forestali, emana con proprio decreto, le norme di attuazione del presente articolo.

### Art. 129. - (Emergenze nel settore agricolo e zootecnico)

1. Per fare fronte alle emergenze determinatesi nel settore agricolo e zootecnico, a seguito delle malattie e della crisi di mercato da esse determinata, con decreto del Ministro delle politiche agricole e forestali, da emanare entro trenta giorni dalla data di entrata in vigore della presente legge, sono stabilite le modalita' per l'attivazione degli interventi in base ai seguenti tetti di spesa:

- a) interventi strutturali e di indennizzo per assicurare l'agibilita' degli allevamenti bovini che operano nella linee vacca-vitello, nonche' di prevenzione in allevamenti di bovini e ovini, in zone di protezione di sorveglianza istituite dall'autorita' sanitaria a seguito della accertata presenza di influenza catarrale dei ruminanti: euro 10.329.138 per ciascuno degli anni 2002 e 2003;
- a-bis) interventi strutturali e di sostegno per fronteggiare le conseguenze della malattia scrapie negli allevamenti ovini: 2,5 milioni di euro;
- b) interventi strutturali e di prevenzione dalla encefalopatia spongiforme bovina negli allevamenti anche con riguardo al sostegno dei sistemi di tracciabilita', nonche' alle razze da carne italiana e delle popolazioni bovine autoctone: lire 10 miliardi per il 2001 e 20 miliardi per ciascuno degli anni 2002 e 2003;
- c) interventi strutturali e di prevenzione ((e di indennizzo)) negli impianti avicoli e di fauna selvatica colpiti dall'influenza aviaria: lire 20 miliardi per il 2001 e 30 miliardi per ciascuno degli anni 2002 e 2003;
- d) interventi strutturali negli impianti viticoli colpiti da flavescenza dorata: lire 20 miliardi per il 2001 e 25 miliardi per ciascuno degli anni 2002 e 2003;
- e) interventi per fronteggiare gli eventi eccezionali conseguenti alla grave crisi di mercato degli agrumi: lire 6 miliardi per il 2001 e 25 miliardi per ciascuno degli anni 2002 e 2003;
- f) interventi strutturali negli impianti frutticoli colpiti dalla malattia della sharka: lire 5 miliardi per ciascuno degli anni 2001 e 2002.

2. All'articolo 1 del decreto-legge 4 febbraio 2000, n. 8, convertito. con modificazioni, dalla legge 7 aprile 2000, n. 79, il quarto periodo del comma 5 e' sostituito dal seguente: "Gli acquirenti, in luogo della materiale trattenuta del prelievo supplementare sul prezzo del latte, possono avvalersi di idonee garanzie immediatamente esigibili con i criteri e le modalita' da definire con decreto del Ministro delle politiche agricole e forestali, di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, sentita la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, pena le sanzioni previste dall'articolo 11, comma 2, della legge 26 novembre 1992, n. 468, e l'eventuale revoca del riconoscimento di primo acquirente, ferma restando la responsabilita' dello stesso per il versamento del prelievo".

### Art. 130. - (Modifiche alla legge 28 ottobre 1999, n. 410, ed altre disposizioni in materia di consorzi agrari)

1. Alla legge 28 ottobre 1999, n. 410, sono apportate le seguenti modificazioni:

- a) all'articolo 4, comma 1, e' aggiunto, in fine, il seguente periodo: "II Ministero del lavoro e della previdenza sociale e' tenuto ad inviare una informativa semestrale al Ministero delle politiche agricole e forestali sulla gestione dei consorzi agrari, anche ai fini di cui all'articolo 11";
- b) all'articolo 8, comma 1, e' aggiunto, in fine, il seguente periodo: "Gli interessi di cui al presente comma sono calcolati: fino al 31 dicembre 1995 sulla base del tasso ufficiale di sconto maggiorato di 4,40 punti, con capitalizzazione annuale; per gli anni 1996 e 1997 sulla base dei soli interessi legali".

2. I trattamenti recante sussidi al reddito per i lavoratori dipendenti dai Consorzi agrari possono essere prorogati nel limite massimo di lire 30 miliardi, secondo criteri e modalita' stabiliti con decreto del Ministero del lavoro e della previdenza sociale, fino al 31 dicembre 2001.

## INTERVENTI IN MATERIA DI TRASPORTI E DI INFRASTRUTTURE VARIE

### Art. 131. - (Disposizioni in materia di trasporto ferroviario e di applicazione della normativa vigente in materia di appalti ferroviari)

1. Al fine di garantire il contenimento delle tariffe e il risanamento finanziario delle attivita' di trasporto ferroviario, il Ministro dei trasporti e della navigazione puo' rilasciare titoli autorizzatori ai soggetti in possesso dei requisiti previsti dal decreto del Presidente della Repubblica 16 marzo 1999, n. 146, anche in deroga a quanto disposto dagli articoli 1, comma 1, lettera a), e 3, comma 1, lettera a), del medesimo decreto, a condizione di reciprocita' qualora si tratti di imprese aventi sede all'estero o loro controllate; puo' altresi' autorizzare la societa' Ferrovie dello Stato Spa e le aziende in concessione ad effettuare operazioni in leasing per l'approvvigionamento d'uso di materiale rotabile. Gli articoli 14 e 18 del decreto-legge 11 luglio 1992, n. 333, convertito con modificazioni, dalla legge 8 agosto 1992, n. 359, si applicano per la parte concernente l'infrastruttura ferroviaria e cessano di applicarsi al trasporto ferroviario. La societa' Ferrovie dello Stato Spa delibera le conseguenti modifiche statutarie.

2. ((COMMA ABROGATO DALLA L. 1 AGOSTO 2002, N. 166)).

3. Al fine di garantire la sollecita conclusione dei lavori relativi alla tratta ferroviaria ad alta capacita' Torino-Milano approvati nella conferenza di servizi tenutasi il 14 luglio 2000 ed il contenimento dei costi di realizzazione, anche in relazione alle esigenze connesse allo svolgimento delle Olimpiadi invernali del 2006, il Ministro dei trasporti e della navigazione entro i quindici giorni successivi alla data di entrata in vigore della presente legge istituisce l'Osservatorio permanente per il monitoraggio dei lavori relativi alla medesima tratta ferroviaria, composto da sei componenti, di cui uno nominato dal Ministro del tesoro, del bilancio e della programmazione economica e cinque nominati dal Ministro dei trasporti e della navigazione e designati, rispettivamente, dal Ministro medesimo, dal presidente della regione Lombardia, dal presidente della regione Piemonte, dalla TAV Spa e dal General Contractor affidatario della progettazione esecutiva e dei lavori di costruzione. Ai componenti non spetta alcun compenso. I servizi di segreteria dell'Osservatorio sono assicurati dal Ministero dei trasporti e della navigazione nell'ambito delle ordinarie dotazioni organiche e finanziarie. Ai lavori di cui al presente comma non si applicano le disposizioni del comma 2.

4. ((COMMA ABROGATO DALLA L. 1 AGOSTO 2002, N. 166)).

5. Tutte le operazioni di ristrutturazione della societa' Ferrovie dello Stato Spa effettuate a decorrere dal 1° gennaio 2000 in esecuzione delle direttive comunitarie 91/440/CEE, 95/18/CE e 95/19/CE, cosi' come recepite dal decreto del Presidente della Repubblica 8 luglio 1998, n. 277, e successive modificazioni, e dal decreto del Presidente della Repubblica 16 marzo 1999, n. 146, nonche' della direttiva del Presidente del Consiglio dei ministri del 18 marzo 1999, pubblicata nella Gazzetta Ufficiale n. 113 del 17 maggio 1999, sono effettuate in regime di neutralita' fiscale e pertanto escluse da ogni imposta e tassa. Gli eventuali maggiori valori realizzati o iscritti, in conseguenza delle predette operazioni, nei bilanci delle societa' interessate non sono riconosciuti ai fini delle imposte sui redditi e dell'imposta regionale sulle attivita' produttive.

### Art. 132. - (Disposizioni in materia di concessioni autostradali)

1. L'articolo 12 della legge 12 agosto 1982, n. 531, e' abrogato.

2. La garanzia dello Stato sui mutui contratti e le obbligazioni emesse dalle societa' per azioni concessionarie per la costruzione e l'esercizio di autostrade di cui all'articolo 3 della legge 24 luglio 1961, n. 729, e successive modificazioni, deve intendersi riconosciuta solo per quei periodi nei quali e' risultata prevalente la partecipazione pubblica e per quelli in cui tale prevalenza e' venuta temporaneamente a mancare a causa delle trasformazioni o modificazioni di istituti di credito soci conseguenti alla applicazione della legge 30 luglio 1990, n. 218, nei limiti delle disponibilita' di bilancio del Fondo centrale di garanzia.

3. In sede di revisione delle concessioni autostradali, ai sensi dell'articolo 11 della legge 23 dicembre 1992, n. 498, il Ministro dei lavori pubblici, di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, e' autorizzato a consentire, nel rispetto dei principi di diritto comunitario, senza oneri per lo Stato, la rimodulazione dei debiti conseguenti ad interventi in qualsiasi epoca effettuati, con eventuali aumenti controllati delle tariffe e con una determinazione negoziata degli interessi, dal Fondo centrale di garanzia.

## INTERVENTI PER LA CONTINUITA' TERRITORIALE CON LA SICILIA

### Art. 133. - (Contributo per le spese di trasporto alle piccole e medie imprese siciliane)

1. E' concesso alle piccole e medie imprese agricole, estrattive e di trasformazione classificate dal decreto del Ministero dell'industria, del commercio e dell'artigianato del 18 settembre 1997, pubblicato nella Gazzetta Ufficiale n. 229 del 1° ottobre 1997, con sede legale e stabilimento operativo nel territorio della regione Sicilia, ad eccezione di quelle di distillazione dei petroli, un contributo, mediante credito d'imposta, per le spese di trasporto ferroviario, marittimo e aereo e combinato, nei limiti stabiliti dall'Unione europea in materia di aiuti di Stato. Il contributo e' concesso nei limiti del comma 2 del presente articolo per i prodotti provenienti dalle imprese site nel territorio della regione Sicilia e destinati al restante territorio comunitario. Per il 2001 il 20 per cento dello stanziamento complessivo di cui al comma 2 e' riservato al contributo per le spese di trasporto su gomma. A decorrere dal 2002 tale percentuale e' diminuita del 5 per cento per ciascun anno.

2. L'attuazione delle disposizioni di cui al comma 1 e' affidata alla regione Sicilia tramite apposita convenzione tra il Ministro delle finanze, il Ministro dei trasporti e della navigazione e il presidente della regione, da definire entro sessanta giorni dalla data di entrata in vigore della presente legge, con la quale si stabiliranno le modalita' per il trasferimento dei fondi dal bilancio statale alla regione Sicilia e l'entita' del cofinanziamento regionale dell'agevolazione di cui al presente articolo, che non dovra' comunque essere inferiore al 50 per cento del contributo statale. L'onere complessivo per il bilancio dello Stato non puo' superare l'importo di lire 25 miliardi per l'anno 2001, e di lire 50 miliardi a decorrere dall'anno 2002. ((36))

------------- AGGIORNAMENTO(36) La L. 30 dicembre 2004, n. 311 ha disposto (con l'art. 1, comma 528) che "In virtu' del combinato disposto dell'articolo 45, comma 14, della legge 23 dicembre 1998, n. 448, e dell'articolo 36 della legge della Regione siciliana 31 maggio 2004, n. 9, e successive modificazioni, i benefici di cui all'articolo 133 della legge 23 dicembre 2000, n. 388, si intendono trasferiti, alle medesime condizioni di cofinanziamento regionale ivi previste, all'articolo 134 della medesima legge n. 388 del 2000, nei limiti delle norme di contabilita' di Stato".

### Art. 134. - (Riqualificazione del settore trasporto merci nella regione Sicilia)

1. E' assegnata alla regione Sicilia la somma di lire 100 miliardi per l'anno 2001 per il cofinanziamento di interventi regionali di carattere straordinario per la ristrutturazione e la riqualificazione del settore del trasporto merci siciliano. Il contributo statale e' erogato subordinatamente alla verifica della coerenza degli interventi con gli obiettivi di cui al presente articolo. Il cofinanziamento regionale non dovra' essere inferiore al 30 per cento del contributo statale.

### Art. 135. - (Continuita' territoriale per la Sicilia)

1. Al fine di realizzare la continuita' territoriale per la Sicilia, in conformita' alle disposizioni di cui al ((regolamento (CE) n. 1008/2008 del Parlamento europeo e del Consiglio del 24 settembre 2008, il Ministro delle infrastrutture e dei trasporti)), entro sessanta giorni dalla data di entrata in vigore della presente legge, dispone con proprio decreto:

- a) l'imposizione degli oneri di servizio pubblico relativamente ai servizi aerei di linea effettuati tra gli scali aeroportuali della Sicilia e i Principali aeroporti nazionali e tra gli scali aeroportuali della Sicilia e quelli delle isole minori siciliane in conformita' alle conclusioni della conferenza di servizi di cui ai commi 2 e 3;
- b) qualora nessun vettore abbia istituito servizi di linea con assunzione di oneri di servizio pubblico, una gara di appalto europea per l'assegnazione delle rotte tra gli scali aeroportuali della Sicilia e gli aeroporti nazionali.

((2. Entro trenta giorni dalla data di entrata in vigore della presente disposizione, il Ministro delle infrastrutture e dei trasporti, d'intesa con il Presidente della Regione siciliana, indice una conferenza di servizi))

3. La conferenza di servizi di cui al comma 2 definisce i contenuti dell'onere di servizio in relazione:

- a) alle tipologie e ai livelli tariffari;
- b) ai soggetti che usufruiscono di agevolazioni;
- c) al numero dei voli;
- d) agli orari dei voli;
- e) alle tipologie degli aeromobili;
- f) alla capacita' dell'offerta;
- g) ((LETTERA ABROGATA DALLA L. 27 DICEMBRE 2019, N. 160)).

((4. Qualora nessun vettore accetti l'imposizione degli oneri di servizio pubblico di cui al comma 1, lettera a), il Ministro delle infrastrutture e dei trasporti, d'intesa con il Presidente della Regione siciliana, provvede all'affidamento mediante gara di appalto secondo la procedura di cui all'articolo 17 del regolamento (CE) n. 1008/2008 del Parlamento europeo e del Consiglio del 24 settembre 2008))

5. Ai sensi delle disposizioni vigenti, la decisione di imporre gli oneri di servizio pubblico relativi ai servizi aerei sulle rotte tra gli scali siciliani e nazionali e' comunicata all'Unione europea.

6. Per le compensazioni degli oneri di servizio pubblico accettati dai vettori conseguentemente all'esito della gara di appalto di cui al comma 4, sono stanziate lire 50 miliardi per l'anno 2001 e lire 100 miliardi a decorrere dall'anno 2002. ((99))

7. ((COMMA ABROGATO DALLA L. 27 DICEMBRE 2019, N. 160)).

-------------- AGGIORNAMENTO (99) La L. 27 dicembre 2019, n. 160, ha disposto (con l'art. 1, comma 709) che "L'autorizzazione di spesa di cui all'articolo 135, comma 6, della legge 23 dicembre 2000, n. 388, e' integrata di 25 milioni di euro per ciascuno degli anni 2021 e 2022".

### Art. 136. - (Oneri di pubblico servizio per i servizi aerei di linea)

1. Al fine di realizzare politiche di coesione tra le diverse aree del Paese, con riguardo ai servizi aerei di linea, il Ministro dei trasporti e della navigazione dispone, con proprio decreto, l'imposizione di oneri di pubblico servizio in conformita' alle disposizioni del regolamento (CEE) n. 2408/92 del Consiglio, del 23 luglio 1992, nelle regioni di cui all'obiettivo 1 di cui al regolamento (CE) n. 1260/1999 del Consiglio del 21 giugno 1999 e provvede a costituire le condizioni necessarie a determinare una effettiva riduzione delle tariffe dei servizi aerei di linea nelle predette regioni.

2. I contenuti dell'onere di pubblico servizio di cui al comma 1 sono determinati secondo le modalita' di cui ai commi 2 e 3 dell'articolo 36 della legge 17 maggio 1999, n. 144.

### Art. 137. - (Ulteriori erogazioni a favore della regione Sicilia)

1. Alla regione Sicilia e' assegnato un limite di impegno di 21 miliardi di lire della durata di quindici anni, corrispondente a un capitale mutuabile di almeno lire 200 miliardi, per interventi diretti a:

- a) contenere i consumi ed i costi energetici delle piccole e medie imprese;
- b) fronteggiare la crisi del settore agrumicolo;
- c) sostenere iniziative e investimenti nei comuni sede di impianti di raffinazione, estrazione e stoccaggio di prodotti petroliferi;

------------- AGGIORNAMENTO (31) La L. 24 dicembre 2003, n. 350 ha disposto (con l'art. 4, comma 148) che "Per l'attuazione della lettera c-bis) del comma 1 dell'articolo 137 della legge 23 dicembre 2000, n. 388, introdotta dal presente comma, e' autorizzata una ulteriore spesa pari a 25 milioni di euro per l'anno 2004".

## INTERVENTI DI PROTEZIONE CIVILE, DI RIASSETTO IDROGEOLOGICO, DI TUTELA DEL PATRIMONIO STORICO ARTISTICO

### Art. 138. - (Disposizioni relative a eventi calamitosi)

1. I soggetti colpiti dal sisma del 13 e 16 dicembre 1990, che ha interessato le province di Catania, Ragusa e Siracusa, individuati ai sensi dell'articolo 3 dell'ordinanza del 21 dicembre 1990, n. 2057, pubblicata nella Gazzetta Ufficiale n. 299 del 24 dicembre 1990, destinatari dei provvedimenti agevolativi in materia di versamento delle somme dovute a titolo di tributi e contributi, possono regolarizzare la propria posizione relativa agli anni 1990, 1991 e 1992, versando l'ammontare dovuto per ciascun tributo a titolo di capitale, al netto dei versamenti gia' eseguiti a titolo di capitale ed interessi, entro il 15 dicembre 2002. (31)

2. Le somme dovute ai sensi del comma 1 possono essere versate fino ad un massimo di dodici rate semestrali, di pari importo. La prima rata deve essere versata entro il termine di cui al comma 1.

3. Le somme dovute dai contribuenti di cui al comma 1, e non versate, sono recuperate mediante iscrizioni in ruoli da rendere esecutivi entro il 31 dicembre dell'anno successivo alla scadenza dell'ultima rata.

4. L'articolo 11 della legge 7 agosto 1997, n. 266, si interpreta nel senso che qualora il contribuente interessato non abbia pagato integralmente o non paghi una o piu' rate relative alla rateazione ai sensi del decreto del Ministro delle finanze e del Ministro del lavoro e della previdenza sociale del 31 luglio 1993, pubblicato nella Gazzetta Ufficiale n. 183 del 6 agosto 1993, e dell'articolo 25 del decreto-legge 23 giugno 1995, n. 244, convertito, con modificazioni, dalla legge 8 agosto 1995, n. 341, ha la possibilita' di versare la meta' delle stesse e di versare la restante meta' in altrettante rate, con decorrenza dall'ultima rata prevista globalmente per ciascuna tipologia di tributo o contributo. Le disposizioni dell'articolo 11 della legge 7 agosto 1997, n. 266, non si applicano alla procedura di cui al presente articolo.

5. Le modalita' di versamento delle somme di cui al comma 1 sono stabilite con decreto del Ministro dell'economia e delle finanze.

6. Per i versamenti dei tributi e contributi sospesi effettuati oltre le scadenze dei termini previsti, ma comunque entro il 1 gennaio 2002, non si da' luogo all'applicazione di sanzioni.

7. Le disposizioni di cui ai commi da 1 a 6 si applicano anche ai contributi e premi dovuti agli enti previdenziali. Le modalita' di versamento sono fissate dagli enti impositori.

7-bis. Fino al termine di cui al comma 1, sono sospesi i procedimenti di riscossione coattiva e le azioni concorsuali relativi ai tributi, contributi e premi di cui al presente articolo.

8. I soggetti residenti alla data delle calamita' di cui all'articolo 2, comma 1, lettera c), della legge 24 febbraio 1992, n. 225, interessati al servizio militare di leva le cui abitazioni principali, a causa degli eventi calamitosi, sono state oggetto di ordinanza di sgombero a seguito di inagibilita' parziale o totale e permangono in questa condizione all'atto della presentazione della domanda di cui al comma 9, possono essere impiegati, fino a quando persiste lo stato di emergenza deliberato dal Consiglio dei ministri ai sensi dell'articolo 5 della citata legge n. 225 del 1992, come coadiutori del personale delle Amministrazioni dello Stato, delle regioni o degli enti locali territoriali per le esigenze connesse alla realizzazione degli interventi necessari a fronteggiare gli eventi calamitosi.

9. Coloro che intendono beneficiare delle disposizioni di cui al comma 8 devono presentare domanda al distretto militare di appartenenza al momento dell'arruolamento ovvero, in caso di avvenuto arruolamento, entro venti giorni dalla data di dichiarazione ovvero di proroga dello stato di emergenza. Se il soggetto e' alle armi, la domanda deve essere presentata ai rispettivi Comandi di corpo. I comandi militari competenti, sulla base delle esigenze rappresentate da parte delle Amministrazioni dello Stato, delle regioni e degli enti locali territoriali e loro consorzi, assegnano, previa convenzione, i soggetti interessati, tenendo conto delle professionalita' richieste e delle attitudini individuali dei soggetti medesimi a svolgere i previsti interventi. Per il vitto e l'alloggio di tali soggetti si provvede tenendo conto della ricettivita' delle caserme e della disponibilita' dei comuni, nonche' autorizzando il pernottamento ed eventualmente il vitto presso le rispettive abitazioni. L'assegnazione dei militari di leva alle amministrazioni che hanno stipulato la convenzione avviene entro venti giorni dalla presentazione della domanda da parte dei militari stessi.

10. Qualora in occasione della chiamata alla leva di ciascun contingente si verifichino circostanze eccezionali che non consentano di assicurare il fabbisogno delle Forze armate, il Ministro della difesa, con proprio decreto, puo' sospendere temporaneamente la applicazione delle disposizioni del comma 8 ovvero di quelle sul servizio di leva recate da norme di legge che prevedano interventi a favore delle zone colpite da eventi calamitosi.

11. Le norme recate dai commi 1 e 2 dell'articolo 1-ter del decreto-legge 27 ottobre 1997, n. 364, convertito, con modificazioni, dalla legge 17 dicembre 1997, n. 434, e successive modificazioni, si applicano, nei limiti delle richieste di personale avanzate dalle singole amministrazioni che attestino la persistenza di effettive esigenze connesse agli interventi necessari a fronteggiare la crisi sismica, fino al 30 giugno 2001.

12. Nell'ambito delle risorse disponibili, in attuazione dell'articolo 3, comma 1, del decreto-legge 13 maggio 1999, n. 132, convertito, con modificazioni, dalla legge 13 luglio 1999, n. 226, i termini previsti dal decreto del Ministro dell'interno delegato per il coordinamento della protezione civile 28 settembre 1998, n. 499, gia' prorogati con l'articolo 5, comma 2, dell'ordinanza del Ministro dell'interno delegato per il coordinamento della protezione civile n. 2991 del 31 maggio 1999, pubblicata nella Gazzetta Ufficiale n. 129 del 4 giugno 1999, sono prorogati fino al 31 dicembre 2006.

13. Al fine di consentire il recupero delle minori entrate dell'imposta comunale sugli immobili relative ai fabbricati colpiti dal sisma del 1998 nell'area del Lagonegrese-Senisese, e' concesso, per il 2001, un contributo straordinario ai comuni colpiti, con le modalita' di cui agli articoli 2 e 4 del decreto-legge 13 maggio 1999, n. 132, convertito, con modificazioni, dalla legge 13 luglio 1999, n. 226.

14. Si intendono ricompresi tra gli oneri detraibili ai sensi dell'articolo 13-bis, comma 1, lettera i-bis), del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, gli importi delle erogazioni liberali in denaro effettuate in favore delle popolazioni colpite da eventi di calamita' pubblica o da altri eventi straordinari anche se avvenuti in altri Stati, eseguite per il tramite dei soggetti identificati ai sensi del decreto del Presidente del Consiglio dei ministri 20 giugno 2000, pubblicato nella Gazzetta Ufficiale n. 155 del 5 luglio 2000. Per il periodo di imposta 2000, si intendono detraibili anche gli importi riferiti alle erogazioni liberali in denaro effettuate nell'anno precedente.

15. Il Magistrato per il Po puo' utilizzare gli enti locali come soggetti attuatori per specifici interventi di protezione civile sul territorio di competenza.

16. Per finanziare gli interventi delle regioni, delle province autonome e degli enti locali, diretti a fronteggiare esigenze urgenti per le calamita' naturali di livello b) di cui all'articolo 108 del decreto legislativo 31 marzo 1998, n. 112, nonche' per potenziare il sistema di protezione civile delle regioni e degli enti locali, e' istituito il "Fondo regionale di protezione civile". Il Fondo e' alimentato per il triennio 2001-2003 da un contributo dello Stato di lire 100 miliardi annue, il cui versamento e' subordinato al versamento al Fondo stesso da parte di ciascuna regione e provincia autonoma di una percentuale uniforme delle proprie entrate accertate nell'anno precedente, determinata dalla Conferenza dei presidenti delle regioni e delle province autonome in modo da assicurare un concorso complessivo delle regioni e delle province autonome non inferiore, annualmente, al triplo del concorso statale. Le risorse regionali e statali sono accreditate su un conto corrente di tesoreria centrale denominato "Fondo regionale di protezione civile". L'utilizzo delle risorse del Fondo e' disposto dal Presidente della Conferenza dei presidenti delle regioni e delle province autonome, d'intesa con il direttore dell'Agenzia di protezione civile e con le competenti autorita' di bacino, in caso di calamita' naturali di carattere idraulico ed idrogeologico, ed e' comunicato tempestivamente alla Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano. ((35))

17. In sede di prima applicazione per il triennio 2001-2003 il concorso delle regioni al Fondo di cui al comma 16 e' assicurato mediante riduzione delle somme trasferite ai sensi della legge 15 marzo 1997, n. 59, per l'importo di lire 200 miliardi per ciascun anno, con corrispondente riduzione delle somme indicate all'articolo 52, comma 6, della presente legge. Per l'anno 2004 il Fondo e' alimentato esclusivamente da un contributo dello Stato pari a 154.970.000 euro. ((35))

18. Sui fondi assegnati a tutto il 2003, l'Ente nazionale per le strade (ANAS) e' tenuto a riservare la somma di lire 600 miliardi, da impegnare nel 2001 e nel 2002, per gli interventi urgenti di ripristino della viabilita' statale nelle regioni danneggiate dagli eventi alluvionali dei mesi di settembre, ottobre e novembre 2000, per i quali e' intervenuta, da parte del Consiglio dei ministri, la dichiarazione dello stato di emergenza ai sensi dell'articolo 5 della legge 24 febbraio 1992, n. 225. A valere su tali somme, l'ANAS provvede anche alle prime opere necessarie d'intesa con gli enti competenti alla messa in sicurezza dei versanti immediatamente adiacenti alla sede stradale nei casi in cui la instabilita' rappresenti un pericolo per la circolazione.

------------- AGGIORNAMENTO (31) La L. 24 dicembre 2003, n. 350 ha disposto (con l'art. 2, comma 66) che il termine di cui al comma 1 del presente articolo e' differito, limitatamente alle somme dovute per contributi, al 30 giugno 2005. ------------- AGGIORNAMENTO (35) Il D.L. 9 novembre 2004, n. 266 convertito con modificazioni dalla L. 27 dicembre 2004, n. 306, ha disposto (con l'art. 19-sexies, comma 1) che "L'operativita' del Fondo regionale di protezione civile, di cui all'articolo 138, commi 16 e 17, della legge 23 dicembre 2000, n. 388, e' prorogata per gli anni 2005, 2006 e 2007, anche al fine di fronteggiare le esigenze connesse all'impiego delle risorse umane necessarie al funzionamento della rete dei Centri funzionali di protezione civile".

### Art. 139. - (Differimento dei termini e altre disposizioni per la ultimazione dei lavori nelle zone colpite dalla catastrofe del Vajont)

1. I termini per la ultimazione dei lavori previsti dall'articolo 8 della legge 10 maggio 1983, n. 190, sono differiti al 31 dicembre 2001 anche per quegli assegnatari la cui pratica contributiva sia gia' stata oggetto di formale revoca alla data di entrata in vigore della presente legge.

((2. I contributi previsti dai commi primo, secondo, terzo e settimo dell'articolo 4 della legge 4 novembre 1963, n. 1457, e successive modificazioni, possono essere concessi ed erogati in un'unica soluzione, a seguito di domanda presentata anche da uno solo degli aventi diritto ai sensi dell'articolo 32 della citata legge n. 1457 del 1963, anche nel caso di rinuncia al completamento della ricostruzione, sino alla concorrenza delle spese sostenute, da comprovare con idonei documenti fiscali o con perizia asseverata da soggetto abilitato))

3. I provvedimenti di assegnazione definitiva delle aree gia' assegnate in via provvisoria agli aventi diritto dovranno essere definiti entro centottanta giorni dalla data di entrata in vigore della presente legge. Decorso inutilmente tale termine l'assegnazione dell'area, gia' provvisoria, diventa definitiva.

4. Per garantire l'erogazione di contributi necessari per la ricostruzione delle abitazioni, nonche' per il completamento della ricostruzione dei centri abitati di Erto, Casso e Vajont, di cui alla legge 4 novembre 1963, n. 1457, e' autorizzato, per l'anno 2001, a favore del Ministero dei lavori pubblici, lo stanziamento di lire 10 miliardi.

### Art. 140. - (Riordino fondiario nelle zone del Friuli-Venezia Giulia)

1. Al fine di consentire il riordino fondiario nelle zone del Friuli-Venezia Giulia colpite dal terremoto del 1976, le disposizioni di cui all'articolo 4 della legge 8 agosto 1977, n. 546, e successive modificazioni, gia' prorogate dall'articolo 1 della legge 23 gennaio 1992, n. 34, e dall'articolo 3, comma 157, della legge 23 dicembre 1996, n. 662, sono ulteriormente prorogate al ((31 dicembre 2005)). I termini stabiliti per il compimento delle procedure sono prorogati, in via di sanatoria, al ((31 dicembre 2005)) per le amministrazioni comunali che abbiano avviato le procedure previste per i piani di ricomposizione parcellare ai sensi delle citate disposizioni.

### Art. 141. - (Patrimonio idrico nazionale)

1. Al fine di assicurare il recupero di risorse idriche disponibili in aree di crisi del territorio nazionale e per il miglioramento e la protezione ambientale, mediante eliminazione di perdite, incremento di efficienza della distribuzione e risanamento delle gestioni, nonche' mediante la razionalizzazione e il completamento di opere e di interconnessioni, il Ministero del tesoro, del bilancio e della programmazione economica provvede alla concessione, ed alla conseguente erogazione direttamente agli istituti mutuanti, di contributi pari agli oneri, per capitale ed interessi, di ammortamento di mutui o altre operazioni finanziarie che i seguenti soggetti sono autorizzati a contrarre in rapporto alle rispettive quote di limiti di impegno quindicennali con decorrenza dagli anni 2002 e 2003:

- a) Consorzio Ovest Sesia Baraggia, del sistema Canale Cavour Vercellese, per la quota di lire 8 miliardi per ciascuno degli anni 2002 e 2003:
- b) Consorzio Irrigazione Est Sesia di Novara, per la quota di lire 8 miliardi per ciascuno degli anni 2002 e 2003;
- c) Canale Emiliano-Romagnolo, per la quota di lire 7,5 miliardi per ciascuno degli armi 2002 e 2003;
- d) Ente Irriguo Umbro-Toscano, per la quota di lire 7,5 miliardi per ciascuno degli anni 2002 e 2003;
- e) Complessi Irrigui della Campania Centrale e Piana del Sele, per la quota di lire 4 miliardi per ciascuno degli anni 2002 e 2003,
- f) Ente per lo sviluppo dell'irrigazione e la trasformazione fondiaria in Puglia, Lucania e Irpinia, per la quota di lire 4,5 miliardi per ciascuno degli anni 2002 e 2003;
- g) Sistema Lentini, Simeto e Ogliastro, per la quota di lire 3,5 miliardi per ciascuno degli anni 2002 e 2003;
- h) Consorzio di bonifica Medio Astico Bacchiglione, per la quota di lire 1 miliardo per ciascuno degli anni 2002 e 2003;
- i) Consorzi di bonifica dell'oristanese, per la quota di lire 1 miliardo per ciascuno degli anni 2002 e 2003;
- l) Consorzio bacini del Trebbia e del Tidone, per la quota di lire 1 miliardo per ciascuno degli anni 2002 e 2003.

2. Gli enti indicati al comma 1 presentano entro il 31 dicembre 2001 progetti esecutivi e cantierabili per la realizzazione delle opere necessarie al recupero di risorse idriche. Il Ministro del tesoro, del bilancio e della programmazione economica provvede alla revoca della concessione degli enti inadempienti a ripartire le connesse risorse tra i rimanenti.

3. Per assicurare altresi' il perseguimento delle finalita' di cui al comma 2 nelle restanti aree del territorio nazionale, sono autorizzati gli ulteriori limiti di impegno quindicennali di lire 10 miliardi per ciascuno degli anni 2002 e 2003, da iscrivere nello stato di previsione del Ministero delle politiche agricole e forestali per la concessione di contributi pluriennali per la realizzazione degli interventi da parte dei soggetti interessati.

((3-bis. Al fine di assicurare il corretto funzionamento degli enti di cui al comma 1 nonche' per la realizzazione di ulteriori investimenti e' autorizzato il limite d'impegno quindicennale di 5.270.000 euro a decorrere dall'anno 2003. Entro il 30 giugno 2003 i suddetti enti presentano al Ministero delle politiche agricole e forestali propri programmi finalizzati al loro corretto funzionamento e alla realizzazione di investimenti))

4. Per l'adempimento degli obblighi comunitari in materia di fognatura, collettamento e depurazione di cui agli articoli 27, 31 e 32 del decreto legislativo 11 maggio 1999, n. 152, e successive modificazioni, le autorita' istituite per gli ambiti territoriali ottimali di cui all'articolo 8 della legge 5 gennaio 1994, n. 36, ovvero, nel caso in cui queste non siano ancora operative, le province, predispongono, entro novanta giorni dalla data di entrata in vigore della presente legge, ed attuano un programma di interventi urgenti, a stralcio e con gli stessi effetti di quello previsto dall'articolo 11, comma 3, della medesima legge 5 gennaio 1994, n. 36. Ove le predette autorita' e province risultino inadempienti, sono sostituite, anche ai sensi dell'articolo 3 del citato decreto legislativo n. 152 del 1999, come modificato dall'articolo 2 del decreto legislativo 18 agosto 2000, n. 258, dai presidenti delle giunte regionali, su delega del Presidente del Consiglio dei ministri.

### Art. 142. - (Fondo per il finanziamento dei piani stralcio di assetto idrogeologico)

1. Per gli interventi relativi al finanziamento delle opere previste dai piani stralcio di assetto idrogeologico, per l'individuazione delle aree a rischio e per le relative misure di salvaguardia e' istituito un apposito fondo.

2. Ai fini di cui al comma 1, per gli anni 2002 e 2003 e' autorizzata la spesa di lire 100 miliardi annue.

### Art. 143. - (Interventi in materia di patrimonio storico-artistico)

1. Al Ministero per i beni e le attivita' culturali e' attribuita, per l'anno 2001, la somma di lire 100 miliardi aggiuntiva rispetto a quanto disposto dall'articolo 3, comma 83, della legge 23 dicembre 1996, n. 662. La predetta somma e' attribuita con decreto del Ministro delle finanze, di concerto con i Ministri del tesoro, del bilancio e della programmazione economica e per i beni e le attivita' culturali, per il recupero e la conservazione dei beni culturali archeologici, storici, artistici, archivistici, delle librerie storiche, delle biblioteche e dei beni librari.

## INTERVENTI IN MATERIA DI INVESTIMENTI PUBBLICI

### Art. 144. - (Limiti di impegno)

1. Al fine di agevolare lo sviluppo dell'economia e dell'occupazione, sono autorizzati nel triennio 2001-2003 i limiti di impegno di cui alla tabella 1, allegata alla presente legge, con la decorrenza e l'anno terminale ivi indicati.((82))

2. Il comune di Venezia e' autorizzato a destinare parte del ricavato dei mutui contratti utilizzando le quote di limiti di impegno ad esso attribuite per la prosecuzione degli interventi per la salvaguardia di Venezia ai sensi dell'articolo 54, comma 1, della legge 23 dicembre 1999, n. 488, alla copertura dei costi aggiuntivi derivanti dalla perdurante inagibilita' del Teatro "La Fenice", mediante trasferimento da effettuare alla Fondazione Teatro La Fenice di Venezia fino ad un importo massimo di lire 4,5 miliardi per ciascuno degli anni 2001 e 2002.

3. Per le finalita' di sviluppo da parte dell'industria a tecnologia avanzata, ai sensi dell'articolo 4 del decreto-legge 17 giugno 1996, n. 321, convertito, con modificazioni, dalla legge 8 agosto 1996, n. 421, di sistemi ad architettura complessa, ritenuti tecnologicamente prioritari dal Comitato di cui all'articolo 2 della legge 24 dicembre 1985, n. 808, e per l'acquisizione degli stessi al Ministero della difesa secondo le procedure di cui all'articolo 2-ter del decreto-legge 23 settembre 1994, n. 547, convertito, con modificazioni, dalla legge 22 novembre 1994, n. 644, sono autorizzati limiti di impegno quindicennali di lire 50 miliardi a decorrere dall'anno 2002 e di lire 42 miliardi a decorrere dall'anno 2003.

4. Per il completamento degli interventi urgenti a seguito degli eventi sismici e idrogeologici avvenuti tra il settembre 1997 e l'agosto 2000, esclusi gli eventi sismici delle regioni Marche e Umbria, e per i quali e' intervenuta da parte del Consiglio dei ministri la dichiarazione dello stato di emergenza ai sensi dell'articolo 5 della legge 24 febbraio 1992, n. 225, il Dipartimento della protezione civile e' autorizzato a concorrere con contributi quindicennali ai mutui che le regioni stipulano mediante un limite di impegno di lire 35 miliardi decorrente dall'anno 2002, da ripartire da parte del medesimo Dipartimento tra le regioni interessate alle esigenze. Per disciplinare gli interverti infrastrutturali di emergenza e a favore dei soggetti privati danneggiati sono emanate ordinanze ai sensi dell'articolo 5 della citata legge n. 225 del 1992, d'intesa con le regioni interessate.

5. Per fronteggiare le esigenze derivanti da eventi calamitosi o da eccezionali avversita' atmosferiche verificatisi nell'anno 2000 sul territorio nazionale, nelle zone definite dalle ordinanze del Ministro dell'interno delegato per il coordinamento della protezione civile, il Dipartimento della protezione civile provvede con le modalita' e le procedure di cui al comma 4 ed e' autorizzato a concorrere con contributi in favore delle regioni che contraggono mutui allo scopo. A tale fine, in aggiunta alle risorse gia' a disposizione del Dipartimento medesimo, sono autorizzati due limiti di impegno quindicennali: di lire 100 miliardi decorrente dall'anno 2001 e di lire 100 miliardi decorrente dall'anno 2002. Per gli interventi nelle zone colpite dall'alluvione in Calabria nei mesi di settembre e ottobre 2000 sono inoltre autorizzati due limiti di impegno quindicennali di lire 10 miliardi a decorrere dall'anno 2002 e di lire 10 miliardi a decorrere dall'anno 2003. (13)

6. Per la prosecuzione degli interventi conseguenti al terremoto della Campania di cui alla legge 3 aprile 1980, n. 116, e' autorizzato un limite di impegno quindicennale decorrente dall'anno 2002 di lire 1 miliardo. Per la prosecuzione degli interventi conseguenti al terremoto di Foggia di cui alla legge 23 gennaio 1992, n. 32, la regione Puglia e' autorizzata a contrarre mutui assistiti da contributo statale, da erogare tramite il Dipartimento della protezione civile, pari ad un limite di impegno quindicennale di lire 2 miliardi, decorrente dall'anno 2002. Per la prosecuzione degli interventi conseguenti al terremoto di cui al decreto-legge 26 maggio 1984, n. 159, convertito, con modificazioni, dalla legge 24 luglio 1984, n. 363, e' autorizzato un limite d'impegno quindicennale decorrente dall'anno 2002 di lire 1 miliardo, ai fini della stipula di un mutuo da parte della regione Lazio, su indicazione del Dipartimento della protezione civile.

7. Al fine di garantire il miglioramento della viabilita' e dei trasporti, sono attribuiti all'ANAS stanziamenti destinati alle seguenti iniziative, nei limiti finanziari indicati:

- a) strada trans-polesana: lire 20.000 milioni per gli anni 2001 e 2002, e lire 40.000 milioni per l'anno 2003;
- b) pedemontana-lombarda: lire 30.000 milioni per gli anni 2001 e 2002, e lire 40.000 milioni per l'anno 2003;
- c) ionica: lire 10.000 milioni per l'anno 2001, lire 20.000 milioni per l'anno 2002, e lire 30.000 milioni per l'anno 2003;
- d) tirreno-adriatica (strada statale n. 652): lire 20.000 milioni per gli anni 2001 e 2002, e lire 30.000 milioni per l'anno 2003;
- e) collegamento aeroporto Malpensa 2000, strade statali n. 32 e n. 527: lire 10.000 milioni per gli anni 2001, 2002 e 2003;
- f) strada trasversale "Delle Serre", in provincia di Vibo Valentia: lire 10.000 milioni per l'anno 2002 e lire 10.000 milioni per l'anno 2003;
- g) strada a scorrimento veloce Caltanissetta-Gela: lire 5.000 milioni per l'anno 2002 e lire 10.000 milioni per l'anno 2003.

8. Per il completamento della dorsale appenninica Atina-Isernia, tronco Atina-confine della regione Lazio, e' attribuita alla provincia di Frosinone la somma di lire 5 miliardi per ciascuno degli anni 2001, 2002 e 2003.

9. Per interventi relativi al miglioramento del nodo stradale Venezia-Mestre e' autorizzata per l'anno 2001 l'erogazione di lire 2.000 milioni a favore della provincia di Venezia.

10. Per interventi relativi alla superstrada Noce Rivello-Colla Maratea nella regione Basilicata e' autorizzata la spesa di lire 4.000 milioni per il 2001 e di lire 2.000 milioni per il 2002. Nell'ambito degli interventi per la risoluzione dei problemi della viabilita' dell'area centrale veneta la regione Veneto e' autorizzata a contrarre mutui quindicennali con onere per capitale ed interessi a carico del bilancio dello Stato. A tal fine e' autorizzato il limite di impegno quindicennale di lire 7 miliardi a decorrere dal 2002. (72)

11. L'ANAS e' inoltre autorizzato, nell'ambito delle risorse esistenti, a contrarre mutui quindicennale assistiti da contributi erariali, nei limiti finanziari indicati:

- a) strada Termoli-San Vittore, A1-A14: lire 3.000 milioni per l'amo 2002 e lire 4.000 milioni per l'anno 2003;
- b) strada Ragusa-Catania: lire 3.000 milioni per gli anni 2002 e 2003.

12. Per la progettazione definitiva del raddoppio dell'intero tracciato, con priorita' per la nuova galleria di valico, della linea ferroviaria Parma-La Spezia (Pontremolese), e' autorizzata la spesa di lire 4.000 milioni nell'anno 2002 e di lire 5.000 milioni nell'anno 2003.

13. Sono autorizzati limiti di impegno quindicennali di lire 1 miliardo a decorrere dall'anno 2002 e di lire 1 miliardo a decorrere dall'anno 2003, in corrispondenza dei mutui che la regione Sicilia stipulera' per il completamento della ferrovia Siracusa-Ragusa-Gela.

14. Per la realizzazione della strada medio Adriatico-medio Tirreno (adeguamento strada statale n. 4, Salaria) sono autorizzati limiti di impegno quindicennali di lire 7 miliardi a decorrere dall'anno 2002 e di lire 9 miliardi a decorrere dall'anno 2003; e' altresi' autorizzata la spesa di lire 10 miliardi per ciascuno degli anni del triennio 2001-2003.

15. Al fine di assicurare il finanziamento del programma triennale di intervento contenuto nel piano di bacino adottato dall'autorita' di bacino del fiume Arno, secondo le procedure previste dagli articoli 17 e 19 della legge 18 maggio 1989, n. 183, nonche' al fine della realizzazione di interventi urgenti per la difesa del suolo dal dissesto idrogeologico, le regioni che insistono sul bacino dell'Arno sono autorizzate a contrarre mutui con ammortamento a carico del bilancio dello Stato pari a un limite di impegno quindicennale di lire 2 miliardi a decorrere dall'anno 2002 e un limite di impegno quindicennale di lire 3 miliardi decorrente dall'anno 2003.

16. Per interventi infrastrutturali di collegamento con la Val d'Aosta, e' concesso alla comunita' montana Valsesia un limite di impegno quindicennale di lire 3 miliardi decorrente dall'anno 2002, da iscrivere nello stato di previsione del Ministero del tesoro, del bilancio e della programmazione economica.

17. E' autorizzato un limite di impegno quindicennale di lire 20 miliardi annue a decorrere dal 2002 e di lire 15 miliardi annue a decorrere dal 2003 destinato alla copertura finanziaria di un programma finalizzato all'avvio della gestione del servizio idrico integrato di cui alla legge 5 gennaio 1994, n. 36, attraverso il finanziamento di interventi diretti con particolare riguardo all'ottimizzazione dell'uso idropotabile di invasi artificiali e di reti. Gli interventi sono riferiti a progetti compresi nel programma e nel piano finanziario di cui all'articolo 11, comma 3, della citata legge n. 36 del 1994, approvati dal soggetto competente per l'ambito territoriale ottimale, individuato ai sensi dell'articolo 9 della medesima legge n. 36 del 1994, per i quali il soggetto gestore si impegna ad anticipare almeno il 30 per cento dell'investimento necessario. Le richieste di finanziamento sono predisposte dalle regioni interessate ed indicano i benefici prodotti sulla dinamica tariffaria contemplata nel piano dell'ambito territoriale ottimale. Il finanziamento delle opere, a valere sugli stanziamenti di cui al presente comma, e' approvato con decreto del Ministro dei lavori pubblici, previa intesa in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano e sentita l'Unita' tecnica-finanza di progetto di cui all'articolo 7 della legge 17 maggio 1999, n. 144.

18. Per il cofinanziamento di interventi per alloggi e residenze per studenti universitari di cui alla legge 14 novembre 2000, n. 338, sono autorizzati limiti di impegno quindicennali di lire 25 miliardi per ciascuno degli anni 2002 e 2003, da iscrivere nello stato di previsione del Ministero dell'universita' e della ricerca scientifica e tecnologica, al fine di consentire la contrazione di mutui con la Cassa depositi e prestiti. Gli interventi di cui alla stessa legge possono essere effettuati anche da fondazioni e istituzioni senza scopo di lucro operanti nel settore del diritto allo studio.

------------- AGGIORNAMENTO (13) La L. 28 dicembre 2001, n. 448 ha disposto (con l'art. 45, comma 4) che "Per la prosecuzione ed il completamento degli interventi di cui all'articolo 144, comma 5, della legge 23 dicembre 2000, n. 388, e' autorizzata la spesa di 7 milioni di euro a decorrere dall'anno 2003". ------------- AGGIORNAMENTO (72) La L. 24 dicembre 2012, n. 228 ha disposto (con l'art. 1, comma 7) che "Le risorse disponibili per gli interventi recati dalle autorizzazioni di spesa di cui all'elenco n. 2, allegato alla presente legge, sono ridotte per ciascuno degli anni 2013, 2014, 2015 e successivi per gli importi ivi indicati". --------------- AGGIORNAMENTO (82) La L. 23 dicembre 2014, n. 190 ha disposto (con l'art. 1, comma 361) che "L'autorizzazione di spesa relativa al contributo straordinario al comune di Reggio Calabria di cui all'articolo 144, comma 1, della legge 23 dicembre 2000, n. 388, e' ridotta di 3 milioni di euro a decorrere dall'anno 2015".

### Art. 145. - (Altri interventi)

1. All'articolo 3, comma 1, della legge 18 giugno 1998, n. 194, dopo le parole "contributo dodecennale", le parole: "del 10 per cento della spesa di investimento, nel limite" sono sostituite dalle seguenti: "per la spesa di investimento, per un importo".

2. COMMA ABROGATO DALLA L. 1 AGOSTO 2002, N. 166.

3. La legge 5 luglio 1964, n. 548, recante la concessione di un contributo annuo a favore dell'Istituto per la contabilita' nazionale, e la legge 29 novembre 1961, n. 1329, relativa alla concessione di un contributo annuo alla Fondazione per lo sviluppo degli studi sul bilancio statale, sono abrogate.

4. COMMA ABROGATO DAL D.LGS. 15 MARZO 2010, N. 66.

5. I progetti nel settore spaziale con particolari ricadute commerciali sono individuati dal Ministero dell'industria, del commercio e dell'artigianato, di concerto con il Ministero dell'universita' e della ricerca scientifica e tecnologica e con il Ministero della difesa. Per tali progetti il Ministro dell'industria, del commercio e dell'artigianato concede finanziamenti con le modalita' e nelle misure di cui alla legge 24 dicembre 1985, n. 808, allo scopo utilizzando la quota degli stanziamenti definita dal CIPE nel quadro delle disponibilita' di cui alla citata legge n. 808 del 1985.

6. Per le finalita' previste dall'articolo 1 del decreto-legge 25 settembre 1997, n. 324, convertito, con modificazioni, dalla legge 25 novembre 1997, n. 403, concernenti la concessione di contributi per la rottamazione degli autoveicoli, e' autorizzata la spesa di lire 15 miliardi per ciascuno degli anni 2001, 2002 e 2003, finalizzata all'acquisto o alla trasformazione di autoveicoli, motocicli e ciclomotori elettrici, a metano e a GPL, di biciclette a pedalata assistita, nonche' all'istallazione sui veicoli a benzina esistenti di un impianto di alimentazione a metano o GPL secondo definizioni adottate con decreto del Ministro dell'ambiente, di concerto con il Ministro dell'industria, del commercio e dell'artigianato, da emanare entro tre mesi dalla data di entrata in vigore della presente legge. (24) (72a)

7. All'articolo 20, primo comma, del testo unico delle leggi sulle tasse automobilistiche, approvato con decreto del Presidente della Repubblica 5 febbraio 1953, n. 39, dopo le parole: "Gli autoveicoli" sono inserite le seguenti: " , i motocicli e i ciclomotori a due, tre o quattro ruote,".

8. All'articolo 4, comma 19, primo periodo, della legge 9 dicembre 1998, n. 426, le parole "tipologie di autoveicoli a minimo impatto ambientale" sono sostituite dalle seguenti: "tipologie di veicoli a minimo impatto ambientale"; dopo le parole: "nel territorio dei comuni con popolazione superiore ai 25 mila abitanti" sono inserite le seguenti: ", dei comuni che fanno parte delle isole minori ove sono presenti aree marine protette, nonche' dei comuni che fanno parte delle aree naturali protette iscritte nell'elenco ufficiale di cui alla deliberazione del Ministro dell'ambiente del 2 dicembre 1996, pubblicata nella Gazzetta Ufficiale n. 141 del 19 giugno 1997".

9. Per le finalita' previste dall'articolo 6 della legge 31 marzo 1998, n. 73, concernenti il programma di metanizzazione della Sardegna, e' autorizzata la spesa di lire 20 miliardi per l'anno 2001. Al fine di evitare che le imprese interessate, a causa dei ritardi nella notifica alla Commissione delle Comunita' europee, perdano i benefici previsti dalla citata legge n. 73 del 1998 per l'esercizio 2000, il credito di imposta maturato e non compensato nello stesso esercizio e' compensabile nel corso dell'esercizio 2001 secondo le modalita' previste dalla stessa legge.

10. Per fare fronte alle esigenze connesse all'avvio del sistema di monitoraggio degli investimenti pubblici di cui all'articolo 1 della legge 17 maggio 1999, n. 144, ivi comprese le spese relative al funzionamento della rete dei nuclei di valutazione e verifica degli investimenti pubblici ed al ruolo di coordinamento svolto dal CIPE, la dotazione annuale del fondo previsto dal comma 7 del predetto articolo 1 e' incrementata di lire 30 miliardi, per una autorizzazione complessiva di spesa di lire 40 miliardi annue a decorrere dall'anno 2001. Tali risorse potranno altresi' cofinanziare anche i costi di funzionamento dei predetti nuclei relativamente ai compensi per gli esperti interni ed esterni. In sede di ripartizione annuale del CIPE una quota del predetto fondo sara' destinata al finanziamento delle attivita' di raccordo, indirizzo e coordinamento della rete da parte del nucleo di valutazione e verifica del Ministero del tesoro, del bilancio e della programmazione economica.

11. Ai fini della trasformazione in societa' per azioni dell'Ente nazionale di assistenza al volo (ENAV) ai sensi delle leggi 21 dicembre 1996, n. 665, e 17 maggio 1999, n. 144, si applica l'articolo 45, comma 25, della legge 23 dicembre 1998, n. 448.

12. I dipendenti dell'ENAV, aventi diritto all'indennita' di buonuscita alla data del 31 dicembre 2000, possono optare per il mantenimento del trattamento di fine servizio secondo le regole per loro vigenti alla medesima data.

13. Al fine di consentire al Comitato olimpico nazionale italiano (CONI) lo svolgimento dei propri compiti istituzionali e il potenziamento dell'attivita' sportiva e' autorizzata la concessione al CONI medesimo di un contributo straordinario di lire 195 miliardi per l'anno 2001 di cui 20 da destinare a sport sociale e giovanile. A tal fine, nei limiti della quota del suddetto contributo, per agevolare e promuovere l'addestramento e la preparazione di giovani calciatori di eta' compresa tra i quattordici ed i diciannove anni compiuti, definiti ai sensi dell'articolo 33 del regolamento interno della Federazione italiana gioco calcio "giovani di serie", alle societa' sportive, militanti nei campionati nazionali di serie C1 e C2, che stipulano un contratto di lavoro avente le predette finalita' sono riconosciuti, per ogni giovane assunto, uno sgravio contributivo in forma capitaria pari ad un milione di lire, nonche' un credito di imposta pari al 30 per cento del reddito di lavoro dipendente corrisposto a tali soggetti, con un limite massimo di lire dieci milioni per dipendente; e per ogni preparatore atletico una riduzione del 3 per cento sul totale dei contributi dovuti alle gestioni previdenziali di competenza. E' possibile la proroga del limite di eta' fino al compimento del ventiduesimo anno nel caso in cui la societa' sportiva abbia provveduto o provveda a stipulare con il giovane di serie il primo contratto professionistico. Con decreto del Ministro delle finanze, da emanare entro sessanta giorni dalla data di entrata in vigore della presente legge, sono stabilite le modalita' di applicazione delle agevolazioni di cui al presente comma.

14. Per le stesse finalita' di cui al comma 13 e' autorizzata la concessione alla Cassa di previdenza per l'assicurazione degli sportivi della somma di lire 15 miliardi per l'anno 2001 nonche' di 6 milioni di euro per l'anno 2002. L'erogazione e' preceduta da una verifica, effettuata dal Ministero del tesoro, del bilancio e della programmazione economica, sulle risultanze contabili e sulle prospettive finanziarie della stessa Cassa, da completare entro il 30 giugno 2001.

15. Per consentire lo svolgimento dei propri compiti istituzionali agli enti di promozione sportiva sono destinate lire 10 miliardi per il potenziamento e finanziamento dei programmi relativi allo sport sociale per l'anno 2001.

16. Per la promozione e lo sviluppo della pratica sportiva delle persone disabili e' autorizzata la concessione alla Federazione italiana sport disabili (FISD) di un contributo straordinario di lire 500 milioni per l'anno 2001.

17. A decorrere dall'anno 2001, sono concessi un contributo annuo di lire 800 milioni al Club alpino italiano, per le attivita' del Corpo nazionale soccorso alpino e speleologico (CNSAS), e un contributo annuo di lire 1.500 milioni complessivamente al Forum permanente per le comunicazioni di cui all'articolo 1, comma 24, della legge 31 luglio 1997, n. 249, nonche' al Forum internazionale per lo sviluppo delle comunicazioni del Mediterraneo. (25)

18. ((COMMA ABROGATO DALLA L. 28 DICEMBRE 2015, N. 208)). ((90))

19. ((COMMA ABROGATO DALLA L. 28 DICEMBRE 2015, N. 208)). ((90))

20. E' autorizzata l'ulteriore spesa di lire 15 miliardi per ciascuno degli anni 2001, 2002 e 2003 per la proroga della convenzione tra il Ministero delle comunicazioni e il Centro di produzione Spa, stipulata ai sensi dell'articolo 1, comma 1, della legge 11 luglio 1999, n. 224.

21. Gli oneri per il completamento del programma di metanizzazione del Mezzogiorno, di cui all'articolo 11 della legge 28 novembre 1980, n. 784, sono posti a carico delle risorse stanziate dalla presente legge per la prosecuzione degli interventi per le aree depresse di cui all'articolo 1, comma 1, della legge 30 giugno 1998, n. 208, in misura pari a lire 150 miliardi per ciascuno degli anni 2001, 2002 e 2003.

22. All'articolo 15 del decreto legislativo 23 maggio 2000, n. 164, e' aggiunto, in fine, il seguente comma: "10-bis. Per le concessioni e gli affidamenti in essere per la realizzazione delle reti e la gestione della distribuzione del gas metano ai sensi dell'articolo 11 della legge 28 novembre 1980, n. 784, e successive modificazioni, e dell'articolo 9 della legge 7 agosto 1997, n. 266, come modificato dall'articolo 28 della legge 17 maggio 1999, n. 144, il periodo transitorio disciplinato dal comma 7 decorre, tenuto conto del tempo necessario alla costruzione delle reti, decorsi due anni dalla data di entrata in vigore del decreto del Ministero del tesoro, del bilancio e della programmazione economica di concessione del contributo".

23. All'articolo 19 del decreto legislativo 23 maggio 2000, n. 164, dopo il comma 6 e' inserito il seguente: "6-bis. Per l'ammissibilita' ai contributi di cui all'articolo 9 della legge 7 agosto 1997, n. 266, come modificato dall'articolo 28 della legge 17 maggio 1999, n. 144, i soggetti titolari di una concessione per la costruzione degli impianti e per la gestione del servizio di distribuzione del gas sono tenuti a dare conferma ai comuni dell'esecuzione della concessione stessa entro due mesi dalla data di pubblicazione delle nuove tariffe di distribuzione del gas determinate dall'Autorita' per l'energia elettrica e il gas ai sensi dell'articolo 23, comma 2. Decorso tale termine, la concessione si intende risolta e i comuni possono procedere ad una gara per l'affidamento ad altro concessionario, fermi restando la validita' delle domande di contributo presentate per l'ottenimento dei benefici di cui alle leggi citate e l'ammontare dei contributi eventualmente gia' determinati. Nel caso di bacini di utenza non sono ammissibili rinunce parziali da parte del concessionario. Il termine per la presentazione delle domande di contributo e' prorogato al 30 giugno 2001".

24. Al comma 8 dell'articolo 6 della legge 28 gennaio 1994, n. 84, le parole: "al netto delle rinfuse liquide" sono sostituite dalle seguenti: "al netto del 90 per cento delle rinfuse liquide".

25. Le disponibilita' del Fondo di solidarieta' per le vittime delle richieste estorsive di cui all'articolo 18 della legge 23 febbraio 1999, n. 44, e del Fondo di solidarieta' per le vittime dell'usura di cui all'articolo 14 della legge 7 marzo 1996, n. 108, possono essere destinate per gli anni 2001 e 2002 con decreto del Ministro dell'interno, adottato di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, per il finanziamento del Fondo per la prevenzione del fenomeno dell'usura di cui all'articolo 15, comma 1, della predetta legge n. 108 del 1996.

26. Le disposizioni dell'articolo 24, commi 1, 2 e 3, della legge 23 febbraio 1999, n. 44, e successive modificazioni, si applicano anche alla richiesta di concessione del mutuo, di cui alla legge 7 marzo 1996, n. 108. In tali casi, fatto salvo quanto previsto dall'articolo, 14, comma 10, primo periodo, della citata legge n. 108 del 1996, le domande di concessione del mutuo devono essere presentate o ripresentate, a pena di decadenza, entro duecentoquaranta giorni dalla data di entrata in vigore della presente legge. Le disposizioni del citato articolo 24, commi 2 e 3, della legge 23 febbraio 1999, n. 44, e successive modificazioni, si applicano anche alle domande di concessione dell'elargizione e del mutuo presentate dopo la data di entrata in vigore della medesima legge ma antecedentemente alla data di entrata in vigore del regolamento di attuazione emanato con decreto del Presidente della Repubblica 16 agosto 1999, n. 455, riferite ad eventi dannosi denunciati o accertati in tale periodo. Qualora sulle suddette domande di concessione dell'elargizione e del mutuo sia stata adottata una decisione nel medesimo periodo, le stesse possono essere ripresentate, rispettivamente, nei termini di' centoventi giorni e di centottanta giorni che ricominciano a decorrere dalla data di entrata in vigore della presente legge. Qualora per gli eventi dannosi di cui al presente comma i termini di presentazione delle domande indicati dall'articolo 13 della citata legge n. 44 del 1999 e dall'articolo 14 della citata legge n. 108 del 1996 siano in corso o gia' scaduti alla data di entrata in vigore del predetto regolamento di attuazione emanato con decreto del Presidente della Repubblica n. 455 del 1999, le relative istanze di concessione dell'elargizione e del mutuo, ove non siano state tempestivamente presentate, possono essere presentate, rispettivamente, entro centoventi giorni ed entro centottanta giorni dalla data di entrata in vigore della presente legge.

27. All'articolo 14, comma 2, della legge 7 marzo 1996, n. 108, la parola: "quinquennio" e' sostituita dalla seguente: "decennio". Tale modifica opera anche per i mutui concessi precedentemente alla data di entrata in vigore della presente legge, relativamente alle somme non ancora restituite dal beneficiario.

28. Il comma 3 dell'articolo 40 della legge 23 dicembre 1994, n. 724, e' sostituito dal seguente: "3. Entro il limite del fabbisogno finanziario di cui al comma 1, la CONSOB determina in ciascun anno l'ammontare delle contribuzioni dovute dai soggetti sottoposti alla sua vigilanza. Nella determinazione delle predette contribuzioni la CONSOB adotta criteri di parametrazione che tengono conto dei costi derivanti dal complesso delle attivita' svolte relativamente a ciascuna categoria di soggetti".

29. Nei commi 1, 2, 3, primo periodo, e 5 dell'articolo 40 della legge 23 dicembre 1994, n. 724, le parole: "dei corrispettivi", "i corrispettivi", "dei corrispettivi", "i corrispettivi di cui al comma 3 sono versati", sono rispettivamente sostituite dalle seguenti: "delle contribuzioni", "le contribuzioni", "delle contribuzioni", "le contribuzioni di cui al comma 3 sono versate". Al comma 5 del predetto articolo 40 le parole: "vengono iscritti" sono sostituite dalle seguenti: "vengono iscritte".

30. Per le regolazioni debitorie dei disavanzi delle ferrovie concesse e in ex gestione commissariale governativa, comprensivi degli oneri di trattamento di fine rapporto, maturati alla data del 31 dicembre 2000, ad esclusione della societa' Ferrovie dello Stato Spa, e per il ripiano dei disavanzi di esercizio delle aziende di trasporto pubblico locale relativi all'anno 1999, il Ministro dei trasporti e della navigazione, con decreto emanato di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, provvede nell'anno 2001 all'erogazione di lire 1.500 miliardi, nonche' di ulteriori lire 300 miliardi per la copertura, per il tramite dell'INPS, degli oneri sopportati dalle aziende esercenti pubblici servizi di trasporto in conseguenza del mancato allineamento, per l'anno 1999, delle aliquote contributive di dette aziende a quelle medie del settore industriale. (45)(97)

31. Sui fondi delle contabilita' speciali aperte presso le sezioni di tesoreria riguardanti il versamento, da parte dei produttori, del prelievo supplementare sulle produzioni lattiere, ai sensi del regolamento (CEE) n. 3950/92 del Consiglio, del 28 dicembre 1992, non sono ammessi atti di sequestro o pignoramento a pena di nullita' rilevabile anche d'ufficio. Gli atti di sequestro o di pignoramento eventualmente notificati si considerano inesistenti e non determinano obbligo di accantonamento da parte del tesoriere.

32. Per il finanziamento dei programmi di riqualificazione urbana, di cui all'articolo 2, comma 63, lettera a), della legge 23 dicembre 1996, n. 662, e' autorizzata la spesa di lire 30 miliardi per l'anno 2001, lire 205 miliardi per l'anno 2002 e lire 295 miliardi per l'anno 2003.

33. Per il finanziamento delle iniziative relative a studi, ricerche e sperimentazioni in materia di edilizia residenziale e all'anagrafe degli assegnatari di abitazioni, di cui all'articolo 2, comma 63, lettera b), della legge 23 dicembre 1996, n. 662, nonche' per il finanziamento di interventi a favore di categorie sociali svantaggiate, di cui all'articolo 2, comma 63, lettera c), della medesima legge, e' autorizzata la spesa di lire 80 miliardi per l'anno 2001. Per l'attuazione delle iniziative di cui alla citata lettera b) e' altresi' autorizzato un limite di impegno quindicennale di lire 80 miliardi per l'anno 2002.

34. Il Ministro della giustizia:

- a) entro trenta giorni dalla data di entrata in vigore della presente legge, predispone l'elenco degli istituti penitenziari ritenuti strutturalmente non idonei alla funzione propria e per i quali risulti necessaria o conveniente la dismissione;
- b) promuove le intese necessarie con le regioni o con gli enti locali interessati, per attuare le suddette dismissioni e reperire le aree per la localizzazione dei nuovi istituti;
- c) puo' valersi, ai fini delle acquisizioni dei nuovi istituti, degli strumenti della locazione finanziaria, della permuta e della finanza di progetto.

35. Al primo comma, dell'articolo 19 della legge 30 marzo 1981, n. 119, dopo le parole: "completamenti, ampliamenti o restauri" sono inserite le seguenti: "di edifici pubblici, nonche'".

36. Per l'assegnazione dei contributi relativi all'acquisto di macchine agricole, di cui all'articolo 17, comma 34, della legge 27 dicembre 1997, n. 449, e' autorizzata la spesa di lire 50 miliardi nell'anno 2001, 10 miliardi nell'anno 2002 e 10 miliardi nell'anno 2003.

37. Per le attivita' di competenza del Ministero delle politiche agricole e forestali, di cui all'articolo 4 della legge 23 dicembre 1999, n. 499, e' autorizzata la spesa di lire 60 miliardi nel 2001, 75 miliardi nel 2002 e 90 miliardi nel 2003.

38. Per la realizzazione dei programmi del settore aeronautico, di cui all'articolo 4, comma 3, della legge 7 agosto 1997, n. 266, e' autorizzata la spesa di lire 200 miliardi nel 2001 e 225 miliardi nel 2002.

39. Il primo e il secondo comma dell'articolo 2 della legge 18 ottobre 1955, n. 908, sono sostituiti dai seguenti: "Le somme affluenti al Fondo sono destinate alla concessione di mutui per la costruzione, la riattivazione, la trasformazione, l'ammodernamento e l'ampliamento di stabilimenti industriali ed aziende artigiane, per costruzioni navali, per attivita' turistico-alberghiere e per altre iniziative necessarie allo sviluppo industriale, con esclusione dei lavori pubblici nonche', per una quota fino al 20 per cento della consistenza patrimoniale del Fondo, per il finanziamento della costruzione di alloggi di tipo popolare, realizzati da parte degli enti previsti dall'articolo 16 del testo unico approvato con regio decreto 28 aprile 1938, n. 1165, e dei soggetti di cui all'articolo 18 della legge 5 agosto 1978, n. 457. Salvo quanto previsto nell'ultimo comma del presente articolo, i mutui sono ammortizzabili nel periodo massimo di quindici anni e non possono superare il 50 per cento della spesa necessaria per la realizzazione dei progetti finanziati; i finanziamenti per iniziative industriali e artigiane e per attivita' turistico-alberghiere possono essere concessi al 70 per cento della spesa necessaria per la realizzazione dei progetti; le eventuali perdite sono a carico del Fondo e degli istituti incaricati dei finanziamenti ai sensi dell'articolo 3 nella misura, rispettivamente, dell'80 e del 20 per cento".

40. E' istituito un fondo di lire 1,5 miliardi nel 2001 e 5.164.589,99 euro a decorrere dall'anno 2002, per la promozione di trasporti marittimi sicuri, anche mediante il finanziamento di studi e ricerche. A tale fine, per la razionalizzazione degli interventi previsti ai sensi del presente comma e per la valorizzazione delle professionalita' connesse con l'utilizzo delle risorse nautiche, negli anni successivi le risorse del fondo, in misura non inferiore all'80 per cento delle dotazioni complessive per ciascun anno, sono destinate a misure di sostegno e incentivazione per l'alta formazione professionale tramite l'istituzione di un forum permanente realizzato da una o piu' ONLUS per la professionalita' nautica partecipate da istituti di istruzione universitaria o convenzionate con gli stessi. Tali misure, in una percentuale non superiore al 50 per cento, possono essere destinate dai citati enti alla realizzazione, tramite il recupero di beni pubblici, di idonee infrastrutture. Con decreto del Ministro dell'economia e delle finanze sono stabilite le modalita' di attuazione delle disposizioni del presente comma.

41. I diritti speciali di prelievo disciplinati dall'articolo 8-quinquies della legge 7 febbraio 1992, n. 150, relativi al commercio e alla detenzione di esemplari di fauna e flora minacciati di estinzione, sono aumentati del 50 per cento.

42. Le autorizzazioni di spesa relative agli interventi di cui all'articolo 14, comma 2, della legge 5 ottobre 1991, n. 317, possono essere utilizzate anche per la concessione di contributi agli interessi ai sensi dell'articolo 4, comma 1, della legge 24 aprile 1990, n. 100, e successive modificazioni.

43. Per l'anno finanziario 2001 i ricavi delle operazioni di cui all'articolo 7, comma 3, del decreto legislativo 31 marzo 1998, n. 143, concluse dall'Istituto per i servizi assicurativi del commercio estero (SACE), detratta la quota spettante agli operatori economici indennizzati dal SACE, affluiscono all'entrata del bilancio dello Stato per essere contestualmente riassegnati ad apposito capitolo di spesa dello stato di previsione del Ministero del tesoro, del bilancio e della programmazione economica, per le finalita' di cui all'articolo 8, comma 2, del citato decreto legislativo n. 143 del 1998.

44. Per promuovere la presenza delle imprese italiane nell'ambito della rassegna "Italia in Giappone 2001", di cui alla legge 10 agosto 2000, n. 252, e' riconosciuto un contributo straordinario:

- a) in favore del Ministero per i beni e le attivita' culturali nella misura di lire 5.500 milioni per l'anno 2001 e di lire 1.000 milioni per l'anno 2002;
- b) in favore del Ministero del commercio con l'estero al fine di finanziare le iniziative promozionali realizzate dai consorzi alle esportazioni, nella misura di lire 4.500 milioni per l'anno 2001 e di lire 4.000 milioni per l'anno 2002.

45. Il contributo annuo previsto dall'articolo 8, comma 3, della legge 11 maggio 1999, n. 140, e' concesso nel limite dell'intensita' di aiuto autorizzata dalla Commissione delle Comunita' europee. Per i progetti ammissibili alle agevolazioni, sulla base dei criteri e delle risorse gia' assegnate a ciascuna regione ai sensi del medesimo comma 3 dell'articolo 8 della legge 11 maggio 1999, n. 140, il contributo, su richiesta dell'impresa, puo' essere erogato a titolo di anticipazione, purche' i relativi investimenti siano stati avviati a realizzazione, con le modalita' e i criteri degli aiuti de minimis di cui alla disciplina comunitaria degli aiuti di Stato.

46. Gli impianti di cui si prevede l'ammodernamento con i benefici di cui all'articolo 8, comma 3, della legge 11 maggio 1999, n. 140, o con altri benefici pubblici statali, regionali o di enti locali, nonche' quelli ricompresi nell'elenco, di cui al decreto del Presidente della Giunta regionale del Piemonte n. 96 del 12 novembre 2002, delle opere connesse allo svolgimento dei giochi olimpici invernali 'Torino 2006', potranno godere, previa verifica da parte degli organi di controllo della loro idoneita' al funzionamento e della loro sicurezza, di una proroga di quattro anni dei termini relativi alle scadenze temporali fissate al paragrafo 3 delle norme regolamentari approvate con decreto del Ministro dei trasporti del 2 gennaio 1985, pubblicato nella Gazzetta Ufficiale n. 26 del 31 gennaio 1985 e riguardanti la durata della vita tecnica, le revisioni speciali e le revisioni generali. (20) (65)

47. Allo scopo di potenziare l'informatica di servizio, con specifico riferimento alle esigenze connesse alle funzioni del giudice di pace, e' disposto un finanziamento di 30 miliardi di lire per l'anno 2001.

48. Per l'avvio di interventi di tipo infrastrutturale inerenti il canale navigabile dei Navicelli e' autorizzata una spesa di 5 miliardi di lire per ciascuno degli anni 2002 e 2003.

49. Il Ministero dell'universita' e della ricerca scientifica e tecnologica e' autorizzato ad utilizzare nel 2001 una somma pari a 7 miliardi di lire per sostenere i programmi della fondazione IDIS relativi al progetto "Citta' della scienza" volti, in collaborazione con le istituzioni europee, ad incentivare le sinergie fra il Mezzogiorno d'Italia e le aree del Mediterraneo, lo sviluppo di un polo di eccellenza sulle nuove tecnologie dell'informazione e della comunicazione, il trasferimento tecnologico e la creazione di imprese.

50. All'articolo 30, comma 1, della legge 11 febbraio 1994, n. 109, e successive modificazioni, dopo le parole: "da prestare anche mediante fidejussione bancaria o assicurativa" sono inserite le seguenti: "o rilasciata dagli intermediari finanziari iscritti nell'elenco speciale di cui all'articolo 107 del decreto legislativo 1 settembre 1993, n. 385, che svolgono in via esclusiva o prevalente attivita' di rilascio di garanzie, a cio' autorizzati dal Ministero del tesoro, del bilancio e della programmazione economica,".

51. Al fine di favorire gli investimenti nei parchi nazionali e' istituito un apposito fondo dell'ammontare di lire 20 miliardi per ciascun anno del triennio 2001-2003. Con decreto del Ministro dell'ambiente, da emanare entro sessanta giorni dalla data di entrata in vigore della presente legge, sono definiti i criteri e le modalita' per l'attuazione del presente comma con la determinazione dei criteri di ripartizione dei finanziamenti tra i parchi nazionali.

52. Il programma speciale di reindustrializzazione di cui all'articolo 5 del decreto-legge 1° aprile 1989, n. 120, convertito, con modificazioni, dalla legge 15 maggio 1989, n. 181, e' integrato con la previsione dello sviluppo di un polo di ricerca e di attivita' industriali ad alta tecnologia nel territorio del comune di Genova anche in relazione all'attuazione dell'articolo 4 del decreto-legge 30 settembre 2003, n. 269, convertito, con modificazioni, dalla legge 24 novembre 2003, n. 326. Per finanziare gli interventi previsti da tale integrazione e' autorizzata la spesa di lire 10 miliardi per ciascuno degli anni 2001, 2002 e 2003. Le risorse di cui al presente comma non possono essere utilizzate per altre finalita' fino al 31 dicembre 2006.

53. Al fine di un piu' adeguato utilizzo dei finanziamenti per la preparazione del Vertice G-8 a Genova, all'articolo 1, comma 1, della legge 8 giugno 2000, n. 149, sono apportate le seguenti modificazioni:

- a) dopo le parole: "(G8),", sono inserite le seguenti: "nonche' per quelle connesse con gli oneri conseguenti ad eventuali ricollocazioni di attivita' produttive";
- b) le parole: "beni del demanio marittimo" sono sostituite dalle seguenti: "beni del demanio";
- c) le parole: "detti beni rimangono, anche successivamente all'evento di cui al presente comma, affidati in concessione al comune di Genova" sono sostituite dalle seguenti: "detti beni, successivamente all'evento, ove abbiano subito un definitivo mutamento nella destinazione d'uso, con l'aggiunta dei sedimi e dei manufatti della Fiera del mare, sono ceduti al comune di Genova ad un prezzo complessivo di lire un miliardo".

54. L'area demaniale di circa 56.200 metri quadrati su piazza dell'umanita' nel comune di Chiavari, e' ceduta al comune di Chiavari ad un prezzo complessivo di 300 milioni di lire.

55. Al comma 7 dell'articolo 9 del decreto legislativo 15 novembre 1993, n. 507, dopo le parole: "di concessione" sono aggiunte le seguenti: "commisurati, questi ultimi, alla effettiva occupazione del suolo pubblico del mezzo pubblicitario".

56. Al comma 3 dell'articolo 12 del decreto legislativo 15 novembre 1993, n. 507, le parole: "dal comma 1", sono sostituire dalle seguenti: "dai commi 1 e 2".

57. All'articolo 32, comma 5, della legge 17 maggio 1999, n. 144, e' aggiunto, in fine, il seguente periodo: "Una quota pari al 5 per cento delle somme stanziate per l'attuazione del Piano e' destinata a interventi volti alla repressione dell'abusivismo pubblicitario e al miglioramento dell'impiantistica pubblicitaria sulle strade, di cui all'articolo 23 del decreto legislativo 30 aprile 1992, n. 285". Conseguentemente, al decreto legislativo 15 novembre 1993, n. 507, sono apportate le seguenti modificazioni:

- a) all'articolo 3, comma 3, sono soppresse le parole "comunque diversi dal concessionario del pubblico servizio";
- b) all'articolo 18, dopo il comma 3, e' aggiunto il seguente: "3-bis. Il comune ha facolta' di chiedere al concessionario delle pubbliche affissioni di svolgere servizi aggiuntivi strumentali alla repressione dell'abusivismo pubblicitario e al miglioramento dell'impiantistica";
- c) all'articolo 24, comma 2, le parole: "da lire duecentomila a lire due milioni" sono sostituite dalle seguenti: "da lire quattrocentomila a lire tre milioni".

58. A valere sulle disponibilita' di tesoreria del fondo rotativo di cui all'articolo 2 del decreto-legge 28 maggio 1981, n. 251, convertito, con modificazioni, dalla legge 29 luglio 1981, n 394, e' autorizzato il trasferimento di 100 miliardi di lire, in ragione di 50 miliardi nel 2001 e 50 miliardi nel 2002, al fondo contributi agli interessi di cui al secondo comma dell'articolo 37 del decreto-legge 26 ottobre 1970, n. 745, convertito, con modificazioni, dalla legge 18 dicembre 1970, n. 1034, e successive modificazioni, per la prosecuzione degli interventi a favore dell'esportazione e dell'internazionalizzazione.

59. E' assegnato alla regione Sardegna un contributo dello Stato pari a lire 30 miliardi per ciascuno degli anni 2001 e 2002 e pari a lire 40 miliardi per l'anno 2003, per l'attuazione degli interventi del piano per la soluzione dell'emergenza idrica.

60. Per le spese di funzionamento in relazione all'attivita' degli advisors nominati per l'esame del progetto del ponte sullo stretto di Messina e' autorizzata la concessione alla societa' Stretto di Messina di un contributo straordinario di lire 2 miliardi per l'anno 2001.

61. Per l'anno 2001 sono stanziate lire 50 miliardi per investimenti nelle sedi di Autorita' portuali. Con proprio decreto, da emanare entro centoventi giorni dalla data di entrata in vigore della presente legge, il Ministro dei trasporti e della navigazione, di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, ripartisce i fondi fra le Autorita' portuali che hanno presentato domanda documentata entro novanta giorni dalla data di entrata in vigore della presente legge.

62. Ai fini dell'applicazione dell'articolo 29 della legge 13 maggio 1999, n. 133, il tasso effettivo globale medio per le medesime operazioni di cui al comma 1 del citato articolo 29 e' da intendersi come il tasso effettivo globale medio dei mutui all'edilizia in corso di ammortamento. Il Ministro del tesoro, del bilancio e della programmazione economica provvede, con proprio decreto, alle opportune integrazioni del decreto del Ministro del tesoro, del bilancio e della programmazione economica del 22 settembre 1999, pubblicato nella Gazzetta Ufficiale n. 225 del 26 settembre 1998, recante classificazione delle operazioni creditizie per categorie omogenee ai fini della rilevazione dei tassi effettivi globali medi praticati dagli intermediari finanziari.

63. La societa' di cui all'articolo 2 del decreto-legge 23 maggio 1994, n. 301, convertito, con modificazioni, dalla legge 23 giugno 1994, n. 403, puo' definire gli impegni derivanti dalle obbligazioni di cui al comma 3 dello stesso articolo 2, anche mediante transazioni con le imprese di assicurazioni, previa autorizzazione del Ministro del tesoro, del bilancio e della programmazione economica.

64. Una parte, stabilita nella misura del 25 per cento, del valore complessivo dei beni provenienti da reato, oggetto di confisca ai sensi dell'articolo 12-sexies del decreto-legge 8 giugno 1992, n. 306, convertito, con modificazioni, dalla legge 7 agosto 1992, n. 356, e dell'articolo 2-decies della legge 31 maggio 1965, n. 575, ovvero una parte, stabilita nella stessa misura, dei fondi provenienti dalla loro vendita, e' destinata per il triennio 2001-2003 all'Organizzazione delle Nazioni Unite (ONU) Office for Drug Control and Crime Prevention, per il conseguimento delle sue finalita' istituzionali. L'importo complessivo dello stanziamento e' determinato annualmente con decreto del Ministro dell'interno, di concerto con il Ministro delle finanze e con il Ministro del tesoro, del bilancio e della programmazione economica.

65. E' abrogato l'articolo 11 della legge 21 febbraio 1963, n. 244.

66. A decorrere dal periodo di' imposta in corso alla data di entrata in vigore della presente legge, ai fini dell'applicazione del trattamento fiscale previsto dall'articolo 4, comma 2, del decreto-legge 30 dicembre 1997, n. 457, convertito, con modificazioni, dalla legge 27 febbraio 1998, n. 30, nel reddito derivante dall'utilizzazione di navi iscritte nel registro internazionale e' compresa la plusvalenza realizzata mediante la cessione della nave a condizione che la stessa sia rimasta iscritta nel registro internazionale, anteriormente alla cessione, per un periodo ininterrotto di almeno tre anni.

67. Per il potenziamento delle attivita' ispettive, di controllo dei traffici marittimi, nonche' di prevenzione degli inquinamenti del mare causati dal trasporto marittimo di sostanze pericolose, svolte da parte delle Capitanerie di porto, e' istituito un apposito fondo nello stato di previsione del Ministero dei trasporti e della navigazione, dotato di lire 5 miliardi per l'anno 2001 e di lire 10 miliardi per ciascuno degli anni 2002 e 2003.

68. Per il finanziamento di opere di ampliamento, ristrutturazione, restauro e manutenzione straordinaria di immobili adibiti ad istituti penitenziari e' autorizzata la spesa di lire 60.000 milioni per l'anno 2001 da iscrivere nello stato di previsione del Ministero della giustizia.

69. Alla tabella III di cui alla legge 10 ottobre 1996, n. 525, e' aggiunta la seguente voce: "per ogni compact disc... 500.000".

70. Dopo il comma 3 dell'articolo 3 della legge 10 ottobre 1996, n. 525 e' inserito il seguente: "3-bis. Gli importi relativi ai diritti forfettizzati di cui alle tabelle I, II e III, allegate alla presente legge, sono aggiornati periodicamente, almeno ogni cinque anni, con decreto del Ministro della giustizia, di concerto con i Ministri del tesoro, del bilancio e della programmazione economica e delle finanze".

71. Per la realizzazione delle infrastrutture per la mobilita' al servizio del nuovo polo esterno della Fiera di Milano per il 2002 e di lire 50 miliardi per il 2003.

72. Per la realizzazione di uno studio di fattibilita' della ferrovia Martigny-Aosta e' autorizzata la spesa di lire 2 miliardi per l'anno 2001, a favore della regione Valle d'Aosta.

73. Per l'eliminazione dei fattori di pericolosita' e di criticita' viaria denominati "punti neri" delle strade statali 52 e 52bis nella regione Friuli-Venezia Giulia, e' autorizzata la spesa di lire 5 miliardi per l'anno 2001, da iscrivere nello stato di previsione del Ministero dei trasporti e della navigazione.

74. All'articolo 11, comma 9, secondo periodo, della legge 27 dicembre 1999, n. 449, come modificato dall'articolo 7, comma 17, della legge 23 dicembre 1999, n. 488, sono aggiunte, in fine, le seguenti parole: " , e di lire 30 miliardi per ciascuno degli anni 2002 e 2003 finalizzata alla fruizione del credito di imposta di cui al comma 1 per l'acquisto di beni strumentali alle attivita' di impresa indicate nel predetto comma destinati alla prevenzione del compimento di atti illeciti da parte di terzi, individuati ai sensi del comma 1-bis del presente articolo". (12)

75. L'infrastruttura di cui all'articolo 50, comma 1, lettera g), secondo periodo, della legge 23 dicembre 1998, n. 448, puo' essere realizzata anche come superstrada. In tal caso sono applicabili, ai sensi dell'articolo 21, comma 3, della legge 24 novembre 2000, n. 340, il pedaggiamento e la concessione di costruzione e gestione, ferme restando le procedure stabilite dall'articolo 10 della legge 17 maggio 1999, n. 144. Ai fini dell'esercizio dell'opzione di cui al presente comma e della valutazione delle alternative progettuali, finanziarie e gestionali, di sostenibilita' ambientale e di efficienza di servizio al territorio, il Ministero dei lavori pubblici conclude entro il 31 marzo 2001 una conferenza di servizi con il Ministero dell'ambiente, la regione Veneto, gli enti locali e gli altri enti e soggetti pubblici interessati. Trascorso il termine predetto senza che sia stabilita la realizzazione di una superstrada a pedaggio, riprende la procedura di cui all'articolo 10 della legge 17 maggio 1999, n. 144.

76. Per la realizzazione del secondo accesso alla citta' di Amelia e' autorizzata la spesa di lire 3 miliardi da erogare alla regione Umbria per gli anni 2001, 2002 e 2003; per la conservazione della foresta fossile di Dunarobba, e' autorizzata la spesa di lire 1 miliardo per l'anno 2001, da erogare al comune di Avigliano Umbro; per la conservazione del campo di concentramento di Fossoli e' autorizzata la spesa di lire 1 miliardo.

77. Al fine di garantire la realizzazione dei centri visitatori e di strutture didattiche di educazione ambientale e di sensibilizzazione ecologica presso il Parco nazionale dello Stelvio, di cui all'articolo 3 del decreto del Presidente della Repubblica 22 marzo 1974, n. 279, e' autorizzata la spesa di lire 3 miliardi per ciascuno degli anni 2001 e 2002.

78. Le risorse finanziarie conferite alla societa' Ferrovie dello Stato spa come contributi alla realizzazione di opere specifiche di cui all'articolo 10, comma 1, del decreto-legge 30 dicembre 1997, n. 457, convertito, con modificazioni, dalla legge 27 febbraio 1998, n. 30; all'articolo 3, comma 2, della legge 18 giugno 1998, n. 194; all'articolo 4, comma 1, della legge 8 ottobre 1998, n. 354, come specificatamente ripartite dal decreto ministeriale n. 110/T del 20 ottobre 1998; all'articolo 3, commi 5 e 7 e all'articolo 6, comma 1, della legge 7 dicembre 1999, n. 472 sono attribuite alla societa' Ferrovie dello Stato spa in conto aumento di capitale sociale per le finalita' previste dalle medesime leggi.

79. I termini di cui all'articolo 1 del decreto-legge 27 settembre 2000, n. 266, convertito, con modificazioni, dalla legge 23 novembre 2000, n. 344, restano applicabili anche in materia di agevolazioni postali elettorali. Gli oneri differenziali derivanti dall'agevolazione, che rimangono a carico del Tesoro, sono rimborsabili sulla base del rendiconto predisposto dalla societa' Poste italiane spa entro il limite massimo di lire 40 miliardi.

80. La disposizione dettata dall'articolo 29, comma 2, del decreto legislativo 1 settembre 1993, n. 385, come sostituito dall'articolo 4, comma 2, lettera d), del decreto legislativo 24 giugno 1998, n. 213, in materia di ridenominazione in euro del valore nominale delle azioni delle banche popolari si applica altresi' alle societa' cooperative autorizzate all'esercizio dell'assicurazione.

81. La scadenza dei termini di centottanta giorni e di centoventi giorni, previsti rispettivamente dall'articolo 11, comma 2, e dall'articolo 12, comma 2, della legge 30 aprile 1999, n. 136, gia' differita al 31 ottobre 2000 dall'articolo 1, comma 5, del decreto legge 25 febbraio 2000, n. 32, convertito, con modificazioni, dalla legge 20 aprile 2000, n. 97, e' ulteriormente differita al 31 ottobre 2001.

82. COMMA ABROGATO DALLA L. 28 DICEMBRE 2001, N. 448.

83. All'articolo 36 della legge 17 maggio 1999, n. 144, dopo il comma 4 e' inserito il seguente: "4-bis. Al fine di contenere i costi di trasporto che gravano sui prodotti finiti o semilavorati esportati fuori dalla regione da aziende agricole, estrattive e di trasformazione con sede di stabilimento in Sardegna, la conferenza di servizi di cui al comma 3 definisce uno schema di contratto di servizio di cui all'articolo 4 del regolamento (CEE) n. 3577/92 del Consiglio del 7 dicembre 1992 da sottoporre ai vettori interessati. In tale schema, sono precisati le tariffe e i noli in relazione alle tipologie merceologiche da trasportare. Qualora nessun vettore accetti di sottoscrivere il contratto di servizio conforme allo schema proposto si applica la procedura prevista dal comma 4. Il rimborso ai vettori selezionati e le agevolazioni previste al comma 5 non possono superare a carico del bilancio dello Stato l'importo di lire 20 miliardi per l'anno 1999 e di lire 30 miliardi a decorrere dall'anno 2000. L'onere di compartecipazione a carico della regione non puo' essere inferiore al 50 per cento del contributo statale".

84. All'articolo 36 della legge 17 maggio 1999, n. 144, il comma 6 e' sostituito dal seguente: "6. Il Ministro delle finanze, con proprio decreto, emana le norme di attuazione delle disposizioni di cui al comma 5 entro sessanta giorni dalla data di entrata in vigore della presente disposizione".

85. Al fine di favorire la conclusione dell'iter di risarcimento ai lavoratori coatti italiani nella Germania nazista negli anni 1943-1945, il Ministero dell'interno e' autorizzato ad erogare contributi per complessive lire 1.000 milioni nel biennio 2001-2002 agli enti e associazioni che predispongono gli atti richiesti per le procedure di risarcimento.

86. A titolo di concorso per l'attuazione dei progetti collocati nella graduatoria dei programmi di iniziativa comunitaria URBAN II di cui al decreto del Ministro dei lavori pubblici, del 19 luglio 2000, pubblicato nel supplemento ordinario alla Gazzetta Ufficiale n. 214 del 13 settembre 2000, viene concesso ai primi venti progetti non ammessi al finanziamento comunitario, con procedure e modalita' da definire con decreto dei Ministri dei lavori pubblici e del tesoro, del bilancio e della programmazione economica, un contributo fino a lire 10 miliardi, per una spesa complessiva massima di lire 100 miliardi annue per ciascuno degli anni 2001 e 2002.

87. A decorrere dall'anno 2001, il fondo di cui alla legge 30 aprile 1985, n. 163, e' incrementato, in favore dei soggetti disciplinati dall'articolo 2, comma 1, lettera a), del decreto legislativo 29 giugno 1996, n. 367, della somma di lire 10 miliardi nonche' dell'ulteriore somma di lire 15 miliardi per le specifiche finalita' di cui agli articoli 6, terzo comma, e 7 della legge 14 agosto 1967, n. 800, con ripartizione tra le predette finalita' effettuata con decreto del Ministro per i beni e le attivita' culturali.

88. Le disposizioni di cui al comma 6 dell'articolo 4 della legge 8 novembre 1991, n. 360, si applicano anche ai canali di Marano Lagunare e di Grado.

89. All'articolo 17, comma 3, della legge 11 febbraio 1994, n. 109, e successive modificazioni, dopo le parole: "il regolamento definisce i limiti e le modalita' per la stipulazione", sono inserite le seguenti: "per intero".

90. Al fine di rendere piu' agevole e rapida la revisione statutaria degli enti e istituti operanti in agricoltura, per i quali si applicano le disposizioni di cui al decreto legislativo 29 ottobre 1999, n. 419, e sottoposti a gestione commissariale, possono essere nominati, con le procedure previste dalle norme vigenti, gli organi di ordinaria amministrazione.

91. Con decreto del Ministro delle finanze da emanare entro il 28 febbraio di ogni anno e' prorogato il periodo di applicazione degli imponibili medi forfettari da applicare agli apparecchi da divertimento e intrattenimento previsti dall'articolo 14-bis del decreto del Presidente della Repubblica 26 ottobre 1972, n. 640, introdotto dall'articolo 9 del decreto legislativo 26 febbraio 1999, n. 60, diversi da quelli indicati dall'articolo 38, comma 2, della presente legge, non muniti di schede magnetiche a deconto o strumenti similari e sono determinati, con esclusione degli apparecchi e attrazioni per bambini, i nuovi imponibili medi forfettari in misura tale da garantire maggiori entrate non inferiori a lire dieci miliardi per ciascuno degli anni 2001, 2002 e 2003.

92. I redditi di pensione estera di cui sono titolari minatori che abbiano lavorato per almeno 20 anni nelle miniere di carbone del Belgio e per i quali sia riscontrata la malattia professionale sono equiparati ai fini fiscali alla rendite INAIL.

93. Ai soggetti e alle opere nei cui confronti ha operato la norma di validazione degli atti e dei provvedimenti adottati e di salvaguardia degli effetti prodottisi e dei rapporti giuridici sorti sulla base dell'articolo 11 del decreto-legge 24 settembre 1996, n. 495, per effetto dell'articolo 2, comma 61, della legge 23 dicembre 1996, n. 662, si applicano le disposizioni di cui ai capi IV e V della legge 28 febbraio 1985, n. 47 e successive modificazioni, e le norme relative all'articolo 9 della legge 28 gennaio 1977, n. 10, per immobili utilizzati per sedi di comunita' terapeutiche per tossicodipendenti, e per disabili, anche oltre i 750 metri cubi, realizzati entro il 31 dicembre 1993, per i quali sia stata gia' presentata richiesta di concessione o di autorizzazione in sanatoria, anche ai sensi dell'articolo 13 della legge 28 febbraio 1985, n. 47.

94. All'insieme dei comuni sedi delle comunita' terapeutiche interessate alla sanatoria di cui al comma 93 e' concesso un contributo fino ad un massimo di lire 5 miliardi, da erogare negli anni 2002 e 2003, secondo i criteri stabiliti con decreto del Ministro dell'interno.

95. L'applicazione delle disposizioni di cui all'articolo 14, comma 2, della legge 27 dicembre 1997, n. 449, per i soggetti indicati alla lettera f) del medesimo comma, opera anche per le spese sostenute nel periodo di imposta in corso al 1° gennaio 2001. In questo caso la deducibilita' delle spese di manutenzione, riparazione, ammodernamento e ristrutturazione ivi indicate e' consentita in quote costanti nel periodo di imposta di sostenimento e nei tre successivi. (12)

96. Gli atti di aggiornamento geometrico di cui all'articolo 9 della legge 1° ottobre, 1969, n. 679, ed agli articoli 5 e 7 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 650, e le denunce di variazione di cui all'articolo 27 del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, resi dai soggetti di cui all'articolo 1, comma 7, del decreto legge 27 aprile 1990, n. 90, convertito, con modificazioni, dalla legge 26 giugno 1990, n. 165, sono redatti conformemente alle disposizioni di cui al decreto del Ministro delle finanze 19 aprile 1994, n. 701. (53) (84) (92)

97. Il Ministro dei lavori pubblici, di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, puo' autorizzare i concessionari di autostrade e trafori a destinare risorse, ai sensi e per gli effetti e nei limiti di cui all'articolo 65 del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, per investimenti volti al recupero di monumenti, edifici e manufatti di valore storico-artistico e alla valorizzazione delle aree che costituiscono sistemi urbani e territoriali di pregio storico-culturale e ambientale.

98. All'articolo 62, comma 1-bis, del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e' aggiunto, in fine, il seguente periodo: "Qualora i fabbricati di cui al secondo periodo siano concessi in uso a dipendenti che abbiano trasferito la loro residenza anagrafica per esigenze di lavoro nel comune in cui prestano l'attivita', per il periodo d'imposta in cui si verifica il trasferimento e nei due periodi successivi, i predetti canoni e spese sono integralmente deducibili".

99. All'articolo 40, comma 2, del testo unico delle imposte sui redditi, approvato con decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e' aggiunto, in fine, il seguente periodo: "Si considerano, altresi', strumentali gli immobili di cui all'ultimo periodo del comma 1-bis dell'articolo 62 per il medesimo periodo temporale ivi indicato".

------------- AGGIORNAMENTO (12) La L. 18 ottobre 2001, n. 383 ha disposto (con l'art. 5, comma 1) che le agevolazioni fiscali di cui al presente articolo sono soppresse, salvo quanto previsto dall'art. 5, comma 1, lettere a) e b). ------------- AGGIORNAMENTO (20) La L. 1 agosto 2002, n. 166 ha disposto (con l'art. 31, comma 2) che "Possono usufruire della proroga di cui all'articolo 145, comma 46, della citata legge n. 388 del 2000, come modificato dal comma 1 del presente articolo, anche gli impianti la cui vita tecnica e' terminata nei sei mesi antecedenti la data di entrata in vigore della presente legge". ------------- AGGIORNAMENTO (24) La L. 12 dicembre 2002, n. 273 ha disposto (con l'art. 28, comma 1) che "Per le finalita' previste dall'articolo 1 del decreto-legge 25 settembre 1997, n. 324, convertito, con modificazioni, dalla legge 25 novembre 1997, n. 403, concernente la concessione di contributi per la rottamazione degli autoveicoli, e' autorizzata la spesa, in aggiunta a quella prevista dall'articolo 145, comma 6, della legge 23 dicembre 2000, n. 388, di 5 milioni di euro per ciascuno degli anni 2002, 2003 e 2004, da destinare alla concessione di contributi per l'acquisto di autoveicoli alimentati a metano o a GPL, di motocicli e ciclomotori elettrici, di biciclette a pedalata assistita, nonche' per l'installazione, sui veicoli a benzina esistenti, di un impianto di alimentazione a metano o a GPL, in conformita' delle definizioni adottate con decreto del Ministro dell'ambiente 5 aprile 2001, pubblicato nella Gazzetta Ufficiale n. 117 del 22 maggio 2001". ------------- AGGIORNAMENTO (25) La L. 27 dicembre 2002, n. 289 ha disposto (con l'art. 80, comma 38) che "Il contributo previsto dall'articolo 145, comma 17, della legge 23 dicembre 2000, n. 388, in favore del Club alpino italiano (CAI), per le attivita' del Corpo nazionale soccorso alpino e speleologico (CNSAS), e' incrementato, a decorrere dall'anno 2003, di 200.000 euro". ------------- AGGIORNAMENTO (45) Il D.L 10 gennaio 2006, n. 4, convertito con modificazioni dalla L. 9 marzo 2006, n. 80, ha disposto (con l'art. 31, comma 1) che "Le regolazioni debitorie dei disavanzi delle ferrovie concesse e in ex gestione commissariale governativa, comprensivi degli oneri di trattamento di fine rapporto maturati alla data del 31 dicembre 2000, previste dall'articolo 145, comma 30, della legge 23 dicembre 2000, n. 388, si intendono definite nei termini delle istruttorie effettuate congiuntamente dal Ministero delle infrastrutture e dei trasporti e dal Ministero dell'economia e delle finanze a seguito delle comunicazioni effettuate e delle istanze formulate dalle aziende interessate entro il 31 agosto 2005". ------------- AGGIORNAMENTO (97) Successivamente la Corte Costituzionale, con sentenza 6 febbraio - 20 marzo 2019, n. 54 (in G.U. 1ª s.s. 27/03/2019, n. 13), ha dichiarato l'illegittimita' costituzionale dell'art. 31 del D.L. 10 gennaio 2006, n. 4, convertito con modificazioni dalla L. 9 marzo 2006, n. 80 (che ha modificato il presente articolo, comma 30). ------------- AGGIORNAMENTO (53) Il D.L. 31 dicembre 2007, n. 248, convertito con modificazioni dalla L. 28 febbraio 2008, n. 31, ha disposto (con l'art. 26, comma 7-ter) che "Il comma 96 dell'articolo 145 della legge 23 dicembre 2000, n. 388, si interpreta nel senso che gli atti ivi indicati possono essere redatti e sottoscritti anche dai soggetti in possesso del titolo di cui alla legge 6 giugno 1986, n. 251, e successive modificazioni". ------------ AGGIORNAMENTO (84) Successivamente la Corte Costituzionale, con sentenza 24 giugno - 15 luglio 2015, n. 154 (in G.U. 1ª s.s. 22/07/2015, n. 29), ha dichiarato l'illegittimita' costituzionale dell'art. 26, comma 7-ter del D.L. 31 dicembre 2007, n. 248, convertito, con modificazioni, dalla L. 28 febbraio 2008, n. 31 (che ha modificato il comma 96 del presente articolo). ------------- AGGIORNAMENTO (65) Il D.L. 29 dicembre 2010, n. 225, convertito con modificazioni dalla L. 26 febbraio 2011, n. 10 (in S.O. n. 53/L relativo alla G.U. 26/2/2011, n. 47), ha disposto (con l'art. 1, comma 1), in relazione al comma 46 del presente articolo, che "E' fissato al 31 marzo 2011 il termine di scadenza dei termini e dei regimi giuridici indicati nella tabella 1 allegata con scadenza in data anteriore al 15 marzo 2011". ------------- AGGIORNAMENTO (72a) Il Il D.P.C.M. 25 marzo 2011 (in G.U. 31/03/2011, n. 74) ha disposto (con l'art. 1, comma 1) che il termine di cui al comma 6 del presente articolo e' prorogato al 31 dicembre 2011. Ha inoltre disposto (con l'art. 1, comma 2) che la presente modifica ha effeto dal 1° aprile 2011. ------------ AGGIORNAMENTO (92) La L. 4 agosto 2017, n. 124 ha disposto (con l'art. 1, comma 151) che "Il comma 96 dell'articolo 145 della legge 23 dicembre 2000, n. 388, si interpreta nel senso che gli atti catastali, sia urbani che rurali, possono essere redatti e sottoscritti anche dai soggetti in possesso del titolo di cui alla legge 6 giugno 1986, n. 251". ------------- AGGIORNAMENTO (90) - La L. 28 dicembre 2015, n. 208 ha disposto (con l'art. 1, comma 164, lettera b)) che "Con effetto a decorrere dalla data di entrata in vigore del regolamento di cui al comma 163, sono abrogate le disposizioni vigenti relative alle provvidenze in favore delle emittenti radiofoniche e televisive operanti in ambito locale, e in particolare le seguenti: [...] b) articolo 145, commi 18 e 19, della legge 23 dicembre 2000, n. 388". - Il regolamento di cui all'art. 1, comma 164, lettera b) della L. 28 dicembre 2015, n. 208 e' stato emanato con D.P.R. 23 agosto 2017, n. 146, pubblicato in G.U. 12/10/2017, n. 239.

## DISPOSIZIONI IN SETTORI DIVERSI

### Art. 146. - (Erogazioni a favore delle emittenti televisive locali)

1. Nell'ambito degli interventi dello Stato a favore dello spettacolo ed al fine di incentivare la produzione televisiva destinata al mercato nazionale ed intenzionale da parte delle emittenti televisive locali, e' stanziata la somma di lire 10 miliardi per il 2001 ((e di 2 milioni di euro per l'anno 2003)) da prelevare dagli stanziamenti di competenza del Ministero per i beni e le attivita' culturali.

2. La somma di cui al comma 1 e' erogata entro il 30 giugno 2001 dal Ministero per i beni e le attivita' culturali alle emittenti televisive locali titolari di concessione che trasmettano programmi autoprodotti, in base ad apposito regolamento adottato entro sessanta giorni dalla data di entrata in vigore della presente legge dal Ministro per i beni e le attivita' culturali di concerto con il Ministro del tesoro, del bilancio e della programmazione economica, sentite le competenti Commissioni parlamentari.

### Art. 147. - (Norme in materia di esecuzione forzata nei confronti di pubbliche amministrazioni)

1. All'articolo 14 del decreto-legge 31 dicembre 1996, n. 669, convertito, con modificazioni, dalla legge 28 febbraio 1997, n. 30, sono apportate le seguenti modifiche:

- a) al comma 1, le parole: "sessanta giorni" sono sostituite dalle seguenti: "centoventi giorni";
- b) dopo il comma 1 e' inserito il seguente: "1-bis. Gli atti di pignoramento e sequestro devono essere a pena di nullita' notificati presso la struttura territoriale dell'ente pubblico nella cui circoscrizione risiedono i soggetti privati interessati e contenere i dati anagrafici dell'interessato, il codice fiscale e il domicilio. L'ente comunque risponde con tutto il patrimonio".

### Art. 148. - (Utilizzo delle somme derivanti da sanzioni amministrative irrogate dall'Autorita' garante della concorrenza e del mercato)

1. Le entrate derivanti dalle sanzioni amministrative irrogate dall'Autorita' garante della concorrenza e del mercato sono destinate ad iniziative a vantaggio dei consumatori ((, salvo quanto previsto al secondo periodo del comma 2)).

2. Le entrate di cui al comma 1 possono essere riassegnate anche nell'esercizio successivo, per la parte eccedente l'importo di 10 milioni di euro per l'anno 2018 e di 8 milioni di euro a decorrere dall'anno 2019, con decreto del Ministro del tesoro, del bilancio e della programmazione economica ad un apposito fondo iscritto nello stato di previsione del Ministero dell'industria, del commercio e dell'artigianato per essere destinate alle iniziative di cui al medesimo comma 1, individuate di volta in volta con decreto del Ministro dell'industria, del commercio e dell'artigianato, sentite le competenti Commissioni parlamentari. ((Le entrate derivanti dalle sanzioni amministrative di cui all'articolo 51-septies, Sezione IX, Capo I, Titolo VI dell'Allegato 1 al decreto legislativo 23 maggio 2011, n. 79, sono destinate a iniziative a vantaggio dei viaggiatori. Tali entrate affluiscono ad apposito capitolo/articolo di entrata del bilancio dello Stato di nuova istituzione e possono essere riassegnate con decreto del Ministro dell'economia e delle finanze a un apposito fondo iscritto nello stato di previsione del Ministero dei beni e delle attivita' culturali e del turismo per essere destinate alle iniziative di cui al primo periodo, individuate di volta in volta con decreto del Ministro dei beni e delle attivita' culturali e del turismo, sentite le commissioni parlamentari.))

2-bis. Limitatamente all'anno 2001, le entrate di cui al comma 1 sono destinate alla copertura dei maggiori oneri derivanti dalle misure antinflazionistiche dirette al contenimento dei prezzi dei prodotti petroliferi. 2-ter: Per l'anno 2017, le entrate di cui al comma 1, incassate nell'ultimo bimestre 2016, sono riassegnate, per l'importo di 23 milioni di euro, al Fondo di garanzia per le piccole e medie imprese di cui all'articolo 2, comma 100, lettera a), della legge 23 dicembre 1996, n. 662.

### Art. 149. - (Indennizzo per la cessazione dell'attivita' commerciale)

1. Nei confronti di coloro che siano in possesso dei requisiti di cui all'articolo 2, comma 2, lettere a) e b), del decreto legislativo 28 marzo 1996, n. 207, si fa luogo all'indennizzo per la cessazione dell'attivita' commerciale anche nel caso in cui la cancellazione dal registro degli esercenti il commercio sia stata effettuata in data successiva alla presentazione della domanda di indennizzo e comunque prima della concessione dell'indennizzo stesso.

### Art. 150.

((ARTICOLO ABROGATO DAL D.LGS. 21 NOVEMBRE 2007, N.231))

### Art. 151.

((ARTICOLO ABROGATO DAL D.LGS. 21 NOVEMBRE 2007, N.231))

### Art. 152.

((IL D.P.R. 30 MAGGIO 2002, N. 115 HA CONFERMATO L'ABROGAZIONE DEL PRESENTE ARTICOLO))

### Art. 153. - (Imprese editrici di quotidiani e periodici)

1. Gli stanziamenti relativi ai contributi di cui alla legge 7 agosto 1990, n. 250, e successive modificazioni, sono, per l'anno 2001, incrementati di lire 40 miliardi.

2. La normativa di cui all'articolo 3, comma 10, della legge. 7, agosto 1990, n. 250, e successive modificazioni si applica esclusivamente alle imprese editrici di quotidiani e periodici, anche telematici, che, oltre che attraverso esplicita menzione riportata in testata, risultino essere organi o giornali di forze politiche che abbiano il proprio gruppo parlamentare in una delle Camere o rappresentanze nel Parlamento europeo o siano espressione di minoranze linguistiche riconosciute, avendo almeno un rappresentante in un ramo del Parlamento italiano nell'anno di riferimento dei contributi.

3. I quotidiani e i periodici telematici organi di movimenti politici di cui al comma 2 debbono essere comunque registrati presso i tribunali. Le richieste di contributi, ai sensi del presente articolo, per tali testate non sono cumulabili con nessuna altra richiesta analoga, che viene automaticamente annullata. Il contributo e' pari al 60 per cento dei costi del bilancio d'esercizio dell'impresa editrice, certificati ai sensi di legge e riferiti alla testata.

4. Entro e non oltre il 1° dicembre 2001 le imprese editrici di quotidiani o periodici organi di movimenti politici, in possesso dei requisiti di cui all'articolo 3, comma 10, della legge 7 agosto 1990, n. 250, e successive modificazioni, possono costituirsi in societa' cooperative, il cui oggetto sociale sia costituito esclusivamente dalla edizione di quotidiani o periodici organi di movimenti politici. A tali cooperative sono attribuiti i contributi di cui all'articolo 3, comma 2, della legge 7 agosto 1990, n. 250, e successive modificazioni.

5. Le imprese di cui al comma 4, per accedere ai contributi debbono, fermi restando i requisiti di cui alla vigente normativa:

- a) aver sottoposto l'intero bilancio di esercizio al quale si riferiscono i contributi alla certificazione di una societa' di revisione scelta tra quelle di cui all'elenco apposito previsto dalla CONSOB;
- b) editare testate con una diffusione formalmente certificata pari ad almeno il 25 per cento della tiratura complessiva se nazionali ovvero almeno al 40 per cento se locali. Ai fini del presente articolo, si intende per diffusione l'insieme delle vendite e degli abbonamenti e per testata locale quella la cui diffusione complessiva e' concentrata per almeno l'80 per cento in una sola regione;
- c) adottare una norma statutaria che introduca il divieto di distribuzione degli utili nell'esercizio di riscossione dei contributi e nei cinque successivi.

### Art. 154. - (Ristrutturazione finanziaria dell'Istituto poligrafico e zecca dello Stato)

1. Il contributo ventennale previsto dall'articolo 22 della legge 17 maggio 1999, n. 144, recante disposizioni sulla ristrutturazione finanziaria dell'Istituto poligrafico e zecca dello Stato, deve considerarsi ad incremento del fondo di dotazione dell'Istituto di cui all'articolo 22 della legge 13 luglio 1966, n. 559.

2. Al primo comma dell'articolo 22 della legge 13 luglio 1966, n. 559, e' aggiunto, in fine, il seguente numero: "5-bis) dal contributo previsto dall'articolo 22 della legge 17 maggio 1999, n. 144".

### Art. 155. - (Norme per la sostituzione della lira con l'euro)

1. Le banconote e le monete metalliche denominate in lire continuano ad avere corso legale fino al 28 febbraio 2002.

2. Il secondo comma dell'articolo 11 della legge 20 aprile 1978, n. 154, e' sostituito dal seguente: "La cassa speciale: a) custodisce le monete metalliche fornite dall'Istituto poligrafico e zecca dello Stato per l'immissione in circolazione; b) custodisce i biglietti di Stato fuori corso legale sino a che non si provveda alla loro distruzione; c) ritira dalla circolazione le monete metalliche dichiarate fuori corso legale da demonetizzare a cura della sezione zecca; d) ritira dalla circolazione le monete metalliche aventi corso legale eccedenti le esigenze di mercato".

3. Sono prorogati di diritto al 2 gennaio 2002 tutti i termini scadenti il 31 dicembre 2001, anche se di prescrizione e di decadenza, cui sia soggetto qualunque adempimento, pagamento od operazione, da effettuare per il tramite della Banca d'Italia, delle banche, della societa' Poste italiane S.p.a., delle imprese di investimento degli agenti di cambio, delle societa' di gestione del risparmio, delle societa' di investimento a capitale variabile (SICAV), delle societa' fiduciarie, delle imprese assicurative, degli intermediari finanziari iscritti nell'elenco previsto dall'articolo 106 del decreto legislativo 1° settembre 1993, n. 385, e successive modificazioni, e degli organismi che svolgono i servizi e le attivita' di cui agli articoli 69, 70 e 80 del decreto legislativo 24 febbraio 1998, n. 58, o che sono disciplinati dalle disposizioni della Commissione nazionale per le societa' e la borsa (CONSOB) e della Banca d'Italia del 16 marzo 1992, e successive modificazioni, pubblicate nella Gazzetta Ufficiale n. 73 del 27 marzo 1992, concernenti l'istituzione, l'organizzazione ed il funzionamento della Cassa di compensazione e garanzia prevista dagli articoli 22 e 23 della legge 2 gennaio 1991, n. 1, nonche' degli altri soggetti, abilitati al regolamento di operazioni finanziarie nell'ambito del sistema di pagamenti denominato "TARGET", eventualmente individuati con decreto del Ministro del tesoro, del bilancio e della programmazione economica.

4. I crediti della Banca d'Italia e i crediti dello Stato rispettivamente derivanti dalla consegna antecedentemente al 1° gennaio 2002, di banconote e di monete metalliche denominate in euro alle banche e ad altri soggetti hanno privilegio generale sui beni mobili, anche risultanti da annotazioni elettroniche, delle banche e degli altri soggetti consegnatari con preferenza su ogni altro credito. Il privilegio generale e' esercitato direttamente dalla Banca d'Italia anche nell'interesse dello Stato, considerato che la somministrazione di monete metalliche denominate in euro alle banche ed agli altri soggetti consegnatari avviene esclusivamente per il tramite della Tesoreria centrale e delle sezioni di tesoreria provinciale dello Stato, ai sensi del comma terzo dell'articolo 11 della legge 20 aprile 1978, n. 154. La Banca d'Italia puo' ritenere, anche nell'interesse dello Stato, i beni delle banche e degli altri soggetti che hanno ricevuto banconote e monete metalliche in euro antecedentemente al 1° gennaio 2002, da essa comunque detenuti, anche mediante annotazioni elettroniche, fino all'integrale soddisfacimento dei crediti derivanti dalle operazioni indicate nei commi precedenti.

## DISPOSIZIONI PER ACCELERARE I PROCESSI DI PRIVATIZZAZIONE

### Art. 156. - (Razionalizzazione e accelerazione delle procedure di' liquidazione delle societa' del gruppo EFIM)

1. I patrimoni delle seguenti societa' in liquidazione coatta amministrativa: Alucasa Spa, Alutekna Spa, Alures Spa, Almax Italia Spa, Comsal Spa, Nuova Comsal Spa, Sardal Spa, Sistemi e Spazio Spa, sono trasferiti, dalla data di entrata in vigore della presente legge, con ogni componente attiva e passiva, ivi compresi i rapporti in corso, alla societa' Alumix Spa in liquidazione coatta amministrativa. I compendi cosi' trasferiti costituiscono, ad ogni effetto di legge, altrettanti patrimoni separati sia tra di loro, sia dal patrimonio della societa' Alumix Spa in liquidazione coatta amministrativa, esistente alla data di entrata in vigore della presente legge. Le liquidazioni coatte amministrative delle predette societa' sono chiuse alla data di entrata in vigore della presente legge e gli organi delle stesse presentano il rendiconto agli organi della liquidazione coatta amministrativa della societa' Alumix Spa.

2. I patrimoni delle seguenti societa' in liquidazione coatta amministrativa: Breda Progetti e Costruzioni Spa, Ecosafe Spa, Edina Spa, Efimdata Spa, Etnea Vini Spa, Istituto Ricerche Breda Spa, Metallotecnica Veneta Spa, Nuova Safim Spa, Nuova Sopal Spa, Olisud Spa, Reggiane OMI Spa, Safimgest Spa, Termomeccanica Italiana Spa, sono trasferiti, dalla data di entrata in vigore della presente legge, con ogni componente attiva e passiva, ivi compresi i rapporti in corso, alla societa' Efimpianti Spa in liquidazione coatta amministrativa. I compendi cosi' trasferiti costituiscono, ad ogni effetto di legge, altrettanti patrimoni separati sia tra di loro, sia dal patrimonio della societa' Efimpianti Spa in liquidazione coatta amministrativa, esistente alla data di entrata in vigore della presente legge. Le liquidazioni coatte amministrative delle predette societa', il cui patrimonio e' trasferito, sono chiuse alla data di entrata in vigore della presente legge. Gli organi di tali liquidazioni coatte amministrative presentano il loro rendiconto agli organi della liquidazione coatta amministrativa della societa' Efimpianti Spa. Il Ministro del tesoro, del bilancio e della programmazione economica nomina due commissari liquidatori in aggiunta a quello in carica alla societa' Efimpianti Spa.

3. Tutte le cause pendenti, promosse da e contro le societa' i cui patrimoni sono trasferiti ai sensi dei commi 1 e 2, sono proseguite direttamente ed a cura della societa' Alumix Spa in liquidazione coatta amministrativa e della societa' Efimpianti Spa in liquidazione coatta amministrativa, che, nella veste di societa' subentranti nei patrimoni trasferiti, devono, ai fini della prosecuzione, costituirsi nei giudizi nella udienza immediatamente successiva al trentesimo giorno dalla data di entrata m vigore della presente legge, senza farsi luogo alla interruzione dei procedimenti. Il commissario liquidatore dell'EFIM, nella sua qualita' di autorita' di vigilanza ai sensi dell'articolo 4, comma 3, del decreto-legge 19 dicembre 1992, n. 487, convertito, con modificazioni, dalla legge 17 febbraio 1993, n. 33, come sostituito dall'articolo 3 del decreto-legge 22 novembre 1994, n. 643, convertito, con modificazioni, dalla legge 27 dicembre 1994, n. 738, vigila sulla piena applicazione e attuazione della disposizione di cui al precedente periodo impartendo direttive ai commissari liquidatori confermati o di nuova nomina affinche' assumano tutte le necessarie e opportune iniziative per la sollecita cura e definizione dei giudizi pendenti, ivi compresi quelli che hanno ad oggetto l'accertamento di responsabilita' ed il risarcimento dei danni, gia' promossi nei confronti di ex amministratori, di direttori generali investiti formalmente di poteri gestionali diretti nelle predette societa' e di componenti dei collegi sindacali delle societa' in liquidazione, nonche' nei confronti delle societa' di revisione incaricate di certificare i bilanci precedenti, e di terzi che comunque abbiano avuto rapporti patrimoniali con le medesime societa'. Alla gestione delle disponibilita' finanziarie della societa' Alumix Spa in liquidazione coatta amministrativa e della societa' Efimpianti Spa in liquidazione coatta amministrativa si applica l'articolo 5, comma 7, secondo e terzo periodo, del decreto-legge 19 dicembre 1992, n. 487, convertito, con modificazioni, dalla legge 17 febbraio 1993, n. 33, sostituendosi al conto infruttifero intestato ad EFIM in liquidazione coatta amministrativa il conto aperto presso la Tesoreria centrale dello Stato intestato,, rispettivamente, alla societa' Alumix Spa in liquidazione coatta amministrativa e alla societa' Efimpianti Spa in liquidazione coatta amministrativa.

4. I patrimoni delle seguenti societa' in liquidazione coatta amministrativa: Breda Energia Spa, Bredafin Innovazione Spa, Breda Fucine Meridionali Spa, CESIS Spa, C.T.O. Spa, Efimservizi Spa, Oto Breda Finanziaria Spa, Oto Trasm Spa, Sistemi e Tecnologie Speciali Spa, Safim Leasing Spa, sono trasferiti, dalla data di entrata in vigore della presente legge, con ogni componente attiva e passiva, ivi compresi i rapporti in corso, alla societa' Nuova Breda Fucine Spa in liquidazione coatta amministrativa. I patrimoni trasferiti alla societa' Nuova Breda Fucine Spa in liquidazione coatta amministrativa, ad ogni effetto di legge, costituiscono altrettanti patrimoni separati sia tra di loro, sia dal patrimonio della societa' Nuova Breda Fucine Spa in liquidazione coatta amministrativa, esistente alla data di entrata in vigore della presente legge, anche allo scopo di garantire ai creditori il mantenimento delle posizioni giuridiche. Le liquidazioni coatte amministrative delle predette societa' sono chiuse alla data di entrata in vigore della presente legge. Gli organi di tali liquidazioni coatte amministrative presentano il loro rendiconto agli organi della liquidazione coatta amministrativa della societa' Nuova Breda Fucine Spa. Tutte le cause pendenti, promosse da e contro le societa' i cui patrimoni sono trasferiti ai sensi del presente comma, sono proseguite direttamente ed a cura della societa' Nuova Breda Fucine Spa in liquidazione coatta amministrativa che, nella veste di societa' subentrante nei patrimoni trasferiti, deve, ai fini della prosecuzione, costituirsi nei giudizi nella udienza immediatamente successiva al trentesimo giorno dalla data di entrata in vigore della presente legge, senza farsi luogo alla interruzione dei procedimenti. Il commissario liquidatore dell'EFIM, nella sua qualita' di autorita' di vigilanza ai sensi dell'articolo 4, comma 3, del decreto-legge 19 dicembre 1992, n. 487, convertito, con modificazioni, dalla legge 17 febbraio 1993, n. 33, come sostituito dall'articolo 3 del decreto-legge 22 novembre 1994, n. 643, convertito, con modificazioni, dalla legge 27 dicembre 1994, n. 738, vigila sulla piena applicazione e attuazione della disposizione di cui al precedente periodo, impartendo direttive ai commissari liquidatoti confermati o di nuova nomina affinche' assumano tutte le necessarie e opportune iniziative per la sollecita cura e definizione dei giudizi pendenti, ivi compresi quelli che hanno ad oggetto l'accertamento di responsabilita' ed il risarcimento dei danni, gia' promossi nei confronti di ex amministratori, di direttori generali investiti formalmente di poteri gestionali diretti nelle predette societa' e di componenti dei collegi sindacali delle societa' in liquidazione, nonche' nei confronti delle societa' di revisione incaricate di certificare i bilanci precedenti, e di terzi che comunque abbiano avuto rapporti patrimoniali con le medesime societa'. Il Ministro del tesoro, del bilancio e della programmazione economica nomina due commissari liquidatori in aggiunta a quello in carica nella societa' Nuova Breda Fucine Spa.

5. Alle societa' F.E.B. Spa e Safim Factor Spa in liquidazione coatta amministrativa si applica il comma 4, ad esclusione dell'ultimo periodo, qualora non abbiano presentato, entro un anno dalla data di entrata in vigore della presente legge, la proposta di concordato di cui all'articolo 214 delle disposizioni approvate con regio decreto 16 marzo 1942, n. 267, o non abbiano altrimenti chiuso la liquidazione coatta amministrativa.

6. Le disposizioni di cui all'articolo 11 del decreto legislativo 16 marzo 1999, n. 79, non si applicano all'impianto previsto dal decreto del Presidente della Repubblica 28 gennaio 1994, pubblicato nella Gazzetta Ufficiale n. 56 del 9 marzo 1994, recante il piano di sviluppo minerario ed energetico del Sulcis-Iglesiente.

7. I trasferimenti dei patrimoni e dei rapporti di cui al presente articolo sono effettuati a titolo gratuito. Tutti gli atti compiuti in attuazione delle norme contenute nel presente articolo sono esenti da qualunque imposta, diretta o indiretta, tassa, obbligo e onere tributario comunque inteso o denominato.

8. In applicazione dell'articolo 5, comma 1, del decreto-legge 19 dicembre 1992, n. 487, convertito, con modificazioni, dalla legge 17 febbraio 1993, n. 33, e successive modificazioni, i crediti e debiti dell'EFIM e delle societa' elencate nei commi 1 e 2 nei confronti delle amministrazioni dello Stato sono estinti alla data di entrata in vigore della presente legge.

## NORME FINALI

### Art. 157. - (Fondi speciali e tabelle)

1. Gli importi da iscrivere nei fondi speciali di cui all'articolo 11-bis della legge 5 agosto 1978, n. 468, introdotto dall'articolo 6 della legge 23 agosto 1988, n. 362, per il finanziamento dei provvedimenti legislativi che si prevede possano essere approvati nel triennio 2001-2003, restano determinati, per ciascuno degli anni 2001, 2002 e 2003, nelle misure indicate nelle tabelle A e B, allegate alla presente legge, rispettivamente per il fondo speciale destinato alle spese correnti e per il fondo speciale destinato alle spese in conto capitale.

2. Le dotazioni da iscrivere nei singoli stati di previsione del bilancio 2001 e triennale 2001-2003, in relazione a leggi di spesa permanente la cui quantificazione e' rinviata alla legge finanziaria, sono indicate nella tabella C allegata alla presente legge.

3. Ai sensi dell'articolo 11, comma 3, lettera f), della legge 5 agosto 1978, n. 468, come sostituita dall'articolo 2, comma 16, della legge 25 giugno 1999. n. 208, gli stanziamenti di spesa per il rifinanziamento di norme che prevedono interventi di sostegno dell'economia classificati fra le spese in conto capitale restano determinati, per ciascuno degli anni 2001, 2002 e 2003, nelle misure indicate nella tabella D allegata alla presente legge.

4. Ai termini dell'articolo 11, comma 3, lettera e), della legge 5 agosto 1978, n. 468, le autorizzazioni di spesa recate dalle leggi indicate nella Tabella E allegata alla presente legge sono ridotte degli importi determinati nella medesima Tabella.

5. Gli importi da iscrivere in bilancio in relazione alle autorizzazioni di spesa recate da leggi a carattere pluriennale restano determinati, per ciascuno degli anni 2001, 2002 e 2003, nelle misure indicate nella tabella F allegata alla presente legge.

6. A valere sulle autorizzazioni di spesa in conto capitale recate da leggi a carattere pluriennale, riportate nella tabella di cui al comma 5, le amministrazioni e gli enti pubblici possono assumere impegni nell'anno 2001, a carico di esercizi futuri nei limiti massimi di impegnabilita' indicati per ciascuna disposizione legislativa in apposita colonna della stessa tabella, ivi compresi gli impegni gia' assunti nei precedenti esercizi a valere sulle autorizzazioni medesime.

### Art. 158. - (Copertura finanziaria ed entrata in vigore)

1. La copertura della presente legge per le nuove o maggiori spese correnti, per le riduzioni di entrata e per le nuove finalizzazioni nette da iscrivere nel Fondo speciale di parte corrente viene assicurata, ai sensi dell'articolo 11, comma 5, della legge 5 agosto 1978, n. 468, e successive modificazioni, secondo il prospetto allegato.

2. Le disposizioni della presente legge sono applicabili nelle regioni a statuto speciale e nelle province autonome di Trento e di Bolzano compatibilmente con le norme dei rispettivi statuti.

3. La presente legge entra il vigore il 1° gennaio 2001. Le disposizioni di cui all'articolo 33, comma 9, acquistano efficacia il giorno successivo a quello di pubblicazione della presente legge nella Gazzetta Ufficiale.

